package com.unis.quality.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.TbCheckstandardInfoVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * 
 * @ClassName: CheckstandardInfoFeign
 * @Description: 检验流程管理——检测标准
 * @author xmpu
 * @date 2018年10月30日10:34:20
 * 
 * @version v1.0
 */
@FeignClient(name = "quality-server")
@Component
public interface CheckstandardInfoFeign {


	@ApiOperation(value = "查询标准信息", notes = "参数: 标准信息checkstandardId")
	@RequestMapping(method = RequestMethod.GET, value = "/checkstandardinfo/findByIdInfo/{checkstandardId}")
	public ResponseWrapper findByIdInfo(@PathVariable String checkstandardId);

	@ApiOperation(value = "更新标准检测信息", notes = "参数：对象checkstandardInfoBO")
	@RequestMapping(method = RequestMethod.POST,value = "/checkstandardinfo/update")
	public ResponseWrapper update(@RequestBody TbCheckstandardInfoVO checkstandardInfoBO);

	@ApiOperation(value = "查询所有检测标准信息", notes = "参数：标准名称，标准品类型，有效期")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "page", value = "起始页", required = true),
			@ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
	})
	@RequestMapping(method = RequestMethod.POST, value = "/checkstandardinfo/findByPage/{page}/{size}")
	public ResponseWrapper findByPage(@RequestBody TbCheckstandardInfoVO checkstandardInfoBO, @PathVariable(value = "page") Integer page, @PathVariable(value = "size") Integer size);

	@ApiOperation(value = "保存检测标准", notes = "参数：检测标准实体类")
	@RequestMapping(method = RequestMethod.POST, value = "/checkstandardinfo/save")
	public ResponseWrapper insert(@RequestBody TbCheckstandardInfoVO checkstandardInfoBO);

	@ApiOperation(value = "获取所有标准分类")
	@RequestMapping(method = RequestMethod.POST, value = "/checkstandardinfo/getAllInfo")
	public ResponseWrapper getAllInfo();

	@ApiOperation(value = "删除检测标准", notes = "参数：标准id，多个以逗号隔开")
	@RequestMapping(method = RequestMethod.GET, value = "/checkstandardinfo/delete")
	public ResponseWrapper deleteInorout(@RequestParam("checkstandardId") String[] checkstandardId);
	
	@ApiOperation(value = "启用、禁用", notes = "参数：对象checkstandardInfoBO")
	@PostMapping(value = "/checkstandardinfo/updateIsUsed/{id}/{isUsed}")
	public ResponseWrapper updateIsUsed(@PathVariable("id") String id,@PathVariable("isUsed") String isUsed);
	
	@ApiOperation(value = "根据标准分类获取标准编码", notes = "参数: 标准分类standardType")
	@PostMapping(value = "/checkstandardinfo/getAllstandardCode/{standardType}")
	public ResponseWrapper getAllstandardCode(@PathVariable("standardType") String standardType) throws Exception;
	
	@ApiOperation(value = "根据标准编码获取标准名称", notes = "参数: 标准信息standardCode")
	@PostMapping(value = "/checkstandardinfo/getAllstandardName/{standardCode}")
	public ResponseWrapper getAllstandardName(@PathVariable("standardCode") String standardCode) throws Exception ;
}
