package com.unis.quality.client;

import com.unis.common.utils.ResponseWrapper;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Repository;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import java.util.List;
import java.util.Map;

/**
 * 
 * @ClassName: DataDictClient 
 * @Description: 数据字典 
 * @author xmpu
 * @date 2018年11月16日 下午4:22:58 
 * 
 * @version v1.0
 */
@FeignClient(name = "DATA-DICT")
@Repository
public interface DataDictClient {

    /**
     * 
     * @Description: 查询某数据字典组下的数据字典树
     *
     * @date 2018年11月16日,下午4:23:32
     * @author xmpu
     * @version v1.0
     *
     * @param groupId
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/dataDictionary/findByGroupId/{groupId}")
    ResponseWrapper findByGroupId(@PathVariable("groupId") String groupId);

    /**
     *
     * @Description: 根据groupId和dictCode查询数据字典
     * @date 2018-11-26 16:57:22
     * @author liyb
     * @version v1.0
     * @param groupId
     * @param dictCode
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/dataDictionary/getDataDictionary/{groupId}/{dictCode}")
    ResponseWrapper getDataDictionary(@PathVariable("groupId") String groupId, @PathVariable("dictCode") String dictCode);

    /**
     * @Description:查询某数据字典组下的数据字典树
     * @date 2019-01-10 18:24:55
     * @author liyb
     * @version v1.0
     * @param groupId
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/dataDictionary/getDataGroupId/{groupId}")
    ResponseWrapper getDataGroupId(@PathVariable("groupId") String groupId);

    /**
     * 获取省市
     * @param
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/dataDictionary/getDataTree/AREA_CODE")
    ResponseWrapper  getDataTree();
    
    
    
    /**
    *
    * @Description: 根据groupId和dictCode查询数据字典
    * @date 2019年7月18日16:25:16
    * @author lifx
    * @version v1.0
    * @param groupId
    * @param dictCode
    * @return
    */
   @RequestMapping(method = RequestMethod.GET, value = "/dataDictionary/getSubDataDictionarysByDictCodeId/{dictCode}")
   ResponseWrapper getSubDataDictionarysByDictCodeId( @PathVariable("dictCode") String dictCode);

    
    
}
