package com.unis.quality.client;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.dto.DictDO;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 
 * @ClassName: DataDictUtils
 * @Description: bean与字典内容转换。
 * @date 2018年12月1日 下午5:06:40
 * 
 * @version v1.0
 */
@Component
public class DataDictUtils {

	private static DataDictClient dataDictClient;

	@Autowired
	public void setDatastore(DataDictClient dataDictClient) {
		DataDictUtils.dataDictClient = dataDictClient;
	}

	/**
	 * 
	 * @Description: 从字典的名称转化成字典的code
	 *
	 * @date 2018年12月1日,下午5:07:15
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param dataDictName 实体类的code属性
	 * @param dataDictGroupId 字典中对应的组id
	 * @return
	 */
	public static String dataDictNameToDataDictCode(String dataDictName, String dataDictGroupId) {

		if (StringUtils.isNotEmpty(dataDictName) && StringUtils.isNotEmpty(dataDictGroupId)) {
			ResponseWrapper status = dataDictClient.findByGroupId(dataDictGroupId);
			String statusJson = JSONArray.toJSONString(status.getData());
			List<DictDO> statusList = JSONObject.parseArray(statusJson, DictDO.class);
			// 从字典的名称转化成字典的code
			for (DictDO statusType : statusList) {
				if (statusType.getDictName().equals(dataDictName)) {
					return statusType.getDictCode();
				}
			}
		}
		return null;
	}
	
	/**
	 * 
	 * @Description: 从beancode转化成字典的名称
	 *
	 * @date 2018年12月1日,下午5:07:15
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param beanCode 实体类的code属性
	 * @param dataDictGroupId 字典中对应的组id
	 * @return
	 */
	public static String beanCodeTo(String beanCode, String dataDictGroupId) {

		if (StringUtils.isNotEmpty(beanCode) && StringUtils.isNotEmpty(dataDictGroupId)) {
			ResponseWrapper status = dataDictClient.findByGroupId(dataDictGroupId);
			String statusJson = JSONArray.toJSONString(status.getData());
			List<DictDO> statusList = JSONObject.parseArray(statusJson, DictDO.class);
			// 实体类code转换成字典名称
			for (DictDO statusType : statusList) {
				if (statusType.getDictCode().equals(beanCode)) {
					return statusType.getDictName();
				}
			}
		}
		return null;
	}
	
	
	/**
	 * 
	 * @Description: 根据GroupId获取一系列数据
	 *
	 * @date 2019年8月15日,上午11:13:53
	 * @author huangshuai
	 * @version v1.0
	 *
	 * @param dataDictGroupId
	 * @return
	 */
	public static List<DictDO> beanCodeTo1(String dataDictGroupId) {

		if ( StringUtils.isNotEmpty(dataDictGroupId)) {
			ResponseWrapper status = dataDictClient.getDataGroupId(dataDictGroupId);
			String statusJson = JSONArray.toJSONString(status.getData());
			List<DictDO> statusList = JSONObject.parseArray(statusJson, DictDO.class);
			// 返回数据集合
			return statusList;
		}
		return null;
	}
}
