package com.unis.quality.client;

import java.util.List;
import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.EntrustQueryVO;
import com.unis.quality.common.vo.EntrustVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 *功能描述
 * @author wangqiang
 * @date 2019/8/21 0021
 * EntrustFeign 强检委托
 */
@FeignClient(name = "quality-server")
@Component
public interface EntrustFeign {
	
	/**
	 *功能描述 更新委托
	 * @author 
	 * @date 2019/8/21 0021
	 * @param :StrongEntrustVO
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "根据质检编号修改", notes = "参数：强检委托对象StrongEntrustVO")
	@PutMapping(value = "/updateLcId/")
	public ResponseWrapper updateLcId(@RequestBody EntrustVO vo) throws Exception;
	
	@ApiOperation(value = "查询质检报告编号", notes = "参数：zjbh")
	@PostMapping(value = "/selectWtIdBhKctb/")
	public ResponseWrapper selectWtIdBhKctb(@RequestBody EntrustQueryVO entrustQueryVO);
	
	@ApiOperation(value = "查询质检报告编号和委托id库存", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/selectWtIdBhKc/")
	public ResponseWrapper selectWtIdBhKc(@RequestBody EntrustQueryVO entrustQueryVO,
			@RequestParam ("page")  Integer page,
			@RequestParam ("size")  Integer size);
	
	@ApiOperation(value = "查询质检报告编号和委托id", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/selectWtIdBh/")
	public ResponseWrapper selectWtIdBh(@RequestBody EntrustQueryVO entrustQueryVO,
			@RequestParam ("page")  Integer page,
			@RequestParam ("size")  Integer size);
	
	@ApiOperation(value = "通过委托id查询质检报告编号", notes = "参数：wtId")
	@GetMapping(value = "/selectByWtId/")
	public ResponseWrapper selectByWtId(@RequestParam("wtId") String wtId);
	
    @ApiOperation(value = "根据委托编号查询委托信息", notes = "参数：organizationId")
    @GetMapping(value = "/entrust/")
    public ResponseWrapper findById(@RequestParam("code") String code);

	@ApiOperation(value = "查询委托信息", notes = "EntrustVO vo")
	@GetMapping(value = "/entrust/selectById")
	public ResponseWrapper selectById(@RequestBody EntrustVO vo);


	@PostMapping(value="/entrust/echartsZjjgqs")
	@ApiOperation(value = "质检信息趋势echarts", notes = "参数：")
	public ResponseWrapper echartsZjjgqs(@RequestBody EntrustQueryVO vo);
    
    /**
	 *功能描述 根据委托编号查询委托信息  其他质检详情
	 * @author 
	 * @date 2019/8/21 0021
	 * @param code
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "根据委托编号查询委托信息", notes = "参数：vo.getJybh()")
	@PostMapping(value = "/entrustQt/")
	public ResponseWrapper findByIdQt(@RequestBody EntrustVO vo) ;

	@ApiOperation(value = "根据交易编号查询委托信息", notes = "参数：code")
	@GetMapping(value = "/findByJybh/")
	public ResponseWrapper findByJybh(@RequestParam("code") String code);
    
    @ApiOperation(value = "保存委托信息", notes = "参数：委托信息对象equipmentVO")
    @PostMapping(value = "/entrust/")
    public ResponseWrapper save(@RequestBody EntrustVO vo) ;

    @ApiOperation(value = "更新委托信息", notes = "参数：设备信息对象equipmentVO")
    @PutMapping(value = "/entrust/")
    public ResponseWrapper update(@RequestBody EntrustVO vo) ;

    @ApiOperation(value = "删除委托信息", notes = "参数：EntrustVO")
    @DeleteMapping(value = "/entrust/")
    public ResponseWrapper delete(@RequestBody EntrustVO vo);

    @ApiOperation(value = "分页查询所有委托信息", notes = "参数：当前页、页面大小")
    @PostMapping( value = "/entrust/page/")
    public ResponseWrapper findByPage(@RequestBody EntrustQueryVO queryVO,
                                      @RequestParam ("page") Integer page,
                                      @RequestParam ("size") Integer size) ;
    
    
    /**
	 *功能描述 分页查询所有委托信息
	 * @author 
	 * @date 2019/8/21 0021
	 * @param :[queryVO, page, size]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "强检查询状态", notes = "参数：")
	@RequestMapping(method = RequestMethod.POST, value = "/entrust/findByPageZt/")
	public ResponseWrapper findByPageZt(@RequestBody EntrustQueryVO queryVO) throws Exception;
    
	@ApiOperation(value = "分页获取交易质检", notes = "参数：当前页、页面大小")
	@PostMapping(value = "/findJyzjByPage/")
	public ResponseWrapper findJyzjByPage(@RequestBody EntrustQueryVO entrustQueryVO,
			@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
			  @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) throws Exception;
	
    /**
	 *功能描述 强检仓号查询
	 * @author 
	 * @date 2019/8/21 0021
	 * @param :[queryVO, page, size]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "条件分页查询强检仓号", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "page", value = "起始页", required = true),
			@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@RequestMapping(method = RequestMethod.POST, value = "/entrust/pagech/")
	public ResponseWrapper findChByPage(@RequestBody EntrustVO queryVO,
			@RequestParam ("page")Integer page,
    		@RequestParam ("size")Integer size);

    /**
     *功能描述 提交委托
     * @author wangqiang
     * @date 2019/8/26 0026
     * @param :[vo]
     * @return com.unis.common.utils.ResponseWrapper
     */
    @ApiOperation(value = "提交委托", notes = "参数：委托对象StrongEntrustVO")
    @PutMapping(value = "/entrust/sub")
    public ResponseWrapper submitEntrust(@RequestBody EntrustVO vo);

    /**
     *功能描述  删除粮库导入数据,物理
     * @author wangqiang
     * @date 2019/9/24 0024
     * @param :
     * @return com.unis.common.utils.ResponseWrapper
     */
    @ApiOperation(value = "删除委托信息", notes = "参数：EntrustVO")
    @DeleteMapping(value = "/entrust/lcdr")
    public ResponseWrapper delete();
    
    
    
    /**
	 *功能描述 向质检中心发送委托
	 * @author 
	 * @date 2019/8/26 0026
	 * @param :[vo]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "发送委托", notes = "参数：委托对象StrongEntrustVO")
	@PutMapping(value = "/sendWt")
	public ResponseWrapper sendWt(@RequestBody EntrustVO vo);
	
	
	@ApiOperation(value = "根据wtbh查询jybh为空的数据", notes = "参数：当前页、页面大小")
	@PostMapping(value = "/findByWtbhQT/")
	public ResponseWrapper findByWtbhQT(@RequestBody EntrustVO entrustQueryVO);
    //======================================交易质检委托===============================

	
	/**
	 *功能描述 自动生成委托编号
	 * @author lfx
	 * @date 2019年11月21日11:09:08
	 * @param code
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "自动生成委托编号", notes = "")
	@GetMapping(value = "/queryMAXWtbh/")
	public ResponseWrapper queryMAXWtbh(@RequestParam("zjbh") String zjbh) throws Exception;
}
