package com.unis.quality.client;

import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.EquipmentVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @author lifx
 * @version 1.0
 * @Title: EquipmentFeign
 * @ProjectName EquipmentService
 * @Description: Equipment层fegin接口
 * @date 2019年8月10日13:08:40
 */
@FeignClient(name = "quality-server")
@Component
public interface EquipmentFeign {

	@ApiOperation(value = "根据id查询设备信息", notes = "参数：organizationId")
	 @GetMapping(value = "/findByIdEquipment/{organizationId}/")
    public ResponseWrapper findByIdEquipment(@PathVariable("organizationId") String organizationId);

	@ApiOperation(value = "保存设备信息", notes = "参数：设备信息对象equipmentVO")
    @RequestMapping(method = RequestMethod.POST, value = "/saveEquipment/")
    public ResponseWrapper saveEquipment(@RequestBody EquipmentVO vo);

	@ApiOperation(value = "更新设备信息", notes = "参数：设备信息对象equipmentVO")
    @RequestMapping(method = RequestMethod.POST, value = "/updateEquipment/")
    public ResponseWrapper updateEquipment(@RequestBody EquipmentVO vo);

	@ApiOperation(value = "删除设备信息", notes = "参数：organizationId(可传入多个)")
    @RequestMapping(method = RequestMethod.POST, value = "/deleteEquipment")
    public ResponseWrapper deleteEquipment(@RequestBody EquipmentVO vo);

	@ApiOperation(value = "查询所有设备信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/findByPageEquipment/{page}/{size}")
    public ResponseWrapper findByPageEquipment(@RequestBody EquipmentVO equipmentVO,
			@PathVariable ("page")Integer page,
			@PathVariable ("size") Integer size);

	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 同步base-server中的设备--检验化验仪器设备
	 * @Date 2020年3月10日 下午3:38:10
	 * @param data
	 * @return ResponseWrapper
	 */
	@PostMapping(value = "/synBaseServerEquipment")
	public ResponseWrapper synBaseServerEquipment(@RequestBody ResponseWrapper data);

}
