package com.unis.quality.client;

import com.unis.common.utils.ResponseWrapper;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * @Auther:lifx
 * @Date: 2019年7月17日15:28:32
 * @Description:
 */
@FeignClient(name = "flowable")
@Component
public interface FlowAbleClient {


    /**
     *  启动工作流
     * @param processKey  流程key
     * @param id  数据id
     * @param statusKey  标识流程状态传参key    status : 1 上集集团用户  2   县粮食局用户  3 市粮食局用户  4  省粮食局用户 :  comeout 1 通过 2 驳回
     * @param status  流程状态status
     * @param userId  用户id
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/task/start")
    ResponseWrapper start(
            @RequestParam(value = "processKey")String processKey,
            @RequestParam(value = "id")String id,
            @RequestParam(value = "statusKey")String statusKey,
            @RequestParam(value = "status")String status,
            @RequestParam(value = "userId")String userId
    );


    /**
     *
     * @param processId  流程id
     * @param userId  用户id
     * @param statusKey  流程状态传参key  标识流程状态传参key    status : 1 上集集团用户  2   县粮食局用户  3 市粮食局用户  4  省粮食局用户 :  comeout 1 通过 2 驳回
     * @param status  流程状态传参value
     * @param assignee  下级审批用户id，多个以逗号隔开
     * @param message  审批建议
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/task/complete")
    ResponseWrapper complete(
            @RequestParam(value = "processId")String processId,
            @RequestParam(value = "userId")String userId,
            @RequestParam(value = "statusKey")String statusKey, 
            @RequestParam(value = "status")String status,
            @RequestParam(value = "assignee")String assignee,
            @RequestParam(value = "message")String message
    );

    /**
     * 添加流程变量
     * @param bbq  报表期
     * @param id   用户名
     * @param pwd  密码
     * @param processId  流程ID
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/task/setVariableByTask")
    ResponseWrapper setVariableByTask(
            @RequestParam(value = "bbq")String bbq,
            @RequestParam(value = "id")String id,
            @RequestParam(value = "pwd")String pwd,
            @RequestParam(value = "processId")String processId,
            @RequestParam(value = "userCreditCode")String userCreditCode
    );


    /**
     * 根据任务ID -- 查询办理任务明细
     * @param taskId
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/task/findByFormKeyByTaskId/{taskId}/{procInsId}")
    ResponseWrapper findByFormKeyByTaskId(@PathVariable(value = "taskId")String taskId,@PathVariable(value = "procInsId")String procInsId);


    /**
     *  查询企业待办任务
     * @param userId
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/task/getUserTaskNoPage")
    ResponseWrapper getUserTaskNoPage(@RequestParam(value = "userId") String userId);


}