package com.unis.quality.client;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.dto.FoodStockDTO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @ClassName FoodStockDao
 * @Description 品质测报-库存粮食质量检测品登统表
 * @author lfx
 * @date 2019年7月24日17:26:44
 * @version v1.0
 */
@FeignClient(name = "quality-server")
@Component
public interface FoodStockFeign {

	/**
	 * @Description 根据id查询详情--质检档案（参数都必传）--自治区汇总（传类型,id）
	 * @version v1.0
	 * @author lfx	 * @date 2018/10/24
	 * @param id
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	/*@ApiOperation(value = "根据id查询详细信息", notes = "参数：(id)")
	@RequestMapping(value = "findById", method = RequestMethod.GET)
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "id", paramType = "query"),
		@ApiImplicitParam(name = "zjda", value = "质检档案", paramType = "query"),
		@ApiImplicitParam(name = "type", value = "类型", paramType = "query"),
		@ApiImplicitParam(name = "batch", value = "批次", paramType = "query"),
		@ApiImplicitParam(name = "areaCode", value = "行政区划", paramType = "query")
	})
	public ResponseWrapper findById( @RequestParam("id") String id,@RequestParam (value="zjda",required=false)String zjda,
			@RequestParam ("type")String type,@RequestParam(value="batch",required=false)String batch,@RequestParam("areaCode")String areaCode ) ;
*/
	
	@ApiOperation(value = "根据id查询详细信息", notes = "参数：(id)")
	@RequestMapping(value = "findById", method = RequestMethod.POST)
	public ResponseWrapper findById( @RequestBody FoodStockDTO fdto1) ;
	/**
	 * @Description 保存安全监测结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:00:33
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存安全监测结果审核", notes = "参数：aduitList")
	@PostMapping(value = "/save")
	public ResponseWrapper save(@RequestBody FoodStockDTO fDto) ;
	/**
	 * @Description 更新安全监测-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:12:26
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新安全监测结果审核", notes = "参数：安全监测aduitList")
	@PostMapping(value = "/update")
	public ResponseWrapper update(@RequestBody FoodStockDTO fDto);

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除", notes = "参数：id(可传入多个)")
	@PostMapping(value = "/deletes")
	public ResponseWrapper deletes(@RequestBody FoodStockDTO fDto) ;

	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有结果审核", notes = "参数：承储企业名称、计划文件名称、当前页、页面大小")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPage/{page}/{size}")
	public ResponseWrapper findByPage(
			@RequestBody FoodStockDTO fDto, 
			@PathVariable("page") Integer page,
			@PathVariable ("size")Integer size) ;
	
	/**
	 * @Description 上报
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "上报", notes = "参数：id")
	@PostMapping(value = "/updateState")
	public ResponseWrapper updateState(@RequestBody FoodStockDTO fDto);
	
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "样品信息同步", notes = "参数")
	@PostMapping(value = "/getSampleInformation")
	public ResponseWrapper getSampleInformation(@RequestBody FoodStockDTO fDto) ;
	
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "结果汇总-盟市、旗县", notes = "参数")
	@PostMapping(value = "/getAll")
	public ResponseWrapper getAll(@RequestBody FoodStockDTO fDto);
	

	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "质检档案-盟市、旗县", notes = "参数")
	@PostMapping(value = "/allInformation")
	public ResponseWrapper allInformation(@RequestBody FoodStockDTO fDto);
	

	/**
	 * @Description 检测业务查询统计     饼图-样品份数
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "检测业务查询统计     饼图-样品份数", notes = "参数")
	@GetMapping(value = "/sampleNumber/{years}")
	public ResponseWrapper sampleNumber(@PathVariable("years") String years) throws Exception;
	
	/**
	 * @Description 检测业务查询统计     柱状图-储存品质总代表数量
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "检测业务查询统计     柱状图-储存品质总代表数量", notes = "参数")
	@GetMapping(value = "/natureNumber/{years}")
	public ResponseWrapper natureNumber(@PathVariable("years") String years) throws Exception;
	
	/**
	 * @Description 检测业务查询统计     柱状图-宜存率 
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "检测业务查询统计     柱状图-宜存率 ", notes = "参数")
	@GetMapping(value = "/suitableDeposit/{years}")
	public ResponseWrapper suitableDeposit(@PathVariable("years") String years) throws Exception;
	
}
