package com.unis.quality.client;

import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.FxlyCompanyVO;
import com.unis.quality.common.vo.OrganizationVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @author lifx
 * @version 1.0
 * @Title: OrganizationFeign
 * @ProjectName OrganizationService
 * @Description: Organization层fegin接口
 * @date 2019年8月10日13:08:40
 */
@FeignClient(name = "quality-server")
@Component
public interface FxlyCompanyFeign {

	/**
	 * 
	 * @Description: excel导入
	 * @date 2019年11月22日17:40:32
	 * @author lfx
	 * @version v1.0
	 * @param file
	 * @return
	 * @throws Exception 
	 */
	@PostMapping(value = "/importExcel")
	public ResponseWrapper importExcel(@RequestParam("fileName") MultipartFile file) throws Exception;
	
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param Id
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "根据企业信用代码查看企业信息", notes = "参数:qyxydm")
	@GetMapping(value = "/findComById/{qyxydm}")
	public ResponseWrapper findComById(@PathVariable("qyxydm") String qyxydm) throws Exception;
	
	/**
	 * @Description 保存
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存机构信息", notes = "参数：机构信息对象acquistionVO")
	@PostMapping(value = "/saveCom")
	public ResponseWrapper saveCom(@RequestBody FxlyCompanyVO organizationVO) throws Exception;
	
	@ApiOperation(value = "分页获取企业信息列表", notes = "参数：企业名称，企业类型")
	@PostMapping(value = "/companyPage/{pageNum}/{pageSize}")
    public ResponseWrapper getCompanyPage(@RequestBody FxlyCompanyVO fxlyCompanyVO,
										  @PathVariable("pageNum")Integer pageNum,
										  @PathVariable("pageSize") Integer pageSize) ;
	
	/**
	 * @author lfx
	 * @Description 修改企业信息
	 * @param companyVO 企业信息实体
	 * @return 新增状态
	 * @throws Exception 
	 */
	@PutMapping(value = "/company")
	@ApiOperation(value = "更新企业信息", notes = "参数：企业统一社会信用代码")
	public ResponseWrapper updatecompany(@RequestBody FxlyCompanyVO companyVO) throws Exception;
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 获取企业列表
	 * @Date 2019年12月6日 下午5:39:01
	 * @param fxlyCompanyVO
	 * @return ResponseWrapper
	 */
	@ApiOperation(value = "获取企业信息列表", notes = "参数：企业名称，企业类型")
	@PostMapping(value = "/findList")
    public ResponseWrapper findList(@RequestBody FxlyCompanyVO fxlyCompanyVO) ;
}
