package com.unis.quality.client;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.OrganizationVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @author lifx
 * @version 1.0
 * @Title: OrganizationFeign
 * @ProjectName OrganizationService
 * @Description: Organization层fegin接口
 * @date 2019年8月10日13:08:40
 */
@FeignClient(name = "quality-server")
@Component
public interface OrganizationFeign {

	@ApiOperation(value = "根据id查询机构信息", notes = "参数：机构信息id")
	@GetMapping(value = "/findById/{id}")
	public ResponseWrapper findById(@PathVariable("id") String id);

	@ApiOperation(value = "保存机构信息", notes = "参数：机构信息对象acquistionVO")
    @RequestMapping(method = RequestMethod.POST, value = "/saveOrg/")
	public ResponseWrapper saveOrg(@RequestBody OrganizationVO organizationVO);

	@ApiOperation(value = "更新机构信息", notes = "参数：机构信息对象organizationVO")
    @RequestMapping(method = RequestMethod.POST, value = "/updateOrg/")
	public ResponseWrapper updateOrg(@RequestBody OrganizationVO organizationVO);

	@ApiOperation(value = "删除机构信息", notes = "参数：机构id(可传入多个)")
    @RequestMapping(method = RequestMethod.POST, value = "/deletesOrg")
	public ResponseWrapper deletesOrg(@RequestBody OrganizationVO organizationVO);

	@ApiOperation(value = "查询所有机构信息", notes = "参数：机构名称模糊查询、所属地区模糊查询、当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/findByPageOrg/{page}/{size}")
	ResponseWrapper findByPageOrg(@RequestBody OrganizationVO organizationVO, 
			@PathVariable ("page") Integer page,
			@PathVariable ("size") Integer size);

	//同步Myuser的机构
	@PostMapping(value = "/synMyUserOrg")
	ResponseWrapper synMyUserOrg(@RequestBody ResponseWrapper data);

}
