package com.unis.quality.client;

import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.PersonnelManagementVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @Description: 质检机构管理--机构信息
 * @ClassName: OrganizationController
 * @author lfx
 * @date 2018年10月26日16:20:35
 * 
 * @version v1.0
 */
@FeignClient(name = "quality-server")
@Component
public interface PersonnelManagementFeign {

	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param Id
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "根据id查询人员信息", notes = "参数：organizationId")
	@GetMapping(value = "/findByIdPer/{organizationId}")
	public ResponseWrapper findByIdPer(@PathVariable("organizationId") String organizationId);

	/**
	 * @Description 保存机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存人员信息", notes = "参数：人员信息对象List<PersonnelManagementVO>")
	@PostMapping(value = "/savePer")
	public ResponseWrapper savePer(@RequestBody PersonnelManagementVO vo) ;
	/**
	 * @Description 更新机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新人员信息", notes = "参数：人员信息对象personnelManagementVO")
	@PostMapping(value = "/updatePer")
	public ResponseWrapper updatePer(@RequestBody PersonnelManagementVO vo);

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param Ids
	 * @date 2018/10/29
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除人员信息", notes = "参数：organizationId(可传入多个)")
	@PostMapping(value = "/deletesPer")
	public ResponseWrapper deletesPer(@RequestBody PersonnelManagementVO vo);

	/**
	 * @Description 根据标题、创建人查询机构信息
	 * @version v1.0
	 * @author lfx
	 * @param OrganizationVO
	 * @date 2018/10/19
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有人员信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPagePer/{page}/{size}")
	public ResponseWrapper findByPagePer(
			@RequestBody PersonnelManagementVO personnelManagementVO, 
			@PathVariable ("page") Integer page,
			@PathVariable ("size") Integer size);

	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 同步base-server中的人员--化验
	 * @Date 2020年3月10日 下午3:36:39
	 * @param data
	 * @return ResponseWrapper
	 */
	@PostMapping(value = "/synBaseServerPerson")
	public ResponseWrapper synBaseServerPerson(@RequestBody ResponseWrapper data);
	
}
