package com.unis.quality.client;

import java.util.List;
import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.dto.CheckSchemeDTO;
import com.unis.quality.common.vo.ZjbgbhVO;
import com.unis.quality.common.vo.tianjin.CcfackVO;
import com.unis.quality.common.vo.tianjin.PointPlanVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @ClassName: PointPlanFeign
 * @Description: 品质测报-布点计划
 * @author lfx
 * @date 2019年7月10日15:01:34
 * 
 * @version v1.0
 */
@FeignClient(name = "quality-server")
@Component
public interface PointPlanFeign {

	

	/**
	 * @Description 根据id查询
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日14:17:21
	 * @param id
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据id查询信息", notes = "参数：id")
	@GetMapping(value = "/findByIdPointPlan/{id}")
	public ResponseWrapper findByIdPointPlan(@PathVariable("id") String id);

	/**
	 * @Description 保存信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @param PointPlanVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "保存信息", notes = "参数：信息对象CheckSchemeDTO")
	@PostMapping(value = "/savePointPlan")
	public ResponseWrapper savePointPlan(@RequestBody CheckSchemeDTO dto) ;

	/**
	 * @Description 更新信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:49
	 * @param PointPlanVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "更新信息", notes = "参数：信息对象PointPlanVO")
	@PutMapping(value = "/updatePointPlan")
	public ResponseWrapper updatePointPlan(@RequestBody CheckSchemeDTO dto);

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:56
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "删除信息", notes = "参数：ids(可传入多个)")
	@DeleteMapping(value = "/deletePointPlan")
	public ResponseWrapper deletePointPlan(@RequestBody CheckSchemeDTO dto);


	/**
	 * @Description 查询、分页
	 * @version v1.0
	 * @author lfx
	 * @param PointPlanVO
	 * @param page
	 * @param size
	 * @date 2018年10月30日15:01:37
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "查询所有设备信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPagePointPlan")
	public ResponseWrapper findByPagePointPlan(@RequestBody CheckSchemeDTO dto,
			@RequestParam ("page")  Integer page,
			@RequestParam ("size")  Integer size);
	
	
	@ApiOperation(value = "抽样检测结果查看", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/kucunliangshiList")
	public ResponseWrapper kucunliangshiList(@RequestBody CheckSchemeDTO dto,
			@RequestParam ("page") Integer page,
			@RequestParam ("size") Integer size) throws Exception;


	@ApiOperation(value = "抽样检测结果查看", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "page", value = "起始页", required = true),
			@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/allSampling")
	public ResponseWrapper allSampling(@RequestBody CheckSchemeDTO dto,
									   @RequestParam ("page") Integer page,
									   @RequestParam ("size") Integer size) throws Exception;
	
	/**
	 * @Description 根据id查询
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日14:17:21
	 * @param id
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据id查询抽样检测信息", notes = "参数：id")
	@PostMapping(value = "/samplingById")
	public ResponseWrapper samplingById(@RequestBody CheckSchemeDTO dto);
	
	/**
	 * @Description 质检中心推送质检编号
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @param PointPlanVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "质检中心推送质检编号", notes = "参数：信息对象")
	@PostMapping(value = "/saveZjbg")
	public ResponseWrapper saveZjbg(@RequestBody ZjbgbhVO resultsVO ) throws Exception;
	
	/**
	 * @Description 抽样方案下发查看记录
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @param PointPlanVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "抽样方案下发查看记录保存", notes = "参数：信息对象")
	@PostMapping(value = "/updateCkjl")
	public ResponseWrapper updateCkjl(@RequestBody CcfackVO resultsVO );
	
	/**
	 * @Description 查询、分页
	 * @version v1.0
	 * @author lfx
	 * @param PointPlanVO
	 * @param page
	 * @param size
	 * @date 2018年10月30日15:01:37
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "抽查方案查看记录列表", notes = "参数：ccfaid")
	@PostMapping(value = "/findCcfa")
	public ResponseWrapper findCcfa(@RequestBody CcfackVO dto) ;
	
}
