package com.unis.quality.client;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.dto.CheckSchemeDTO;
import com.unis.quality.common.dto.ViewSituationDTO;
import com.unis.quality.common.vo.tianjin.QualityHarvestCornVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @ClassName: QualityHarvestCornFeign
 * @Description: 品质测报-抽样方案
 * @author lfx
 * @date 2019年7月10日15:01:34
 * 
 * @version v1.0
 */
@FeignClient(name = "quality-server")
@Component
public interface QualityHarvestCornFeign {

	

	/**
	 * @Description 根据id查询
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日14:17:21
	 * @param id
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据id查询信息", notes = "参数：id")
	@PostMapping(value = "/findByIdHarvestCorn")
	public ResponseWrapper findByIdHarvestCorn(@RequestBody CheckSchemeDTO dto) ;
	

	/**
	 * @Description 保存信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @param QualityHarvestCornVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "保存信息", notes = "参数：信息对象CheckSchemeDTO")
	@PostMapping(value = "/saveHarvestCorn")
	public ResponseWrapper saveHarvestCorn(@RequestBody CheckSchemeDTO dto);

	/**
	 * @Description 更新信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:49
	 * @param QualityHarvestCornVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "更新信息", notes = "参数：对象QualityHarvestCornVO")
	@PutMapping(value = "/updateHarvestCorn")
	public ResponseWrapper updateHarvestCorn(@RequestBody QualityHarvestCornVO vo) ;

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:56
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "删除信息", notes = "参数：ids(可传入多个)")
	@DeleteMapping(value = "/deleteHarvestCorn")
	public ResponseWrapper deleteHarvestCorn(@RequestBody String ids[]) ;
	/**
	 * @Description 查询、分页
	 * @version v1.0
	 * @author lfx
	 * @param QualityHarvestCornVO
	 * @param page
	 * @param size
	 * @date 2018年10月30日15:01:37
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "查询信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPageHarvestCorn")
	public ResponseWrapper findByPageHarvestCorn(@RequestBody CheckSchemeDTO vo,
			@RequestParam ("page") Integer page,
			@RequestParam ("size") Integer size);
	
	/**
	 * @Description 上报
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "发布", notes = "参数：id")
	@PutMapping(value = "/updateStateCorn/{id}")
	public ResponseWrapper updateStateCorn(@PathVariable("id") String id);
	

	/**
	 * @Description 查询抽查方案标题
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询计划文件名", notes = "参数：计划类型")
	@GetMapping(value = "/getProgramme")
	public ResponseWrapper getProgramme();
	
	/**
	 * @Description 抽样方案接收
	 * @version v1.0
	 * @author ldq
	 * @date 2018年10月30日10:43:55
	 * @param QualityHarvestCornVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "保存信息", notes = "参数：信息对象ViewSituationDTO")
	@PostMapping(value = "/updateViewSituation")
	public ResponseWrapper updateViewSituation(@RequestBody ViewSituationDTO vo);
}
