package com.unis.quality.client;

import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.QualityPredictionAduitVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @ClassName: QualityPredictionAduitController
 * @Description: 品质测报-结果审核
 * @author lfx
 * @date 2019年7月10日14:57:38
 * 
 * @version v1.0
 */
@FeignClient(name = "quality-server")
@Component
public interface QualityPredictionAduitFegin {


    /**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx	 * @date 2018/10/24
	 * @param id
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "根据id查询详细信息", notes = "参数：(id)")
	@GetMapping(value = "/findByIdAduit/{id}/{batch}")
	public ResponseWrapper findByIdAduit(@PathVariable("id") String id,@PathVariable("batch") String batch) ;

	/**
	 * @Description 保存品质测报结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:00:33
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存品质测报结果审核", notes = "参数：aduitList")
	@PostMapping(value = "/saveAduit")
	public ResponseWrapper saveAduit(@RequestBody QualityPredictionAduitVO vo) ;

	/**
	 * @Description 更新品质测报-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:12:26
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新品质测报结果审核", notes = "参数：品质测报aduitList")
	@PostMapping(value = "/updateAduit")
	public ResponseWrapper updateAduit(@RequestBody QualityPredictionAduitVO vo);

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除", notes = "参数：id(可传入多个)")
	@PostMapping(value = "/deletesAduit")
	public ResponseWrapper deletesAduit(@RequestBody QualityPredictionAduitVO vo);
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有结果审核", notes = "参数：承储企业名称、计划文件名称、当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPageAduit/{page}/{size}")
	public ResponseWrapper findByPageAduit(
			@RequestBody QualityPredictionAduitVO qualityVO,
			@PathVariable ("page") Integer page,
			@PathVariable ("size") Integer size) ;
	
	/**
	 * @Description 上报
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "上报", notes = "参数：id")
	@PostMapping(value = "/updateStateAduit")
	public ResponseWrapper updateStateAduit(@RequestBody QualityPredictionAduitVO vo) ;
	
	/**
	 * @Description 移动端-新收获粮分类汇总统计
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	@ApiOperation(value = "移动端-新收获粮分类汇总统计", notes = "参数：(years)")
	@GetMapping(value = "/qualityHarvestCorn/{years}")
	public ResponseWrapper qualityHarvestCorn(@PathVariable("years") String years);
	
	/**
	 * @Description 移动端-按企业、企业总数、合格率
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	@ApiOperation(value = "移动端-按企业、企业总数、合格率", notes = "参数：")
	@PostMapping(value = "/company")
	public ResponseWrapper company();
	
	/**
	 * @Description 移动端-按品种、企业总数、合格率
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	@ApiOperation(value = "移动端-按品种、企业总数、合格率", notes = "参数：(years)")
	@GetMapping(value = "/varieties/{varieties}")
	public ResponseWrapper varieties(@PathVariable("varieties") String varieties);
}
