package com.unis.quality.client;

import java.util.List;
import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.QualityPredictionPlannedVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @ClassName: QualityPredictionPlannedController
 * @Description: 品质测报计划下发
 * @author lfx
 * @date 2019年7月10日14:57:38
 * 
 * @version v1.0
 */
@FeignClient(name = "quality-server")
@Component
public interface QualityPredictionPlannedFeign {


    /**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "根据id查询详细信息", notes = "参数：(id)")
	@GetMapping(value = "/findByIdPlan/{id}")
	public ResponseWrapper findByIdPlan(@PathVariable("id") String id) ;

	/**
	 * @Description 保存品质测报计划下发
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:00:33
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存品质测报计划下发", notes = "参数：品质测报对象QualityPredictionPlannedVO")
	@PostMapping(value = "/savePlan")
	public ResponseWrapper savePlan(@RequestBody QualityPredictionPlannedVO resultsVO) ;

	/**
	 * @Description 更新品质测报计划下发
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:12:26
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新品质测报计划下发", notes = "参数：品质测报QualityPredictionPlannedVO")
	@PostMapping(value = "/updatePlan")
	public ResponseWrapper updatePlan(@RequestBody QualityPredictionPlannedVO resultsVO);

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除", notes = "参数：id(可传入多个)")
	@PostMapping(value = "/deletesPlan")
	public ResponseWrapper deletesPlan(@RequestBody QualityPredictionPlannedVO qualityVO) ;

	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有计划下发", notes = "参数：计划文件名称、计划下达时间、状态、当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPagePlan/{page}/{size}")
	public ResponseWrapper findByPagePlan(
			@RequestBody QualityPredictionPlannedVO qualityVO, 
			@PathVariable ("page") Integer page,
			@PathVariable ("size") Integer size) ;
	
	
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询计划文件名", notes = "参数：计划类型")
	@PostMapping(value = "/getFlieName")
	public ResponseWrapper getFlieName(@RequestBody QualityPredictionPlannedVO vo) ;
	
	/**
	 * @Description 下发
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "下发", notes = "参数：id")
	@PostMapping(value = "/updateStatePlan")
	public ResponseWrapper updateStatePlan(@RequestBody QualityPredictionPlannedVO vo) ;
}
