package com.unis.quality.client;

import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.TestParametersVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @ClassName: TestParametersController
 * @Description: 质检机构管理--检验信息
 * @author lfx
 * @date 2018年10月30日10:34:20
 * 
 * @version v1.0
 */
@FeignClient(name = "quality-server")
@Component
public interface TestParametersFeign {


	/**
	 * @Description 根据id查询人员详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:18:35
	 * @param id
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "根据id查询信息", notes = "参数：organizationId")
	@GetMapping(value = "/findByIdTest/{organizationId}/")
	public ResponseWrapper findByIdTest(@PathVariable("organizationId") String organizationId) ;

	/**
	 * @Description 保存信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:43
	 * @param PersonnelManagementVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存检验信息", notes = "参数：检验信息对象List<TestParametersVO>")
	@RequestMapping(method = RequestMethod.POST, value = "/saveTestp/")
	public ResponseWrapper saveTestp(@RequestBody TestParametersVO vo) ;
	/**
	 * @Description 更新信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:37
	 * @param PersonnelManagementVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新检验信息", notes = "参数：检验信息对象TestParametersVO")
	@PostMapping(value = "/updateTest")
	public ResponseWrapper updateTest(@RequestBody TestParametersVO vo) ;
	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:45
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除检验信息", notes = "参数：organizationId(可传入多个)")
	@PostMapping(value = "/deletesTest")
	public ResponseWrapper deletesTest(@RequestBody TestParametersVO vo) ;


	/**
	 * @Description 查询检验信息、分页
	 * @version v1.0
	 * @author lfx
	 * @param PersonnelManagementVO
	 * @date 2018年10月30日10:38:06
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有检验信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPageTest/{page}/{size}")
	public ResponseWrapper findByPageTest(
			@RequestBody TestParametersVO testParametersVO,
			@PathVariable("page") Integer page,
			@PathVariable ("size")Integer size) ;
}
