package com.unis.quality.common.constant;

import com.unis.quality.common.vo.EntrustInspectApplyVO;
import com.unis.quality.common.vo.EntrustInspectVO;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.HashMap;
import java.util.Map;
import java.util.function.Function;

/**
 * 第三方质检 流程节点
 * @author by PIG
 * 2023/10/24 15
 */
@Component
public class EntrustInspectNode {

    Map<String, Function<EntrustInspectApplyVO, EntrustInspectApplyVO.NODE_INFO>> applyOperationMap = new HashMap<>();
    Map<String, Function<EntrustInspectVO, EntrustInspectVO.NODE_INFO>> operationMap = new HashMap<>();

    @PostConstruct
    private void init(){
        applyOperationMap.put(EntrustInspectApplyVO.NODE_INFO.COMMIT_PEND.getValue(), this::commitPend);
        applyOperationMap.put(EntrustInspectApplyVO.NODE_INFO.SEAL_PEND.getValue(), this::sealPend);
        applyOperationMap.put(EntrustInspectApplyVO.NODE_INFO.SEAL_REJECT.getValue(), this::sealReject);
        applyOperationMap.put(EntrustInspectApplyVO.NODE_INFO.ACCEPT_PEND.getValue(), this::acceptPend);
        applyOperationMap.put(EntrustInspectApplyVO.NODE_INFO.REJECTED.getValue(), this::rejected);

        operationMap.put(EntrustInspectVO.NODE_INFO.CREATE_PEND.getValue(), this::createPend);
        operationMap.put(EntrustInspectVO.NODE_INFO.SEAL_PEND.getValue(), this::sealPend);
        operationMap.put(EntrustInspectVO.NODE_INFO.SEAL_REJECT.getValue(), this::sealReject);
        operationMap.put(EntrustInspectVO.NODE_INFO.ACCEPT_PEND.getValue(), this::acceptPend);
        operationMap.put(EntrustInspectVO.NODE_INFO.UPLOAD_ENTRUST_PEND.getValue(), this::uploadEntrustPend);
        operationMap.put(EntrustInspectVO.NODE_INFO.UPLOAD_REPORT_PEND.getValue(), this::uploadReportPend);
        operationMap.put(EntrustInspectVO.NODE_INFO.OPINION_PEND.getValue(), this::opinionPend);
    }


    public EntrustInspectVO.NODE_INFO doOperation(EntrustInspectVO entity){
        EntrustInspectVO.NODE_INFO nodeInfo = operationMap.get(entity.getNodeId()).apply(entity);
        return nodeInfo;
    }

    public void doOperation(EntrustInspectApplyVO entity){
        applyOperationMap.get(entity.getNodeId()).apply(entity);
    }

    // 申请
    private EntrustInspectApplyVO.NODE_INFO commitPend(EntrustInspectApplyVO entity) {
        EntrustInspectApplyVO.NODE_INFO nodeInfo = EntrustInspectApplyVO.NODE_INFO.SEAL_PEND;
        entity.setNodeId(nodeInfo.getValue());
        entity.setNodeName(nodeInfo.getName());
        return nodeInfo;
    }
    private EntrustInspectApplyVO.NODE_INFO sealPend(EntrustInspectApplyVO entity) {
        String actionType = entity.getActionType();
        EntrustInspectApplyVO.NODE_INFO nodeInfo = actionType.equals("1") ? EntrustInspectApplyVO.NODE_INFO.ACCEPT_PEND : EntrustInspectApplyVO.NODE_INFO.SEAL_REJECT;
        entity.setNodeId(nodeInfo.getValue());
        entity.setNodeName(nodeInfo.getName());
        return nodeInfo;
    }
    private EntrustInspectApplyVO.NODE_INFO sealReject(EntrustInspectApplyVO entity) {
        EntrustInspectApplyVO.NODE_INFO nodeInfo = EntrustInspectApplyVO.NODE_INFO.SEAL_PEND;
        entity.setNodeId(nodeInfo.getValue());
        entity.setNodeName(nodeInfo.getName());
        return nodeInfo;
    }
    private EntrustInspectApplyVO.NODE_INFO acceptPend(EntrustInspectApplyVO entity) {
        String actionType = entity.getActionType();
        EntrustInspectApplyVO.NODE_INFO nodeInfo = actionType.equals("1") ? EntrustInspectApplyVO.NODE_INFO.ACCEPTED : EntrustInspectApplyVO.NODE_INFO.REJECTED;
        entity.setAcceptStatus(Integer.valueOf(actionType));
        entity.setNodeId(nodeInfo.getValue());
        entity.setNodeName(nodeInfo.getName());
        return nodeInfo;
    }
    private EntrustInspectApplyVO.NODE_INFO rejected(EntrustInspectApplyVO entity) {
        String actionType = entity.getActionType();
        EntrustInspectApplyVO.NODE_INFO nodeInfo = actionType.equals("1") ? EntrustInspectApplyVO.NODE_INFO.ACCEPT_PEND : EntrustInspectApplyVO.NODE_INFO.SEAL_REJECT;
        entity.setNodeId(nodeInfo.getValue());
        entity.setNodeName(nodeInfo.getName());
        return nodeInfo;
    }
    // -----------------委托书
    private EntrustInspectVO.NODE_INFO createPend(EntrustInspectVO entity) {
        entity.setNodeId(EntrustInspectVO.NODE_INFO.SEAL_PEND.getValue());
        entity.setNodeName(EntrustInspectVO.NODE_INFO.SEAL_PEND.getName());
        return  EntrustInspectVO.NODE_INFO.SEAL_PEND;
    }

    private EntrustInspectVO.NODE_INFO sealPend(EntrustInspectVO entity) {
        String actionType = entity.getActionType();
        EntrustInspectVO.NODE_INFO nodeInfo = actionType.equals("1") ? EntrustInspectVO.NODE_INFO.ACCEPT_PEND : EntrustInspectVO.NODE_INFO.SEAL_REJECT;
        entity.setNodeId(nodeInfo.getValue());
        entity.setNodeName(nodeInfo.getName());
        return nodeInfo;
    }
    private EntrustInspectVO.NODE_INFO sealReject(EntrustInspectVO entity) {
        EntrustInspectVO.NODE_INFO nodeInfo = EntrustInspectVO.NODE_INFO.SEAL_PEND;
        entity.setNodeId(nodeInfo.getValue());
        entity.setNodeName(nodeInfo.getName());
        return nodeInfo;
    }

    private EntrustInspectVO.NODE_INFO acceptPend(EntrustInspectVO entity) {
        entity.setNodeId(EntrustInspectVO.NODE_INFO.UPLOAD_ENTRUST_PEND.getValue());
        entity.setNodeName(EntrustInspectVO.NODE_INFO.UPLOAD_ENTRUST_PEND.getName());
        return EntrustInspectVO.NODE_INFO.UPLOAD_ENTRUST_PEND;
    }

    private EntrustInspectVO.NODE_INFO uploadEntrustPend(EntrustInspectVO entity) {
        entity.setNodeId(EntrustInspectVO.NODE_INFO.UPLOAD_REPORT_PEND.getValue());
        entity.setNodeName(EntrustInspectVO.NODE_INFO.UPLOAD_REPORT_PEND.getName());
        return EntrustInspectVO.NODE_INFO.UPLOAD_REPORT_PEND;
    }

    private EntrustInspectVO.NODE_INFO uploadReportPend(EntrustInspectVO entity) {
        entity.setNodeId(EntrustInspectVO.NODE_INFO.FINISH.getValue());
        entity.setNodeName(EntrustInspectVO.NODE_INFO.FINISH.getName());
        return EntrustInspectVO.NODE_INFO.FINISH;
    }

    private EntrustInspectVO.NODE_INFO opinionPend(EntrustInspectVO entity) {
        entity.setNodeId(EntrustInspectVO.NODE_INFO.FINISH.getValue());
        entity.setNodeName(EntrustInspectVO.NODE_INFO.FINISH.getName());
        return EntrustInspectVO.NODE_INFO.FINISH;
    }
}
