package com.unis.quality.common.utils;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.lang.reflect.InvocationTargetException;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.multipart.MultipartFile;


/**
 * @author lidiaoquan
 * @version 1.0
 * @Title: ExcelUtil
 * @Description: excel导入导出工具类
 * @date 2020年3月5日 上午10:54:27
 */
public class ExcelUtil {
	
/*	  导入使用例子
	public ResponseWrapper importExcel(@RequestParam(value = "fileName")MultipartFile file) throws Exception {
		// 指定输入文件
		
		// 指定每列对应的类属性
		LinkedHashMap<String, String> alias = new LinkedHashMap<>();
		alias.put("企业名称", "qymc");
		alias.put("企业信用代码", "qyxydm");
		alias.put("企业类型", "lx");
		alias.put("产品", "cp");
		alias.put("备注", "bz");
		// 转换成map的对象数组
		List<Map<String, Object>> ls = ExcelUtil.excel2Pojo(file, alias);
	}
*/
	
	
/*	导出使用例子
	public void downloadImpTemp(HttpServletResponse response) {
		try {
			LinkedHashMap<String, String> alias = new LinkedHashMap<>();
			alias.put("qymc", "企业名称");
			alias.put("qyxydm", "企业信用代码");
			alias.put("lx", "企业类型");
			alias.put("cp", "产品");
			alias.put("bz", "备注");
            response.reset();// 清空输出流
			ServletOutputStream outputStream = response.getOutputStream();
//直接返回文件时候打开，不打开则返回文件流
//			response.setContentType("application/octet-stream; charset=UTF-8");
//			response.setHeader("content-disposition", "attachment;filename=" + URLEncoder.encode("放心粮油企业.xls", "UTF-8"));
			ExcelUtil.pojo2ExcelTemp(outputStream, alias, null);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}	
*/	
	
	private static final Logger logger = LoggerFactory.getLogger(ExcelUtil.class);
    private final static String xls = "xls";  
    private final static String xlsx = "xlsx"; 


	// 判断是否为空，若为空设为""
	private static Object isNull(Object object) {
		if (object != null) {
			return object;
		} else {
			return "";
		}
	}
	
	/**
	 * @Description: 对表格中数值进行格式化
	 * @date 2018年12月25日,下午3:46:06
	 * @author xmpu
	 * @version v1.0
	 * @param cell
	 * @return
	 */
    public static Object getCellValue(Cell cell) {
        Object value = null;
        DecimalFormat df = new DecimalFormat(); // 格式化number String字符
        SimpleDateFormat sdf = new SimpleDateFormat("yyy-MM-dd"); // 日期格式化
        DecimalFormat df2 = new DecimalFormat("0"); // 格式化数字

        switch (cell.getCellType()) {
        case STRING:
            value = cell.getRichStringCellValue().getString();
            break;
        case NUMERIC:
            if ("General".equals(cell.getCellStyle().getDataFormatString())) {
                value = df.format(cell.getNumericCellValue());
//				value = cell.getNumericCellValue();
            } else if ("m/d/yy".equals(cell.getCellStyle().getDataFormatString())) {
                value = sdf.format(cell.getDateCellValue());
            } else {
                value = df.format(cell.getNumericCellValue());
//				value = cell.getNumericCellValue();
            }
            break;
        case BOOLEAN:
            value = cell.getBooleanCellValue();
            break;
        case BLANK:
            value = "";
            break;
        default:
            break;
        }
        return value;
    }
    
	/**
	 * 此方法作用是创建表头的列名
	 * 
	 * @param alias
	 *            要创建的表的列名与实体类的属性名的映射集合
	 * @param sheet
	 *            指定行创建列名
	 * @return
	 */
	private static void insertColumnName(int rowNum, HSSFSheet sheet, Map<String, String> alias) {
		HSSFRow row = sheet.createRow(rowNum);
		// 列的数量
		int columnCount = 0;

		Set<Entry<String, String>> entrySet = alias.entrySet();

		for (Entry<String, String> entry : entrySet) {
			// 创建第一行的第columnCount个格子
			HSSFCell cell = row.createCell(columnCount++);
			// 将此格子的值设置为alias中的键名
			cell.setCellValue(isNull(entry.getValue()).toString());
		}
	}
	
	/**
	 * 从指定行开始插入数据
	 * 
	 * @param beginRowNum
	 *            开始行
	 * @param models
	 *            对象数组
	 * @param sheet
	 *            表
	 * @param alias
	 *            列别名
	 * @throws Exception
	 */
	private static <T> void insertColumnDate(int beginRowNum, List<T> models, HSSFSheet sheet,
			Map<String, String> alias) throws Exception {
		for (T model : models) {
			// 创建新的一行
			HSSFRow rowTemp = sheet.createRow(beginRowNum++);
			logger.info("创建了第:{}行", beginRowNum);

			// 获取列的迭代
			Set<Entry<String, String>> entrySet = alias.entrySet();

			// 从第0个格子开始创建
			int columnNum = 0;
			for (Entry<String, String> entry : entrySet) {
				// 获取属性值
				String property = BeanUtils.getProperty(model, entry.getKey());
				// 创建一个格子
				HSSFCell cell = rowTemp.createCell(columnNum++);
				cell.setCellValue(property);
			}
		}
	}
	
	/**
	 * 生成一个属性-列的对应关系的map
	 * 
	 * @param sheet
	 *            表
	 * @param alias
	 *            别名
	 * @return
	 */
	private static Map<String, Integer> generateColumnPropertyMap(Sheet sheet,
			LinkedHashMap<String, String> alias) throws Exception {
		Map<String, Integer> propertyMap = new HashMap<>();

		Row row = sheet.getRow(0);
		short firstCellNum = row.getFirstCellNum();
		short lastCellNum = row.getLastCellNum();

		for (int i = firstCellNum; i < lastCellNum; i++) {
			Cell cell = row.getCell(i);
			if (cell == null) {
				continue;
			}
			// 列名
			String cellValue = cell.getStringCellValue();
			String propertyName = alias.get(cellValue);
			
			// 对应属性名
			propertyMap.put(propertyName, i);
		}
		return propertyMap;
	}

	/**
	 * 根据指定关系将表数据转换成对象数组
	 * 
	 * @param sheet
	 *            表
	 * @param propertyMap
	 *            属性映射关系Map<"属性名",一行第几列>
	 * @return
	 * @throws InstantiationException
	 * @throws IllegalAccessException
	 * @throws InvocationTargetException
	 */
	private static <T> List<Map<String, Object>> generateList(Sheet sheet, Map<String, Integer> propertyMap) throws InstantiationException, IllegalAccessException, InvocationTargetException {
		// 对象数组
		// List<T> pojoList=new ArrayList<>();
		List<Map<String, Object>> ls = new ArrayList<Map<String, Object>>();
		for (Row row : sheet) {
			// 跳过第一行的title
			if (row.getRowNum() < 1) {
				continue;
			}
			// T instance = claz.newInstance();
			Set<Entry<String, Integer>> entrySet = propertyMap.entrySet();
			Map<String, Object> m = new HashMap<String, Object>();
			for (Entry<String, Integer> entry : entrySet) {
				// 获取此行指定列的值,即为属性对应的值
				Integer val = entry.getValue();
				Cell property = row.getCell(val);
				if (property == null) {
					continue;
				}
				// String property1 = property.getStringCellValue();
				// String property2 = property1.toString();
				// BeanUtils.setProperty(instance, entry.getKey(),
				// property.getStringCellValue());
				if(getCellValue(property) == null) {
					throw new RuntimeException("传数据模板有误，与下载的模板不一致。");
				}
				m.put(entry.getKey(), getCellValue(property));
			}
			ls.add(m);
		}
		return ls;
	}
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 将excel表转换成指定类型的对象数组
	 * @Date 2020年3月5日 上午10:49:11
	 * @param <T>
	 * @param file
	 * @param alias 列别名,格式要求：Map<"列名","类属性名">
	 * @return
	 * @throws Exception List<Map<String,Object>>
	 */
	public static <T> List<Map<String, Object>> excel2Pojo(MultipartFile file,
			LinkedHashMap<String, String> alias) throws Exception {
		
        //获得文件名  
        String fileName = file.getOriginalFilename();  
       
        //判断文件是否是excel文件  
        if(!fileName.endsWith(xls) && !fileName.endsWith(xlsx)){  
            logger.error(fileName + "不是excel文件");  
            throw new IOException(fileName + "不是excel文件");  
        }
        
        //获得Workbook工作薄对象  
        Workbook wb = getWorkBook(file);  
		Sheet sheet = wb.getSheetAt(0);
		// 生成属性和列对应关系的map，Map<类属性名，对应一行的第几列>
		Map<String, Integer> propertyMap = generateColumnPropertyMap(sheet, alias);
		// 根据指定的映射关系进行转换
		List<Map<String, Object>> pojoList = generateList(sheet, propertyMap);
		wb.close();
		return pojoList;
	}




	
	/**
	 * 将对象数组转换成excel生成导入模板
	 * @param out 输出流
	 * @param alias 指定对象属性别名，生成列名和列顺序Map<"类属性名","列名">
	 * @param pojoList 
	 * @throws Exception
	 */
	public static <T> void pojo2ExcelTemp(OutputStream out, LinkedHashMap<String, String> alias, List<T> pojoList) throws Exception {
		// 创建一个工作簿
		HSSFWorkbook wb = new HSSFWorkbook();
		// 创建一个表
		HSSFSheet sheet = wb.createSheet();
		// 在第一行插入列名
		insertColumnName(0, sheet, alias);
		
		if(pojoList != null && pojoList.size() > 0) {
			// *从第2行开始插入数据
			insertColumnDate(1, pojoList, sheet, alias);
		}
		// 输出表格文件
		try {
			wb.write(out);
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			wb.close();
			out.close();
		}
	}
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 根据文件EXCEL类型获取对应的Workbook
	 * @Date 2020年3月5日 上午10:50:37
	 * @param file
	 * @return Workbook
	 */
    public static Workbook getWorkBook(MultipartFile file) {  
        //获得文件名  
        String fileName = file.getOriginalFilename();  
        //创建Workbook工作薄对象，表示整个excel  
        Workbook workbook = null;  
        try {  
            //获取excel文件的io流  
            InputStream is = file.getInputStream();  
            //根据文件后缀名不同(xls和xlsx)获得不同的Workbook实现类对象  
            if(fileName.endsWith(xls)){  
                //2003  
                workbook = new HSSFWorkbook(is);  
            }else if(fileName.endsWith(xlsx)){  
                //2007  
                workbook = new XSSFWorkbook(is);  
            }  
        } catch (IOException e) {  
            logger.info(e.getMessage());  
        }  
        return workbook;  
    } 
}
