package com.unis.quality.common.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.base.common.vo.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Column;
import java.util.*;

/**
 * @author by PIG
 * 2023/9/20 15
 */
@ApiModel(value = "委托检验申请")
@Data
@EqualsAndHashCode(callSuper = true)
public class EntrustInspectApplyVO extends BaseEntity {

    private Long fid;

    @ApiModelProperty(value = "节点id")
    private String nodeId;

    private String nodeName;

    @ApiModelProperty(value = "操作")
    private String actionType;

    @ApiModelProperty(value = "检验申请编号", example = "20230911090")
    private String applyNumber;

    @DateTimeFormat(pattern = "yyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty(value = "检验申请时间")
    private Date applyDate;

    @ApiModelProperty(value = "申请单位")
    private String applyOrg;
    private String applyOrgName;
    @ApiModelProperty(value = "联系人")
    private String linkMan;
    @ApiModelProperty(value = "申请地址")
    private String applyAddress;
    @ApiModelProperty(value = "联系电话")
    private String linkPhone;
    @ApiModelProperty(value = "类型", example = "出库质检、入库质检、移入质检、移出质检")
    private Integer entrustApplyType;
    private String entrustApplyTypeName;
    /** 品种*/
    @ApiModelProperty(value = "品种")
    private String applySubType;
    private String applySubTypeName;

    /** 经办人*/
    private String operator;
    /** 负责人*/
    private String principal;

    @ApiModelProperty(value = "签章信息")
    @Column(name = "signature")
    private String signature;

    /** 签章日期*/
    @ApiModelProperty(value = "签章日期")
    @DateTimeFormat(pattern = "yyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @Column(name = "signature_date")
    private Date signatureDate;

    @ApiModelProperty(value = "接收状态")
    private Integer acceptStatus;
    @ApiModelProperty(value = "接收人")
    private String acceptUsername;
    @ApiModelProperty(value = "接收意见")
    private String acceptDesc;
    @DateTimeFormat(pattern = "yyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    @ApiModelProperty(value = "接收时间")
    private Date acceptDate;

    @ApiModelProperty(value = "轮换申请编号")
    private String rotateApplyCode;

    @ApiModelProperty(name = "仓号")
    private String houseName;
    List<EntrustInspectApplyDetailVO> entrustInspectApplyDetailList;

    public enum NODE_INFO {
        COMMIT_PEND("90000000", "待提交"),
        SEAL_PEND("90000010", "待盖章"),
        SEAL_REJECT("90000011", "盖章驳回"),
        ACCEPT_PEND("90000020", "待接收"),
        REJECTED("90000021", "已驳回"),
        ACCEPTED("90000030", "已接收");
        @Getter
        private final String value;
        @Getter
        private final String name;

        NODE_INFO(String value, String name) {
            this.value = value;
            this.name = name;
        }
        public boolean equalVal(String targetVal) {
            return this.value.equals(targetVal);
        }
    }
    public enum ENTRUST_APPLY_TYPE {
        CK(1, "出库质检", "C"),
        RK(2, "入库质检", "R"),
        YR(3, "移入质检", "R"),
        YC(4, "移出质检", "C");

        @Getter
        private final Integer value;
        @Getter
        private final String name;
        @Getter
        private final String type;

        ENTRUST_APPLY_TYPE(Integer value, String name, String type) {
            this.value = value;
            this.name = name;
            this.type = type;
        }

        public boolean equalsVal(Integer entrustApplyType) {
            return Objects.equals(this.value, entrustApplyType);
        }
    }

    public static ENTRUST_APPLY_TYPE getEntrustApplyTypeName(Integer applyType) {
        Map<Integer, ENTRUST_APPLY_TYPE> map = new HashMap<>();
        map.put(1, ENTRUST_APPLY_TYPE.CK);
        map.put(2, ENTRUST_APPLY_TYPE.RK);
        map.put(3, ENTRUST_APPLY_TYPE.YR);
        map.put(4, ENTRUST_APPLY_TYPE.YC);
        return map.get(applyType);
    }

    public void initNode(){
        this.nodeId = NODE_INFO.SEAL_PEND.getValue();
        this.nodeName = NODE_INFO.SEAL_PEND.getName();
    }

    public void outInitNode() {
        this.entrustApplyType = ENTRUST_APPLY_TYPE.CK.getValue();
        this.entrustApplyTypeName = ENTRUST_APPLY_TYPE.CK.getName();
        this.nodeId = NODE_INFO.COMMIT_PEND.getValue();
        this.nodeName = NODE_INFO.COMMIT_PEND.getName();
    }

}
