package com.unis.quality.common.vo;

import com.alibaba.fastjson.annotation.JSONField;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.base.common.vo.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springframework.format.annotation.DateTimeFormat;


import javax.persistence.Column;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 检测委托书
 * 委托检验申请接收后创建
 * @author by PIG
 * @Date 2023/9/21 14
 */
@ApiModel(value = "检测委托书")
@Data
@EqualsAndHashCode(callSuper = true)
public class EntrustInspectVO extends BaseEntity {

    @ApiModelProperty(value = "id")
    private Long fid;

    @Column(name = "node_id")
    private String nodeId;

    @Column(name = "node_name")
    private String nodeName;

    @Column(name = "action_type")
    private String actionType;

    /** 委托书编号 e.g. 津DC-R(C)-四位年份-两位顺序号*/
    @ApiModelProperty(name = "委托书编号", example = "津DC-R(C)-四位年份-两位顺序号")
    @Column(name = "entrust_num")
    private String entrustNum;

    /** 申请类型 e.g:出库质检、入库质检、移入质检、移出质检 */
    @ApiModelProperty(value = "申请类型")
    @Column(name = "entrust_apply_type")
    private Integer entrustApplyType;
    /** 申请类型 e.g:出库质检、入库质检、移库质检 */
    @ApiModelProperty(value = "申请类型", allowableValues = "出库质检,入库质检,移入质检,移出质检")
    @Column(name = "entrust_apply_type_name")
    private String entrustApplyTypeName;

    /** 委托方*/
    @ApiModelProperty(value = "委托方")
    private String entrustOrg;
    /** 委托方联系人*/
    @ApiModelProperty(value = "委托方联系人")
    private String entrustLinkMan;
    @ApiModelProperty(value = "委托方联系人电话")
    private String entrustLinkPhone;
    // 被检单位
    @ApiModelProperty(value = "被检单位")
    private String beInspectOrg;
    @ApiModelProperty(value = "被检单位")
    private String beInspectOrgName;
    /** 受检地址*/
    @ApiModelProperty(value = "受检地址")
    private String beInspectAddress;

    /** 抽样单位联系人*/
    @ApiModelProperty(value = "抽样单位联系人")
    private String chooserLinkMan;
    @ApiModelProperty(value = "抽样单位联系人电话")
    private String chooseOrgLinkPhone;
    @ApiModelProperty(value = "")
    private String subTypeDetailed;
    @ApiModelProperty(value = "")
    private String subTypeDetailedName;
    //样品状态 e.g 颗粒袋装、液态瓶装
    @ApiModelProperty(value = "样品状态 e.g 颗粒袋装、液态瓶装", example = "[颗粒袋装,液态瓶装]")
    private String sampleStatus;
    @ApiModelProperty(value = "抽样基数 库存数量")
    private BigDecimal sampleBasicNum; /** 抽样基数 库存数量*/

    @ApiModelProperty(value = "委托时间")
    @JSONField(format="yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    private Date entrustDate;

    @ApiModelProperty(name = "仓号")
    private String houseId;
    @ApiModelProperty(name = "仓号")
    private String houseName;

    @ApiModelProperty(value = "完成时间")
    @JSONField(format="yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    private Date finishDate;
    @ApiModelProperty(value = "检验项目")
    private String qualityItem;
    @ApiModelProperty(value = "受委托方意见")
    private String chooseOrgOpinion;
    @ApiModelProperty(value = "")
    private String entrustOrgSignature;
    @ApiModelProperty(value = "签章时间")
    @JSONField(format="yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    private Date entrustOrgSignatureDate;
    @ApiModelProperty(value = "提交日期")
    @JSONField(format="yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    private Date entrustOrgSubmitDate;

    @ApiModelProperty(value = "检验单位签章", notes = "实际业务没用")
    private String chooseOrgSignature;
    @ApiModelProperty(value = "检验单位签章使时间", notes = "实际业务没用")
    private Date chooseOrgSignatureDate;
    /** 检测扦样机构*/
    @ApiModelProperty(value = "检测扦样机构")
    private String  chooser;
    @ApiModelProperty(value = "")
    @JSONField(format="yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    private Date  chooseDate;
    /** 附件-受委托方盖章委托书*/
    @ApiModelProperty(value = "附件-受委托方盖章委托书")
    private String chooseAttachment;
    /** 附件-质检结果*/
    @ApiModelProperty(value = "附件-质检结果")
    private String inspectAttachment;
    /**
     * @see EntrustInspectApplyDetailVO
     * EntrustInspectApplyDetailVO.fid
     * */
    @ApiModelProperty(value = "申请.fid")
    private Long applyDetailFid;
    @ApiModelProperty(value = "申请编号")
    private String applyNumber;
    /** 品种*/
    private String applySubType;

    public enum NODE_INFO {
        CREATE_PEND("90000030", "待生成"),
        SEAL_REJECT("90000031", "盖章驳回"),
        SEAL_PEND("90000040", "待盖章"),
        ACCEPT_PEND("90000050", "待第三方接收"),
        UPLOAD_ENTRUST_PEND("90000060", "待上传委托书"),
        UPLOAD_REPORT_PEND("90000070", "待上传质检报告"),
        OPINION_PEND("90000080", "待出具质检意见"),
        FINISH("90000090", "质检完成");

        private final String value;
        private final String name;

        NODE_INFO(String value, String name) {
            this.value = value;
            this.name = name;
        }

        public boolean equalVal(String targetVal) {
            return this.value.equals(targetVal);
        }
        public String getName() {
            return name;
        }
        public String getValue() {
            return value;
        }
    }


}
