package com.unis.quality.common.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.unis.common.vo.base.BaseVO;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.validation.constraints.NotBlank;
import java.util.Date;
import java.util.List;

/**
 * @ClassName: TbCheckstandardInfoVO
 * @Description: 检验流程管理——检测标准
 * @date 2019年7月17日 下午2:27:25 
 * 
 * @version v1.0
 */
@Data
@ApiModel(value="检测标准")
public class TbCheckstandardInfoVO extends BaseVO {

	@ApiModelProperty(value="监测id")
	private String checkstandardId;
	

	/**
	 *  标准类型文字
	 */
	private String standardTypeHz;

	/**
	 * 创建时间
	 */
	@ApiModelProperty(value="创建时间")
	private Date createDate;
	
	/**
	 * 创建人
	 */
	@ApiModelProperty(value="创建人")
	private String creator;

	/**
	 * 状态code
	 */
	@ApiModelProperty(value="状态code")
	private Integer status;

	@Length(max=255,message="0:禁用;1:启用 最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
	@ApiModelProperty(value = "0:禁用;1:启用 ", notes ="0:禁用;1:启用0:禁用;1:启用 ", example = "无字段注释 ")
	@Column(name="IS_USED", length=255, columnDefinition = "VARCHAR")
	private String isUsed;

	@Length(max=255,message="无字段注释 最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
	@ApiModelProperty(value = "无字段注释 ", notes ="无字段注释 ", example = "无字段注释 ")
	@Column(name="ORG_CODE", length=255, columnDefinition = "VARCHAR")
	private String orgCode;

	@Length(max=255,message="标准编号 最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
	@ApiModelProperty(value = "标准编号 ", notes ="标准编号 ", example = "标准编号 ")
	@Column(name="STANDARD_CODE", length=255, columnDefinition = "VARCHAR")
	private String standardCode;

	@Length(max=255,message="标准文件 最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
	@ApiModelProperty(value = "标准文件 ", notes ="标准文件 ", example = "标准文件 ")
	@Column(name="STANDARD_FILE", length=255, columnDefinition = "VARCHAR")
	private String standardFile;

	@Length(max=255,message="标准名称 最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
	@ApiModelProperty(value = "标准名称 ", notes ="标准名称 ", example = "标准名称 ")
	@Column(name="STANDARD_NAME", length=255, columnDefinition = "VARCHAR")
	private String standardName;

	@Length(max=255,message="标准类型 最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
	@ApiModelProperty(value = "标准类型 ", notes ="标准类型 ", example = "标准类型 ")
	@Column(name="STANDARD_TYPE", length=255, columnDefinition = "VARCHAR")
	private String standardType;

	@ApiModelProperty(value = "无字段注释 ", notes ="无字段注释 ", example = "2019-10-01")
	@Column(name="DO_TIME", columnDefinition = "TIMESTAMP")
	@DateTimeFormat( pattern = "yyyy-MM-dd")
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
	private Date doTime;

	@ApiModelProperty(value = "无字段注释 ", notes ="无字段注释 ", example = "2019-10-01")
	@Column(name="PUB_TIME", columnDefinition = "TIMESTAMP")
	@DateTimeFormat( pattern = "yyyy-MM-dd")
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
	private Date pubTime;

	@ApiModelProperty(value = "无字段注释 ", notes ="无字段注释 ", example = "2019-10-01")
	@Column(name="VALID_TIME", columnDefinition = "TIMESTAMP")
	@DateTimeFormat( pattern = "yyyy-MM-dd")
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
	private Date validTime;

	private List<String> standardFileList;

	@ApiModelProperty(value="开始时间")
	@DateTimeFormat( pattern = "yyyy-MM-dd")
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
	private Date createDateStart;

	@ApiModelProperty(value="结束时间")
	@DateTimeFormat( pattern = "yyyy-MM-dd")
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
	private Date createDateEnd;

	@ApiModelProperty(value="质检系统的标准id,这个ID是大写的")
	private String standardId;

}
