/*
* AbnormalShowVO.java
* 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
* Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
* 2020-05-14 19:31:13 created by lipenghe with LAPTOP-IJQ2SDFV
*/
package com.unis.quality.common.vo.abnormal;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.quality.common.vo.backlog.ReceiverCollectionVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * TY_YCQKZGTZ-异常情况整改通知
 * @author lipenghe at 2020-05-14 19:31:13
 */
@ApiModel(value = "TY_YCQKZGTZ:异常情况整改通知-AbnormalShowVO")
@Data
@Table(name="TY_YCQKZGTZ")
public class AbnormalShowVO implements Serializable{

    @NotBlank(message = "异常情况id不能为空",groups ={UpdateGroup.class})
    @Length(max=50,message="异常情况id最大为50字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "异常情况id#<主键><唯一><非空>", notes ="异常情况id", example = "异常情况id#<主键><唯一><非空>")
    @Id
    @Column(name="YCQKID",length=50)
    private String ycqkid;

    @NotBlank(message = "委托编号不能为空",groups ={InsertGroup.class})
    @Length(max=32,message="委托编号最大为32字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "委托编号#<非空>", notes ="委托编号", example = "委托编号#<非空>", hidden = true)
    @Column(name="WTBH", length=32)
    private String wtbh;

    @Length(max=200,message="承储/受检单位最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "承储/受检单位", notes ="承储/受检单位", example = "承储/受检单位", hidden = true)
    @Column(name="CCDW", length=200)
    private String ccdw;

    @ApiModelProperty(value = "委托时间", notes ="委托时间", example = "2019-10-01", hidden = true)
    @Column(name="WTSJ")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date wtsj;

    @Length(max=200,message="委托人最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "委托人", notes ="委托人", example = "委托人", hidden = true)
    @Column(name="WTR", length=200)
    private String wtr;

    @Length(max=200,message="仓号编码聚合数据最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "仓号编码聚合数据", notes ="仓号编码聚合数据", example = "仓号编码聚合数据", hidden = true)
    @Column(name="CH", length=200)
    private String ch;

    @Length(max=200,message="仓号名称聚合数据最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "仓号名称聚合数据", notes ="仓号名称聚合数据", example = "仓号名称聚合数据", hidden = true)
    @Column(name="CHMCS", length=200)
    private String chmcs;

    @Length(max=200,message="已归纳的异常最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "已归纳的异常#只添加不删除", notes ="已归纳的异常", example = "已归纳的异常#只添加不删除", hidden = true)
    @Column(name="YCS", length=200)
    private String ycs;

    @Length(max=200,message="异常位置聚合数据最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "异常位置聚合数据#会添加和删除", notes ="异常位置聚合数据", example = "异常位置聚合数据#会添加和删除", hidden = true)
    @Column(name="YCWZS", length=200)
    private String ycwzs;

    @Length(max=100,message="异常状态最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "异常状态#草稿10,", notes ="异常状态", example = "异常状态#草稿10,", hidden = true)
    @Column(name="YCZT", length=100)
    private String yczt;

    @Length(max=100,message="异常状态名称最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "异常状态名称", notes ="异常状态名称", example = "异常状态名称", hidden = true)
    @Column(name="YCZTMC", length=100)
    private String ycztmc;

    @Length(max=100,message="整改检查人最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "整改检查人", notes ="整改检查人", example = "整改检查人", hidden = true)
    @Column(name="ZGJCR", length=100)
    private String zgjcr;

    @ApiModelProperty(value = "整改检查时间", notes ="整改检查时间", example = "2019-10-01", hidden = true)
    @Column(name="ZGJCSJ")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date zgjcsj;

    //数据库类型:LONGVARCHAR,长度:2048
    @ApiModelProperty(value = "异常情况盖章", notes ="异常情况盖章", example = "异常情况盖章", hidden = true)
    @Column(name="YCQKGZ")
    private String ycqkgz;

    //数据库类型:LONGVARCHAR,长度:2048
    @ApiModelProperty(value = "整改要求", notes ="整改要求", example = "整改要求", hidden = true)
    @Column(name="ZGYQ")
    private String zgyq;

    @ApiModelProperty(value = "整改开始时间", notes ="整改开始时间", example = "2019-10-01", hidden = true)
    @Column(name="ZGKSSJ")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date zgkssj;

    @ApiModelProperty(value = "整改结束时间", notes ="整改结束时间", example = "2019-10-01", hidden = true)
    @Column(name="ZGJSSJ")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date zgjssj;

    @Length(max=100,message="整改承储企业负责人最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "整改承储企业负责人", notes ="整改承储企业负责人", example = "整改承储企业负责人", hidden = true)
    @Column(name="ZGCCQYFZR", length=100)
    private String zgccqyfzr;

    //数据库类型:LONGVARCHAR,长度:2048
    @ApiModelProperty(value = "整改承储企业盖章", notes ="整改承储企业盖章", example = "整改承储企业盖章", hidden = true)
    @Column(name="ZGCCQYGZ")
    private String zgccqygz;

    @Length(max=100,message="验收结果最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "验收结果", notes ="验收结果", example = "验收结果", hidden = true)
    @Column(name="YSJG", length=100)
    private String ysjg;

    //数据库类型:LONGVARCHAR,长度:2048
    @ApiModelProperty(value = "验收情况", notes ="验收情况", example = "验收情况", hidden = true)
    @Column(name="YSQK")
    private String ysqk;

    @Length(max=200,message="验收附件最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "验收附件", notes ="验收附件", example = "验收附件", hidden = true)
    @Column(name="YSFJ", length=200)
    private String ysfj;

    @Length(max=200,message="验收检查人最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "验收检查人", notes ="验收检查人", example = "验收检查人", hidden = true)
    @Column(name="YSJCR", length=200)
    private String ysjcr;

    @ApiModelProperty(value = "验收检查时间", notes ="验收检查时间", example = "2019-10-01", hidden = true)
    @Column(name="YSJCSJ")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date ysjcsj;

    @Length(max=200,message="验收承储企业负责人最大为200字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "验收承储企业负责人", notes ="验收承储企业负责人", example = "验收承储企业负责人", hidden = true)
    @Column(name="YSCCQYFZR", length=200)
    private String ysccqyfzr;

    @ApiModelProperty(value = "状态#<默认值:1>1：正常，0：已作废", notes ="状态", example = "1", hidden = true)
    @Column(name="STATUS", length=10, precision=10, scale=0)
    private Integer status;

    @Length(max=32,message="创建人最大为32字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "创建人", notes ="创建人", example = "创建人", hidden = true)
    @Column(name="CREATOR", length=32)
    private String creator;

    @ApiModelProperty(value = "创建时间#<默认值:current>", notes ="创建时间", example = "2019-10-01", hidden = true)
    @Column(name="CREATE_DATE")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date createDate;

    //数据库类型:LONGVARCHAR,长度:100
    @ApiModelProperty(value = "整改验收盖章", notes ="整改验收盖章", example = "整改验收盖章", hidden = true)
    @Column(name="ZGYSGZ")
    private String zgysgz;

    //数据库类型:LONGVARCHAR,长度:100
    @ApiModelProperty(value = "整改确认盖章", notes ="整改确认盖章", example = "整改确认盖章", hidden = true)
    @Column(name="ZGQRYSGZ")
    private String zgqrysgz;

    public AbnormalShowVO(){
        super();
        this.status= BaseStatusConstant.STATUS_NORMAL;
    }

    @ApiModelProperty(value = "异常情况整改通知明细", notes ="子表---TY_YCQKZGTZMX", example = "", hidden = true)
    private List<AbnormalDetailShowVO> detailList;

    @ApiModelProperty(value = "待办用户")
    List<ReceiverCollectionVO> userList;

    @ApiModelProperty(value = "事项详情Url")
    private String itemUrl;// 事项详情url

    private String itemQuery; // 详情跳转参数 （BacklogAddVO）

    private String handlerId; // 已办-处理人主键 （BacklogUpdateVO）

    private String sendresult; // 库级推送结果

    @ApiModelProperty(value = "查询字段")
    private String itemQueryHaveDone;
}