/*
* RainShowVO.java
* 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
* Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
* 2020-08-11 17:08:12 created by lipenghe with LAPTOP-IJQ2SDFV
*/
package com.unis.quality.common.vo.weather;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Date;

/**
 * PLUG_WEATHER_RAIN-降雨量表
 * @author lipenghe at 2020-08-11 17:08:12
 */
@ApiModel(value = "PLUG_WEATHER_RAIN:降雨量表-RainShowVO")
@Data
@Table(name="PLUG_WEATHER_RAIN")
public class RainShowVO implements Serializable{

    @NotNull(message = "降雨量表主键不能为空",groups ={UpdateGroup.class})
    @ApiModelProperty(value = "降雨量表主键#<主键><唯一><非空>", notes ="降雨量表主键", example = "0")
    @Id
    @Column(name="RAIN_ID",length=20,precision=20,scale=0)
    private Long rainId;

    @ApiModelProperty(value = "id#<唯一>", notes ="id")
    @Column(name="ID", length=20, precision=20, scale=0)
    private Long id;

    @Length(max=50,message="id字符串最大为50字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "id字符串", notes ="id字符串", example = "id字符串", hidden = true)
    @Column(name="ID_STR", length=50)
    private String idStr;

    @Length(max=50,message="外部id字符串最大为50字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "外部id字符串", notes ="外部id字符串", example = "外部id字符串", hidden = true)
    @Column(name="OUT_ID", length=50)
    private String outId;

    @Length(max=50,message="外部id来源最大为50字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "外部id来源", notes ="外部id来源", example = "外部id来源", hidden = true)
    @Column(name="OUT_FROM", length=50)
    private String outFrom;

    @Length(max=100,message="父级id最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "父级id#<唯一>", notes ="父级id")
    @Column(name="PARENT_ID", length=100)
    private String parentId;

    @Length(max=100,message="城市拼音或者英文名最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "城市拼音或者英文名", notes ="城市拼音或者英文名", example = "城市拼音或者英文名", hidden = true)
    @Column(name="NAMEEN", length=100)
    private String nameen;

    @Length(max=100,message="城市/地区/企业中文名字最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "城市/地区/企业中文名字", notes ="城市/地区/企业中文名字", example = "城市/地区/企业中文名字", hidden = true)
    @Column(name="CITYNAME", length=100)
    private String cityname;

    @Length(max=100,message="城市/地区/企业编码最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "城市/地区/企业编码", notes ="城市/地区/企业编码", example = "城市/地区/企业编码", hidden = true)
    @Column(name="CITY", length=100)
    private String city;

    @Length(max=100,message="当前温度最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "当前温度", notes ="当前温度", example = "当前温度", hidden = true)
    @Column(name="TEMP", length=100)
    private String temp;

    @Length(max=100,message="华氏温度最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "华氏温度", notes ="华氏温度", example = "华氏温度", hidden = true)
    @Column(name="TEMPF", length=100)
    private String tempf;

    @Length(max=100,message="风向及等级最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "风向及等级", notes ="风向及等级", example = "风向及等级", hidden = true)
    @Column(name="WD", length=100)
    private String wd;

    @Length(max=100,message="风向英文缩写最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "风向英文缩写", notes ="风向英文缩写", example = "风向英文缩写", hidden = true)
    @Column(name="WDE", length=100)
    private String wde;

    @Length(max=100,message="风速等级最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "风速等级", notes ="风速等级", example = "风速等级", hidden = true)
    @Column(name="WS", length=100)
    private String ws;

    @Length(max=100,message="风速最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "风速", notes ="风速", example = "风速", hidden = true)
    @Column(name="WSE", length=100)
    private String wse;

    @Length(max=100,message="空气湿度最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "空气湿度", notes ="空气湿度", example = "空气湿度", hidden = true)
    @Column(name="SD", length=100)
    private String sd;

    @Length(max=100,message="天气最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "天气", notes ="天气", example = "天气", hidden = true)
    @Column(name="WEATHER", length=100)
    private String weather;

    @Length(max=100,message="天气英文最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "天气英文", notes ="天气英文", example = "天气英文", hidden = true)
    @Column(name="WEATHERE", length=100)
    private String weathere;

    @Length(max=100,message="天气代码最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "天气代码", notes ="天气代码", example = "天气代码", hidden = true)
    @Column(name="WEATHERCODE", length=100)
    private String weathercode;

    @Length(max=100,message="气压最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "气压", notes ="气压", example = "气压", hidden = true)
    @Column(name="QY", length=100)
    private String qy;

    @Length(max=100,message="能见度最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "能见度", notes ="能见度", example = "能见度", hidden = true)
    @Column(name="NJD", length=100)
    private String njd;

    @Length(max=100,message="当前降雨量(毫米)最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "当前降雨量(毫米)", notes ="当前降雨量(毫米)", example = "当前降雨量(毫米)", hidden = true)
    @Column(name="RAIN", length=100)
    private String rain;

    @Length(max=100,message="24h降雨量(毫米)最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "24h降雨量(毫米)", notes ="24h降雨量(毫米)", example = "24h降雨量(毫米)", hidden = true)
    @Column(name="RAIN24", length=100)
    private String rain24;

    @Length(max=100,message="空气质量指数最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "空气质量指数", notes ="空气质量指数", example = "空气质量指数", hidden = true)
    @Column(name="AQI", length=100)
    private String aqi;

    @Length(max=100,message="汽车限号最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "汽车限号", notes ="汽车限号", example = "汽车限号", hidden = true)
    @Column(name="LIMITNUMBER", length=100)
    private String limitnumber;

    @Length(max=100,message="空气质量指数(PM)最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "空气质量指数(PM)", notes ="空气质量指数(PM)", example = "空气质量指数(PM)", hidden = true)
    @Column(name="AQI_PM25", length=100)
    private String aqiPm25;

    @Length(max=100,message="日期标示最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "日期标示", notes ="日期标示", example = "日期标示", hidden = true)
    @Column(name="DATE_STAMP", length=100)
    private String dateStamp;

    @Length(max=100,message="时间标示最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "时间标示#<唯一>", notes ="时间标示")
    @Column(name="TIME_STAMP", length=100)
    private String timeStamp;

    @Length(max=100,message="降雨等级最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "降雨等级", notes ="降雨等级", example = "降雨等级", hidden = true)
    @Column(name="RAIN_LEVEL", length=100)
    private String rainLevel;

    @Length(max=100,message="降雨量(毫米)最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "降雨量(毫米)", notes ="降雨量(毫米)", example = "降雨量(毫米)", hidden = true)
    @Column(name="RAIN_VALUE", length=100)
    private String rainValue;

    @Length(max=100,message="降雨消息最大为100字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "降雨消息", notes ="降雨消息", example = "降雨消息", hidden = true)
    @Column(name="RAIN_MSG", length=100)
    private String rainMsg;

    @ApiModelProperty(value = "排序", notes ="排序", example = "1", hidden = true)
    @Column(name="DATA_ORDER", length=10, precision=10, scale=0)
    private Integer dataOrder;

    @Length(max=32,message="数据版本号最大为32字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "数据版本号", notes ="数据版本号", example = "数据版本号", hidden = true)
    @Column(name="VERSION", length=32)
    private String version;

    @Length(max=32,message="数据uuid值最大为32字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "数据uuid值", notes ="数据uuid值", example = "数据uuid值", hidden = true)
    @Column(name="DATA_UUID", length=32)
    private String dataUuid;

    @Length(max=32,message="数据md5值最大为32字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "数据md5值", notes ="数据md5值", example = "数据md5值", hidden = true)
    @Column(name="DATA_MD5", length=32)
    private String dataMd5;

    @Length(max=32,message="数据时间戳最大为32字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "数据时间戳", notes ="数据时间戳", example = "数据时间戳", hidden = true)
    @Column(name="DATA_STAMP", length=32)
    private String dataStamp;

    @Length(max=32,message="数据类型最大为32字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "数据类型", notes ="数据类型", example = "数据类型", hidden = true)
    @Column(name="DATA_TYPE", length=32)
    private String dataType;

    @Length(max=32,message="创建人最大为32字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "创建人", notes ="创建人", example = "创建人", hidden = true)
    @Column(name="CREATOR", length=32)
    private String creator;

    @ApiModelProperty(value = "创建时间", notes ="创建时间", example = "2019-10-01", hidden = true)
    @Column(name="CREATE_DATE")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date createDate;

    public RainShowVO(){
        super();
    }
}