package com.unis.quality.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.TbCheckstandardInfoVO;
import com.unis.quality.server.entity.quality.TbCheckstandardInfoDO;
import com.unis.quality.server.service.impl.CheckstandardInfoServer;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName: TbCheckstandardInfoVO
 * @Description: 检验流程管理——检测标准
 * @date 2019年7月17日 下午2:27:25 
 * 
 * @version v1.0
 */
@RestController
@RequestMapping("/checkstandardinfo")
@Slf4j
@Api(tags = "检验流程管理---检测标准")
public class CheckstandardInfoController {
	
	@Autowired
	private CheckstandardInfoServer checkstandardInfoServer;
	
	
	@ApiOperation(value = "查询标准信息", notes = "参数: 标准信息checkstandardId")
	@GetMapping(value = "/findByIdInfo/{checkstandardId}")
	public ResponseWrapper findByIdInfo(@PathVariable String checkstandardId) throws Exception {
		TbCheckstandardInfoDO result = checkstandardInfoServer.findById(checkstandardId);
		if (ObjectUtils.notEqual(result, null)) {
			return ResponseWrapper.success(200, "查询成功", result);
		}
		return ResponseWrapper.error("已删除，查询失败");
	}
	
	
	@ApiOperation(value = "更新标准检测信息", notes = "参数：对象checkstandardInfoBO")
	@PostMapping(value = "/update")
	public ResponseWrapper update(@RequestBody TbCheckstandardInfoVO checkstandardInfoBO) {
		try {
			int flag = checkstandardInfoServer.update(checkstandardInfoBO);
			if (flag > 0) {
				return ResponseWrapper.success();
			}
			return ResponseWrapper.error();
		} catch (Exception e) {
			log.error("更新对象，发生异常", e.getMessage());
			return ResponseWrapper.error(
					HttpStatus.INTERNAL_SERVER_ERROR.value(),
					HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "操作失败");
		}

	}

	@ApiOperation(value = "查询所有检测标准信息", notes = "参数：标准名称，标准品类型，有效期")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody TbCheckstandardInfoVO checkstandardInfoBO, @PathVariable(value = "page") Integer page, @PathVariable(value = "size") Integer size) {
        try {
           
           Map<Object, Object> checkstandardInfoPOs = checkstandardInfoServer.findByPage(checkstandardInfoBO, page, size);
            return ResponseWrapper.success(200, "查询成功", checkstandardInfoPOs);
        } catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error(
					HttpStatus.INTERNAL_SERVER_ERROR.value(),
					HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "操作失败");
        }
    }
	
	@ApiOperation(value = "保存检测标准", notes = "参数：检测标准实体类")
	@PostMapping("/save")
	public ResponseWrapper insert(@RequestBody TbCheckstandardInfoVO checkstandardInfoBO) {
		try {
			int res = checkstandardInfoServer.save(checkstandardInfoBO);
			if (res > 0) {
				return ResponseWrapper.success("保存检测标准信息成功");
			}
			return ResponseWrapper.error("保存检测标准失败");

		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error("请联系管理员！");
		}
	}
	
	@ApiOperation(value = "获取所有标准分类")
	@PostMapping("/getAllInfo")
	public ResponseWrapper getAllInfo() {
		try {
			List<Map<String,Object>> res = checkstandardInfoServer.getAllInfo();
			return ResponseWrapper.success(200,"获取所有标准分类成功",res);

		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error("请联系管理员！");
		}
	}
	
	@ApiOperation(value = "删除检测标准", notes = "参数：标准id，多个以逗号隔开")
	@GetMapping(value = "/delete")
    public ResponseWrapper deleteInorout(String[] checkstandardId) {
        try {
           
            int tbStandardInfos = checkstandardInfoServer.delete(checkstandardId);
            if(tbStandardInfos>0) {
				return ResponseWrapper.success(
						HttpStatus.OK.value(),
						HttpStatus.OK.getReasonPhrase(), "删除标准品信息成功");
            }
            return ResponseWrapper.error("删除标准品信息失败");
        } catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error(
					HttpStatus.INTERNAL_SERVER_ERROR.value(),
					HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "查询失败");
        }
    }
	
	@ApiOperation(value = "启用、禁用", notes = "参数：对象checkstandardInfoBO")
	@PostMapping(value = "/updateIsUsed/{id}/{isUsed}")
	public ResponseWrapper updateIsUsed(@PathVariable("id") String id,@PathVariable("isUsed") String isUsed) {
		try {
			int flag = checkstandardInfoServer.updateIsUsed(id,isUsed);
			if (flag > 0) {
				return ResponseWrapper.success();
			}
			return ResponseWrapper.error();
		} catch (Exception e) {
			log.error("更新对象，发生异常", e.getMessage());
			return ResponseWrapper.error(
					HttpStatus.INTERNAL_SERVER_ERROR.value(),
					HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "操作失败");
		}
	}
	
	@ApiOperation(value = "根据标准分类获取标准编码", notes = "参数: 标准分类standardType")
	@PostMapping(value = "/getAllstandardCode/{standardType}")
	public ResponseWrapper getAllstandardCode(@PathVariable("standardType") String standardType) throws Exception {
		List<Map<String,Object>> result = checkstandardInfoServer.getAllstandardCode(standardType);
		if (ObjectUtils.notEqual(result, null)) {
			return ResponseWrapper.success(200, "查询成功", result);
		}
		return ResponseWrapper.error("查询失败");
	}
	
	@ApiOperation(value = "根据标准编码获取标准名称", notes = "参数: 标准信息standardCode")
	@PostMapping(value = "/getAllstandardName/{standardCode}")
	public ResponseWrapper getAllstandardName(@PathVariable("standardCode") String standardCode) throws Exception {
		List<Map<String,Object>> result = checkstandardInfoServer.getAllstandardName(standardCode);
		if (ObjectUtils.notEqual(result, null)) {
			return ResponseWrapper.success(200, "查询成功", result);
		}
		return ResponseWrapper.error("查询失败");
	}

}
