package com.unis.quality.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.TbCheckstandardItemVO;
import com.unis.quality.server.service.impl.CheckstandardItemServer;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName: CheckstandardItemController 
 * @Description: 检验流程管理---检测项目
 * @date 2019年7月17日 下午2:37:41 
 * 
 * @version v1.0
 */
@RestController
@RequestMapping("/checkstandarditem")
@Slf4j
@Api(tags = "检验流程管理---检测项目")
public class CheckstandardItemController {
	
	@Autowired
	private CheckstandardItemServer checkstandardItemServer;
	

	@ApiOperation(value = "查询所有检测项目信息", notes = "参数：标准名称，项目要求")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody TbCheckstandardItemVO checkstandardItemBO, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {
           
            Map<Object, Object> findByPage = checkstandardItemServer.findByPage(checkstandardItemBO, page, size);
            return ResponseWrapper.success(200, "查询成功", findByPage);
        } catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error(
					HttpStatus.INTERNAL_SERVER_ERROR.value(),
					HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "查询失败");
        }
    }
	
	@ApiOperation(value = "保存检测项目", notes = "参数：检测标准实体类")
	@PostMapping("/save")
	public ResponseWrapper insert(@RequestBody TbCheckstandardItemVO checkstandardItemBO) {
		try {
			int res = checkstandardItemServer.save(checkstandardItemBO);
			if (res > 0) {
				return ResponseWrapper.success("保存检测标准信息成功");
			}
			return ResponseWrapper.error("保存检测标准失败，检查标准是否存在");

		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error("请联系管理员！");
		}
	}
	
	@ApiOperation(value = "删除检测项目", notes = "参数：标准id，多个以逗号隔开")
	@GetMapping(value = "/delete")
    public ResponseWrapper deleteInorout(String[] itemId) {
        try {
           
            int tbStandardInfos = checkstandardItemServer.delete(itemId);
            if(tbStandardInfos>0) {
            	return ResponseWrapper.success(200, "删除标准品信息成功", null);
            }
            return ResponseWrapper.error("删除标准品信息失败");
        } catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error(
					HttpStatus.INTERNAL_SERVER_ERROR.value(),
					HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "查询失败");
        }
    }
	
	@ApiOperation(value = "返回所有的为删除的项目集合(包含规则)")
	@PostMapping("/getAllInfo")
	public ResponseWrapper getAllInfo() {
		try {
		List<TbCheckstandardItemVO> allInfo = checkstandardItemServer.getAllInfo();
			return ResponseWrapper.success(200,"获取检测项目信息成功",allInfo);

		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error("请联系管理员！");
		}
	}
	
	@ApiOperation(value = "更新项目信息", notes = "参数：对象checkstandardItemBO")
	@PostMapping(value = "/update")
	public ResponseWrapper update(@RequestBody TbCheckstandardItemVO checkstandardItemBO) {
		try {
			int flag = checkstandardItemServer.update(checkstandardItemBO);
			if (flag > 0) {
				return ResponseWrapper.success();
			}
			return ResponseWrapper.error();
		} catch (Exception e) {
			log.error("更新对象，发生异常", e.getMessage());
			return ResponseWrapper.error(
					HttpStatus.INTERNAL_SERVER_ERROR.value(),
					HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "操作失败");
		}
	}
	
	@ApiOperation(value = "查询项目信息", notes = "参数: 项目信息itemId")
	@GetMapping(value = "/findByItemId/{itemId}")
	public ResponseWrapper findByItemId(@PathVariable String itemId) throws Exception {
		 TbCheckstandardItemVO result = checkstandardItemServer.findByItemId(itemId);
		if (ObjectUtils.notEqual(result, null)) {
			return ResponseWrapper.success(200, "查询成功", result);
		}
		return ResponseWrapper.error();
	}
}
