package com.unis.quality.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.dto.CheckSchemeDTO;
import com.unis.quality.common.vo.EntrustQueryVO;
import com.unis.quality.common.vo.EntrustVO;
import com.unis.quality.server.service.EntrustService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 *功能描述 质检委托
 * @author wangqiang
 * @date 2019/8/21 0021
 * @param
 * @return
 */
@RestController
@Api(value = "质检委托", hidden = true)
public class EntrustController {

	@Autowired
	private EntrustService entrustService;


	/**
	 *功能描述 更新委托
	 * @author
	 * @date 2019/8/21 0021
	 * @param :StrongEntrustVO
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "根据质检编号修改", notes = "参数：强检委托对象StrongEntrustVO")
	@PutMapping(value = "/updateLcId/")
	public ResponseWrapper updateLcId(@RequestBody EntrustVO vo) throws Exception {
		boolean update = entrustService.updateLcId(vo);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), update);
	}


	@ApiOperation(value = "查询质检报告编号", notes = "参数：zjbh")
	@PostMapping(value = "/selectWtIdBhKctb/")
	public ResponseWrapper selectWtIdBhKctb(@RequestBody EntrustQueryVO entrustQueryVO) throws Exception{
		Map<String, Object> result = entrustService.selectWtIdBhKctb(entrustQueryVO);
		return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}

	@PostMapping(value="/entrust/echartsZjjgqs")
	@ApiOperation(value = "质检信息趋势echarts", notes = "参数：")
	public ResponseWrapper echartsZjjgqs(@RequestBody EntrustQueryVO entrustQueryVO){
		return entrustService.echartsZjjgqs(entrustQueryVO);
	}

	@ApiOperation(value = "查询质检报告编号和委托id库存", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/selectWtIdBhKc/")
	public ResponseWrapper selectWtIdBhKc(@RequestBody EntrustQueryVO entrustQueryVO,
			@RequestParam ("page")  Integer page,
			@RequestParam ("size")  Integer size) throws Exception{
		Map<String, Object> result = entrustService.selectWtIdBhKc(entrustQueryVO,page, size);
		return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}

	@ApiOperation(value = "查询质检报告编号和委托id", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/selectWtIdBh/")
	public ResponseWrapper selectWtIdBh(@RequestBody EntrustQueryVO entrustQueryVO,
			@RequestParam ("page")  Integer page,
			@RequestParam ("size")  Integer size) throws Exception{
		Map<String, Object> result = entrustService.selectWtIdBh(entrustQueryVO,page, size);
		return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}

	@ApiOperation(value = "分页获取交易质检", notes = "参数：当前页、页面大小")
	@PostMapping(value = "/findJyzjByPage/")
	public ResponseWrapper findJyzjByPage(@RequestBody EntrustQueryVO entrustQueryVO,
			@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
			  @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) throws Exception{
		Map<String,Object> byPage = entrustService.findJyzjByPage(entrustQueryVO,pageNum, pageSize);
		return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                byPage);
	}


  	@ApiOperation(value = "通过委托id查询质检报告编号", notes = "参数：wtId")
	@GetMapping(value = "/selectByWtId/")
	public ResponseWrapper selectByWtId(@RequestParam("wtId") String wtId) throws Exception {
  		String zjbgbh=entrustService.selectZjbgByWtId(wtId);
  		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), zjbgbh);
  	}

	@ApiOperation(value = "查询委托信息", notes = "EntrustVO vo")
	@PostMapping(value = "/entrust/selectById")
	public ResponseWrapper selectById(@RequestBody EntrustVO vo){
		return entrustService.selectById(vo);
	}

	/**
	 *功能描述 根据委托编号查询委托信息
	 * @author wangqiangng
	 * @date 2019/8/21 0021
	 * @param code
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "根据委托编号查询委托信息", notes = "参数：code")
	@GetMapping(value = "/entrust/")
	public ResponseWrapper findById(@RequestParam("code") String code) throws Exception {
		EntrustVO entrustVO = entrustService.findById(code);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), entrustVO);
	}

	/**
	 *功能描述 根据委托编号查询委托信息  其他质检详情
	 * @author
	 * @date 2019/8/21 0021
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "根据委托编号查询委托信息", notes = "参数：code")
	@PostMapping(value = "/entrustQt/")
	public ResponseWrapper findByIdQt(@RequestBody EntrustVO vo) throws Exception {
		EntrustVO entrustVO = entrustService.findByIdQt(vo);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), entrustVO);
	}

	/**
	 *功能描述 根据交易编号查询委托信息
	 * @author wangqiangng
	 * @date 2019/8/21 0021
	 * @param code
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "根据交易编号查询委托信息", notes = "参数：code")
	@GetMapping(value = "/findByJybh/")
	public ResponseWrapper findByJybh(@RequestParam("code") String code) throws Exception {
		EntrustVO entrustVO = entrustService.findByJybh(code);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), entrustVO);
	}

	/**
	 *功能描述 保存委托信息
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :StrongEntrustVO
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "保存强检委托信息", notes = "参数：委托信息对象StrongEntrustVO")
	@PostMapping(value = "/entrust/")
	public ResponseWrapper save(@RequestBody EntrustVO vo) throws Exception {
		boolean save = entrustService.save(vo);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), save);
	}

	/**
	 *功能描述 更新委托
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :StrongEntrustVO
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "更新委托", notes = "参数：强检委托对象StrongEntrustVO")
	@PutMapping(value = "/entrust/")
	public ResponseWrapper update(@RequestBody EntrustVO vo) throws Exception {
		boolean update = entrustService.update(vo);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), update);
	}

	/**
	 *功能描述 删除委托信息
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[id]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "删除委托信息", notes = "参数：id")
	@DeleteMapping(value = "/entrust/")
	public ResponseWrapper delete(@RequestBody EntrustVO vo) throws Exception {
		boolean delete = entrustService.delete(vo);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), delete);
	}

	/**
	 *功能描述 分页查询所有委托信息
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[queryVO, page, size]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "条件分页查询委托信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "page", value = "起始页", required = true),
			@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@RequestMapping(method = RequestMethod.POST, value = "/entrust/page/")
	public ResponseWrapper findByPage(@RequestBody EntrustQueryVO queryVO,
									  Integer page, Integer size) throws Exception {
		PageInfo<List<Map>> byPage = entrustService.findByPage(queryVO, page, size);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), byPage);
	}

	/**
	 *功能描述 分页查询所有委托信息
	 * @author
	 * @date 2019/8/21 0021
	 * @param :[queryVO, page, size]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "强检查询状态", notes = "参数：")
	@RequestMapping(method = RequestMethod.POST, value = "/entrust/findByPageZt/")
	public ResponseWrapper findByPageZt(@RequestBody EntrustQueryVO queryVO) throws Exception {
		List<EntrustVO> byPage = entrustService.findByPageZt(queryVO);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), byPage);
	}

	/**
	 *功能描述 强检仓号查询
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[queryVO, page, size]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "条件分页查询强检仓号", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "page", value = "起始页", required = true),
			@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@RequestMapping(method = RequestMethod.POST, value = "/entrust/pagech/")
	public ResponseWrapper findChByPage(@RequestBody EntrustVO queryVO,
			@RequestParam ("page")Integer page,
    		@RequestParam ("size")Integer size) throws Exception {
		PageInfo<List<Map>> byPage = entrustService.findChByPage(queryVO, page, size);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), byPage);
	}
	/**
	 *功能描述 提交委托
	 * @author wangqiang
	 * @date 2019/8/26 0026
	 * @param :[vo]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "提交委托", notes = "参数：委托对象StrongEntrustVO")
	@PutMapping(value = "/entrust/sub")
	public ResponseWrapper submitEntrust(@RequestBody EntrustVO vo) throws Exception {
		boolean update = entrustService.submitEntrust(vo);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), update);
	}

	/**
	 *功能描述 删除委托信息
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[id]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "删除委托信息", notes = "参数：id")
	@DeleteMapping(value = "/entrust/lcdr")
	public ResponseWrapper delete() throws Exception {
		boolean delete = entrustService.delete();
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), delete);
	}


	/**
	 *功能描述 向质检中心发送委托
	 * @author
	 * @date 2019/8/26 0026
	 * @param :[vo]
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "发送委托", notes = "参数：委托对象StrongEntrustVO")
	@PutMapping(value = "/sendWt")
	public ResponseWrapper sendWt(@RequestBody EntrustVO vo) throws Exception {
		String result = entrustService.sendWt(vo);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), result);
	}


	@ApiOperation(value = "根据wtbh查询jybh为空的数据", notes = "参数：当前页、页面大小")
	@PostMapping(value = "/findByWtbhQT/")
	public ResponseWrapper findByWtbhQT(@RequestBody EntrustVO entrustQueryVO) throws Exception{
		List<Map> result = entrustService.findByWtbhQT(entrustQueryVO);
		return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}

	/**
	 *功能描述 自动生成委托编号
	 * @author lfx
	 * @date 2019年11月21日11:09:08
	 * @return com.unis.common.utils.ResponseWrapper
	 */
	@ApiOperation(value = "自动生成委托编号", notes = "")
	@GetMapping(value = "/queryMAXWtbh/")
	public ResponseWrapper queryMAXWtbh(@RequestParam("zjbh") String zjbh) throws Exception {
		String wtbh = entrustService.queryMAXWtbh(zjbh);
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), wtbh);
	}

}
