package com.unis.quality.server.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.unis.cbl.common.constant.ErrorMessageConstant;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.base.PageResult;
import com.unis.quality.common.constant.ApiTag;
import com.unis.quality.common.vo.*;
import com.unis.quality.server.entity.quality.QualityInspectionDO;
import com.unis.quality.server.service.EntrustInspectService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;

/**
 * 第三方质检委托
 * @author by PIG
 * 2023/10/10 10
 */
@Api(value = "第三方质检委托", tags = ApiTag.SANG_FANG)
@RestController
@RequestMapping(value = "/entrust_inspect")
@Log4j2
public class EntrustInspectController {

    @Autowired
    private EntrustInspectService entrustInspectService;

    //>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>委托申请
    @ApiOperation(value = "委托申请 分页查询列表", notes = "pageSize,pageNum从url传", tags = {ApiTag.SANG_FANG})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/apply/selectPageByEntity")
    public ResponseWrapper selectApplyPageByEntity(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                              @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                              @RequestParam(value = "pageType", defaultValue = "1") int pageType,
                                              @RequestBody JSONObject queryParams) {
        PageResult<EntrustInspectApplyVO> page = entrustInspectService.selectApplyPageByEntity(pageNum, pageSize, pageType, queryParams);
        return ResponseWrapper.success(page);
    }

    @ApiImplicitParam(name = "fid", value = "pk", dataType = "String", paramType = "path")
    @ApiOperation(value = "查询详情", notes = "")
    @GetMapping("/apply/selectById/{fid}")
    public ResponseWrapper selectById(@PathVariable("fid") Long fid) {
        if (fid != null) {
            log.info("{}", fid);
            EntrustInspectApplyVO res = entrustInspectService.selectEntrustInspectApplyById(fid);
            Map<String, Object> data = Collections.singletonMap("res", res);
            return ResponseWrapper.success(res);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "质检委托申请-新增", notes = "")
    @PostMapping("/apply/insertEntitySelective")
    public ResponseWrapper insertEntrustInspectApply(@RequestBody EntrustInspectApplyVO entity) {
        if (entity != null) {
            log.info("质检委托申请-新增 >>>>>>>>>>>>>>>>>>>> \n {}", JSON.toJSONString(entity));
            int res = entrustInspectService.insertEntrustInspectApply(entity);
            if (-1 == res) {
                return ResponseWrapper.error("仓房重复填报");
            }
            Map<String, Object> data = Collections.singletonMap("res", res);
            return ResponseWrapper.success(data);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "出库质检委托申请-新增 来自轮换申请", notes = "", tags = {ApiTag.SANG_FANG, ApiTag.SANG_FANG_APPLY})
    @PostMapping("/apply/saveEntrustInspectApplyOut")
    public ResponseWrapper saveEntrustInspectApplyOut(@RequestBody JSONObject jsonData) {
        if (jsonData != null) {
            log.info("出库质检委托申请-新增 来自轮换申请 >>>>>>>>>> {}\n", jsonData.toJSONString());
            EntrustInspectApplyVO entity = jsonData.toJavaObject(EntrustInspectApplyVO.class);
            entity.outInitNode();
            int updateRows = entrustInspectService.saveEntrustInspectApplyOut(entity);
            return ResponseWrapper.success(updateRows);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "质检委托申请 修改", notes = "")
    @PutMapping("/apply/updateByEntitySelective")
    public ResponseWrapper updateEntrustInspectApply(@RequestBody EntrustInspectApplyVO entity) {
        if (entity != null) {
            log.info("质检委托申请 修改 >>>>>>>>>> {}\n", JSONObject.toJSONString(entity));
            int i = entrustInspectService.updateEntrustInspectApply(entity);
            return ResponseWrapper.success(i);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiImplicitParam(name = "fid", value = "pk", dataTypeClass = Long.class, paramType = "path")
    @ApiOperation(value = "删除", notes = "")
    @DeleteMapping("/apply/remove/{fid}")
    public ResponseWrapper removeById(@PathVariable("fid") Long fid) {
        if (fid != null) {
            int i = entrustInspectService.removeEntrustInspectApplyById(fid);
            return ResponseWrapper.success(i);
        } else {
            log.error("========= fid 为 null");
            return ResponseWrapper.error(ErrorMessageConstant.INVALID_DATA);
        }
    }

    //>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>委托

    @ApiOperation(value = "委托 分页查询列表", notes = "pageSize,pageNum从query传")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                              @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                              @RequestParam(value = "pageType", defaultValue = "1") int pageType,
                                              @RequestBody JSONObject queryParams) {
        PageResult<EntrustInspectVO> page = entrustInspectService.selectPageByEntity(pageNum, pageSize, pageType, queryParams);
        return ResponseWrapper.success(page);
    }

    @ApiOperation(value = "质检委托 查看", notes = "")
    @GetMapping("/selectById/{fid}")
    public ResponseWrapper getEntrustInspectById(@PathVariable("fid") Long fid) {
        if (fid != null) {
            log.info("委托书id {}", fid);
            EntrustInspectVO data = entrustInspectService.getEntrustInspectById(fid);

            return ResponseWrapper.success(data);
        } else {
            return ResponseWrapper.invalid();
        }
    }


    @ApiOperation(value = "质检委托 生成委托书", notes = "")
    @PutMapping("/create_entrust_inspect")
    public ResponseWrapper createEntrustInspect(@RequestBody EntrustInspectVO entity) {
        if (entity != null) {
            log.info("create_entrust_inspect 参数 >>>>>>>>>>>> {}", entity);
            Map<String, Object> data = entrustInspectService.createEntrustInspect(entity);
            return ResponseWrapper.success(data);
        } else {
            return ResponseWrapper.invalid();
        }
    }


    @ApiOperation(value = "委托书", notes = "")
    @PutMapping("/update_entrust_inspect")
    public ResponseWrapper updateEntrustInspect(@RequestBody EntrustInspectVO entity) {
        if (entity != null) {
            log.info("委托书 修改 >>>>>>>>>> {}\n", JSONObject.toJSONString(entity));
            int i = entrustInspectService.updateEntrustInspect(entity);
            return ResponseWrapper.success(i);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "委托书 上传质检报告", notes = "")
    @PutMapping("/upload_quality_inspection")
    public ResponseWrapper uploadQualityInspection(@RequestBody JSONObject data) {
        log.info("参数 -------> \n{}\n", JSON.toJSONString(data));
        if (data != null) {
            Long entrustInspectFid = data.getLong("entrustInspectFid");
            String inspectAttachment = data.getString("inspectAttachment");
            QualityInspectionVO qualityInspectionVO = data.getObject("qualityInspectionVO", QualityInspectionVO.class);
            int i = entrustInspectService.uploadQualityInspection(entrustInspectFid, inspectAttachment, qualityInspectionVO);
            return ResponseWrapper.success(i);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "检查委托是是否完成", notes = "")
    @GetMapping("/check_finish")
    public ResponseWrapper checkFinish(@RequestParam("xybh") String xybh, @RequestParam("houseId") String houseId) {
        log.info("check_finish 参数 >>>>>>>>>>>> \"xybh\": {}\n \"houseId\":{}", xybh, houseId);
        if (houseId != null && xybh != null) {
            return entrustInspectService.checkFinish(xybh, houseId);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    //>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> 质检报告

    @ApiOperation(value = "质检报告 分页查询列表", notes = "pageSize,pageNum从query传")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/report/selectQualityInspectionPageByEntity")
    public ResponseWrapper selectQualityInspectionPageByEntity(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                              @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                              @RequestParam(value = "pageType", defaultValue = "1") int pageType,
                                              @RequestBody JSONObject queryParams) {
        PageResult<QualityInspectionVO> page = entrustInspectService.selectQualityInspectionPageByEntity(pageNum, pageSize, pageType, queryParams);
        return ResponseWrapper.success(page);
    }

    @ApiImplicitParam(name = "fid", value = "pk", dataType = "String", paramType = "path")
    @ApiOperation(value = "质检报告查询详情", notes = "")
    @GetMapping("/report/selectById/{fid}")
    public ResponseWrapper selectReportById(@PathVariable("fid") Long fid) {
        if (fid != null) {
            log.info("{}", fid);
            QualityInspectionVO res = entrustInspectService.selectQualityInspectionById(fid);
            return ResponseWrapper.success(res);
        } else {
            return ResponseWrapper.invalid();
        }
    }


}
