package com.unis.quality.server.controller;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.dto.FoodStockDTO;
import com.unis.quality.server.service.FoodStockService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @ClassName: QualityPredictionAduitController
 * @Description: 安全监测-结果审核
 * @author lfx
 * @date 2019年7月10日14:57:38
 * 
 * @version v1.0
 */
@RestController
@Api(value = "安全监测-结果审核", tags = "安全监测-结果审核")
public class FoodStockController {

	@Autowired
	private FoodStockService foodStockService;

    /**
	 * @Description 根据id查询详情--质检档案（参数都必传）--自治区汇总（传类型,id）
	 * @version v1.0
	 * @author lfx	 * @date 2018/10/24
	 * @param id
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
/*	@ApiOperation(value = "根据id查询详细信息", notes = "参数：(id)")
	@RequestMapping(value = "findById", method = RequestMethod.GET)
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "id", paramType = "query"),
		@ApiImplicitParam(name = "zjda", value = "质检档案", paramType = "query"),
		@ApiImplicitParam(name = "type", value = "类型", paramType = "query"),
		@ApiImplicitParam(name = "batch", value = "批次", paramType = "query"),
		@ApiImplicitParam(name = "areaCode", value = "行政区划", paramType = "query")
	})
	public ResponseWrapper findById( @RequestParam("id") String id,@RequestParam (value="zjda",required=false)String zjda,
			@RequestParam ("type")String type,@RequestParam(value="batch",required=false)String batch,@RequestParam("areaCode")String areaCode) throws Exception{
		Map<String,Object> resultsVO = foodStockService.findByIdAndIsDeleted(id,zjda,type,batch,areaCode);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resultsVO);
	}*/
	
	@ApiOperation(value = "根据id查询详细信息", notes = "参数：(id)")
	@RequestMapping(value = "findById", method = RequestMethod.POST)
	public ResponseWrapper findById(@RequestBody FoodStockDTO fdto1) throws Exception{
		Map<String,Object> resultsVO = foodStockService.findByIdAndIsDeleted( fdto1);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resultsVO);
	}
	
	/**
	 * @Description 保存安全监测结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:00:33
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存安全监测结果审核", notes = "参数：aduitList")
	@PostMapping(value = "/save")
	public ResponseWrapper save(@RequestBody FoodStockDTO fDto) throws Exception{
		Map<String, Object> aduitList=fDto.getAduitList();
		Boolean flag = foodStockService.save(aduitList,fDto);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}

	/**
	 * @Description 更新安全监测-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:12:26
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新安全监测结果审核", notes = "参数：安全监测aduitList")
	@PostMapping(value = "/update")
	public ResponseWrapper update( @RequestBody FoodStockDTO fDto) throws Exception{
		Map<String, Object> aduitList=fDto.getAduitList();
		boolean flag = foodStockService.update(aduitList,fDto);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除", notes = "参数：id(可传入多个)")
	@PostMapping(value = "/deletes")
	public ResponseWrapper deletes(@RequestBody FoodStockDTO dto) throws Exception{
			Boolean flag = foodStockService.deletes(dto.getIds(),dto.getBatch(),dto.getAreaCode(),dto.getDeptName());
			if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "删除设备失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}

	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有结果审核", notes = "参数：承储企业名称、计划文件名称、当前页、页面大小")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPage/{page}/{size}")
	public ResponseWrapper findByPage(
			@RequestBody FoodStockDTO fDto, 
			@PathVariable Integer page,
			@PathVariable Integer size) throws Exception{
			Map<String, Object> result  = foodStockService.findByPage(fDto, page, size);
			return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}
	
	/**
	 * @Description 上报
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "上报", notes = "参数：id")
	@PostMapping(value = "/updateState")
	public ResponseWrapper updateState(@RequestBody FoodStockDTO fDto) throws Exception{
		Boolean flag = foodStockService.updateState(fDto);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}
	
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "样品信息同步", notes = "参数")
	@PostMapping(value = "/getSampleInformation")
	public ResponseWrapper getSampleInformation(@RequestBody FoodStockDTO fDto) throws Exception{
		List<Map> result  = foodStockService.getSampleInformation(fDto);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "结果汇总-盟市、旗县", notes = "参数")
	@PostMapping(value = "/getAll")
	public ResponseWrapper getAll(@RequestBody FoodStockDTO fDto) throws Exception{
		Map<String,Object> result  = foodStockService.getAll(fDto.getType(),fDto.getAreaCode());
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "质检档案-盟市、旗县", notes = "参数")
	@PostMapping(value = "/allInformation")
	public ResponseWrapper allInformation(@RequestBody FoodStockDTO fDto) throws Exception{
		Map<String,Object> result  = foodStockService.allInformation(fDto);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	
	/**
	 * @Description 检测业务查询统计     饼图-样品份数
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "检测业务查询统计     饼图-样品份数", notes = "参数")
	@GetMapping(value = "/sampleNumber/{years}")
	public ResponseWrapper sampleNumber(@PathVariable("years") String years) throws Exception{
		List<Map> result  = foodStockService.sampleNumber(years);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	
	/**
	 * @Description 检测业务查询统计     柱状图-储存品质总代表数量
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "检测业务查询统计     柱状图-储存品质总代表数量", notes = "参数")
	@GetMapping(value = "/natureNumber/{years}")
	public ResponseWrapper natureNumber(@PathVariable("years") String years) throws Exception{
		List<Map> result  = foodStockService.natureNumber(years);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	
	/**
	 * @Description 检测业务查询统计     柱状图-宜存率 
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "检测业务查询统计     柱状图-宜存率 ", notes = "参数")
	@GetMapping(value = "/suitableDeposit/{years}")
	public ResponseWrapper suitableDeposit(@PathVariable("years") String years) throws Exception{
		List<Map> result  = foodStockService.suitableDeposit(years);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
}
