package com.unis.quality.server.controller;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.FxlyCompanyVO;
import com.unis.quality.common.vo.OrganizationVO;
import com.unis.quality.server.service.FxlyCompanyService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @Description: 质检机构管理--机构信息
 * @ClassName: OrganizationController
 * @author lfx
 * @date 2018年10月26日16:20:35
 * 
 * @version v1.0
 */
@RestController
@Api(value = "质检机构管理--机构信息", tags = "质检机构管理--机构信息")
public class FxlyCompanyController {

	@Autowired
	private FxlyCompanyService fxlyCompanyService;
	
	/**
	 * 
	 * @Description: excel导入
	 * @date 2019年11月22日17:40:32
	 * @author lfx
	 * @version v1.0
	 * @param file
	 * @return
	 * @throws Exception 
	 */
	@PostMapping(value = "/importExcel")
	public ResponseWrapper importExcel(@RequestParam("fileName") MultipartFile file) throws Exception {
		Boolean flag = fxlyCompanyService.importExcel(file);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "导入失败");
    }
    return  ResponseWrapper.success(
            HttpStatus.OK.value(),
            HttpStatus.OK.getReasonPhrase(),
            null);
	}
	
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param Id
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "根据id查询机构信息", notes = "参数：机构信息id")
	@GetMapping(value = "/findComById/{qyxydm}")
	public ResponseWrapper findComById(@PathVariable("qyxydm") String qyxydm) throws Exception{
		FxlyCompanyVO organizationVO = fxlyCompanyService.findByIdAndIsDeleted(qyxydm);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                organizationVO);
	}
	
	/**
	 * @Description 保存
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存机构信息", notes = "参数：机构信息对象acquistionVO")
	@PostMapping(value = "/saveCom")
	public ResponseWrapper saveCom(@RequestBody FxlyCompanyVO organizationVO) throws Exception{
		boolean flag = fxlyCompanyService.save(organizationVO);
		if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "保存失败");
	    }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}
	@ApiOperation(value = "分页获取企业信息列表", notes = "参数：企业名称，企业类型")
	@PostMapping(value = "/companyPage/{pageNum}/{pageSize}")
    public ResponseWrapper getCompanyPage(@RequestBody FxlyCompanyVO fxlyCompanyVO,
										  @PathVariable("pageNum")Integer pageNum,
										  @PathVariable("pageSize") Integer pageSize) throws Exception {
		Map<String, Object> result = fxlyCompanyService.findByPage(fxlyCompanyVO, pageNum, pageSize);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	
	/**
	 * @author lfx
	 * @Description 修改企业信息
	 * @param companyVO 企业信息实体
	 * @return 新增状态
	 * @throws Exception 
	 */
	@PutMapping(value = "/company")
	@ApiOperation(value = "更新企业信息", notes = "参数：企业统一社会信用代码")
	public ResponseWrapper updatecompany(@RequestBody FxlyCompanyVO companyVO) throws Exception {
		boolean flag = fxlyCompanyService.update(companyVO);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "更新失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}
	
	
	@ApiOperation(value = "获取企业信息列表", notes = "参数：企业名称，企业类型")
	@PostMapping(value = "/findList")
    public ResponseWrapper findList(@RequestBody FxlyCompanyVO fxlyCompanyVO) throws Exception {
		List<FxlyCompanyVO> result = fxlyCompanyService.findList(fxlyCompanyVO);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
}
