package com.unis.quality.server.controller;

import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.OrganizationVO;
import com.unis.quality.server.service.OrganizationService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @Description: 质检机构管理--机构信息
 * @ClassName: OrganizationController
 * @author lfx
 * @date 2018年10月26日16:20:35
 * 
 * @version v1.0
 */
@RestController
@Api(value = "质检机构管理--机构信息", tags = "质检机构管理--机构信息")
public class OrganizationController {

	@Autowired
	private OrganizationService organizationService;
	
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param Id
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "根据id查询机构信息", notes = "参数：机构信息id")
	@GetMapping(value = "/findById/{id}")
	public ResponseWrapper findById(@PathVariable("id") String id) throws Exception{
		OrganizationVO organizationVO = organizationService.findByIdAndIsDeleted(id);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                organizationVO);
	}

	/**
	 * @Description 保存机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存机构信息", notes = "参数：机构信息对象acquistionVO")
	@PostMapping(value = "/saveOrg")
	public ResponseWrapper saveOrg(@RequestBody OrganizationVO organizationVO) throws Exception{
		boolean flag = organizationService.save(organizationVO);
		String id=organizationService.findByName(organizationVO.getOrganizationName());
		if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "该机构已存在无法添加");
	    }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                id);
	}
	/**
	 * @Description 更新机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新机构信息", notes = "参数：机构信息对象organizationVO")
	@PostMapping(value = "/updateOrg")
	public ResponseWrapper updateOrg(@RequestBody OrganizationVO organizationVO) throws Exception{
		boolean flag = organizationService.update(organizationVO);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "更新失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param Ids
	 * @date 2018/10/29
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除机构信息", notes = "参数：机构id(可传入多个)")
	@PostMapping(value = "/deletesOrg")
	public ResponseWrapper deletesOrg(@RequestBody OrganizationVO organizationVO) throws Exception{
		Boolean flag = organizationService.deletes(organizationVO.getIds(),organizationVO);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "删除机构失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}

	/**
	 * @Description 根据标题、创建人查询机构信息
	 * @version v1.0
	 * @author lfx
	 * @param OrganizationVO
	 * @date 2018/10/19
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有机构信息", notes = "参数：机构名称模糊查询、所属地区模糊查询、当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPageOrg/{page}/{size}")
	public ResponseWrapper findByPageOrg(
			@RequestBody OrganizationVO organizationVO, 
			@PathVariable Integer page,
			@PathVariable Integer size) throws Exception{
		Map<String, Object> result = organizationService.findByPage(organizationVO, page, size);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	
	
	
	
	
	
	
	//同步Myuser的机构
	@PostMapping(value = "/synMyUserOrg")
	public ResponseWrapper synMyUserOrg(@RequestBody ResponseWrapper requestWrapper) {
		Object data = requestWrapper.getData();
    	JSONArray contentJsonArr = JSONObject.parseArray(JsonUtils.serialize(data));
    	boolean result = false;
    	try {
			if(contentJsonArr != null && contentJsonArr.size() > 0) {
				result = organizationService.synMyuserOrg(contentJsonArr);
			}
		} catch (Exception e) {
			ResponseWrapper.error("同步机构异常");
			e.printStackTrace();
		}
		return ResponseWrapper.success(result);
	}
}
