package com.unis.quality.server.controller;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.PersonnelManagementVO;
import com.unis.quality.server.service.PersonnelManagementService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @Description: 质检机构管理--机构信息
 * @ClassName: OrganizationController
 * @author lfx
 * @date 2018年10月26日16:20:35
 * 
 * @version v1.0
 */
@RestController
@Api(value = "质检机构管理--人员信息", tags = "质检机构管理--人员信息")
public class PersonnelManagementController {

	@Autowired
	private PersonnelManagementService personnelManagementService;
	
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param Id
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "根据id查询人员信息", notes = "参数：organizationId")
	@GetMapping(value = "/findByIdPer/{organizationId}")
	public ResponseWrapper findByIdPer(@PathVariable("organizationId") String organizationId)  throws Exception{
		List<PersonnelManagementVO> list = personnelManagementService.findByIdAndIsDeleted(organizationId);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                list);
	}

	/**
	 * @Description 保存机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存人员信息", notes = "参数：人员信息对象List<PersonnelManagementVO>")
	@PostMapping(value = "/savePer")
	public ResponseWrapper savePer(@RequestBody PersonnelManagementVO vo) throws Exception{
		boolean flag = personnelManagementService.save(vo.getPersonnelManagementVOlist(),vo);
		if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "该人员已存在无法添加");
	    }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}
	/**
	 * @Description 更新机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新人员信息", notes = "参数：人员信息对象personnelManagementVO")
	@PostMapping(value = "/updatePer")
	public ResponseWrapper updatePer(@RequestBody PersonnelManagementVO vo) throws Exception{
		boolean flag = personnelManagementService.update(vo.getPersonnelManagementVOlist(),vo);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "更新失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param Ids
	 * @date 2018/10/29
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除人员信息", notes = "参数：organizationId(可传入多个)")
	@PostMapping(value = "/deletesPer")
	public ResponseWrapper deletesPer(@RequestBody PersonnelManagementVO vo) throws Exception{
		Boolean flag = personnelManagementService.deletes(vo.getIds(),vo);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "删除人员失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}

	/**
	 * @Description 根据标题、创建人查询机构信息
	 * @version v1.0
	 * @author lfx
	 * @param OrganizationVO
	 * @date 2018/10/19
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有人员信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPagePer/{page}/{size}")
	public ResponseWrapper findByPagePer(
			@RequestBody PersonnelManagementVO personnelManagementVO, 
			@PathVariable Integer page,
			@PathVariable Integer size) throws Exception{
		Map<String, Object> result = personnelManagementService.findByPage(personnelManagementVO, page, size);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	
	
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 同步base-server中的人员--化验
	 * @Date 2020年3月10日 下午3:47:24
	 * @param requestWrapper
	 * @return ResponseWrapper
	 */
	@PostMapping(value = "/synBaseServerPerson")
	public ResponseWrapper synBaseServerPerson(@RequestBody ResponseWrapper requestWrapper) {
    	JSONArray contentJsonArr = JSONObject.parseArray(JsonUtils.serialize(requestWrapper.getData()));
    	boolean result = false;
    	try {
			if(contentJsonArr != null && contentJsonArr.size() > 0) {
				result = personnelManagementService.synBaseServerPerson(contentJsonArr);
			}
		} catch (Exception e) {
			ResponseWrapper.error("同步人员异常");
			e.printStackTrace();
		}
		return ResponseWrapper.success(result);
	}
}
