package com.unis.quality.server.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.base.PageResult;
import com.unis.quality.common.constant.ApiTag;
import com.unis.quality.common.vo.QualityOpinionInVO;
import com.unis.quality.common.vo.QualityOpinionOutVO;
import com.unis.quality.server.service.QualityOpinionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Collections;
import java.util.Map;

/**
 * @author by PIG
 * 2023/10/30 09
 */
@Api(value = "质检意见", tags = {ApiTag.QUALITY_OPINION})
@RestController
@RequestMapping(value = "/quality_opinion")
@Log4j2
public class QualityOpinionController {

    @Autowired
    private QualityOpinionService qualityOpinionService;


    @ApiOperation(value = "质检意见 创建", notes = "")
    @PostMapping("/in/create_quality_opinion")
    public ResponseWrapper createQualityOpinion(@RequestBody QualityOpinionInVO entity) {
        if (entity != null) {
            log.info("质检意见 创建 参数 >>>>>>>>>>>> {}", JSON.toJSONString(entity));
            if (null == entity.getYsbgbh()) {
                return ResponseWrapper.invalid();
            }
            if (null == entity.getNodeId()) {
                entity.initNode();
            }
            Map<String, Object> data = qualityOpinionService.createQualityOpinion(entity);
            return ResponseWrapper.success(data);
        } else {
            return ResponseWrapper.invalid();
        }
    }


    @ApiOperation(value = "质检意见 分页查询列表", notes = "pageSize,pageNum从url传", tags = {ApiTag.SANG_FANG})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/in/selectPageByEntity")
    public ResponseWrapper selectInOpinionPageByEntity(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                       @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                                       @RequestParam(value = "pageType", defaultValue = "1") int pageType,
                                                       @RequestBody JSONObject queryParams) {
        PageResult<QualityOpinionInVO> page = qualityOpinionService.selectInOpinionPageByEntity(pageNum, pageSize, pageType, queryParams);
        return ResponseWrapper.success(page);
    }

    @ApiImplicitParam(name = "fid", value = "pk", dataType = "String", paramType = "path")
    @ApiOperation(value = "质检意见 查询详情", notes = "")
    @GetMapping("/in/selectById/{fid}")
    public ResponseWrapper selectInOpinionById(@PathVariable("fid") Long fid) {
        if (fid != null) {
            log.info("{}", fid);
            QualityOpinionInVO res = qualityOpinionService.selectInOpinionById(fid);
            Map<String, Object> data = Collections.singletonMap("res", res);
            return ResponseWrapper.success(data);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "质检意见 修改", notes = "")
    @PutMapping("/in/updateByEntitySelective")
    public ResponseWrapper updateInOpinion(@RequestBody QualityOpinionInVO entity) {
        if (entity != null) {
            log.info("updateByEntitySelective 参数 >>>>>>>>>>>> {}", JSON.toJSONString(entity));

            int i = qualityOpinionService.updateInOpinion(entity);
            return ResponseWrapper.success(i);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @GetMapping("/in/change_quality_opinion_node")
    public ResponseWrapper changeQualityOpinionNode(@RequestParam("ysbgbh")String ysbgbh){
        log.info("验收报告编号 ================>\n{}", ysbgbh);
        if (null == ysbgbh) {
            return ResponseWrapper.invalid();
        }
        return qualityOpinionService.changeQualityOpinionNode(ysbgbh);
    }

    @ApiImplicitParam(name = "ysbgbh", value = "pk", dataType = "String", paramType = "path")
    @ApiOperation(value = "质检意见 查询详情", notes = "")
    @GetMapping("/in/selectByYsbgbh/{ysbgbh}")
    public ResponseWrapper selectInOpinionByYsbgbh(@PathVariable("ysbgbh") String ysbgbh) {
        if (ysbgbh != null) {
            log.info("{}", ysbgbh);
            QualityOpinionInVO res = qualityOpinionService.selectInOpinionByYsbgbh(ysbgbh);
            return ResponseWrapper.success(res);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "质检意见 修改", notes = "")
    @PutMapping("/out/updateByEntitySelective")
    public ResponseWrapper updateOutOpinion(@RequestBody QualityOpinionOutVO entity) {
        if (entity != null) {
            log.info("updateByEntitySelective 参数 >>>>>>>>>>>> {}", JSON.toJSONString(entity));

            int i = qualityOpinionService.updateOutOpinion(entity);
            return ResponseWrapper.success(i);
        } else {
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "质检意见 分页查询列表", notes = "pageSize,pageNum从url传", tags = {ApiTag.SANG_FANG})
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/out/selectPageByEntity")
    public ResponseWrapper selectOutOpinionPageByEntity(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                       @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                                       @RequestParam(value = "pageType", defaultValue = "1") int pageType,
                                                       @RequestBody JSONObject queryParams) {
        PageResult<QualityOpinionOutVO> page = qualityOpinionService.selectOutOpinionPageByEntity(pageNum, pageSize, pageType, queryParams);
        return ResponseWrapper.success(page);
    }

    @ApiImplicitParam(name = "fid", value = "pk", dataType = "String", paramType = "path")
    @ApiOperation(value = "质检意见 查询详情", notes = "")
    @GetMapping("/out/selectById/{fid}")
    public ResponseWrapper selectOutOpinionById(@PathVariable("fid") Long fid) {
        if (fid != null) {
            log.info("{}", fid);
            QualityOpinionOutVO res = qualityOpinionService.selectOutOpinionById(fid);
            Map<String, Object> data = Collections.singletonMap("res", res);
            return ResponseWrapper.success(res);
        } else {
            return ResponseWrapper.invalid();
        }
    }

}
