package com.unis.quality.server.controller;

import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.QualityPredictionAduitVO;
import com.unis.quality.server.service.QualityPredictionAduitService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @ClassName: QualityPredictionAduitController
 * @Description: 品质测报-结果审核
 * @author lfx
 * @date 2019年7月10日14:57:38
 * 
 * @version v1.0
 */
@RestController
@Api(value = "品质测报-结果审核", tags = "品质测报-结果审核")
public class QualityPredictionAduitController {

	@Autowired
	private QualityPredictionAduitService qualityResultsService;

    /**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx	 * @date 2018/10/24
	 * @param id
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "根据id查询详细信息", notes = "参数：(id)")
	@GetMapping(value = "/findByIdAduit/{id}/{batch}")
	public ResponseWrapper findByIdAduit(@PathVariable("id") String id,@PathVariable("batch") String batch) throws Exception{

			Map<String,Object> resultsVO = qualityResultsService.findByIdAndIsDeleted(id,batch);
			return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                resultsVO);
	}

	/**
	 * @Description 保存品质测报结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:00:33
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存品质测报结果审核", notes = "参数：aduitList")
	@PostMapping(value = "/saveAduit")
	public ResponseWrapper saveAduit(@RequestBody QualityPredictionAduitVO vo) throws Exception{
		Map<String, Object> aduitList=vo.getAduitList();
		boolean flag = qualityResultsService.save(aduitList,vo);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "该结果已存在无法添加");
	    }
	    return  ResponseWrapper.success(
	            HttpStatus.OK.value(),
	            HttpStatus.OK.getReasonPhrase(),
	            null);
	}

	/**
	 * @Description 更新品质测报-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:12:26
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新品质测报结果审核", notes = "参数：品质测报aduitList")
	@PostMapping(value = "/updateAduit")
	public ResponseWrapper updateAduit(@RequestBody QualityPredictionAduitVO vo) throws Exception{
		Map<String, Object> aduitList=vo.getAduitList();
		boolean flag = qualityResultsService.update(aduitList,vo);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除", notes = "参数：id(可传入多个)")
	@PostMapping(value = "/deletesAduit")
	public ResponseWrapper deletesAduit(@RequestBody QualityPredictionAduitVO vo) throws Exception{
		String[] ids=vo.getIds();
		Boolean flag = qualityResultsService.deletes(ids,vo);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);	
	}

	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有结果审核", notes = "参数：承储企业名称、计划文件名称、当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPageAduit/{page}/{size}")
	public ResponseWrapper findByPageAduit(
			@RequestBody QualityPredictionAduitVO qualityVO,
			@PathVariable Integer page,
			@PathVariable Integer size) throws Exception{
			Map<String, Object> result  = qualityResultsService.findByPage(qualityVO, page, size);
			return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}
	
	/**
	 * @Description 上报
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "上报", notes = "参数：id")
	@PostMapping(value = "/updateStateAduit")
	public ResponseWrapper updateStateAduit(@RequestBody QualityPredictionAduitVO vo) throws Exception{
		Boolean flag = qualityResultsService.updateState(vo);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}
	
	/**
	 * @Description 移动端-新收获粮分类汇总统计
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	@ApiOperation(value = "移动端-新收获粮分类汇总统计", notes = "参数：(years)")
	@GetMapping(value = "/qualityHarvestCorn/{years}")
	public ResponseWrapper qualityHarvestCorn(@PathVariable("years") String years) throws Exception {
		Map<String,Object> map = qualityResultsService.qualityHarvestCorn(years);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                map);
	}
	/**
	 * @Description 移动端-按企业、企业总数、合格率
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	@ApiOperation(value = "移动端-按企业、企业总数、合格率", notes = "参数：")
	@PostMapping(value = "/company")
	public ResponseWrapper company() throws Exception {
		Map<String,Object> map = qualityResultsService.company();
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                map);
	}
	
	/**
	 * @Description 移动端-按品种、企业总数、合格率
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	@ApiOperation(value = "移动端-按品种、企业总数、合格率", notes = "参数：")
	@GetMapping(value = "/varieties/{varieties}")
	public ResponseWrapper varieties(@PathVariable("varieties") String varieties) throws Exception {
		Map<String,Object> map = qualityResultsService.varieties(varieties);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                map);
	}
}
