package com.unis.quality.server.controller;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.TestParametersVO;
import com.unis.quality.server.service.TestParametersService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @ClassName: TestParametersController
 * @Description: 质检机构管理--检验信息
 * @author lfx
 * @date 2018年10月30日10:34:20
 * 
 * @version v1.0
 */
@RestController
@Api(value = "质检机构管理--检验信息", tags = "质检机构管理--检验信息")
public class TestParametersController {
	@Autowired
	private TestParametersService testParametersService;
	

	/**
	 * @Description 根据id查询人员详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:18:35
	 * @param id
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "根据id查询信息", notes = "参数：organizationId")
	@GetMapping(value = "/findByIdTest/{organizationId}")
	public ResponseWrapper findByIdTest(@PathVariable("organizationId") String organizationId) throws Exception{
		List<TestParametersVO> list = testParametersService.findByIdAndIsDeleted(organizationId);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                list);
	}

	/**
	 * @Description 保存信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:43
	 * @param PersonnelManagementVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "保存检验信息", notes = "参数：检验信息对象List<TestParametersVO>")
	@PostMapping(value = "/saveTestp")
	public ResponseWrapper saveTestp(@RequestBody TestParametersVO vo) throws Exception{
		boolean flag =  testParametersService.save(vo.getTestParametersVOlist(),vo);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "该检验信息已存在无法添加");
	    }
	    return  ResponseWrapper.success(
	            HttpStatus.OK.value(),
	            HttpStatus.OK.getReasonPhrase(),
	            null);	
	}

	/**
	 * @Description 更新信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:37
	 * @param PersonnelManagementVO
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "更新检验信息", notes = "参数：检验信息对象TestParametersVO")
	@PostMapping(value = "/updateTest")
	public ResponseWrapper updateTest(@RequestBody TestParametersVO vo) throws Exception{

		boolean flag = testParametersService.update(vo.getTestParametersVOlist(),vo);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);	

	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:45
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "删除检验信息", notes = "参数：organizationId(可传入多个)")
	@PostMapping(value = "/deletesTest")
	public ResponseWrapper deletesTest(@RequestBody TestParametersVO vo) throws Exception{
		Boolean flag = testParametersService.deletes(vo.getIds(),vo);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "删除检验信息失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);	
	}


	/**
	 * @Description 查询检验信息、分页
	 * @version v1.0
	 * @author lfx
	 * @param PersonnelManagementVO
	 * @date 2018年10月30日10:38:06
	 * @return ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询所有检验信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPageTest/{page}/{size}")
	public ResponseWrapper findByPageTest(
			@RequestBody TestParametersVO testParametersVO,
			@PathVariable Integer page,
			@PathVariable Integer size) throws Exception{
			// 模糊查询的条件可以包含，标题模糊查询、创建人模糊查询
			Map<String, Object> result = testParametersService.findByPage(testParametersVO, page, size);
			return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}
}
