/*
 * AbnormalController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-05-12 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.controller.abnormal;

import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.quality.common.vo.abnormal.AbnormalListVO;
import com.unis.quality.common.vo.abnormal.AbnormalShowVO;
import com.unis.quality.common.vo.abnormal.AbnormalVO;
import com.unis.quality.server.service.AbnormalService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

//import org.springframework.web.bind.annotation.GetMapping;

/**
 * TY_YCQKZGTZ-异常情况整改通知
 * @author lipenghe at 2020-05-12 17:01:50
 */
@RestController
@RequestMapping("/manager")
@Api( tags = "异常情况---异常情况整改通知")
public class AbnormalController {

    @Autowired
    private AbnormalService abnormalService;

    @ApiOperation(value = "异常情况---异常情况整改通知---选择性插入字段", notes = "异常情况整改通知")
    @PostMapping("/abnormal/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(
        @Validated({InsertGroup.class}) @RequestBody AbnormalVO abnormalVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return abnormalService.insertEntitySelectiveResult(abnormalVO);
        }
    }

    @ApiOperation(value = "异常情况---异常情况整改通知----根据实体不为空的属性,选择性更新字段", notes = "异常情况整改通知")
    @PostMapping("/abnormal/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody AbnormalVO abnormalVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return abnormalService.updateByEntitySelectiveResult(abnormalVO,null);
        }
    }

    @ApiOperation(value = "异常情况---异常情况整改通知---根据实体不为空的属性,选择性更新字段,只更新主表", notes = "异常情况整改通知")
    @PostMapping("/abnormal/updateSingleByEntitySelective")
    public ResponseWrapper updateSingleByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody AbnormalVO abnormalVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return abnormalService.updateSingleByEntitySelectiveResult(abnormalVO,null);
        }
    }

    @ApiOperation(value = "异常情况---异常情况整改通知---更改状态", notes = "异常情况整改通知")
    @PostMapping("/abnormal/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(
        @RequestBody AbnormalVO abnormalVO) {
        if(abnormalVO!=null){
            return abnormalService.updateStatusByEntityResult(abnormalVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "异常情况---异常情况整改通知---[真删除]根据实体的某些属性进行单条或者批量删除", notes = "异常情况整改通知")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "ycqkid", value = "异常情况id#<主键><唯一><非空>", dataType = "String", paramType = "header")
    })
    @PostMapping("/abnormal/deleteByEntity")
    public ResponseWrapper deleteByEntity(
        @RequestBody AbnormalShowVO abnormalShowVO){
        if(abnormalShowVO!=null){
            AbnormalVO abnormalVO= JsonUtils.parse(
                JsonUtils.serialize(abnormalShowVO), AbnormalVO.class);
            abnormalVO.setStatus(Integer.valueOf(BaseStatusConstant.STATUS_DELETED));
            return abnormalService.deleteByEntityResult(abnormalVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "异常情况---异常情况整改通知---根据实体(唯一标示)查询一条数据", notes = "异常情况整改通知")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "ycqkid", value = "异常情况id#<主键><唯一><非空>", dataType = "String", paramType = "header")
    })
    @PostMapping("/abnormal/selectById")
    public ResponseWrapper selectById(
        @RequestBody AbnormalShowVO abnormalShowVO){
        if(abnormalShowVO!=null){
            AbnormalVO abnormalVO= JsonUtils.parse(
                JsonUtils.serialize(abnormalShowVO), AbnormalVO.class);
            return abnormalService.selectByIdResult(abnormalVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "异常情况---异常情况整改通知---根据实体的某些属性查询分页数据,pageSize,pageNum从url传", notes = "异常情况整改通知")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/abnormal/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody AbnormalListVO abnormalListVO) {
        AbnormalVO abnormalVO= JsonUtils.parse(
            JsonUtils.serialize(abnormalListVO), AbnormalVO.class);
        return abnormalService.selectPageByEntityResult(pageNum,pageSize
            , abnormalVO,"YCQKID DESC");
    }

    @ApiOperation(value = "异常情况---异常情况整改通知---根据实体的某些属性查询列表", notes = "异常情况整改通知")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/abnormal/selectByEntity")
    public ResponseWrapper selectByEntity(
        @RequestBody AbnormalListVO abnormalListVO) {
        AbnormalVO abnormalVO= JsonUtils.parse(
            JsonUtils.serialize(abnormalListVO), AbnormalVO.class);
        return abnormalService.selectByEntityResult(abnormalVO);
    }

    @ApiOperation(value = "异常情况---异常情况整改通知---初始化数据", notes = "异常情况整改通知")
    @PostMapping("/abnormal/selectInitData")
    public ResponseWrapper selectInitData(
        @RequestBody AbnormalVO abnormalVO){
        if(abnormalVO!=null){
            return abnormalService.selectInitDataResult(abnormalVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
