/*
 * CheckstandardInfoController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-20 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.controller.standard;

import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.quality.common.vo.standard.CheckstandardInfoListVO;
import com.unis.quality.common.vo.standard.CheckstandardInfoShowVO;
import com.unis.quality.common.vo.standard.CheckstandardInfoVO;
import com.unis.quality.server.service.CheckstandardInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

//import org.springframework.web.bind.annotation.GetMapping;

/**
 * CHECKSTANDARD_INFO-标准信息
 * @author lipenghe at 2020-08-20 22:44:51
 */
@RestController
@RequestMapping("/manager/standard")
@Api( tags = "标准信息---标准信息")
public class StandardInfoController {

    @Autowired
    private CheckstandardInfoService checkstandardInfoService;

    @ApiOperation(value = "标准信息---标准信息---选择性保存,包含新增和修改", notes = "标准信息")
    @PostMapping("/checkstandardInfo/saveEntitySelective")
    public ResponseWrapper saveEntitySelective(
        @RequestBody CheckstandardInfoVO checkstandardInfoVO) {
        return checkstandardInfoService.saveEntitySelectiveResult(checkstandardInfoVO);
    }

    @ApiOperation(value = "标准信息---标准信息---选择性插入字段", notes = "标准信息")
    @PostMapping("/checkstandardInfo/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(
        @Validated({InsertGroup.class}) @RequestBody CheckstandardInfoVO checkstandardInfoVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return checkstandardInfoService.insertEntitySelectiveResult(checkstandardInfoVO);
        }
    }

    @ApiOperation(value = "标准信息---标准信息----根据实体不为空的属性,选择性更新字段", notes = "标准信息")
    @PostMapping("/checkstandardInfo/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody CheckstandardInfoVO checkstandardInfoVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return checkstandardInfoService.updateByEntitySelectiveResult(checkstandardInfoVO,null);
        }
    }

    @ApiOperation(value = "标准信息---标准信息---根据实体不为空的属性,选择性更新字段,只更新主表", notes = "标准信息")
    @PostMapping("/checkstandardInfo/updateSingleByEntitySelective")
    public ResponseWrapper updateSingleByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody CheckstandardInfoVO checkstandardInfoVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return checkstandardInfoService.updateSingleByEntitySelectiveResult(checkstandardInfoVO,null);
        }
    }

    @ApiOperation(value = "标准信息---标准信息---更改状态", notes = "标准信息")
    @PostMapping("/checkstandardInfo/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(
        @RequestBody CheckstandardInfoVO checkstandardInfoVO) {
        if(checkstandardInfoVO!=null){
            return checkstandardInfoService.updateStatusByEntityResult(checkstandardInfoVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "标准信息---标准信息---[真删除]根据实体的某些属性进行单条或者批量删除", notes = "标准信息")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "checkstandardId", value = "标准id#<主键><唯一><非空>", dataType = "String", paramType = "header")
    })
    @PostMapping("/checkstandardInfo/deleteByEntity")
    public ResponseWrapper deleteByEntity(
        @RequestBody CheckstandardInfoShowVO checkstandardInfoShowVO){
        if(checkstandardInfoShowVO!=null){
            CheckstandardInfoVO checkstandardInfoVO= JsonUtils.parse(
                JsonUtils.serialize(checkstandardInfoShowVO), CheckstandardInfoVO.class);
            checkstandardInfoVO.setStatus(Integer.valueOf(BaseStatusConstant.STATUS_DELETED));
            return checkstandardInfoService.deleteByEntityResult(checkstandardInfoVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "标准信息---标准信息---根据实体(唯一标示)查询一条数据", notes = "标准信息")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "checkstandardId", value = "标准id#<主键><唯一><非空>", dataType = "String", paramType = "header")
    })
    @PostMapping("/checkstandardInfo/selectById")
    public ResponseWrapper selectById(
        @RequestBody CheckstandardInfoShowVO checkstandardInfoShowVO){
        if(checkstandardInfoShowVO!=null){
            CheckstandardInfoVO checkstandardInfoVO= JsonUtils.parse(
                JsonUtils.serialize(checkstandardInfoShowVO), CheckstandardInfoVO.class);
            return checkstandardInfoService.selectByIdResult(checkstandardInfoVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "标准信息---标准信息---根据实体的某些属性查询分页数据,pageSize,pageNum从url传", notes = "标准信息")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/checkstandardInfo/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody CheckstandardInfoListVO checkstandardInfoListVO) {
        CheckstandardInfoVO checkstandardInfoVO= JsonUtils.parse(
            JsonUtils.serialize(checkstandardInfoListVO), CheckstandardInfoVO.class);
        return checkstandardInfoService.selectPageByEntityResult(pageNum,pageSize
            , checkstandardInfoVO,"CHECKSTANDARD_ID DESC");
    }

    @ApiOperation(value = "标准信息---标准信息---根据实体的某些属性查询列表", notes = "标准信息")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/checkstandardInfo/selectByEntity")
    public ResponseWrapper selectByEntity(
        @RequestBody CheckstandardInfoListVO checkstandardInfoListVO) {
        CheckstandardInfoVO checkstandardInfoVO= JsonUtils.parse(
            JsonUtils.serialize(checkstandardInfoListVO), CheckstandardInfoVO.class);
        return checkstandardInfoService.selectByEntityResult(checkstandardInfoVO);
    }

    @ApiOperation(value = "标准信息---标准信息---初始化数据", notes = "标准信息")
    @PostMapping("/checkstandardInfo/selectInitData")
    public ResponseWrapper selectInitData(
        @RequestBody CheckstandardInfoVO checkstandardInfoVO){
        if(checkstandardInfoVO!=null){
            return checkstandardInfoService.selectInitDataResult(checkstandardInfoVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
