/*
 * CheckstandardItemController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-20 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.controller.standard;

import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.quality.common.vo.standard.CheckstandardItemListVO;
import com.unis.quality.common.vo.standard.CheckstandardItemShowVO;
import com.unis.quality.common.vo.standard.CheckstandardItemVO;
import com.unis.quality.server.service.CheckstandardItemService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

//import org.springframework.web.bind.annotation.GetMapping;

/**
 * CHECKSTANDARD_ITEM-标准详情
 * @author lipenghe at 2020-08-20 22:44:51
 */
@RestController
@RequestMapping("/manager/standard")
@Api( tags = "标准详情---标准详情")
public class StandardItemController {

    @Autowired
    private CheckstandardItemService checkstandardItemService;

    @ApiOperation(value = "标准详情---标准详情---选择性保存,包含新增和修改", notes = "标准详情")
    @PostMapping("/checkstandardItem/saveEntitySelective")
    public ResponseWrapper saveEntitySelective(
        @RequestBody CheckstandardItemVO checkstandardItemVO) {
        return checkstandardItemService.saveEntitySelectiveResult(checkstandardItemVO);
    }

    @ApiOperation(value = "标准详情---标准详情---选择性插入字段", notes = "标准详情")
    @PostMapping("/checkstandardItem/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(
        @Validated({InsertGroup.class}) @RequestBody CheckstandardItemVO checkstandardItemVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return checkstandardItemService.insertEntitySelectiveResult(checkstandardItemVO);
        }
    }

    @ApiOperation(value = "标准详情---标准详情----根据实体不为空的属性,选择性更新字段", notes = "标准详情")
    @PostMapping("/checkstandardItem/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody CheckstandardItemVO checkstandardItemVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return checkstandardItemService.updateByEntitySelectiveResult(checkstandardItemVO,null);
        }
    }

    @ApiOperation(value = "标准详情---标准详情---根据实体不为空的属性,选择性更新字段,只更新主表", notes = "标准详情")
    @PostMapping("/checkstandardItem/updateSingleByEntitySelective")
    public ResponseWrapper updateSingleByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody CheckstandardItemVO checkstandardItemVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return checkstandardItemService.updateSingleByEntitySelectiveResult(checkstandardItemVO,null);
        }
    }

    @ApiOperation(value = "标准详情---标准详情---更改状态", notes = "标准详情")
    @PostMapping("/checkstandardItem/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(
        @RequestBody CheckstandardItemVO checkstandardItemVO) {
        if(checkstandardItemVO!=null){
            return checkstandardItemService.updateStatusByEntityResult(checkstandardItemVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "标准详情---标准详情---[真删除]根据实体的某些属性进行单条或者批量删除", notes = "标准详情")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "itemId", value = "项目id#<主键><唯一><非空>", dataType = "String", paramType = "header")
    })
    @PostMapping("/checkstandardItem/deleteByEntity")
    public ResponseWrapper deleteByEntity(
        @RequestBody CheckstandardItemShowVO checkstandardItemShowVO){
        if(checkstandardItemShowVO!=null){
            CheckstandardItemVO checkstandardItemVO= JsonUtils.parse(
                JsonUtils.serialize(checkstandardItemShowVO), CheckstandardItemVO.class);
            checkstandardItemVO.setStatus(Integer.valueOf(BaseStatusConstant.STATUS_DELETED));
            return checkstandardItemService.deleteByEntityResult(checkstandardItemVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "标准详情---标准详情---根据实体(唯一标示)查询一条数据", notes = "标准详情")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "itemId", value = "项目id#<主键><唯一><非空>", dataType = "String", paramType = "header")
    })
    @PostMapping("/checkstandardItem/selectById")
    public ResponseWrapper selectById(
        @RequestBody CheckstandardItemShowVO checkstandardItemShowVO){
        if(checkstandardItemShowVO!=null){
            CheckstandardItemVO checkstandardItemVO= JsonUtils.parse(
                JsonUtils.serialize(checkstandardItemShowVO), CheckstandardItemVO.class);
            return checkstandardItemService.selectByIdResult(checkstandardItemVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "标准详情---标准详情---根据实体的某些属性查询分页数据,pageSize,pageNum从url传", notes = "标准详情")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/checkstandardItem/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody CheckstandardItemListVO checkstandardItemListVO) {
        CheckstandardItemVO checkstandardItemVO= JsonUtils.parse(
            JsonUtils.serialize(checkstandardItemListVO), CheckstandardItemVO.class);
        return checkstandardItemService.selectPageByEntityResult(pageNum,pageSize
            , checkstandardItemVO,"ITEM_ID DESC");
    }

    @ApiOperation(value = "标准详情---标准详情---根据实体的某些属性查询列表", notes = "标准详情")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/checkstandardItem/selectByEntity")
    public ResponseWrapper selectByEntity(
        @RequestBody CheckstandardItemListVO checkstandardItemListVO) {
        CheckstandardItemVO checkstandardItemVO= JsonUtils.parse(
            JsonUtils.serialize(checkstandardItemListVO), CheckstandardItemVO.class);
        return checkstandardItemService.selectByEntityResult(checkstandardItemVO);
    }

    @ApiOperation(value = "标准详情---标准详情---初始化数据", notes = "标准详情")
    @PostMapping("/checkstandardItem/selectInitData")
    public ResponseWrapper selectInitData(
        @RequestBody CheckstandardItemVO checkstandardItemVO){
        if(checkstandardItemVO!=null){
            return checkstandardItemService.selectInitDataResult(checkstandardItemVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
