package com.unis.quality.server.controller.tianjin;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.quality.common.vo.EntrustVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.dto.CheckSchemeDTO;
import com.unis.quality.common.dto.ViewSituationDTO;
import com.unis.quality.common.vo.tianjin.QualityHarvestCornVO;
import com.unis.quality.server.entity.quality.tianjin.QualityHarvestCornDO;
import com.unis.quality.server.service.tianjin.QualityHarvestCornService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @ClassName: QualityHarvestCornController
 * @Description: 品质测报-抽样方案
 * @author lfx
 * @date 2019年7月10日15:01:34
 * 
 * @version v1.0
 */
@RestController
@Api(value = "抽样方案Controller", tags = "抽样方案Controller")
public class QualityHarvestCornController {

	@Autowired
	private QualityHarvestCornService service;
	

	/**
	 * @Description 根据id查询
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日14:17:21
	 * @param id
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据id查询信息", notes = "参数：id")
	@PostMapping(value = "/findByIdHarvestCorn")
	public ResponseWrapper findByIdHarvestCorn(@RequestBody CheckSchemeDTO dto)  throws Exception{
		Map<String,Object> map =service.findById(dto);
		System.out.println(map);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                map);
	}

	/**
	 * @Description 保存信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @param QualityHarvestCornVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "保存信息", notes = "参数：信息对象CheckSchemeDTO")
	@PostMapping(value = "/saveHarvestCorn")
	public ResponseWrapper saveHarvestCorn(@RequestBody CheckSchemeDTO vo) throws Exception {
		boolean flag = service.save(vo.getAduitList(),vo);
		Map<String,Object> aduitData=(Map<String,Object>)vo.getAduitList().get("aduitData");
		String id=service.queryFabt(aduitData.get("fabt")+"",aduitData.get("wtlx")+"");
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "该名称已存在无法添加或缺少详情数据");
        }else{
			return  ResponseWrapper.success(
					HttpStatus.OK.value(),
					HttpStatus.OK.getReasonPhrase(),
					id);
		}
	}

	/**
	 * @Description 更新信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:49
	 * @param QualityHarvestCornVO
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "更新信息", notes = "参数：信息对象QualityHarvestCornVO")
	@PutMapping(value = "/updateHarvestCorn")
	public ResponseWrapper updateHarvestCorn(@RequestBody QualityHarvestCornVO vo) throws Exception{
		boolean flag = service.update(vo.getAduitList(),vo);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "更新失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:56
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "删除信息", notes = "参数：ids(可传入多个)")
	@DeleteMapping(value = "/deleteHarvestCorn")
	public ResponseWrapper deleteHarvestCorn(@RequestBody String ids[]) throws Exception{
	 	 Boolean flag = service.deletes(ids);
		 if (!flag) {
	            return ResponseWrapper.error(
	                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
	                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
	                    "删除信息失败");
	        }
	        return  ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                null);
	}


	/**
	 * @Description 查询、分页
	 * @version v1.0
	 * @author lfx
	 * @param QualityHarvestCornVO
	 * @param page
	 * @param size
	 * @date 2018年10月30日15:01:37
	 * @return ResponseWrapper
	 * @throws Exception
	 */
	@ApiOperation(value = "查询信息", notes = "参数：当前页、页面大小")
	@ApiImplicitParams({ 
		@ApiImplicitParam(name = "page", value = "起始页", required = true),
		@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPageHarvestCorn")
	public ResponseWrapper findByPageHarvestCorn(@RequestBody CheckSchemeDTO vo,
			@RequestParam ("page") Integer page,
			@RequestParam ("size") Integer size) throws Exception{
		Map<String, Object> result = service.findByPage(vo, page, size);
		return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                result);
	}
	
	
	/**
	 * @Description 上报
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "发布", notes = "参数：id")
	@PutMapping(value = "/updateStateCorn/{id}")
	public ResponseWrapper updateState(@PathVariable("id") String id) throws Exception{
		Boolean flag = service.updateState(id);
		if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "发布失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
	}
	
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "查询计划文件名", notes = "参数：计划类型")
	@GetMapping(value = "/getProgramme")
	public ResponseWrapper getFlieName() throws Exception{
		List<QualityHarvestCornDO> result  = service.getFlieName();
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
}
