/*
 * RainController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-11 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.controller.weather;

import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.base.PageResult;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.quality.common.vo.weather.RainListVO;
import com.unis.quality.common.vo.weather.RainShowVO;
import com.unis.quality.common.vo.weather.RainVO;
import com.unis.quality.common.vo.weather.TianQiResult;
import com.unis.quality.server.service.RainService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

//import org.springframework.web.bind.annotation.GetMapping;

/**
 * PLUG_WEATHER_RAIN-降雨量表
 * @author lipenghe at 2020-08-11 17:08:12
 */
@RestController
@RequestMapping("/manager/weather")
@Api( tags = "天气-降雨量---降雨量表")
public class RainController {

    @Autowired
    private RainService rainService;

    @ApiOperation(value = "天气-降雨量---降雨量表---选择性插入字段", notes = "天气-降雨量")
    @PostMapping("/rain/saveSelective")
    public ResponseWrapper saveSelective(@RequestBody List<TianQiResult> tianQiResultList
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return rainService.saveSelective(tianQiResultList);
        }
    }

    @ApiOperation(value = "天气-降雨量---降雨量表---选择性插入字段", notes = "天气-降雨量")
    @PostMapping("/rain/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(
        @Validated({InsertGroup.class}) @RequestBody RainVO rainVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return rainService.insertEntitySelectiveResult(rainVO);
        }
    }

    @ApiOperation(value = "天气-降雨量---降雨量表----根据实体不为空的属性,选择性更新字段", notes = "天气-降雨量")
    @PostMapping("/rain/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody RainVO rainVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return rainService.updateByEntitySelectiveResult(rainVO,null);
        }
    }

    @ApiOperation(value = "天气-降雨量---降雨量表---更改状态", notes = "天气-降雨量")
    @PostMapping("/rain/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(
        @RequestBody RainVO rainVO) {
        if(rainVO!=null){
            return rainService.updateStatusByEntityResult(rainVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "天气-降雨量---降雨量表---[真删除]根据实体的某些属性进行单条或者批量删除", notes = "天气-降雨量")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>", dataType = "Long", paramType = "header")
        ,@ApiImplicitParam(name = "parentId", value = "父级id#<唯一>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "timeStamp", value = "时间标示#<唯一>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "rainId", value = "降雨量表主键#<主键><唯一><非空>", dataType = "Long", paramType = "header")
    })
    @PostMapping("/rain/deleteByEntity")
    public ResponseWrapper deleteByEntity(
        @RequestBody RainShowVO rainShowVO){
        if(rainShowVO!=null){
            RainVO rainVO= JsonUtils.parse(
                JsonUtils.serialize(rainShowVO), RainVO.class);
            rainVO.setStatus(Integer.valueOf(BaseStatusConstant.STATUS_DELETED));
            return rainService.deleteByEntityResult(rainVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "天气-降雨量---降雨量表---根据实体(唯一标示)查询一条数据", notes = "天气-降雨量")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>", dataType = "Long", paramType = "header")
        ,@ApiImplicitParam(name = "parentId", value = "父级id#<唯一>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "timeStamp", value = "时间标示#<唯一>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "rainId", value = "降雨量表主键#<主键><唯一><非空>", dataType = "Long", paramType = "header")
    })
    @PostMapping("/rain/selectById")
    public ResponseWrapper selectById(
        @RequestBody RainShowVO rainShowVO){
        if(rainShowVO!=null){
            RainVO rainVO= JsonUtils.parse(
                JsonUtils.serialize(rainShowVO), RainVO.class);
            return rainService.selectByIdResult(rainVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "天气-降雨量---降雨量表---根据实体的某些属性查询分页数据,pageSize,pageNum从url传", notes = "天气-降雨量")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/rain/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody RainListVO rainListVO) {
        RainVO rainVO= JsonUtils.parse(
            JsonUtils.serialize(rainListVO), RainVO.class);
        return rainService.selectPageByEntityResult(pageNum,pageSize
            , rainVO,"RAIN_ID DESC");
    }

    @ApiOperation(value = "天气-降雨量---降雨量表---根据实体的某些属性查询列表", notes = "天气-降雨量")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/rain/selectByEntity")
    public ResponseWrapper selectByEntity(
        @RequestBody RainListVO rainListVO) {
        RainVO rainVO= JsonUtils.parse(
            JsonUtils.serialize(rainListVO), RainVO.class);
        return rainService.selectByEntityResult(rainVO);
    }

    @ApiOperation(value = "天气-降雨量---降雨量表---初始化数据", notes = "天气-降雨量")
    @PostMapping("/rain/selectInitData")
    public ResponseWrapper selectInitData(
        @RequestBody RainVO rainVO){
        if(rainVO!=null){
            return rainService.selectInitDataResult(rainVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
