package com.unis.quality.server.dao;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.unis.quality.server.entity.quality.TbCheckstandardInfoDO;

@Repository
@Transactional(propagation = Propagation.NESTED, rollbackFor = Exception.class)
public interface CheckstandardInfoRepository  extends JpaRepository<TbCheckstandardInfoDO,Serializable>,JpaSpecificationExecutor <TbCheckstandardInfoDO>{

	/**
	 * @param checkstandardId
	 * @param i
	 * @return根据id获取检测标准
	 */
	TbCheckstandardInfoDO findByCheckstandardIdAndStatus(String checkstandardId, int i);

	/**
	 * 删除检测标准
	 * @param checkstandardId
	 * @param string
	 * @param string2
	 */
	@Modifying
	@Query(value="update tb_checkstandard_info "
			+ "set REFRESHER = ?2,"
			+ "REFRESHER_CODE = ?3,"
			+ "status = 0,"
			+ "REFRESH_TIME = sysdate"
			+ " where checkstandard_id in ?1",nativeQuery = true)
	void deletecheckstandard(String[] checkstandardId, String string, String string2);

	/**
	 * @param status
	 * @return获取所有检测标准信息
	 */
    @Query(value = "SELECT DISTINCT STANDARD_TYPE as standardType FROM TB_CHECKSTANDARD_INFO where  status=1 and  IS_USED=?1 ",nativeQuery = true)
    List<Map<String,Object>> selectall(String isued);
	
	
	//启用、禁用
	@Modifying
	@Query(value="update tb_checkstandard_info set IS_USED = ?2  where checkstandard_id = ?1",nativeQuery = true)
	int updateIsUsed(String id,String isUsed);
	
	/**
	 * 根据标准分类获取标准编码
	 */
	@Query(value = "SELECT  STANDARD_CODE as standardcode FROM TB_CHECKSTANDARD_INFO where  status=1 and  IS_USED=1  and STANDARD_TYPE=?1",nativeQuery = true)
	List<Map<String,Object>> findAllByType(String standardType);
	
	/**
	 * 根据标准编码获取标准名称
	 */
	@Query(value = "SELECT  STANDARD_NAME as standardname FROM TB_CHECKSTANDARD_INFO where  status=1 and  IS_USED=1  and STANDARD_CODE=?1",nativeQuery = true)
	List<Map<String,Object>> findAllByCode(String standardCode);

}
