package com.unis.quality.server.dao;

import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.unis.quality.common.vo.EquipmentVO;
import com.unis.quality.server.entity.quality.EquipmentDO;
import tk.mybatis.mapper.common.Mapper;

/**
 * @Description 粮食质量安全检测体系-机构设备信息
 * @ClassName EquipmentDao
 * @author lfx
 * @date 2018年10月30日14:09:15
 * @version v1.0
 */
@Transactional(rollbackFor = Exception.class)
@org.apache.ibatis.annotations.Mapper
@Repository
public interface EquipmentDao extends Mapper<EquipmentDO>{
	

	/**
	 * @Description 根据id查询设备详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日14:21:43
	 * @param id
	 * @return EquipmentDO
	 * @throws Exception
	 */
	public List<EquipmentVO> findByIdAndIsDeleted(String id) throws Exception;
	

	/**
	 * @Description 查询设备信息、分页
	 * @version v1.0
	 * @author lfx
	 * @param EquipmentVO
	 * @date 2018年10月30日15:01:37
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(EquipmentVO equipmentVO, Integer page, Integer size) throws Exception;

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:56
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids,EquipmentVO vo) throws Exception;

	/**
	 * @Description 保存信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @param EquipmentVO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(Map<String, Object> equipmentList,EquipmentVO vo) throws Exception;

	/**
	 * @Description 更新设备信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:49
	 * @param EquipmentVO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(Map<String, Object> EquipmentVOlist,EquipmentVO vo) throws Exception;

	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 查询所有deviceCoding 未删除
	 * @Date 2020年3月18日 下午2:26:41
	 * @return Set<String>
	 */
	public Set<String> findDeviceCodingList(@Param("createBy")String createBy);

	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description  根据 deviceCoding 数组 删除
	 * @Date 2020年3月18日 下午2:27:21
	 * @param setLocal void
	 */
	public void deleteByDeviceCodings(@Param("setLocal")Set<String> setLocal);
}
