package com.unis.quality.server.dao;

import java.util.List;
import java.util.Map;

import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.unis.quality.common.dto.FoodStockDTO;
import com.unis.quality.common.vo.FoodStockItemsVO;
import com.unis.quality.server.entity.quality.FoodStockDO;

import tk.mybatis.mapper.common.Mapper;

/**
 * @ClassName FoodStockDao
 * @Description 品质测报-库存粮食质量检测品登统表
 * @author lfx
 * @date 2019年7月24日17:26:44
 * @version v1.0
 */
@Transactional(rollbackFor = Exception.class)
@org.apache.ibatis.annotations.Mapper
@Repository
public interface FoodStockDao extends Mapper<FoodStockDO>{

	/**
	 * @Description 根据id查询审核详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public Map<String, Object>  findByIdAndIsDeleted(String id,String zjda,String type) throws Exception;
	
	public FoodStockDO findByIdAndIsDeleted(String id,String zjda, int isDelete,String areaCode) throws Exception ;
	
	/**
	 * @Description 根据id查询明细
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	 public List<FoodStockItemsVO> findItemsByIdAndIsDeleted(String id) throws Exception;
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(FoodStockDTO aduitVO, Integer page, Integer size) throws Exception;

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids) throws Exception;

	
	
	/**
	 * @Description 样品信息同步
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> getSampleInformation(FoodStockDTO fDto) throws Exception;
	
	
	/**
	 * @Description 盟市、旗县、自治区汇总
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public Map<String,Object> getAll(String type,String areaCode) throws Exception;
	
	//查询最大批次
	String queryMaxBatch(FoodStockDTO fDto);
	

	/**
	 * @Description 检测业务查询统计     柱状图-储存品质总代表数量
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> natureNumber(String years) throws Exception;
	
	

	/**
	 * @Description 检测业务查询统计     柱状图-宜存率 
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> suitableDeposit(String years) throws Exception;
}
