package com.unis.quality.server.dao;

import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.unis.quality.common.vo.OrganizationVO;
import com.unis.quality.server.entity.quality.OrganizationDO;

import tk.mybatis.mapper.common.Mapper;

/**
 * @Description 粮食质量安全检测体系-机构信息
 * @ClassName OrganizationService
 * @version v1.0
 * @author lfx
 * @date 2018年10月26日 下午3:50:01
 *
 */
@Transactional(rollbackFor = Exception.class)
@org.apache.ibatis.annotations.Mapper
@Repository
public interface OrganizationDao extends Mapper<OrganizationDO>{
	
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param organizationId
	 * @return
	 * @throws Exception
	 */
	public OrganizationVO findByIdAndIsDeleted(String organizationId) throws Exception;

	public OrganizationDO findByIdAndIsDeleted(String id, int isDelete) throws Exception;
	/**
	 * @Description 根据标题、创建人查询机构信息
	 * @version v1.0
	 * @author lfx
	 * @param OrganizationVO
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(OrganizationVO organizationVO, Integer page, Integer size) throws Exception;

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param organizationIds
	 * @date 2018/10/29
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids,OrganizationVO organizationVO) throws Exception;

	/**
	 * @Description 保存机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(OrganizationVO OrganizationVO) throws Exception;

	/**
	 * @Description 更新机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param OrganizationVO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(OrganizationVO organizationVO) throws Exception;
	
	/**
	 * @Description 根据名称查询id
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param organizationName
	 * @return
	 * @throws Exception
	 */
	public String findByName(String organizationName) throws Exception;

	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 查询所有orgId 未删除
	 * @Date 2020年3月18日 下午2:02:11
	 * @return Set<String>
	 */
	public Set<String> findOrgIdList(@Param("createBy")String createBy);

	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 根据 orgId 数组 删除
	 * @Date 2020年3月18日 下午2:14:38
	 * @param setLocal void
	 */
	public void deleteByOrgIds(@Param("setLocal")Set<String> setLocal);
}
