package com.unis.quality.server.dao;

import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.unis.quality.common.vo.PersonnelManagementVO;
import com.unis.quality.server.entity.quality.PersonnelManagementDO;

import tk.mybatis.mapper.common.Mapper;

/**
 * @Description 粮食质量安全检测体系-人员信息
 * @ClassName PersonnelManagementService
 * @author lfx
 * @date 2018年10月30日10:17:43
 * @version v1.0
 *
 */
@Transactional(rollbackFor = Exception.class)
@org.apache.ibatis.annotations.Mapper
@Repository
public interface PersonnelManagementDao extends Mapper<PersonnelManagementDO>{
	

	/**
	 * @Description 根据id查询人员详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:18:35
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public List<PersonnelManagementVO> findByIdAndIsDeleted(String id) throws Exception;

	/**
	 * @Description 查询人员信息、分页
	 * @version v1.0
	 * @author lfx
	 * @param PersonnelManagementVO
	 * @date 2018年10月30日10:38:06
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(PersonnelManagementVO personnelManagementVO, Integer page, Integer size) throws Exception;

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:45
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids,PersonnelManagementVO vo) throws Exception;

	/**
	 * @Description 保存信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:43
	 * @param PersonnelManagementVO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(Map<String, Object> pManagementList,PersonnelManagementVO vo) throws Exception;

	/**
	 * @Description 更新信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:37
	 * @param PersonnelManagementVO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(Map<String, Object> personnelManagementVOlist,PersonnelManagementVO vo) throws Exception;

	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 根据姓名 + 生日 删除
	 * @Date 2020年3月18日 下午2:46:10
	 * @param string
	 * @param string2 void
	 */
	public void deleteByNameAndBirthday(@Param("name")String name, @Param("birthday")String birthday);

	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 查询所有 (name - birthday) 的字符串  未删除
	 * @Date 2020年3月18日 下午2:48:14
	 * @return Set<String>
	 */
	public Set<String> findNameConcatBirthdayList(@Param("createBy")String createBy);
}
