package com.unis.quality.server.dao;

import java.util.List;
import java.util.Map;

import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.unis.quality.common.dto.FoodStockDTO;
import com.unis.quality.common.vo.FoodStockItemsVO;
import com.unis.quality.server.entity.quality.FoodStockDO;
import com.unis.quality.server.entity.quality.SummaryResultsDO;

import tk.mybatis.mapper.common.Mapper;

/**
 * @ClassName SummaryResultsService
 * @Description 安全监测-粮食质量检验结果汇总表
 * @author lfx
 * @date 2019年7月24日17:26:44
 * @version v1.0
 */
@Transactional(rollbackFor = Exception.class)
@org.apache.ibatis.annotations.Mapper
@Repository
public interface SummaryResultsDao extends Mapper<SummaryResultsDO>{

	/**
	 * @Description 根据id查询审核详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public Map<String, Object>  findByIdAndIsDeleted(String id,String zjda,String type,String batch) throws Exception;
	
	public FoodStockDO findByIdAndIsDeleted(String id,String zjda, int isDelete) throws Exception ;
	
	/**
	 * @Description 根据id查询明细
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	 public List<FoodStockItemsVO> findItemsByIdAndIsDeleted(String id) throws Exception;
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(FoodStockDTO aduitVO, Integer page, Integer size) throws Exception;

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids) throws Exception;

	/**
	 * @Description 保存品质测报-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日11:25:58
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(Map<String, Object> aduitList) throws Exception;

	/**
	 * @Description 更新品质测报-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:02:41
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(Map<String, Object> aduitList) throws Exception;
	
	
	/**
	 * @Description 品质测报-结果上报
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月19日15:12:44
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateState(String id) throws Exception;
	
	
	/**
	 * @Description 样品信息同步
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> getSampleInformation(FoodStockDTO fDto) throws Exception;
	
	
	/**
	 * @Description 盟市、旗县汇总
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> getAllFoodStock(String type,String areaCode) throws Exception;
	
	/**
	 * @Description 
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> summaryResult(FoodStockDTO fDto) throws Exception;
	
	/**
	 * @Description 检测业务查询统计     饼图-样品份数
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> sampleNumber(String years) throws Exception;
	
	
}
