package com.unis.quality.server.domain;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import com.github.pagehelper.Page;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.constant.AbnormalConstant;
import com.unis.quality.common.constant.Constant;
import com.unis.quality.common.vo.EntrustCheckVO;
import com.unis.quality.common.vo.echarts.stackedline.StackedLine;
import com.unis.quality.common.vo.echarts.stackedline.StackedLineXAxis;
import com.unis.quality.common.vo.echarts.stackedline.StackedSeries;
import com.unis.quality.server.dao.tianjin.TyZjxxmxbDao;
import com.unis.quality.server.entity.quality.tianjin.TyZjxxmxbDO;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.MapUtil;
import com.unis.common.utils.UUIDUtils;
import com.unis.quality.common.vo.EntrustQueryVO;
import com.unis.quality.common.vo.EntrustVO;
import com.unis.quality.server.dao.WTDao;
import com.unis.quality.server.entity.quality.EntrustDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 *功能描述  质检委托领域对象
 * @author wangqiang
 * @date 2019/8/21 0021
 * @param
 * @return
 */
@Getter
@Setter
@ToString
@Component
public class EntrustDomain {
	
	@Autowired
	private WTDao WTDao;

	@Autowired
	private TyZjxxmxbDao tyZjxxmxbDao;

	@Value("${zhijianUrl}")
	String zhijianUrl;

	/**
	 *功能描述 根据交易编号修改lcId
	 * @author lfx
	 * @date 2019/8/21 0021
	 * @param :[EntrustVOlist, vo]
	 * @return boolean
	 */
	public boolean updateLcId(EntrustVO vo) throws Exception {
		EntrustDO entrustDO = LsBeanUtils.copyProperties(vo, EntrustDO.class);
		int i = WTDao.updateLcId(entrustDO);
		if (i>0){
			return true;
		}
		return false;
	}

	
	public Map<String,  Object> selectWtIdBhKc(EntrustQueryVO entrustQueryVO,Integer  page,  Integer  size)throws Exception {
		PageHelper.startPage(page, size,"C.DATAORDER DESC");
		List<Map>  ListMap  = WTDao.selectWtIdBhKc( entrustQueryVO);
		List<Map> newlist =new ArrayList<Map>();
		if(ListMap.size()>0) {
			for(Map map:ListMap) {
				newlist.add(MapUtil.convertKey2LowerCase(map));
			}
		}
    	PageInfo<Map>  pageInfo  =  new  PageInfo<Map>(newlist);
		Map<String,  Object>  resultMap  =  new  HashMap<String,  Object>();
		resultMap.put("total",  pageInfo.getTotal());
		resultMap.put("resultList",  newlist);
		return  resultMap;
	}
	
	public Map<String,  Object> selectWtIdBhKctb(EntrustQueryVO entrustQueryVO)throws Exception {
		List<Map>  ListMap  = WTDao.selectWtIdBhKc( entrustQueryVO);
		Map<String,  Object>  resultMap  =  new  HashMap<String,  Object>();
		resultMap.put("resultList",  ListMap);
		return  resultMap;
	}

	public ResponseWrapper echartsZjjgqs(EntrustQueryVO entrustQueryVO){
		StackedLine stackedLine=new StackedLine();
		StackedLineXAxis xAxis=new StackedLineXAxis();
		List<String> xList=new ArrayList<>();

		xAxis.setData(xList);
		stackedLine.setXAxis(xAxis);

		String shuifen= AbnormalConstant.ShuiFen.getValue();
		String zazhi=AbnormalConstant.ZaZhi.getValue();
		String buwanshanli=AbnormalConstant.BuWanShanLi.getValue();

		StackedSeries sfSeries=new StackedSeries();
		sfSeries.setName(shuifen);
		sfSeries.setStack(shuifen+"总量");
		stackedLine.getSeries().add(sfSeries);

		StackedSeries zzSeries=new StackedSeries();
		zzSeries.setName(zazhi);
		zzSeries.setStack(zazhi+"总量");
		stackedLine.getSeries().add(zzSeries);

		StackedSeries bwslSeries=new StackedSeries();
		bwslSeries.setName(buwanshanli);
		bwslSeries.setStack(buwanshanli+"总量");
		stackedLine.getSeries().add(bwslSeries);
		SimpleDateFormat sdf=new SimpleDateFormat("yyyy-MMM-dd HH:mm");
		List<EntrustCheckVO> list=WTDao.echartsZjjgqs(entrustQueryVO);
		for(EntrustCheckVO entrustCheckVO : list){
			xAxis.getData().add(sdf.format(entrustCheckVO.getWtsj()));
			String zjxxid=entrustCheckVO.getZjxxid();
			List<TyZjxxmxbDO> mxList=tyZjxxmxbDao.selectByEntity(zjxxid);
			/*Map<String, TyZjxxmxbDO> mxMap=mxList.stream().collect(Collectors.toMap(a->a.getJyxm(),b->b,(k1,k2)->k1));
			if(mxMap.containsKey(shuifen)){
				sfSeries.getData().add(Double.valueOf(mxMap.get(shuifen).getJyjg()));
			}else{
				sfSeries.getData().add(0d);
			}
			if(mxMap.containsKey(zazhi)){
				zzSeries.getData().add(Double.valueOf(mxMap.get(zazhi).getJyjg()));
			}else{
				zzSeries.getData().add(0d);
			}
			if(mxMap.containsKey(buwanshanli)){
				bwslSeries.getData().add(Double.valueOf(mxMap.get(buwanshanli).getJyjg()));
			}else{
				bwslSeries.getData().add(0d);
			}*/
			boolean sfyc=false;
			boolean zzyc=false;
			boolean bwslyc=false;
			for(TyZjxxmxbDO zjxxmxbDO: mxList){
				if(zjxxmxbDO.getJyxm() !=null && shuifen.equals(zjxxmxbDO.getJyxm().replace(Constant.AbnormalItemExt,"")) ){
					sfSeries.getData().add(Double.valueOf(zjxxmxbDO.getJyjg()));
					sfyc=true;
				}
				if(zjxxmxbDO.getJyxm() !=null && zazhi.equals(zjxxmxbDO.getJyxm().replace(Constant.AbnormalItemExt,"")) ){
					zzSeries.getData().add(Double.valueOf(zjxxmxbDO.getJyjg()));
					zzyc=true;
				}
				if(zjxxmxbDO.getJyxm() !=null && buwanshanli.equals(zjxxmxbDO.getJyxm().replace(Constant.AbnormalItemExt,"")) ){
					bwslSeries.getData().add(Double.valueOf(zjxxmxbDO.getJyjg()));
					bwslyc=true;
				}
			}
			if(!sfyc){
				sfSeries.getData().add(0d);
			}
			if(!zzyc){
				zzSeries.getData().add(0d);
			}
			if(!bwslyc){
				bwslSeries.getData().add(0d);
			}
		}
		return ResponseWrapper.success(stackedLine);
	}

	public Map<String,  Object> selectWtIdBh(EntrustQueryVO entrustQueryVO,Integer  page,  Integer  size)throws Exception {
		PageHelper.startPage(page, size);
		List<Map>  ListMap  = WTDao.selectWtIdBh( entrustQueryVO);
		List<Map> newlist =new ArrayList<Map>();
		if(ListMap.size()>0) {
			for(Map map:ListMap) {
				newlist.add(MapUtil.convertKey2LowerCase(map));
			}
		}
    	PageInfo<Map>  pageInfo  =  new  PageInfo<Map>(newlist);
		Map<String,  Object>  resultMap  =  new  HashMap<String,  Object>();
		resultMap.put("total",  pageInfo.getTotal());
		resultMap.put("resultList",  newlist);
		return  resultMap;
	}
	
	
	public String selectZjbgByWtId(String wtId)throws Exception {
		return WTDao.selectZjbgByWtId(wtId);
	}
	
	/**
	 *功能描述  根据委托编号查询
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[id]
	 * @return com.unis.quality.common.vo.EntrustVO
	 */
	public EntrustVO findById(String id) throws Exception {
		EntrustVO vo=new EntrustVO();
		vo.setId(id);
		EntrustDO entrustDO = WTDao.selectByPrimaryKey(vo);
		EntrustVO resultVO = LsBeanUtils.copyProperties(entrustDO, EntrustVO.class);
		return resultVO;
	}

	public EntrustVO selectById(EntrustVO vo){
		EntrustDO entrustDO = WTDao.selectById(vo);
		EntrustVO resultVO = LsBeanUtils.copyProperties(entrustDO, EntrustVO.class);
		return resultVO;
	}

	
	/**
	 *功能描述  根据交易编号查询
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[id]
	 * @return com.unis.quality.common.vo.EntrustVO
	 */
	public EntrustVO findByJybh(String jybh) throws Exception {
		EntrustVO vo=new EntrustVO();
		vo.setJybh(jybh);
		EntrustDO entrustDO = WTDao.selectByPrimaryKey(vo);
		EntrustVO resultVO = LsBeanUtils.copyProperties(entrustDO, EntrustVO.class);
		return resultVO;
	}

	/**
	 *功能描述  根据交易编号查询,wtbh不唯一废弃
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[id]
	 * @return com.unis.quality.common.vo.EntrustVO
	 */
	/*public EntrustVO findByWtbh(String wtbh) throws Exception {
		EntrustVO vo=new EntrustVO();
		vo.setWtbh(wtbh);
		EntrustDO entrustDO = WTDao.selectByPrimaryKey(vo);
		EntrustVO resultVO = LsBeanUtils.copyProperties(entrustDO, EntrustVO.class);
		return resultVO;
	}*/


	/**
	 *功能描述 分页获取委托信息  
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[entrustQueryVO]
	 * @return java.util.List<com.unis.quality.common.vo.EntrustVO>
	 */
	public List<EntrustVO> findByPage(EntrustQueryVO entrustQueryVO) throws Exception {
		List<EntrustDO> dataByPage = WTDao.getDataByPage(entrustQueryVO);
		ArrayList<EntrustVO> entrustVOList = new ArrayList<>();
		LsBeanUtils.copyCollection(dataByPage, entrustVOList,EntrustVO.class);
		return entrustVOList;
	}
	
	/**
	 *功能描述 状态查询
	 * @author 
	 * @date 2019/8/21 0021
	 * @param :[entrustQueryVO]
	 * @return java.util.List<com.unis.quality.common.vo.EntrustVO>
	 */
	public Page<EntrustVO> findByPageZt(EntrustQueryVO entrustQueryVO) throws Exception {
		Page<EntrustDO> dataByPage = WTDao.getDataByPageZt(entrustQueryVO);
		Page<EntrustVO> entrustVOList = new Page<>();
		LsBeanUtils.copyCollection(dataByPage, entrustVOList,EntrustVO.class);
		entrustVOList.setTotal(dataByPage.getTotal());
		return entrustVOList;
	}
	
	/**
	 *功能描述 强检仓号查询
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[entrustQueryVO]
	 * @return java.util.List<com.unis.quality.common.vo.EntrustVO>
	 */
	public List<EntrustVO> findChByPage(EntrustVO EntrustVO) throws Exception {
		List<EntrustDO> dataByPage = WTDao.getDataChByPage(EntrustVO);
		ArrayList<EntrustVO> entrustVOList = new ArrayList<>();
		LsBeanUtils.copyCollection(dataByPage, entrustVOList,EntrustVO.class);
		return entrustVOList;
	}
	/**
	 *功能描述  逻辑删除委托信息  强检、其他质检
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[id]
	 * @return boolean
	 */
	public boolean delete(EntrustVO vo) throws Exception {
		EntrustDO entrustDO = LsBeanUtils.copyProperties(vo, EntrustDO.class);
		int i = WTDao.deleteByPrimaryKey(entrustDO);
		if (i>0){
			return true;
		}
		return false;
	}
	public boolean delete( ) throws Exception {

		int i = WTDao.delete("粮库导入");
		if (i>0){
			return true;
		}
		return false;
	}

	public boolean deleteByJybh( EntrustVO vo) throws Exception {

		int i = WTDao.deleteByJybh(vo);
		if (i>0){
			return true;
		}
		return false;
	}

	/**
	 *功能描述 保存质检委托信息
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[vo]
	 * @return boolean
	 */
	public boolean save(EntrustVO vo) throws Exception {
		EntrustDO entrustDO = LsBeanUtils.copyProperties(vo, EntrustDO.class);
		boolean result = false;

		EntrustDO entrustDO1 = WTDao.selectByPrimaryKey(vo);
		if(!"交易质检".equals(vo.getZjbh()) && StringUtils.isEmpty(vo.getId())) {
			if (null!=entrustDO1 && StringUtils.isNotEmpty(vo.getId())) {
				throw new RuntimeException(vo.getWtbh()+ "已存在!");
			}
		}

		if(null==vo.getWtlx()) {
			entrustDO.setWtlx(vo.getWtlxbm());
		}
		if(StringUtils.isEmpty(entrustDO.getLcid())){
			entrustDO.setLcid("待委托");
		}
		int num=0;
		if(entrustDO1==null || entrustDO.getCreateBy() != null  &&  !("").contentEquals(entrustDO.getCreateBy()) && entrustDO.getCreateBy().equals("委托")) {
			if(StringUtils.isEmpty(entrustDO.getId())){
				entrustDO.setId(UUIDUtils.uuid());
			}
			entrustDO.buildInsertData();
			num = WTDao.insert(entrustDO);
		}else {
			entrustDO.setId(vo.getWtId());
			entrustDO.buildUpdateData();
			num = WTDao.updateByPrimaryKeySelective(entrustDO);
		}
		result=num>0;
		return result;
	}

	/**
	 *功能描述 保存交易的质检委托信息
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[vo]
	 * @return boolean
	 */
	public boolean insertEntityJiaoYi(EntrustVO vo) throws Exception {
		EntrustDO entrustDO = LsBeanUtils.copyProperties(vo, EntrustDO.class);
		boolean result = false;

		if(null==vo.getWtlx()) {
			entrustDO.setWtlx(vo.getWtlxbm());
		}
		if(StringUtils.isEmpty(entrustDO.getLcid())){
			entrustDO.setLcid("待委托");
		}
		int num=0;
		if(StringUtils.isEmpty(entrustDO.getId())){
			entrustDO.setId(UUIDUtils.uuid());
		}
		entrustDO.buildInsertData();
		num = WTDao.insert(entrustDO);
		return num>0;
	}

	/**
	 *功能描述 修改质检委托信息
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[EntrustVOlist, vo]
	 * @return boolean
	 */
	public boolean update(EntrustVO vo) throws Exception {
		EntrustDO entrustDO = LsBeanUtils.copyProperties(vo, EntrustDO.class);
		if(null==vo.getWtlx()) {
			entrustDO.setWtlx(vo.getWtlxbm());
		}
		int i = WTDao.updateByPrimaryKeySelective(entrustDO);
		if (i>0){
			return true;
		}
		return false;
	}

	public boolean submitEntrust(EntrustVO vo) throws Exception{
		boolean bool=false;
		vo.setCreateBy("");
		EntrustDO entrustDO = LsBeanUtils.copyProperties(vo, EntrustDO.class);
		entrustDO.setUpdateTime(new Date());
		entrustDO.setLcid("已委托");
		int i = WTDao.updateByPrimaryKeySelective(entrustDO);
		if (i>0){
			bool=true;
		}
		return bool;
	}
	//=====================================================其他质检=====================================================
	
	/**
	 *功能描述  根据wtbh查询
	 * @author 
	 * @date 2019/8/21 0021
	 * @param :[id]
	 * @return com.unis.quality.common.vo.EntrustVO
	 */
	public List<Map> findByWtbhQT(EntrustVO vo) throws Exception {
		List<Map> list = WTDao.findByWtbhQT(vo);
		List<Map> newlist =new ArrayList<Map>();
		if(list.size()>0) {
			for(Map map:list) {
				newlist.add(MapUtil.convertKey2LowerCase(map));
			}
		}
		return newlist;
	}
	
	/**
	 *功能描述 保存其他质检
	 * @author lfx
	 * @date 2019/8/21 0021
	 * @param :[vo]
	 * @return boolean
	 */
	public boolean saveQt(EntrustVO vo) throws Exception {
		boolean bool=false;
		boolean doInsert= StringUtils.isEmpty(vo.getId());
		vo.setJybh(vo.getWtbh());
		bool=save(vo);
		if(bool==true) {
			if(null!=vo.getListmx()) {
				List<Map> listMx=vo.getListmx();
				for(int i=0;i<listMx.size();i++) {
					String wtdw=listMx.get(i).get("wtdw")+"";
					String ch=listMx.get(i).get("ch")+"";
					String pz=listMx.get(i).get("pz")+"";
					String sl=listMx.get(i).get("sl")+"";
					vo.setWtdw(wtdw);
					vo.setCcdw(wtdw);
					vo.setCh(ch);
					vo.setPz(pz);
					vo.setSl(sl);
					EntrustDO entrustDO = LsBeanUtils.copyProperties(vo, EntrustDO.class);
					if(doInsert){
						entrustDO.setId(UUIDUtils.uuid());
						entrustDO.setJybh("");
						entrustDO.buildInsertData();
						entrustDO.setCreateBy("委托");
						int insert = WTDao.insert(entrustDO);
						if (insert>0){
							bool=true;
						}
					}else{
						entrustDO.setJybh("");
						entrustDO.setCreateBy("委托");
						entrustDO.buildUpdateData();
						int insert = WTDao.updateByPrimaryKeySelective(entrustDO);
						if (insert>0){
							bool=true;
						}
					}
				}
			}else {
				vo.setJybh(vo.getWtbh());
				bool=save(vo);
			}
		}
		return bool;
	}
	
	/**
	 *功能描述 修改其它质检委托信息
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[EntrustVOlist, vo]
	 * @return boolean
	 */
	public boolean updateQt(EntrustVO vo) throws Exception {
		boolean bool=false;
		bool=update(vo);
		if(bool==true) {
			if(null!=vo.getListmx()) {
				List<Map> oldList = findByWtbhQT(vo); 
				List<Map> listMx=vo.getListmx();
				int num = listMx.size(); 
				  for(int i = 0; i<num; i++){
					  String wtdw=listMx.get(i).get("wtdw")+"";
						String ch=listMx.get(i).get("ch")+"";
						String pz=listMx.get(i).get("pz")+"";
						String sl=listMx.get(i).get("sl")+"";
						vo.setWtdw(wtdw);
						vo.setCcdw(wtdw);
						vo.setCh(ch);
						vo.setPz(pz);
						vo.setSl(sl);
						vo.setId(listMx.get(i).get("id")+"");
						vo.setWtbh(listMx.get(i).get("wtbh")+"");
						vo.setJybh("");
						EntrustDO entrustDO = LsBeanUtils.copyProperties(vo, EntrustDO.class);
						int t = WTDao.updateByPrimaryKeySelective(entrustDO);
						if (t>0){
							bool=true;
						}
				  }
				
			}
		}
		return bool;
	}
	

	/**
	 *功能描述 分页获取委托信息  
	 * @author wangqiang
	 * @date 2019/8/21 0021
	 * @param :[entrustQueryVO]
	 * @return java.util.List<com.unis.quality.common.vo.EntrustVO>
	 */
	public List<EntrustVO> findByPageQT(EntrustQueryVO entrustQueryVO) throws Exception {
		List<EntrustDO> dataByPage = WTDao.getDataByPageQT(entrustQueryVO);
		ArrayList<EntrustVO> entrustVOList = new ArrayList<>();
		LsBeanUtils.copyCollection(dataByPage, entrustVOList,EntrustVO.class);
		return entrustVOList;
	}
	
	//详情
	public EntrustVO findByIdQt(EntrustVO vo) throws Exception {
		//根据委托编号查出上面的数据,交易编号有的是空的
		EntrustVO evo=findById(vo.getId());
		//根据wtbh查询交易编号为空的明细数据
		List<Map> listmx=findByWtbhQT(evo);
		
		evo.setListmx(listmx);
		return evo;
		
	}
	
	
	//=====================================================推送委托=====================================================

	//推送委托
	public String sendWt(EntrustVO vo) {
		Map<String, Object> aduitList=new HashMap<String, Object>();
		List<Map> itemsData=new ArrayList<>();
		Map<String,  Object>  map  =  new  HashMap<String,  Object>();
		Date ss=vo.getWtsj() ;
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		String dateStr = sdf.format(ss );
		map.put("wtId", vo.getWtId());
		map.put("wtbt", vo.getWtbt());
		map.put("wtr", vo.getWtr());
		map.put("wtlx", vo.getWtlx());
		map.put("wtsj", dateStr);
		map.put("wtnr", vo.getWtnr());
		map.put("fj", vo.getFjid());
		map.put("qyd", vo.getQyd());
		map.put("xxdz", vo.getXxdz());
		map.put("jckd", vo.getJckd());
		map.put("pz", vo.getPz());
		map.put("sl", vo.getSl());
		map.put("chsl", vo.getChsl());
		itemsData.add(map);
		aduitList.put("detailList", itemsData);

		//String url="http://1550a451z2.iok.la:46130/Login/PostOrderList";
		//String url="http://1550a451z2.iok.la:29598/Login/PostOrderList";
		//http://1550a451z2.iok.la:29598/Home/AdminLTE#
		String str=JSON.toJSONString(aduitList);
		String result=sendPost(zhijianUrl, str);
		System.out.println("zhijianUrl:"+zhijianUrl+"   str:"+str+"   sendWt:"+result);
		return result;
	}
	
	
	 public static String sendPost(String url, String param) {
	        OutputStreamWriter out = null;
	        BufferedReader in = null;
	        String result = "";
	        try {
	            URL realUrl = new URL(url);
	            HttpURLConnection conn = null;
	            // 打开和URL之间的连接
	            conn = (HttpURLConnection) realUrl.openConnection();
	            // 发送POST请求必须设置如下两行
	            conn.setDoOutput(true);
	            conn.setDoInput(true);
	            conn.setRequestMethod("POST");    // POST方法

	            // 设置通用的请求属性
	            conn.setRequestProperty("accept", "*/*");
	            conn.setRequestProperty("connection", "Keep-Alive");
	            conn.setRequestProperty("user-agent",
	                    "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
	            conn.setRequestProperty("Content-Type", "application/json;charset=utf-8");
	            conn.connect();
	            // 获取URLConnection对象对应的输出流
	            out = new OutputStreamWriter(conn.getOutputStream(), "UTF-8");
	            // 发送请求参数
	            out.write(param);
	            // flush输出流的缓冲
	            out.flush();
	            // 定义BufferedReader输入流来读取URL的响应
	            in = new BufferedReader(new InputStreamReader(conn.getInputStream()));
	            String line;
	            while ((line = in.readLine()) != null) {
	                result += line;
	            }
	        } catch (Exception e) {
	            System.out.println("发送 POST 请求出现异常:"+url+"   " + e);
	            e.printStackTrace();
	        }
	        //使用finally块来关闭输出流、输入流
	        finally {
	            try {
	                if (out != null) {
	                    out.close();
	                }
	                if (in != null) {
	                    in.close();
	                }
	            } catch (IOException ex) {
	                ex.printStackTrace();
	            }
	        }
	        return result;
	    }
	 
	 //查询数据库中最大的wtbh  'wt20191121000001'
	 public String queryMAXWtbhBYCodeDate(EntrustQueryVO vo) {
		return WTDao.getWtbh(vo);
	 }
	 
	//拼接
	public   String queryMAXWtbh(String zjbh) throws Exception{
		//设置日期格式
		 SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
		 String date= sdf.format(new Date());
	    //拼接“A20180512”
		 String codeDate ="";
		 if("强检".equals(zjbh)) {
			 codeDate = "QJ"+date;
		 }else {
			 codeDate = "QT"+date;
		 }
	    //M20190211
	    EntrustQueryVO vo=new EntrustQueryVO();
	    vo.setZjbh(zjbh);
	    vo.setCode(codeDate);
	    //获取已入库最大ID
	    String oldMaxCustAddressId = queryMAXWtbhBYCodeDate(vo);
	    //M20190211000010
	    int serialNumber = 0;
	    String serialNumberStr = "";
	   if(StringUtils.isEmpty(oldMaxCustAddressId)) //首次生成
	    {
	      return codeDate + "001";
	    }
	    else //拼接最新ID
	    {//000010
	      int previousSerialNumber = Integer.valueOf(oldMaxCustAddressId.substring(oldMaxCustAddressId.length()-3, oldMaxCustAddressId.length()));
	      serialNumber = previousSerialNumber + 1;//000011
	      serialNumberStr = String.valueOf(serialNumber);
	      //不足6位左侧自动补零
	      String str=StringUtils.leftPad(serialNumberStr,3, "0");
	      return codeDate + str;
	    }
	  }
	
	// 将map值全部转换为小写
		public static Map<String, Object> transformLowerCase(Map<String, Object> orgMap) {
			Map<String, Object> resultMap = new HashMap<>();
			if (orgMap == null || orgMap.isEmpty()) {
				return resultMap;
			}
			Set<String> keySet = orgMap.keySet();
			for (String key : keySet) {
				String newKey = key.toLowerCase();
//				newKey = newKey.replace("_", "");
				resultMap.put(newKey, orgMap.get(key));
			}
			return resultMap;

		}
}
