package com.unis.quality.server.domain;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.quality.common.constant.DataReceiveConstant;
import com.unis.quality.common.vo.EquipmentVO;
import com.unis.quality.common.vo.OrganizationVO;
import com.unis.quality.server.dao.EquipmentDao;
import com.unis.quality.server.dao.OrganizationDao;
import com.unis.quality.server.entity.quality.EquipmentDO;
import com.unis.quality.server.entity.quality.OrganizationDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * @Description: 质检机构管理--设备信息
 * @ClassName: OrganizationService
 * @author lfx
 * @date 2018年10月30日14:12:47
 * 
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class EquipmentDomain {
	
	@Autowired
	private EquipmentDao equipmentDao;
	
	@Autowired
	private OrganizationDao organizationMapper;
	
	/**
	 * @Description 根据id查询设备详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日14:17:21
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public List<EquipmentVO> findByIdAndIsDeleted(String id) throws Exception {
		Example example = new Example(EquipmentDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("organizationId", id);
		List<EquipmentDO> list  = equipmentDao.selectByExample(example);
		List<EquipmentVO> resulEquipmentVOList = new ArrayList<>();
		if (!list.isEmpty()) {
			for (EquipmentDO resultDO : list) {
				EquipmentVO resultVO = LsBeanUtils.copyProperties(resultDO, EquipmentVO.class);
				String time=resultVO.getProductionDate();
				if(null!=time) {
					String date=time.substring(0, 10);
					resultVO.setProductionDate(date);
				}
				resulEquipmentVOList.add(resultVO);
			}
		}
		return resulEquipmentVOList;
	}

	  //判断字符串是否为空
    public String isNull(String key) {
    	String str="";
    	if("null".equals(key)) {
    		str="";
    	}else {
    		str=key;
    	}
    	return  str;
    }
	/**
	 * @Description 查询设备信息、分页
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日15:01:37
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(EquipmentVO equipmentVO, Integer page, Integer size) throws Exception {
	
 		Example example = new Example(EquipmentDO.class);
		Criteria criteria = example.createCriteria();
		// 未删除的收购资格
		criteria.andIsNull("deleteTime");
		//根据机构id只能查询自己机构下的设备
		criteria.andEqualTo("organizationId",equipmentVO.getOrganizationId());
		// 按时间排序
		example.setOrderByClause("CREATE_TIME DESC");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		
		List<EquipmentDO> resultEquipmentDOList = equipmentDao.selectByExample(example);
		PageInfo<EquipmentDO> pageInfo = new PageInfo<EquipmentDO>(resultEquipmentDOList);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<EquipmentVO> resulEquipmentVOList = new ArrayList<>();
		if (!resultEquipmentDOList.isEmpty()) {
			for (EquipmentDO resultDO : resultEquipmentDOList) {
				EquipmentVO resultVO = LsBeanUtils.copyProperties(resultDO, EquipmentVO.class);
				resulEquipmentVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resulEquipmentVOList);
		return resultMap;
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:56
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids,EquipmentVO vo) throws Exception {
		for (String id : ids) {
			Example example = new Example(EquipmentDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("organizationId", id);
			criteria.andIsNull("deleteTime");
			List<EquipmentDO> list = equipmentDao.selectByExample(example);
			if(null==list) {
				throw new RuntimeException("此数据未存储到数据库中。");
			}
			if (!list.isEmpty()) {
				for (EquipmentDO resultDO : list) {
					resultDO.setDeleteBy(vo.getDeleteBy());
					resultDO.setDeleteTime(DateUtil.getNowDate());
					equipmentDao.updateByPrimaryKey(resultDO);
				}
			}
		}
		return true;
	}

	/**
	 * @Description 保存信息--批量
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(Map<String, Object>  equipmentList,EquipmentVO vo) throws Exception {
		boolean bool = false;
		Example example = new Example(EquipmentDO.class);
		Criteria criteria = example.createCriteria();
		String OrganizationId=equipmentList.get("id").toString();
		List<Map> voList=(List<Map>) equipmentList.get("yqsbData");
		if (voList.size() > 0 && voList != null) {
			for (int i = 0; i < voList.size(); i++) {
				if (voList.get(i) != null) {
					if(null==voList.get(i).get("id")) {
						if (!"".equals(equipmentList.get("id")) && null != equipmentList.get("id")) {
							criteria.andEqualTo("organizationId", OrganizationId);
						}
						if (!"".equals(voList.get(i).get("equipmentName")) && null != voList.get(i).get("equipmentName")) {
							criteria.andEqualTo("equipmentName", voList.get(i).get("equipmentName"));
						}if ( null == voList.get(i).get("equipmentName")) {
							throw new RuntimeException("请输入设备名称");
						}
						criteria.andIsNull("deleteTime");
						if (equipmentDao.selectCountByExample(example) > 0) {
							throw new RuntimeException(voList.get(i).get("equipmentName") + "已存在!");
						}
						EquipmentDO equipmentDO = new EquipmentDO();
						equipmentDO.setOrganizationId(OrganizationId);
						equipmentDO.setEquipmentName(isNull(voList.get(i).get("equipmentName")+""));
						equipmentDO.setDeviceCoding(isNull(voList.get(i).get("deviceCoding")+""));
						equipmentDO.setUsingState(isNull(voList.get(i).get("usingState")+""));
						equipmentDO.setManufacturer(isNull(voList.get(i).get("manufacturer")+""));
						equipmentDO.setProductionDate(isNull(voList.get(i).get("productionDate")+""));
						equipmentDO.setContactPerson(isNull(voList.get(i).get("contactPerson")+""));
						equipmentDO.setPhone(isNull(voList.get(i).get("phone")+""));
						equipmentDO.setNumberEquipment(isNull(voList.get(i).get("numberEquipment")+""));
						/**-------天津-start---------**/
						equipmentDO.setUnit(isNull(voList.get(i).get("unit")+""));
						equipmentDO.setModel(isNull(voList.get(i).get("model")+""));
						equipmentDO.setValue(isNull(voList.get(i).get("value")+""));
						equipmentDO.setDomesticImport(isNull(voList.get(i).get("domesticImport")+""));
						equipmentDO.setFactoryCode(isNull(voList.get(i).get("factoryCode")+""));
						SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
					    String receiptDate=voList.get(i).get("receiptDate")+"";
					    String enableDate=voList.get(i).get("enableDate")+"";
					    System.out.println(!"null".equals(receiptDate));
					    if(!"null".equals(receiptDate)) {
					    	equipmentDO.setReceiptDate(sdf.parse(receiptDate));
					    }
					    if(!"null".equals(enableDate) ) {
					    	equipmentDO.setEnableDate(sdf.parse(enableDate));
					    }
					    equipmentDO.setReceivingState(isNull(voList.get(i).get("receivingState")+""));
					    equipmentDO.setPlacePoint(isNull(voList.get(i).get("placePoint")+""));
					    equipmentDO.setSoftwareName(isNull(voList.get(i).get("softwareName")+""));
					    equipmentDO.setTechnicalParameter(isNull(voList.get(i).get("technicalParameter")+""));
					    equipmentDO.setWhetherCertify(isNull(voList.get(i).get("whetherCertify")+""));
		    			/**-------天津-end---------**/
						equipmentDO.setDeptId(vo.getDeptId() + "");
						equipmentDO.setAreaCode(vo.getAreaCode());
						equipmentDO.setCreateBy(vo.getCreateBy());
						equipmentDO.setCreateTime(DateUtil.getNowDate());
						if (equipmentDao.insert(equipmentDO) < 1) {
							throw new RuntimeException(equipmentDO.getEquipmentName() + "无法保存成功，请检查数据。");
						} 
						bool = true;
					}
				}
			}
		}else {
			throw new RuntimeException("请输入正确的设备信息!");
		}
		return bool;
	}

	/**
	 * @Description 更新设备信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:49
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(Map<String, Object> EquipmentVOlist,EquipmentVO vo) throws Exception {
		 //根据机构id查询页面有多少条数据 
		String OrganizationId=EquipmentVOlist.get("id").toString();
		List<Map> voList=(List<Map>) EquipmentVOlist.get("yqsbData");
	    List<EquipmentVO> oldList = findByIdAndIsDeleted(OrganizationId); 
	    if (null==oldList) {
			throw new RuntimeException("此数据未存储到数据库中。");
		}
	    int num = voList.size(); 
	    if(voList != null&&voList.size() > 0){ 
	        //检查页面的信息是否有修改，然后更新到数据库 
	        for(int i = 0; i<num; i++){ 
	        	if(null==voList.get(i).get("id")) {
	        		save(EquipmentVOlist,vo);
	        	}else {
		        	EquipmentDO equipmentDO = new EquipmentDO();
					equipmentDO.setId(oldList.get(i).getId());
					equipmentDO.setOrganizationId(OrganizationId);
					equipmentDO.setEquipmentName(isNull(voList.get(i).get("equipmentName")+""));
					equipmentDO.setDeviceCoding(isNull(voList.get(i).get("deviceCoding")+""));
					equipmentDO.setUsingState(isNull(voList.get(i).get("usingState")+""));
					equipmentDO.setManufacturer(isNull(voList.get(i).get("manufacturer")+""));
					equipmentDO.setProductionDate(isNull(voList.get(i).get("productionDate")+""));
					equipmentDO.setContactPerson(isNull(voList.get(i).get("contactPerson")+""));
					equipmentDO.setPhone(isNull(voList.get(i).get("phone")+""));
					equipmentDO.setNumberEquipment(isNull(voList.get(i).get("numberEquipment")+""));
					/**-------天津-start---------**/
					equipmentDO.setUnit(isNull(voList.get(i).get("unit")+""));
					equipmentDO.setModel(isNull(voList.get(i).get("model")+""));
					equipmentDO.setValue(isNull(voList.get(i).get("value")+""));
					equipmentDO.setDomesticImport(isNull(voList.get(i).get("domesticImport")+""));
					equipmentDO.setFactoryCode(isNull(voList.get(i).get("factoryCode")+""));
					SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
				    String receiptDate=voList.get(i).get("receiptDate")+"";
				    String enableDate=voList.get(i).get("enableDate")+"";
				    if(!"null".equals(receiptDate)) {
				    	equipmentDO.setReceiptDate(sdf.parse(receiptDate));
				    }
				    if(!"null".equals(enableDate) ) {
				    	equipmentDO.setEnableDate(sdf.parse(enableDate));
				    }
				    equipmentDO.setReceivingState(isNull(voList.get(i).get("receivingState")+""));
				    equipmentDO.setPlacePoint(isNull(voList.get(i).get("placePoint")+""));
				    equipmentDO.setSoftwareName(isNull(voList.get(i).get("softwareName")+""));
				    equipmentDO.setTechnicalParameter(isNull(voList.get(i).get("technicalParameter")+""));
				    equipmentDO.setWhetherCertify(isNull(voList.get(i).get("whetherCertify")+""));
	    			/**-------天津-end---------**/
					equipmentDO.setOrgId(oldList.get(i).getOrgId() + "");
					equipmentDO.setDeptId(oldList.get(i).getDeptId() + "");
					equipmentDO.setAreaCode(oldList.get(i).getAreaCode());
					equipmentDO.setCreateBy(oldList.get(i).getCreateBy());
					equipmentDO.setUpdateBy(vo.getUpdateBy());
					equipmentDO.setUpdateTime(DateUtil.getNowDate());
					if (equipmentDao.updateByPrimaryKey(equipmentDO) < 1) {
						throw new RuntimeException("更新失败，请检查数据格式。");
					}
	        	}
	        }
	    }
	    return true;
	}

	
	
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 同步base-server中的设备--检验化验仪器设备
	 * @Date 2020年3月10日 下午3:51:43
	 * @param contentJsonArr
	 * @return boolean
	 */
	public boolean synBaseServerEquipment(JSONArray contentJsonArr) {
		//删除质量有 库级没有的机构
		deleteSynData(contentJsonArr);
		
		Example exampleOrgList = new Example(EquipmentDO.class);
		Criteria criteriaOrgList = exampleOrgList.createCriteria();
		criteriaOrgList.andEqualTo("createBy", DataReceiveConstant.KJTS);
		criteriaOrgList.andIsNull("deleteTime");
		List<OrganizationDO> orgList = organizationMapper.selectByExample(exampleOrgList);
		for (int i = 0; i < contentJsonArr.size(); i++) {
			JSONObject jsonObject = contentJsonArr.getJSONObject(i);
			String sbyqmc = jsonObject.getString("sbyqmc");
			String sbbh = jsonObject.getString("sbbh");
			String kdmc = jsonObject.getString("kdmc");
			String kddm = jsonObject.getString("kddm");
			String cgjg = jsonObject.getString("cgjg");
			String whsj = jsonObject.getString("whsj");
			String sccj = jsonObject.getString("sccj");
			String sbzt = jsonObject.getString("sbzt");
//			String jgId = jsonObject.getString("jgId");
			
			EquipmentDO record = new EquipmentDO();
			record.setEquipmentName(sbyqmc);
			record.setDeviceCoding(sbbh);
			record.setUnit(kdmc);
			record.setValue(cgjg);
			record.setManufacturer(sccj);
			record.setUsingState(sbzt);
			record.setOrgId(kddm);
			
			for (OrganizationDO org : orgList) {
				/*if(org.getOrganizationCode().equals("911201101037433414001")) {
					System.out.println(11111111);
				}*/
				if(org.getOrganizationCode().contentEquals(kddm)) {
					record.setOrganizationId(org.getId());
				}
			}
			
			if(record.getOrganizationId() == null) {
				continue;
			}
			
//			record.setProductionDate(productionDate);
			try {
				record.setReceiptDate(DateUtil.stringToDate(whsj, "yyyy-MM-dd"));
			} catch (ParseException e) {
				e.printStackTrace();
			}
			
			Example exampleEqu = new Example(EquipmentDO.class);
			Criteria criteriaEqu = exampleEqu.createCriteria();
			criteriaEqu.andEqualTo("deviceCoding", sbbh);
			criteriaEqu.andIsNull("deleteTime");
			EquipmentDO dbDO = equipmentDao.selectOneByExample(exampleEqu);
			
			//若查不到 新增，查得到 修改
			if(dbDO == null) {
				record.buildKjPush();
				equipmentDao.insertSelective(record);
			}else {
				equipmentDao.updateByExampleSelective(record, exampleEqu);
			}
		}
		return true;
	}
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 删除质量有 库级没有的设备
	 * @Date 2020年3月18日 上午10:46:41
	 * @param contentJsonArr void
	 */
    private void deleteSynData(JSONArray contentJsonArr) {
    	//质量
    	Set<String> setLocal = equipmentDao.findDeviceCodingList(DataReceiveConstant.KJTS);
    	
    	//库级
    	Set<String> setPush = new HashSet<>();
    	for (int i = 0; i < contentJsonArr.size(); i++) {
    		String sbbh = contentJsonArr.getJSONObject(i).getString("sbbh");
    		setPush.add(sbbh);
		}
    	
    	//拿出质量-有,库级-没有的 删除
		setLocal.removeAll(setPush);
		if(setLocal.size() > 0) {
			equipmentDao.deleteByDeviceCodings(setLocal);
		}
	}
}
