package com.unis.quality.server.domain;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.quality.common.constant.Constant;
import com.unis.quality.common.dto.FoodStockDTO;
import com.unis.quality.common.vo.FoodStockItemsVO;
import com.unis.quality.common.vo.FoodStockVO;
import com.unis.quality.common.vo.GradeTestResultsItemsVO;
import com.unis.quality.common.vo.QualityPredictionAduitVO;
import com.unis.quality.common.vo.SummaryInspectionResultVO;
import com.unis.quality.common.vo.SummaryNotSuitableVO;
import com.unis.quality.common.vo.SummaryResultsItemsVO;
import com.unis.quality.common.vo.SummarySubstandardSampleVO;
import com.unis.quality.server.dao.FoodStockDao;
import com.unis.quality.server.dao.FoodStockItemsDao;
import com.unis.quality.server.dao.GradeTestResultsDao;
import com.unis.quality.server.dao.GradeTestResultsItemsDao;
import com.unis.quality.server.dao.SummaryResultsDao;
import com.unis.quality.server.entity.quality.FoodStockDO;
import com.unis.quality.server.entity.quality.FoodStockItemsDO;
import com.unis.quality.server.entity.quality.GradeTestResultsDO;
import com.unis.quality.server.entity.quality.GradeTestResultsItemsDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * 
 * @ClassName: QualityPredictionAduitService
 * @Description: 安全监测-结果审核   
 * @author lfx
 * @date 2019年7月10日15:01:34
 * 
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class FoodStockDomain  {
	@Autowired
	private SummaryResultsDao service1;
	
	@Autowired
	private SummaryResultsDomain service;
	
	@Autowired
	private QualityPredictionAduitDomain mapper;
   
	@Autowired
	private FoodStockDao foodMapper;
	
	@Autowired
	private FoodStockItemsDao foodItemsMapper;
	
	@Autowired
	private GradeTestResultsDao gradeMapper;
	
	@Autowired
	private GradeTestResultsItemsDao gradeItemsMapper;
	/**
	 * @Description 根据id查询登统表详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public FoodStockDO findByIdAndIsDeleted(String id,String zjda, int isDelete,String areaCode,String batch) throws Exception {
		Example example = new Example(FoodStockDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		String ac="";
		if (!"".equals(areaCode) && null != areaCode) {
	        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
	            ac= areaCode.substring(0, 2);
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	            ac= areaCode.substring(0, 4);
	        } else {
	            ac= areaCode;
	        }
	    }
		if("zjda".equals(zjda)) {//质检档案查询
			criteria.andEqualTo("planId", id);
			criteria.andLike("areaCode", ac+"%");
		}else {
			criteria.andEqualTo("id", id);
		}
		System.out.println(null!=batch);
		System.out.println("null"==batch);
		System.out.println(batch);
		if(null!=batch) {
			criteria.andEqualTo("batch", batch);
		}
		FoodStockDO qualityResultsDO = foodMapper.selectOneByExample(example);
		if (ObjectUtils.equals(qualityResultsDO, null)) {
			return null;
		}
		return qualityResultsDO;
	}
	
	/**
	 * @Description 根据planId查询登统表详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public List<FoodStockVO> findByIdLs(String id,String zjda, int isDelete,String areaCode,String batch) throws Exception {
		Example example = new Example(FoodStockDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		String ac="";
		if (!"".equals(areaCode) && null != areaCode) {
	        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
	            ac= areaCode.substring(0, 2);
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	            ac= areaCode.substring(0, 4);
	        } else {
	            ac= areaCode;
	        }
	    }
		if("zjda".equals(zjda)) {//质检档案查询
			criteria.andEqualTo("planId", id);
			criteria.andLike("areaCode", ac+"%");
		}else {
			criteria.andEqualTo("id", id);
		}
		if(!"".equals(batch)) {
			criteria.andEqualTo("batch", batch);
		}
		List<FoodStockDO> list = foodMapper.selectByExample(example);
		List<FoodStockVO> resultVOList = new ArrayList<>();
		if (!list.isEmpty()) {
			for (FoodStockDO resultDO : list) {
				FoodStockVO resultVO = LsBeanUtils.copyProperties(resultDO, FoodStockVO.class);
				resultVOList.add(resultVO);
			}
		}
		return resultVOList;
	}

    
    /**
	 * @Description 根据id查询登统表明细详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
    public List<FoodStockItemsVO> findItemsByIdAndIsDeleted(String id,String batch) throws Exception {
		Example example = new Example(FoodStockItemsDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("foodStockId", id);
		if(!"".equals(batch)) {
			criteria.andEqualTo("batch", batch);
		}
		List<FoodStockItemsDO> list = foodItemsMapper.selectByExample(example);
		List<FoodStockItemsVO> resultVOList = new ArrayList<>();
		if (!list.isEmpty()) {
			for (FoodStockItemsDO resultDO : list) {
				FoodStockItemsVO resultVO = LsBeanUtils.copyProperties(resultDO, FoodStockItemsVO.class);
				resultVOList.add(resultVO);
			}
		}
		return resultVOList;
	}
    
    /**
	 * @Description 根据id查询登记表详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
    public GradeTestResultsDO findGradeByIdAndIsDeleted(String id,String batch) throws Exception {
		Example example = new Example(GradeTestResultsDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("foodStockId", id);
		if(!"".equals(batch)) {
			criteria.andEqualTo("batch", batch);
		}
		GradeTestResultsDO gradeDO =  gradeMapper.selectOneByExample(example);
		if (ObjectUtils.equals(gradeDO, null)) {
			return null;
		}
		return gradeDO;
	}
    
    /**
   	 * @Description 根据id查询登记表明细详情
   	 * @version v1.0
   	 * @author lfx
   	 * @date 2018/10/24
   	 * @param id
   	 * @return
   	 * @throws Exception
   	 */
       public List<GradeTestResultsItemsVO> findGradeItemsByIdAndIsDeleted(FoodStockDTO fdto) throws Exception {
   		Example example = new Example(GradeTestResultsItemsDO.class);
   		Criteria criteria = example.createCriteria();
   		criteria.andIsNull("deleteTime");
   		String id=fdto.getPlanId();
		String type=fdto.getType();
		String batch=fdto.getBatch();
		String planFileName=fdto.getPlanFileName();
   		if(!"".equals(id)) {
   			criteria.andEqualTo("gradeTestResultsId", id);
   		}if(!"".equals(type)) {
   			criteria.andEqualTo("type", type);
   		}
   		if(!"".equals(batch)) {
			criteria.andEqualTo("batch", batch);
		}
   		if(null!=planFileName) {
			criteria.andEqualTo("planFileName", planFileName);
		}
   		List<GradeTestResultsItemsDO> list = gradeItemsMapper.selectByExample(example);
   		List<GradeTestResultsItemsVO> resultVOList = new ArrayList<>();
   		if (!list.isEmpty()) {
   			for (GradeTestResultsItemsDO resultDO : list) {
   				GradeTestResultsItemsVO resultVO = LsBeanUtils.copyProperties(resultDO, GradeTestResultsItemsVO.class);
   				/*if(resultVO.getWaterContent()>=1 && resultVO.getWaterContent()<8) {
   					list.remove(resultDO);
   				}*/
   				resultVOList.add(resultVO);
   			}
   		}
   		return resultVOList;
   	}
	
	public Map<String, Object> findByPage1(FoodStockVO qualityVO, Integer page, Integer size) throws Exception {
    	
		Example example = new Example(FoodStockDO.class);
		Criteria criteria = example.createCriteria();
		//数据过滤
		 String areaCode=qualityVO.getAreaCode();
		 String deptName=qualityVO.getDeptId();
		 QualityPredictionAduitVO vo=new QualityPredictionAduitVO();
		 vo.setAreaCode(areaCode);
		 vo.setDeptId(deptName);
		 vo.setFindingsAudit(qualityVO.getFindingsAudit());
		 vo.setState(qualityVO.getState());
		 Map<String,Object> map=mapper.findByArea(vo);
		 String condition1=map.get("condition").toString();
		 String conditionZt=map.get("conditionZt").toString();
		 String ac=map.get("areaCode").toString();
		 criteria.andCondition("1=1");
		 if("".equals(conditionZt)) {
			 criteria.andCondition(condition1);
		 }
		 //添加按状态查询
		 if(!"".equals(conditionZt)) {
			 criteria.andCondition(conditionZt);
		 }
	     criteria.andLike("areaCode",  ac + "%");
		// 添加按承储企业名称查询
		if (!"".equals(qualityVO.getPlanFileName()) && null != qualityVO.getPlanFileName()) {
			criteria.andLike("planFileName", "%" + qualityVO.getPlanFileName() + "%");
		}
		// 添加按计划下发时间查询
		if (!"".equals(qualityVO.getCity()) && null != qualityVO.getCity()) {
			criteria.andLike("city", "%" + qualityVO.getCity() + "%");
		}
		// 未删除的
		criteria.andIsNull("deleteTime");
		// 按时间排序
		example.setOrderByClause("CREATE_TIME DESC");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<FoodStockDO> resultQualityList = foodMapper.selectByExample(example);
		PageInfo<FoodStockDO> pageInfo = new PageInfo<FoodStockDO>(resultQualityList);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<FoodStockVO> resultList = new ArrayList<>();
		if (!resultQualityList.isEmpty()) {
			for (FoodStockDO resultDO : resultQualityList) {
				FoodStockVO resultVO = LsBeanUtils.copyProperties(resultDO, FoodStockVO.class);
				if(ac.length()==2) {//省
					if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("15".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("12".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("驳回");
							}if("8".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}if("10".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("8".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}if("11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}/*if("12".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}*/
						}
					}
					if((Constant.LSJ).equals(deptName)) {
						if("10".equals(resultVO.getFindingsAudit())) {
							resultVO.setStateName("未审核");
						}
					}
					
				}else if(ac.length()==4) {//市
					if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("14".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}
							if("5".equals(resultVO.getFindingsAudit()) || "4".equals(resultVO.getFindingsAudit()) || "6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}if("15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("4".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("未上报");
							}
							if("5".equals(resultVO.getFindingsAudit()) || "15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit())||"6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}
						}
						
					}
					if((Constant.LSJ).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("5".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("15".equals(resultVO.getFindingsAudit()) || "6".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}
						if("上报".equals(qualityVO.getState())) {
							if("15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}
							if("6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}
						}
					}
				}
				else {//县
					if((Constant.LSJ).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("1".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
									resultVO.setStateName("审核通过");
								}
						}if("上报".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}if("14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("已上报");
								}
						}
						
					}if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
								||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
								||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("已上报");
							}
						}
						
					}
				}
				resultList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultList);
		return resultMap;
	}
	
	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletesFoodStock(String[] ids,String batch,String areaCode,String deptName) throws Exception {
		for (String id : ids) {
			Example example = new Example(FoodStockDO.class);
			Criteria criteria = example.createCriteria();
			if (!"".equals(areaCode) && null != areaCode) {
		        String condition = "";
		        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
		        	 condition = " FINDINGS_AUDIT ='8'  and AREA_CODE="+areaCode;
		        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
		            condition = " FINDINGS_AUDIT ='4'  and AREA_CODE="+areaCode;
		        } else {
		            condition = " FINDINGS_AUDIT ='0' ";
		        }
		        criteria.andCondition(condition);
			}
			
			criteria.andEqualTo("id", id);
			criteria.andEqualTo("batch", batch);
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			FoodStockDO qDO = foodMapper.selectOneByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				qDO.setDeleteBy(deptName);
				qDO.setDeleteTime(DateUtil.getNowDate());
				foodMapper.updateByPrimaryKey(qDO);
			}
		}
		return true;
	}

    public boolean deletesFoodStockItems(String[] ids,String batch,String deptName) throws Exception {
		for (String id : ids) {
			Example example = new Example(FoodStockItemsDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("foodStockId", id);
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			criteria.andEqualTo("batch", batch);
			List<FoodStockItemsDO> qDO = foodItemsMapper.selectByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				for(int i=0;i<qDO.size();i++) {
					qDO.get(i).setDeleteBy(deptName);
					qDO.get(i).setDeleteTime(DateUtil.getNowDate());
					foodItemsMapper.updateByPrimaryKey(qDO.get(i));
				}
			}
		}
		return true;
	}
    
    public boolean deletesGrade(String[] ids,String batch,String deptName) throws Exception {
		for (String id : ids) {
			Example example = new Example(GradeTestResultsDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("foodStockId", id);
			criteria.andEqualTo("batch", batch);
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			GradeTestResultsDO qDO = gradeMapper.selectOneByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				qDO.setDeleteBy(deptName);
				qDO.setDeleteTime(DateUtil.getNowDate());
				gradeMapper.updateByPrimaryKey(qDO);
			}
		}
		return true;
	}

    public boolean deletesGradeItems(String[] ids,String batch,String deptName) throws Exception {
		for (String id : ids) {
			Example example = new Example(GradeTestResultsItemsDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("foodStockId", id);
			criteria.andEqualTo("batch", batch);
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			List<GradeTestResultsItemsDO> qDO = gradeItemsMapper.selectByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				for(int i=0;i<qDO.size();i++) {
					qDO.get(i).setDeleteBy(deptName);
					qDO.get(i).setDeleteTime(DateUtil.getNowDate());
					gradeItemsMapper.updateByPrimaryKey(qDO.get(i));
				}
			}
		}
		return true;
	}
    
    
    
    //保存登统表信息
    public boolean saveFoodStock(Map<String,Object> aduitData,FoodStockDO resultsDO) {
    	Example example = new Example(FoodStockDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andLike("areaCode",  resultsDO.getAreaCode() + "%");
    	if (!"".equals(aduitData.get("planFileName")) && null != aduitData.get("planFileName")) {
			criteria.andEqualTo("planFileName", aduitData.get("planFileName"));
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		String condition = " FINDINGS_AUDIT not in ('3' ,'13','9','7','12')";
    	criteria.andCondition(condition);
		if (foodMapper.selectCountByExample(example) > 0) {
			throw new RuntimeException(aduitData.get("planFileName") + "已存在!");
		}
		resultsDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
		resultsDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
		resultsDO.setCity(mapper.isNull(aduitData.get("city")+""));
		resultsDO.setType(mapper.isNull(aduitData.get("type")+""));
		resultsDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
		resultsDO.setFillingDate(mapper.isNull(aduitData.get("fillingDate")+""));
		resultsDO.setRegistrar(mapper.isNull(aduitData.get("registrar")+""));
		resultsDO.setCreateTime(DateUtil.getNowDate());
		resultsDO.setStateName("未上报");
		if (foodMapper.insert(resultsDO) < 1) {
			throw new RuntimeException(resultsDO.getPlanFileName() + "无法保存成功，请检查数据。");
		}
			
		return true;
    }
    
    //保存登统表详细信息
    public boolean saveFoodStockItems(List<Map> itemsData,FoodStockDO resultsDO) {
    	Example example1 = new Example(FoodStockItemsDO.class);
		Criteria criteria1 = example1.createCriteria();
		String areaCode=resultsDO.getAreaCode();
		for (int t = 0; t < itemsData.size(); t++) {
			if (itemsData.get(t) != null) {
				if(null==itemsData.get(t).get("id")) {
					criteria1.andLike("areaCode",  areaCode + "%");
					if (!"".equals(itemsData.get(t).get("sampleNumber")) && null != itemsData.get(t).get("sampleNumber")) {
						criteria1.andEqualTo("sampleNumber", itemsData.get(t).get("sampleNumber"));
					}
					criteria1.andIsNull("deleteTime");
					/*if (foodItemsMapper.selectCountByExample(example1) > 0) {
						throw new RuntimeException(itemsData.get(t).get("sampleNumber")+ "已存在!");
					}*/
					FoodStockItemsDO itemsDO = new FoodStockItemsDO();
					itemsDO.setBatch(resultsDO.getBatch());
					itemsDO.setFoodStockId(resultsDO.getId());//登统表id
					itemsDO.setSampleNumber(mapper.isNull(itemsData.get(t).get("sampleNumber")+""));
					itemsDO.setCheckLibraryPoints(mapper.isNull(itemsData.get(t).get("checkLibraryPoints")+""));
					itemsDO.setWarehouse(mapper.isNull(itemsData.get(t).get("warehouse")+""));
					itemsDO.setNature(mapper.isNull(itemsData.get(t).get("nature")+""));
					itemsDO.setVarieties(mapper.isNull(itemsData.get(t).get("varieties")+""));
					String behalfNumber=mapper.isNull(itemsData.get(t).get("behalfNumber")+"");
					if(!"".equals(behalfNumber)) {
						itemsDO.setBehalfNumber(Integer.parseInt(behalfNumber));
					}
					itemsDO.setStorageGrade(mapper.isNull(itemsData.get(t).get("storageGrade")+""));
					itemsDO.setPlaceOrigin(mapper.isNull(itemsData.get(t).get("placeOrigin")+""));
					itemsDO.setYears(mapper.isNull(itemsData.get(t).get("years")+""));
					itemsDO.setStorageTime(mapper.isNull(itemsData.get(t).get("storageTime")+""));
					itemsDO.setPackagingOrBulkPacking(mapper.isNull(itemsData.get(t).get("packagingOrBulkPacking")+""));
					itemsDO.setLocalSafeStorageOfWater(mapper.isNull(itemsData.get(t).get("localSafeStorageOfWater")+""));
					itemsDO.setGrainTemperature(mapper.isNull(itemsData.get(t).get("grainTemperature")+""));
					itemsDO.setStorageTechnology(mapper.isNull(itemsData.get(t).get("storageTechnology")+""));
					itemsDO.setRemarks(mapper.isNull(itemsData.get(t).get("remarks")+""));
					itemsDO.setAreaCode(resultsDO.getAreaCode());
					itemsDO.setCreateBy(resultsDO.getCreateBy());
					itemsDO.setCreateTime(DateUtil.getNowDate());
					if (foodItemsMapper.insert(itemsDO) < 1) {
						throw new RuntimeException(itemsDO.getSampleNumber() + "无法保存成功，请检查数据。");
					}
				}
			}
		}
    	return true;
    }
    
    //保存登记表信息
    public boolean saveGradeTest(Map<String,Object> aduitData,GradeTestResultsDO resultsDO) {
    	Example example2 = new Example(GradeTestResultsDO.class);
		Criteria criteria2 = example2.createCriteria();
		String areaCode=resultsDO.getAreaCode();
		criteria2.andLike("areaCode",  areaCode + "%");
		if (!"".equals(aduitData.get("planFileName")) && null != aduitData.get("planFileName")) {
			criteria2.andEqualTo("planFileName", aduitData.get("planFileName"));
		}
		if (!"".equals(aduitData.get("foodStockId")) && null != aduitData.get("foodStockId")) {
			criteria2.andEqualTo("foodStockId", aduitData.get("foodStockId"));
		}
		// 未删除
		criteria2.andIsNull("deleteTime");
		/*if (gradeMapper.selectCountByExample(example2) > 0) {
			throw new RuntimeException(aduitData.get("planFileName") + "已存在");
		}*/
		resultsDO.setFoodStockId(mapper.isNull(aduitData.get("varietiesId")+""));//
		resultsDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
		resultsDO.setCity(mapper.isNull(aduitData.get("city")+""));
		resultsDO.setType(mapper.isNull(aduitData.get("type")+""));
		resultsDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
		resultsDO.setFillingDate(mapper.isNull(aduitData.get("fillingDate")+""));
		resultsDO.setVarieties(mapper.isNull(aduitData.get("varieties")+""));
		
		resultsDO.setCreateTime(DateUtil.getNowDate());
		if (gradeMapper.insert(resultsDO) < 1) {
			throw new RuntimeException(resultsDO.getPlanFileName() + "无法保存成功，请检查数据。");
		}
    	return true;
    }
    
    //保存登记表详细信息
    public boolean saveGradeTestItems(List<Map> itemsData,GradeTestResultsDO resultsDO) {
    	if(itemsData.size() > 0 && itemsData != null) {
			Example example3 = new Example(GradeTestResultsItemsDO.class);
			Criteria criteria3 = example3.createCriteria();
			String areaCode=resultsDO.getAreaCode();
			criteria3.andLike("areaCode",  areaCode + "%");
			for (int t = 0; t < itemsData.size(); t++) {
				if (itemsData.get(t) != null) {
					if(null==itemsData.get(t).get("id1")) {
						if (!"".equals(itemsData.get(t).get("sampleNumber")) && null != itemsData.get(t).get("sampleNumber")) {
							criteria3.andEqualTo("sampleNumber", itemsData.get(t).get("sampleNumber"));
						}						
						criteria3.andIsNull("deleteTime");
						/*if (gradeItemsMapper.selectCountByExample(example3) > 0) {
							throw new RuntimeException(itemsData.get(t).get("sampleNumber") + "已存在");
						}*/
					    GradeTestResultsItemsDO itemsDO = new GradeTestResultsItemsDO();
					    itemsDO.setBatch(resultsDO.getBatch());
						itemsDO.setGradeTestResultsId(resultsDO.getId());//登记表id
						itemsDO.setFoodStockId(itemsData.get(t).get("foodStockId")+"");
						itemsDO.setSampleNumber(mapper.isNull(itemsData.get(t).get("sampleNumber")+""));
						itemsDO.setCheckLibraryPoints(mapper.isNull(itemsData.get(t).get("checkLibraryPoints")+""));
						itemsDO.setWarehouse(mapper.isNull(itemsData.get(t).get("warehouse")+""));
						itemsDO.setNature(mapper.isNull(itemsData.get(t).get("nature")+""));
						itemsDO.setVarieties(mapper.isNull(itemsData.get(t).get("varieties")+""));
						itemsDO.setBehalfNumber(mapper.isNull(itemsData.get(t).get("behalfNumber")+""));
						itemsDO.setStorageGrade(mapper.isNull(itemsData.get(t).get("storageGrade")+""));
						itemsDO.setPlaceOrigin(mapper.isNull(itemsData.get(t).get("placeOrigin")+""));
						itemsDO.setYears(mapper.isNull(itemsData.get(t).get("years")+""));
						itemsDO.setStorageTime(mapper.isNull(itemsData.get(t).get("storageTime")+""));
						String waterContent=mapper.isNull(itemsData.get(t).get("waterContent")+"");
						if(!"".equals(waterContent)) {
							itemsDO.setWaterContent(Integer.parseInt(waterContent));
						}
						itemsDO.setImpurity(mapper.isNull(itemsData.get(t).get("impurity")+""));
						itemsDO.setImperfectGrain(mapper.isNull(itemsData.get(t).get("imperfectGrain")+""));
						itemsDO.setBulkDensity(mapper.isNull(itemsData.get(t).get("bulkDensity")+""));
						itemsDO.setColourSmell(mapper.isNull(itemsData.get(t).get("colourSmell")+""));
						itemsDO.setMoldyKernel(mapper.isNull(itemsData.get(t).get("moldyKernel")+""));
						itemsDO.setTasteScore(mapper.isNull(itemsData.get(t).get("tasteScore")+""));
						itemsDO.setFattyAcidValue(mapper.isNull(itemsData.get(t).get("fattyAcidValue")+""));
						itemsDO.setInspectionGrade(mapper.isNull(itemsData.get(t).get("inspectionGrade")+""));
						itemsDO.setResultJudgment(mapper.isNull(itemsData.get(t).get("resultJudgment")+""));
						itemsDO.setIntegrityRateGranule(mapper.isNull(itemsData.get(t).get("integrityRateGranule")+""));
						itemsDO.setDamageRateGranule(mapper.isNull(itemsData.get(t).get("damageRateGranule")+""));
						itemsDO.setRoughness(mapper.isNull(itemsData.get(t).get("roughness")+""));
						itemsDO.setBrownRice(mapper.isNull(itemsData.get(t).get("brownRice")+""));
						itemsDO.setHeadRiceRate(mapper.isNull(itemsData.get(t).get("headRiceRate")+""));
						itemsDO.setMixingRate(mapper.isNull(itemsData.get(t).get("mixingRate")+""));
						itemsDO.setYellowGrainedRice(mapper.isNull(itemsData.get(t).get("yellowGrainedRice")+""));
						itemsDO.setFattyAcidValueStorage(mapper.isNull(itemsData.get(t).get("fattyAcidValueStorage")+""));
						itemsDO.setViscosity(mapper.isNull(itemsData.get(t).get("viscosity")+""));
						itemsDO.setTasteScoreStorage(mapper.isNull(itemsData.get(t).get("tasteScoreStorage")+""));
						itemsDO.setColourSmellStorage(mapper.isNull(itemsData.get(t).get("colourSmellStorage")+""));
						itemsDO.setResultJudgmentStorage(mapper.isNull(itemsData.get(t).get("resultJudgmentStorage")+""));
						itemsDO.setGlutenWaterAbsorption(mapper.isNull(itemsData.get(t).get("glutenWaterAbsorption")+""));
						itemsDO.setProteinSolubilityRatio(mapper.isNull(itemsData.get(t).get("proteinSolubilityRatio")+""));
						itemsDO.setType("2");
						
						itemsDO.setAreaCode(resultsDO.getAreaCode());
						itemsDO.setCreateBy(resultsDO.getCreateBy());
						itemsDO.setCreateTime(DateUtil.getNowDate());
						if (gradeItemsMapper.insert(itemsDO) < 1) {
							throw new RuntimeException(itemsDO.getSampleNumber() + "无法保存成功，请检查数据。");
						}
					}
				}
			}
		}
    	return true;
    }

    //修改登统表信息
    public boolean updateFoodStock(Map<String,Object> aduitData,FoodStockDO resultsDO) throws Exception {
    	Example example = new Example(FoodStockDO.class);
		Criteria criteria = example.createCriteria();
		String areaCode=resultsDO.getAreaCode();
		String deptName=resultsDO.getDeptId();
		criteria.andLike("areaCode",  areaCode + "%");
		QualityPredictionAduitVO vo=new QualityPredictionAduitVO();
		vo.setAreaCode(areaCode);
		vo.setDeptId(deptName);
		Map<String,Object> map=mapper.findByArea(vo);
	    String ac=map.get("areaCode").toString();
		FoodStockDO qualityResultsDO = findByIdAndIsDeleted(aduitData.get("id")+"","", 0,areaCode,resultsDO.getBatch());
		if (ObjectUtils.equals(qualityResultsDO, null)) {
			throw new RuntimeException("此数据未存储到数据库中。");
		}
		String ss=aduitData.get("createTime")+"" ;
		if(null!=ss) {
			SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
			Date dateStr = sdf.parse(ss);
			resultsDO.setCreateTime(dateStr);
		}
		resultsDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
		resultsDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
		resultsDO.setCity(mapper.isNull(aduitData.get("city")+""));
		resultsDO.setType(mapper.isNull(aduitData.get("type")+""));
		resultsDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
		resultsDO.setFillingDate(mapper.isNull(aduitData.get("fillingDate")+""));
		resultsDO.setRegistrar(mapper.isNull(aduitData.get("registrar")+""));
		resultsDO.setId(mapper.isNull(aduitData.get("id")+""));
		//if("0".equals(aduitData.get("findingsAudit"))|| "4".equals(aduitData.get("findingsAudit"))) {
			/*if(ac.length()==4) {
				if(null==aduitData.get("shzjzxState")) {
					resultsDO.setFindingsAudit("4");
				}
			}else if(ac.length()==6) {
				if(null==aduitData.get("xlsjState")) {
					resultsDO.setFindingsAudit("0");
				}
			}*/
		//}
		resultsDO.setProcessId(mapper.isNull(aduitData.get("processId")+""));
		resultsDO.setCreateBy(mapper.isNull(aduitData.get("createBy")+""));
		resultsDO.setAreaCode(qualityResultsDO.getAreaCode());
		resultsDO.setUpdateTime(DateUtil.getNowDate());
		if (foodMapper.updateByPrimaryKey(resultsDO) < 1) {
			throw new RuntimeException("更新失败，请检查数据格式。");
		}
			
		return true;
    }
    
  //修改登统表详细信息
    public boolean updateFoodStockItems(List<Map> itemsData,String id,String batch) throws Exception {
    	List<FoodStockItemsVO> oldList = findItemsByIdAndIsDeleted(id,batch); 
		int num = itemsData.size(); 
		if(itemsData != null&&itemsData.size() > 0){ 
	        //检查页面的信息是否有修改，然后更新到数据库 
	        for(int t = 0; t<num; t++){
	        	if(null==itemsData.get(t).get("id")) {
	        		FoodStockDO resultsDO=new FoodStockDO();
	        		resultsDO.setId(id);
	        		resultsDO.setBatch(batch);
	        		saveFoodStockItems(itemsData,resultsDO);
	        	}else {
	        		FoodStockItemsDO itemsDO = new FoodStockItemsDO();
	        		itemsDO.setBatch(batch);
					itemsDO.setFoodStockId(id);//登统表id
					itemsDO.setId(oldList.get(t).getId());
					itemsDO.setSampleNumber(mapper.isNull(itemsData.get(t).get("sampleNumber")+""));
					itemsDO.setCheckLibraryPoints(mapper.isNull(itemsData.get(t).get("checkLibraryPoints")+""));
					itemsDO.setWarehouse(mapper.isNull(itemsData.get(t).get("warehouse")+""));
					itemsDO.setNature(mapper.isNull(itemsData.get(t).get("nature")+""));
					itemsDO.setVarieties(mapper.isNull(itemsData.get(t).get("varieties")+""));
					String behalfNumber=mapper.isNull(itemsData.get(t).get("behalfNumber")+"");
					if(!"".equals(behalfNumber)) {
						itemsDO.setBehalfNumber(Integer.parseInt(behalfNumber));
					}
					itemsDO.setStorageGrade(mapper.isNull(itemsData.get(t).get("storageGrade")+""));
					itemsDO.setPlaceOrigin(mapper.isNull(itemsData.get(t).get("placeOrigin")+""));
					itemsDO.setYears(mapper.isNull(itemsData.get(t).get("years")+""));
					itemsDO.setStorageTime(mapper.isNull(itemsData.get(t).get("storageTime")+""));
					itemsDO.setPackagingOrBulkPacking(mapper.isNull(itemsData.get(t).get("packagingOrBulkPacking")+""));
					itemsDO.setLocalSafeStorageOfWater(mapper.isNull(itemsData.get(t).get("localSafeStorageOfWater")+""));
					itemsDO.setGrainTemperature(mapper.isNull(itemsData.get(t).get("grainTemperature")+""));
					itemsDO.setStorageTechnology(mapper.isNull(itemsData.get(t).get("storageTechnology")+""));
					itemsDO.setRemarks(mapper.isNull(itemsData.get(t).get("remarks")+""));
					itemsDO.setAreaCode(itemsData.get(t).get("areaCode")+"");
					itemsDO.setCreateTime(DateUtil.getNowDate());
					if (foodItemsMapper.updateByPrimaryKey(itemsDO) < 1) {
						throw new RuntimeException("更新失败，请检查数据格式。");
					}
	        	}
			}
		}
    	return true;
    }
    
  //修改登记表信息
    public boolean updateGradeTest(Map<String,Object> aduitData,GradeTestResultsDO grado) throws Exception {
    	Example example2 = new Example(GradeTestResultsDO.class);
		Criteria criteria2 = example2.createCriteria();
		GradeTestResultsDO qualityResultsDO = findGradeByIdAndIsDeleted(aduitData.get("foodStockId")+"",aduitData.get("batch")+"");
		if (ObjectUtils.equals(qualityResultsDO, null)) {
			GradeTestResultsDO resultsDO1 = new GradeTestResultsDO();
			resultsDO1.setId(grado.getId());
			resultsDO1.setBatch(String.valueOf(aduitData.get("batch")));
			resultsDO1.setAreaCode(grado.getAreaCode());
			saveGradeTest(aduitData,resultsDO1);
		}else {
			GradeTestResultsDO resultsDO=new GradeTestResultsDO();
			resultsDO.setBatch(mapper.isNull(aduitData.get("batch")+""));
			resultsDO.setFoodStockId(mapper.isNull(aduitData.get("varietiesId")+""));
			resultsDO.setId(mapper.isNull(aduitData.get("id")+""));
			resultsDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
			resultsDO.setCity(mapper.isNull(aduitData.get("city")+""));
			resultsDO.setType(mapper.isNull(aduitData.get("type")+""));
			resultsDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
			resultsDO.setFillingDate(mapper.isNull(aduitData.get("fillingDate")+""));
			resultsDO.setVarieties(mapper.isNull(aduitData.get("varieties")+""));
			resultsDO.setAreaCode(aduitData.get("areaCode")+"");
			resultsDO.setCreateTime(DateUtil.getNowDate());
			if (gradeMapper.updateByPrimaryKey(resultsDO) < 1) {
				throw new RuntimeException("更新失败，请检查数据格式。");
			}
		}
    	return true;
    }
    
    
    //修改登记表详细信息
    public boolean updateGradeTestItems(List<Map> itemsData,String id,String batch) throws Exception {
    	FoodStockDTO fdto=new FoodStockDTO();
    	fdto.setPlanId(id);
    	fdto.setBatch(batch);
    	List<GradeTestResultsItemsVO> oldList = findGradeItemsByIdAndIsDeleted(fdto); 
    	if(oldList.size()==0) {
    		   GradeTestResultsDO resultsDO=new GradeTestResultsDO();
			   resultsDO.setId(id);
			   resultsDO.setBatch(batch);
			   saveGradeTestItems(itemsData,resultsDO);
    	}else {
    		int num = itemsData.size(); 
    		if(itemsData != null&&itemsData.size() > 0){ 
    	        //检查页面的信息是否有修改，然后更新到数据库 
    	        for(int t = 0; t<num; t++){
    				 /*  if(null==itemsData.get(t).get("id")) {
    					
    				   }else {*/
    					   GradeTestResultsItemsDO itemsDO = new GradeTestResultsItemsDO();
    					   	itemsDO.setBatch(batch);
    						itemsDO.setGradeTestResultsId(mapper.isNull(itemsData.get(t).get("gradeTestResultsId")+""));//登统表id
    						itemsDO.setFoodStockId(oldList.get(t).getFoodStockId());
    						itemsDO.setId(mapper.isNull(itemsData.get(t).get("id")+""));
    						itemsDO.setSampleNumber(mapper.isNull(itemsData.get(t).get("sampleNumber")+""));
    						itemsDO.setCheckLibraryPoints(mapper.isNull(itemsData.get(t).get("checkLibraryPoints")+""));
    						itemsDO.setWarehouse(mapper.isNull(itemsData.get(t).get("warehouse")+""));
    						itemsDO.setNature(mapper.isNull(itemsData.get(t).get("nature")+""));
    						itemsDO.setVarieties(mapper.isNull(itemsData.get(t).get("varieties")+""));
    						itemsDO.setBehalfNumber(mapper.isNull(itemsData.get(t).get("behalfNumber")+""));
    						itemsDO.setStorageGrade(mapper.isNull(itemsData.get(t).get("storageGrade")+""));
    						itemsDO.setPlaceOrigin(mapper.isNull(itemsData.get(t).get("placeOrigin")+""));
    						itemsDO.setYears(mapper.isNull(itemsData.get(t).get("years")+""));
    						itemsDO.setStorageTime(mapper.isNull(itemsData.get(t).get("storageTime")+""));
    						String waterContent=mapper.isNull(itemsData.get(t).get("waterContent")+"");
    						if(!"".equals(waterContent)) {
    							itemsDO.setWaterContent(Integer.parseInt(waterContent));
    						}
    						itemsDO.setImpurity(mapper.isNull(itemsData.get(t).get("impurity")+""));
    						itemsDO.setImperfectGrain(mapper.isNull(itemsData.get(t).get("imperfectGrain")+""));
    						itemsDO.setBulkDensity(mapper.isNull(itemsData.get(t).get("bulkDensity")+""));
    						itemsDO.setColourSmell(mapper.isNull(itemsData.get(t).get("colourSmell")+""));
    						itemsDO.setMoldyKernel(mapper.isNull(itemsData.get(t).get("moldyKernel")+""));
    						itemsDO.setTasteScore(mapper.isNull(itemsData.get(t).get("tasteScore")+""));
    						itemsDO.setFattyAcidValue(mapper.isNull(itemsData.get(t).get("fattyAcidValue")+""));
    						itemsDO.setInspectionGrade(mapper.isNull(itemsData.get(t).get("inspectionGrade")+""));
    						itemsDO.setResultJudgment(mapper.isNull(itemsData.get(t).get("resultJudgment")+""));
    						itemsDO.setIntegrityRateGranule(mapper.isNull(itemsData.get(t).get("integrityRateGranule")+""));
    						itemsDO.setDamageRateGranule(mapper.isNull(itemsData.get(t).get("damageRateGranule")+""));
    						itemsDO.setRoughness(mapper.isNull(itemsData.get(t).get("roughness")+""));
    						itemsDO.setBrownRice(mapper.isNull(itemsData.get(t).get("brownRice")+""));
    						itemsDO.setHeadRiceRate(mapper.isNull(itemsData.get(t).get("headRiceRate")+""));
    						itemsDO.setMixingRate(mapper.isNull(itemsData.get(t).get("mixingRate")+""));
    						itemsDO.setYellowGrainedRice(mapper.isNull(itemsData.get(t).get("yellowGrainedRice")+""));
    						itemsDO.setFattyAcidValueStorage(mapper.isNull(itemsData.get(t).get("fattyAcidValueStorage")+""));
    						itemsDO.setViscosity(mapper.isNull(itemsData.get(t).get("viscosity")+""));
    						itemsDO.setTasteScoreStorage(mapper.isNull(itemsData.get(t).get("tasteScoreStorage")+""));
    						itemsDO.setColourSmellStorage(mapper.isNull(itemsData.get(t).get("colourSmellStorage")+""));
    						itemsDO.setResultJudgmentStorage(mapper.isNull(itemsData.get(t).get("resultJudgmentStorage")+""));
    						itemsDO.setGlutenWaterAbsorption(mapper.isNull(itemsData.get(t).get("glutenWaterAbsorption")+""));
    						itemsDO.setProteinSolubilityRatio(mapper.isNull(itemsData.get(t).get("proteinSolubilityRatio")+""));
    						itemsDO.setType(mapper.isNull(oldList.get(t).getType()));
    						itemsDO.setAreaCode(oldList.get(t).getAreaCode());
    						itemsDO.setUpdateTime(DateUtil.getNowDate());
    						if (gradeItemsMapper.updateByPrimaryKey(itemsDO) < 1) {
    							throw new RuntimeException("更新失败，请检查数据格式。");
    						}
    				   //}
    				}
    		     }
    	}
		
    	return true;
    }
	
    /**
	 * @Description 安全监测-结果上报
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月19日15:12:44
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateState1(FoodStockDTO fdto) throws Exception{
		Example example = new Example(FoodStockDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("id", fdto.getId());
		// 未删除的
		criteria.andIsNull("deleteTime");
		FoodStockDO qDO = foodMapper.selectOneByExample(example);
		if (ObjectUtils.notEqual(qDO, null)) {
			 qDO.setFindingsAudit(fdto.getFindingsAudit());
		     qDO.setStateName("已上报");
			foodMapper.updateByPrimaryKey(qDO);
		}
		return true;
	}
	
	
	/**
	 * @Description 安全监测-结果上报
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月19日15:12:44
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateState(FoodStockDTO fDto) throws Exception{
		boolean bool=false;
		if("1".equals(fDto.getType())) {//旗县盟市
			bool=updateState1(fDto);
		}else {//自治区
			bool=service.updateState(fDto);
		}
		return bool;
	}
	/**
	 * @Description 样品信息同步
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> getSampleInformation(FoodStockDTO fDto) throws Exception{
		//数据过滤
		 String areaCode=fDto.getAreaCode();
		 String findingsAudit="";
		//FindingsAudit
		if (!"".equals(areaCode) && null != areaCode) {
	        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
	        	findingsAudit="8";
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	        	findingsAudit="4";
	        } else {
	        	findingsAudit="0";
	        }
		}
		// 未删除的收购资格
		fDto.setAreaCode(areaCode);
		fDto.setFindingsAudit(findingsAudit);
		List<Map> list = foodMapper.getSampleInformation(fDto);
		return list;
	}
	
	/**
	 * @Description 查询数据库中最大batch
	 * @version v1.0
	 * @author lfx
	 * @date 2019年8月16日11:28:06
	 * @param codedate
	 * @return String
	 * @throws Exception
	 */
	public  String queryMaxBatch(FoodStockDTO fDto) throws Exception{
		String batch = foodMapper.queryMaxBatch(fDto);
		return batch;
	}
	
	/**
	 * @Description 自治区、盟市、旗县汇总
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public Map<String,Object> getAll(String type,String areaCode) throws Exception{
		//数据过滤
		 String findingsAudit="";
		//FindingsAudit
		 String ac="";
		if (!"".equals(areaCode) && null != areaCode) {
		 if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
			 ac= areaCode.substring(0, 2);
	        	//findingsAudit="8";
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	        	 ac= areaCode.substring(0, 4);
        	//findingsAudit="6";
	        } else {
	        	 ac= areaCode;
	        	//findingsAudit="2";
	        }
		}
		FoodStockDTO fDto=new FoodStockDTO ();
		//fDto.setCity(areaCode);
		fDto.setAreaCode(ac);
		fDto.setFindingsAudit(findingsAudit);
		fDto.setType(type);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<Map> list =new ArrayList();
		if("1".equals(type)) {//登统表
			 list = foodMapper.getSampleInformation(fDto);
			 resultMap.put("itemsData", list);
		}else if("2".equals(type)){//登记表
			GradeTestResultsDO gradeDO=new GradeTestResultsDO ();
			//gradeDO.setCity(areaCode);
			fDto.setAreaCode(ac);
			gradeDO.setFindingsAudit(findingsAudit);
			gradeDO.setType(type);
			list=gradeMapper.getAllGradeTest(gradeDO);
			resultMap.put("itemsData", list);
		}else if("3".equals(type)) {//3、粮食质量检验结果汇总表-明细表
			List<SummaryResultsItemsVO> listData = service.findItemsByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}else if("4".equals(type)){//4、质量不达标样品汇总表
			List<SummarySubstandardSampleVO> listData=service.findSampleByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}else if("5".equals(type)){//5、粮食储存品质检验结果汇总表
			List<SummaryInspectionResultVO>  listData=service.findInspectionByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}else if("6".equals(type)){//6、储存品质不宜存样品汇总表
			List<SummaryNotSuitableVO>   listData=service.findyNotSuitableByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}else if("7".equals(type)){//7、检验等级与验收等级不符样品汇总表
			List<GradeTestResultsItemsVO> listData=findGradeItemsByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}
		return resultMap;
	}
	
	
	/**
	 * @Description 自治区、盟市、旗县质检档案
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public Map<String,Object> AllInformation(FoodStockDTO fDto) throws Exception{
		//数据过滤fDto.getType(),fDto.getAreaCode(),fDto.getPlanFileName(),fDto.getyears()
		 String findingsAudit="";
		 String type=fDto.getType();
		 String areaCode=fDto.getAreaCode();
		 String planFileName=fDto.getPlanFileName();
		 String ac="";
		if (!"".equals(areaCode) && null != areaCode) {
		 if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
			 ac= areaCode.substring(0, 2);
	        	//findingsAudit="8";
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	        	 ac= areaCode.substring(0, 4);
        	//findingsAudit="6";
	        } else {
	        	 ac= areaCode;
	        	//findingsAudit="2";
	        }
		}
		//FoodStockDTO fDto=new FoodStockDTO ();
		//fDto.setCity(areaCode);
		fDto.setAreaCode(ac);
		fDto.setFindingsAudit(findingsAudit);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<Map> list =new ArrayList();
		if("1".equals(type)) {//登统表
			 list = foodMapper.getSampleInformation(fDto);
			 resultMap.put("itemsData", list);
		}else if("2".equals(type)){//登记表
			GradeTestResultsDO gradeDO=new GradeTestResultsDO ();
			//gradeDO.setCity(areaCode);
			fDto.setAreaCode(ac);
			gradeDO.setFindingsAudit(findingsAudit);
			gradeDO.setType(type);
			gradeDO.setPlanFileName(planFileName);
			list=gradeMapper.getAllGradeTest(gradeDO);
			resultMap.put("itemsData", list);
		}else if("3".equals(type)) {//3、粮食质量检验结果汇总表-明细表
			List<Map> listData = service1.summaryResult(fDto);
			resultMap.put("itemsData", listData);
		}else if("4".equals(type)){//4、质量不达标样品汇总表
			List<SummarySubstandardSampleVO> listData=service.findSampleByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}else if("5".equals(type)){//5、粮食储存品质检验结果汇总表
			List<SummaryInspectionResultVO>  listData=service.findInspectionByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}else if("6".equals(type)){//6、储存品质不宜存样品汇总表
			List<SummaryNotSuitableVO>   listData=service.findyNotSuitableByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}else if("7".equals(type)){//7、检验等级与验收等级不符样品汇总表
			List<GradeTestResultsItemsVO> listData=findGradeItemsByIdAndIsDeleted(fDto);
			resultMap.put("itemsData", listData);
		}
		return resultMap;
	}
	
	
	/**
	 * @Description 检测业务查询统计     柱状图-储存品质总代表数量
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> natureNumber(String years) throws Exception{
		List<Map> list=foodMapper.natureNumber(years);
		return list;
	}
	
	/**
	 * @Description 检测业务查询统计     柱状图-宜存率 
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> suitableDeposit(String years) throws Exception{
		List<Map> list=foodMapper.suitableDeposit(years);
		return list;
	}
	
}
