package com.unis.quality.server.domain;

import java.io.FileInputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.ExcelUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UpdateTool;
import com.unis.quality.common.vo.FxlyCompanyVO;
import com.unis.quality.server.dao.FxlyCompanyDao;
import com.unis.quality.server.entity.quality.FxlyCompanyDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * 
 * @ClassName: OrganizationServiceImpl
 * @Description: 质检机构管理--机构基本信息
 * @author lfx
 * @date 2019年7月8日15:24:17
 * 
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class FxlyCompanyDomain {
	
	@Autowired
	private FxlyCompanyDao fxlyCompanyDao;
	
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return
	 * @throws Exception
	 */
	public FxlyCompanyVO findByIdAndIsDeleted(String qyxydm) throws Exception {
		FxlyCompanyDO reportManagementDO = findByIdAndIsDeleted(qyxydm, 0);
		FxlyCompanyVO resultVO = LsBeanUtils.copyProperties(reportManagementDO, FxlyCompanyVO.class);
		return resultVO;
	}
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return
	 * @throws Exception
	 */
	public FxlyCompanyDO findByIdAndIsDeleted(String qyxydm, int isDelete) throws Exception {
		Example example = new Example(FxlyCompanyDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("qyxydm", qyxydm);
		FxlyCompanyDO reportManagementDO = fxlyCompanyDao.selectOneByExample(example);
		if (ObjectUtils.equals(reportManagementDO, null)) {
			return null;
		}
		return reportManagementDO;
	}

	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return
	 * @throws Exception
	 */
	public FxlyCompanyDO findById(String id, int isDelete) throws Exception {
		Example example = new Example(FxlyCompanyDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		FxlyCompanyDO reportManagementDO = fxlyCompanyDao.selectOneByExample(example);
		if (ObjectUtils.equals(reportManagementDO, null)) {
			return null;
		}
		return reportManagementDO;
	}

	/**
	 * @Description 根据质检机构名称、所属地区查询机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public  Map<String,  Object>  findByPage(FxlyCompanyVO  organizationVO,  Integer  page,  Integer  size)  throws  Exception  {

		Example  example  =  new  Example(FxlyCompanyDO.class);
		Criteria  criteria  =  example.createCriteria();
		
		//  企业名称
		if  (!"".equals(organizationVO.getQymc())  &&  null  !=  organizationVO.getQymc())  {
			if("%%".equals(organizationVO.getQymc())) {
				criteria.andLike("qymc",  "% ["  +  organizationVO.getQymc()  +  "] %");
			}else {
				criteria.andLike("qymc",  "%"  +  organizationVO.getQymc()  +  "%");
			}
		}
	//  企业信用代码
		if  (!"".equals(organizationVO.getQyxydm())  &&  null  !=  organizationVO.getQyxydm())  {
			if("%%".equals(organizationVO.getQyxydm())) {
				criteria.andLike("qyxydm",  "% ["  +  organizationVO.getQyxydm()  +  "] %");
			}else {
				criteria.andLike("qyxydm",  "%"  +  organizationVO.getQyxydm()  +  "%");
			}
		}
	//  类型
		if  (!"".equals(organizationVO.getLx())  &&  null  !=  organizationVO.getLx())  {
			criteria.andEqualTo("lx",   organizationVO.getLx() );
		}
	//  状态
		if  (!"".equals(organizationVO.getZt())  &&  null  !=  organizationVO.getZt())  {
			criteria.andEqualTo("zt",   organizationVO.getZt()  );
		}
		//  未删除的
		criteria.andIsNull("deleteTime");
		//  按时间排序
		example.setOrderByClause("CREATE_TIME  DESC");
		PageHelper.startPage(page,  size,  "CREATE_TIME  DESC");
		List<FxlyCompanyDO>  resultOrganizationDOList  =  fxlyCompanyDao.selectByExample(example);
		PageInfo<FxlyCompanyDO>  pageInfo  =  new  PageInfo<FxlyCompanyDO>(resultOrganizationDOList);
		Map<String,  Object>  resultMap  =  new  HashMap<String,  Object>();
		List<FxlyCompanyVO>  resulOrganizationVOList  =  new  ArrayList<>();
		if  (!resultOrganizationDOList.isEmpty())  {
			for  (FxlyCompanyDO  resultDO  :  resultOrganizationDOList)  {
				FxlyCompanyVO  resultVO  =  LsBeanUtils.copyProperties(resultDO,  FxlyCompanyVO.class);
				if("1".equals(resultVO.getZt())) {
					resultVO.setZtmc("启用");
				}if("0".equals(resultVO.getZt())) {
					resultVO.setZtmc("禁用");
				}
				resulOrganizationVOList.add(resultVO);
			}
		}
		resultMap.put("total",  pageInfo.getTotal());
		resultMap.put("resultList",  resulOrganizationVOList);
		return  resultMap;
		}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/29
	 * @return boolean
	 * @throws Exception
	 *//*

	public boolean deletes(String[] ids,OrganizationVO organizationVO) {
		for (String id : ids) {
			Example example = new Example(OrganizationDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andIsNull("deleteTime");
			OrganizationDO organizationDO = fxlyCompanyDao.selectOneByExample(example);
			if(ObjectUtils.equals(organizationDO, null)) {
				throw new RuntimeException("此数据未存储到数据库中。");
			}
			if (ObjectUtils.notEqual(organizationDO, null)) {
				organizationDO.setDeleteBy(organizationVO.getDeleteBy());
				organizationDO.setDeleteTime(DateUtil.getNowDate());
				fxlyCompanyDao.updateByPrimaryKey(organizationDO);
			}
		}
		return true;
	}*/
	/**
	 * @Description 保存
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(FxlyCompanyVO vo) throws Exception {
		Example example = new Example(FxlyCompanyDO.class);
		Criteria criteria = example.createCriteria();
		if (!"".equals(vo.getQyxydm()) && null != vo.getQyxydm()) {
			criteria.andEqualTo("qyxydm", vo.getQyxydm());
		}
		criteria.andIsNull("deleteTime");
		if (fxlyCompanyDao.selectCountByExample(example) > 0) {
			throw new RuntimeException(vo.getQyxydm() + "已存在!");
		}
		
		if(!"放心粮油生产企业".equals(vo.getLx())){
			if(!"粮油销售放心店".equals(vo.getLx())) {
				throw new RuntimeException("请正确填写企业类型:粮油销售放心店/放心粮油生产企业");
			}
		}
		if(!"1".equals(vo.getZt()) ) {
			if(!"0".equals(vo.getZt())) {
				throw new RuntimeException("请正确填写状态:启用/禁用");
			}
		}
		if("启用".equals(vo.getZtmc())) {
			vo.setZt("1");
		}if("禁用".equals(vo.getZtmc())) {
			vo.setZt("0");
		}
		FxlyCompanyDO fxlyCompanyDO = new FxlyCompanyDO();
		LsBeanUtils.copyPropertiesIgnoreNull(vo, fxlyCompanyDO);
	
		fxlyCompanyDO.setOrgId(vo.getOrgId() + "");
		fxlyCompanyDO.setDeptId(vo.getDeptId() + "");
		fxlyCompanyDO.setAreaCode(vo.getAreaCode());
		fxlyCompanyDO.setCreateBy(vo.getCreateBy());
		fxlyCompanyDO.setCreateTime(DateUtil.getNowDate());
		if (fxlyCompanyDao.insert(fxlyCompanyDO) < 1) {
			throw new RuntimeException(fxlyCompanyDO.getQyxydm() + "无法保存成功，请检查数据。");
		}
		return true;
	}

	//放心粮油导入
	public boolean importExcel(MultipartFile file) throws Exception {

		// 指定输入文件
		FileInputStream fis = (FileInputStream) file.getInputStream();
		// 指定每列对应的类属性
		LinkedHashMap<String, String> alias = new LinkedHashMap<>();
		alias.put("企业名称", "qymc");
		alias.put("类型", "lx");
		alias.put("企业信用代码", "qyxydm");
		alias.put("产品", "cp");
		alias.put("联系人", "lxr");
		alias.put("联系方式", "lxfs");
		alias.put("状态", "zt");
		// 转换成map的对象数组
		List<Map<String, Object>> ls = ExcelUtil.excel2Pojo(fis, alias);
		// 转换成json
		String compJson = JSONArray.toJSONString(ls);
		// 转换成pojo
		List<FxlyCompanyVO> resultLs = JSONObject.parseArray(compJson, FxlyCompanyVO.class);
		// 保存专家
		for (FxlyCompanyVO res : resultLs) {
			// 字段校验 start
			String qylxName = res.getLx();
			if(!"放心粮油生产企业".equals(qylxName) || !"粮油销售放心店".equals(qylxName)){
				throw new RuntimeException("请正确填写企业类型:粮油销售放心店/放心粮油生产企业");
			}
			if(!"启用".equals(res.getZt()) || !"禁用".equals(res.getZt())) {
				throw new RuntimeException("请正确填写状态:启用/禁用");
			}
		}
		for (FxlyCompanyVO res : resultLs) {
			save(res);
		}
		return true;
	}
	
	/**
	 * @Description 更新
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(FxlyCompanyVO organizationVO) throws Exception {
		FxlyCompanyDO organizationDO = findById(organizationVO.getId(), 0);
		if(ObjectUtils.equals(organizationDO, null)) {
			throw new RuntimeException("此数据未存储到数据库中。");
		}
		FxlyCompanyDO organizationDO1 = new FxlyCompanyDO();
		// 拷贝页面数据
		LsBeanUtils.copyPropertiesIgnoreNull(organizationVO, organizationDO1);
		// 数据放进DO里
		UpdateTool.copyNullProperties(organizationDO, organizationDO1);
		
		organizationDO1.setId(organizationDO.getId() + "");
		organizationDO1.setOrgId(organizationVO.getOrgId() + "");
		organizationDO1.setDeptId(organizationVO.getDeptId() + "");
		organizationDO1.setAreaCode(organizationVO.getAreaCode());
		organizationDO1.setUpdateBy(organizationVO.getUpdateBy());
		organizationDO1.setUpdateTime(DateUtil.getNowDate());
		if (fxlyCompanyDao.updateByPrimaryKey(organizationDO1) < 1) {
			throw new RuntimeException("更新失败，请检查数据格式。");
		}
		return true;
	}
	
	/**
	 * @Description 根据名称查询id
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param organizationName
	 * @return
	 * @throws Exception
	 *//*
	public String findByName(String organizationName) throws Exception{
		Example example = new Example(OrganizationDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("organizationName", organizationName);
		OrganizationDO reportManagementDO = fxlyCompanyDao.selectOneByExample(example);
		if (ObjectUtils.equals(reportManagementDO, null)) {
			return null;
		}
		return reportManagementDO.getId();
	}*/
	
	public  List<FxlyCompanyVO>  findList(FxlyCompanyVO  organizationVO)  throws  Exception  {

		Example  example  =  new  Example(FxlyCompanyDO.class);
		Criteria  criteria  =  example.createCriteria();
		
		//  企业名称
		if  (!"".equals(organizationVO.getQymc())  &&  null  !=  organizationVO.getQymc())  {
			if("%%".equals(organizationVO.getQymc())) {
				criteria.andLike("qymc",  "% ["  +  organizationVO.getQymc()  +  "] %");
			}else {
				criteria.andLike("qymc",  "%"  +  organizationVO.getQymc()  +  "%");
			}
		}
	//  企业信用代码
		if  (!"".equals(organizationVO.getQyxydm())  &&  null  !=  organizationVO.getQyxydm())  {
			if("%%".equals(organizationVO.getQyxydm())) {
				criteria.andLike("qyxydm",  "% ["  +  organizationVO.getQyxydm()  +  "] %");
			}else {
				criteria.andLike("qyxydm",  "%"  +  organizationVO.getQyxydm()  +  "%");
			}
		}
	//  类型
		if  (!"".equals(organizationVO.getLx())  &&  null  !=  organizationVO.getLx())  {
			criteria.andEqualTo("lx",   organizationVO.getLx() );
		}
	//  状态
		if  (!"".equals(organizationVO.getZt())  &&  null  !=  organizationVO.getZt())  {
			criteria.andEqualTo("zt",   organizationVO.getZt()  );
		}
		//  未删除的
		criteria.andIsNull("deleteTime");
		//  按时间排序
		example.setOrderByClause("CREATE_TIME  DESC");
		List<FxlyCompanyDO>  resultOrganizationDOList  =  fxlyCompanyDao.selectByExample(example);
		List<FxlyCompanyVO>  resulOrganizationVOList  =  new  ArrayList<>();
		if  (!resultOrganizationDOList.isEmpty())  {
			for  (FxlyCompanyDO  resultDO  :  resultOrganizationDOList)  {
				FxlyCompanyVO  resultVO  =  LsBeanUtils.copyProperties(resultDO,  FxlyCompanyVO.class);
				if("1".equals(resultVO.getZt())) {
					resultVO.setZtmc("启用");
				}if("0".equals(resultVO.getZt())) {
					resultVO.setZtmc("禁用");
				}
				resulOrganizationVOList.add(resultVO);
			}
		}
		return  resulOrganizationVOList;
		}

}
