package com.unis.quality.server.domain;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UpdateTool;
import com.unis.quality.common.constant.Constant;
import com.unis.quality.common.constant.DataReceiveConstant;
import com.unis.quality.common.vo.OrganizationVO;
import com.unis.quality.server.dao.OrganizationDao;
import com.unis.quality.server.entity.quality.OrganizationDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * 
 * @ClassName: OrganizationServiceImpl
 * @Description: 质检机构管理--机构基本信息
 * @author lfx
 * @date 2019年7月8日15:24:17
 * 
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class OrganizationDomain {
	
	@Autowired
	private OrganizationDao organizationMapper;
	
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return
	 * @throws Exception
	 */
	public OrganizationVO findByIdAndIsDeleted(String id) throws Exception {
		OrganizationDO reportManagementDO = findByIdAndIsDeleted(id, 0);
		OrganizationVO resultVO = LsBeanUtils.copyProperties(reportManagementDO, OrganizationVO.class);
		String w=reportManagementDO.getAffiliatingArea();
		if(!"".equals(w)) {
			String[] q=w.split(",");
			resultVO.setAffiliatingArea(q);
		}
		return resultVO;
	}
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return
	 * @throws Exception
	 */
	public OrganizationDO findByIdAndIsDeleted(String id, int isDelete) throws Exception {
		Example example = new Example(OrganizationDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		OrganizationDO reportManagementDO = organizationMapper.selectOneByExample(example);
		if (ObjectUtils.equals(reportManagementDO, null)) {
			return null;
		}
		return reportManagementDO;
	}
	/**
	 * @Description 根据质检机构名称、所属地区查询机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public  Map<String,  Object>  findByPage(OrganizationVO  organizationVO,  Integer  page,  Integer  size)  throws  Exception  {

		Example  example  =  new  Example(OrganizationDO.class);
		Criteria  criteria  =  example.createCriteria();
		//数据过滤
	    String areaCode=organizationVO.getAreaCode();
		if (!"".equals(areaCode) && null != areaCode) {
	        String ac="";
	        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
	            ac= areaCode.substring(0, 2);
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	            ac= areaCode.substring(0, 4);
	        } else {
	            ac= areaCode;
	        }
	        criteria.andLike("areaCode",  ac + "%");
		}
		String area="";
		if(null!=organizationVO.getAffiliatingArea() && organizationVO.getAffiliatingArea().length!=0) {
			String[] aa=organizationVO.getAffiliatingArea();
			int len=aa.length;
			if(len==1) {
				area=aa[0];
			}else if(len==2) {
				area=aa[0]+","+aa[1];
			}else if(len==3) {
				area=aa[0]+","+aa[1]+","+aa[2];
			}
		//  添加按所属地区查询
			if  ( null  !=  organizationVO.getAffiliatingArea())  {
				criteria.andLike("affiliatingArea",    area+"%" );
			}
		}
		
		//  添加按机构名称
		if  (!"".equals(organizationVO.getOrganizationName())  &&  null  !=  organizationVO.getOrganizationName())  {
			if("%%".equals(organizationVO.getOrganizationName())) {
				criteria.andLike("organizationName",  "% ["  +  organizationVO.getOrganizationName()  +  "] %");
			}else {
				criteria.andLike("organizationName",  "%"  +  organizationVO.getOrganizationName()  +  "%");
			}
		}
		
		//  未删除的
		criteria.andIsNull("deleteTime");
		//  按时间排序
		example.setOrderByClause("CREATE_TIME  DESC");
		PageHelper.startPage(page,  size,  "CREATE_TIME  DESC");
		List<OrganizationDO>  resultOrganizationDOList  =  organizationMapper.selectByExample(example);
		PageInfo<OrganizationDO>  pageInfo  =  new  PageInfo<OrganizationDO>(resultOrganizationDOList);
		Map<String,  Object>  resultMap  =  new  HashMap<String,  Object>();
		List<OrganizationVO>  resulOrganizationVOList  =  new  ArrayList<>();
		if  (!resultOrganizationDOList.isEmpty())  {
			for  (OrganizationDO  resultDO  :  resultOrganizationDOList)  {
			OrganizationVO  resultVO  =  LsBeanUtils.copyProperties(resultDO,  OrganizationVO.class);
			resultVO.setAffiliatingArea1(resultDO.getAffiliatingArea());
				resulOrganizationVOList.add(resultVO);
			}
		}
		resultMap.put("total",  pageInfo.getTotal());
		resultMap.put("resultList",  resulOrganizationVOList);
		return  resultMap;
		}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/29
	 * @return boolean
	 * @throws Exception
	 */

	public boolean deletes(String[] ids,OrganizationVO organizationVO) {
		for (String id : ids) {
			Example example = new Example(OrganizationDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andIsNull("deleteTime");
			OrganizationDO organizationDO = organizationMapper.selectOneByExample(example);
			if(ObjectUtils.equals(organizationDO, null)) {
				throw new RuntimeException("此数据未存储到数据库中。");
			}
			if (ObjectUtils.notEqual(organizationDO, null)) {
				organizationDO.setDeleteBy(organizationVO.getDeleteBy());
				organizationDO.setDeleteTime(DateUtil.getNowDate());
				organizationMapper.updateByPrimaryKey(organizationDO);
			}
		}
		return true;
	}
	/**
	 * @Description 保存机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(OrganizationVO organizationVO) throws Exception {
		Example example = new Example(OrganizationDO.class);
		Criteria criteria = example.createCriteria();
		if (!"".equals(organizationVO.getOrganizationName()) && null != organizationVO.getOrganizationName()) {
			criteria.andEqualTo("organizationName", organizationVO.getOrganizationName());
		}
		criteria.andIsNull("deleteTime");
		if (organizationMapper.selectCountByExample(example) > 0) {
			throw new RuntimeException(organizationVO.getOrganizationName() + "已存在!");
		}
		if(organizationVO.getLegalRepresentative().length()>50) {
			throw new RuntimeException("法定代表人的名称过长，请重新输入！");
		}
		OrganizationDO organizationDO = new OrganizationDO();
		LsBeanUtils.copyPropertiesIgnoreNull(organizationVO, organizationDO);
		String area="";
		if(null!=organizationVO.getAffiliatingArea()) {
			String[] aa=organizationVO.getAffiliatingArea();
			int len=aa.length;
			if(len==1) {
				area=aa[0];
			}else if(len==2) {
				area=aa[0]+","+aa[1];
			}else if(len==3) {
				area=aa[0]+","+aa[1]+","+aa[2];
			}
		}
		organizationDO.setAffiliatingArea(area);
		organizationDO.setOrgId(organizationVO.getOrgId() + "");
		organizationDO.setDeptId(organizationVO.getDeptId() + "");
		organizationDO.setAreaCode(organizationVO.getAreaCode());
		organizationDO.setCreateBy(organizationVO.getCreateBy());
		organizationDO.setCreateTime(DateUtil.getNowDate());
		if (organizationMapper.insert(organizationDO) < 1) {
			throw new RuntimeException(organizationDO.getOrganizationName() + "无法保存成功，请检查数据。");
		}
		return true;
	}

	/**
	 * @Description 更新机构信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(OrganizationVO organizationVO) throws Exception {
		OrganizationDO organizationDO = findByIdAndIsDeleted(organizationVO.getId(), 0);
		if(ObjectUtils.equals(organizationDO, null)) {
			throw new RuntimeException("此数据未存储到数据库中。");
		}
		OrganizationDO organizationDO1 = new OrganizationDO();
		// 拷贝页面数据
		LsBeanUtils.copyPropertiesIgnoreNull(organizationVO, organizationDO1);
		// 数据放进DO里
		UpdateTool.copyNullProperties(organizationDO, organizationDO1);
		String area="";
		if(null!=organizationVO.getAffiliatingArea()) {
			String[] aa=organizationVO.getAffiliatingArea();
			int len=aa.length;
			if(len==1) {
				area=aa[0];
			}else if(len==2) {
				area=aa[0]+","+aa[1];
			}else if(len==3) {
				area=aa[0]+","+aa[1]+","+aa[2];
			}
		}
		organizationDO1.setAffiliatingArea(area);
		organizationDO1.setOrgId(organizationVO.getOrgId() + "");
		organizationDO1.setDeptId(organizationVO.getDeptId() + "");
		organizationDO1.setAreaCode(organizationVO.getAreaCode());
		organizationDO1.setUpdateBy(organizationVO.getUpdateBy());
		organizationDO1.setUpdateTime(DateUtil.getNowDate());
		if (organizationMapper.updateByPrimaryKey(organizationDO1) < 1) {
			throw new RuntimeException("更新失败，请检查数据格式。");
		}
		return true;
	}
	
	/**
	 * @Description 根据名称查询id
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param organizationName
	 * @return
	 * @throws Exception
	 */
	public String findByName(String organizationName) throws Exception{
		Example example = new Example(OrganizationDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("organizationName", organizationName);
		OrganizationDO reportManagementDO = organizationMapper.selectOneByExample(example);
		if (ObjectUtils.equals(reportManagementDO, null)) {
			return null;
		}
		return reportManagementDO.getId();
	}
	
	/**
	 * @Description 根据名称查询id
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param organizationName
	 * @return
	 * @throws Exception
	 */
	public OrganizationVO findOrgByName(String organizationName) throws Exception{
		Example example = new Example(OrganizationDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("organizationName", organizationName);
		OrganizationDO reportManagementDO = organizationMapper.selectOneByExample(example);
		if (ObjectUtils.equals(reportManagementDO, null)) {
			return null;
		}
		OrganizationVO organizationVO = new OrganizationVO();
		LsBeanUtils.copyPropertiesIgnoreNull(organizationVO , reportManagementDO);
		return organizationVO;
	}
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 同步用户中心机构
	 * @Date 2020年3月10日 上午10:11:33
	 * @param contentJsonArr 
	 * @return boolean
	 * @throws Exception 
	 */
	public boolean synMyuserOrg(JSONArray contentJsonArr) {
		//删除质量有 库级没有的机构
		deleteSynData(contentJsonArr);
		
		for (int i = 0; i < contentJsonArr.size(); i++) {
			JSONObject jsonObject = contentJsonArr.getJSONObject(i);
			String qymc = jsonObject.getString("qymc");
			String qyjgdm = jsonObject.getString("qyjgdm");
			String kddm = jsonObject.getString("kddm");
			String qyszqy = jsonObject.getString("qyszqy");
			String qylxr = jsonObject.getString("qylxr");
			String bgdh = jsonObject.getString("bgdh");
			String qytxdz = jsonObject.getString("qytxdz");
			String zcrq = jsonObject.getString("zcrq");
			
			OrganizationDO orgDO = new OrganizationDO();
			orgDO.setOrganizationName(qymc);
			orgDO.setUnit(qymc);
			orgDO.setOrganizationCode(kddm);
			orgDO.setAffiliatingArea(qyszqy);
			orgDO.setLinkMan(qylxr);
			orgDO.setPhone(bgdh);
			orgDO.setUnitAddress(qytxdz);
			orgDO.setRegistrationTime(zcrq);
			orgDO.setOrgId(qyjgdm);
			
			Example example = new Example(OrganizationDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andIsNull("deleteTime");
			criteria.andEqualTo("organizationName", qymc);
			OrganizationDO orgDb = organizationMapper.selectOneByExample(example);
			
			//固定字段
			orgDO.setInstitutional("库内质检站");
			orgDO.setInstitutionalCategories("区级");
			orgDO.setMonitoringBodies("否");
			orgDO.setMetrologicalAuthentication("否");
			//若查不到 新增，查得到 修改
			if(orgDb == null) {
				orgDO.buildKjPush();
				organizationMapper.insertSelective(orgDO);
			}else {
				orgDO.setUpdateTime(DateUtil.getNowDate());
				organizationMapper.updateByExampleSelective(orgDO, example);
			}
		}
		return false;
	}
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 删除质量有 库级没有的机构
	 * @Date 2020年3月18日 上午10:46:41
	 * @param contentJsonArr void
	 */
    private void deleteSynData(JSONArray contentJsonArr) {
    	//质量
    	Set<String> setLocal = organizationMapper.findOrgIdList(DataReceiveConstant.KJTS);
    	
    	//库级
    	Set<String> setPush = new HashSet<>();
    	for (int i = 0; i < contentJsonArr.size(); i++) {
    		String qyjgdm = contentJsonArr.getJSONObject(i).getString("qyjgdm");
    		setPush.add(qyjgdm);
		}
    	
    	//拿出质量-有,库级-没有的 删除
		setLocal.removeAll(setPush);
		if(setLocal.size() > 0) {
			organizationMapper.deleteByOrgIds(setLocal);
		}
	}
}
