package com.unis.quality.server.domain;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.quality.common.constant.DataReceiveConstant;
import com.unis.quality.common.enums.BaseServerEduEnum;
import com.unis.quality.common.enums.BaseTechnicalEnum;
import com.unis.quality.common.vo.PersonnelManagementVO;
import com.unis.quality.server.dao.OrganizationDao;
import com.unis.quality.server.dao.PersonnelManagementDao;
import com.unis.quality.server.entity.quality.EquipmentDO;
import com.unis.quality.server.entity.quality.OrganizationDO;
import com.unis.quality.server.entity.quality.PersonnelManagementDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * @Description: 质检机构管理--人员信息
 * @ClassName: PersonnelManagementServiceImpl
 * @author lfx
 * @date 2018年10月30日10:34:30
 * 
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class PersonnelManagementDomain  {
	
	@Autowired
	private PersonnelManagementDao personnelManagementMapper;
	
	@Autowired
	private EquipmentDomain mapper;
	
	@Autowired
	private OrganizationDao organizationMapper;
	

	/**
	 * @Description 根据id查询人员详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:33:06
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public List<PersonnelManagementVO> findByIdAndIsDeleted(String id) throws Exception {
		Example example = new Example(PersonnelManagementDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("organizationId", id);
		List<PersonnelManagementDO> list  = personnelManagementMapper.selectByExample(example);
		List<PersonnelManagementVO> resulEquipmentVOList = new ArrayList<>();
		if (!list.isEmpty()) {
			for (PersonnelManagementDO resultDO : list) {
				PersonnelManagementVO resultVO = LsBeanUtils.copyProperties(resultDO, PersonnelManagementVO.class);
				resulEquipmentVOList.add(resultVO);
			}
		}
		return resulEquipmentVOList;
	}


	/**
	 * @Description 查询人员信息、分页
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:39:05
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(PersonnelManagementVO personnelManagementVO, Integer page, Integer size) throws Exception {
	
 		Example example = new Example(PersonnelManagementDO.class);
		Criteria criteria = example.createCriteria();
	
		// 未删除的人员
		criteria.andIsNull("deleteTime");
		//根据机构id只能查询自己机构下的人员
		criteria.andEqualTo("organizationId",personnelManagementVO.getOrganizationId());
		// 按时间排序
		example.setOrderByClause("CREATE_TIME DESC");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<PersonnelManagementDO> resultPersonnelManagementDOList = personnelManagementMapper.selectByExample(example);
		PageInfo<PersonnelManagementDO> pageInfo = new PageInfo<PersonnelManagementDO>(resultPersonnelManagementDOList);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<PersonnelManagementVO> resulPersonnelManagementVOList = new ArrayList<>();
		if (!resultPersonnelManagementDOList.isEmpty()) {
			for (PersonnelManagementDO resultDO : resultPersonnelManagementDOList) {
				PersonnelManagementVO resultVO = LsBeanUtils.copyProperties(resultDO, PersonnelManagementVO.class);
				resulPersonnelManagementVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resulPersonnelManagementVOList);
		return resultMap;
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:56
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids,PersonnelManagementVO vo) throws Exception {
		for (String id : ids) {
			Example example = new Example(PersonnelManagementDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("organizationId", id);
			criteria.andIsNull("deleteTime");
			List<PersonnelManagementDO> list = personnelManagementMapper.selectByExample(example);
			if(null==list) {
				throw new RuntimeException("此数据未存储到数据库中。");
			}
			if (!list.isEmpty()) {
				for (PersonnelManagementDO resultDO : list) {
					resultDO.setDeleteBy(vo.getDeleteBy());
					resultDO.setDeleteTime(DateUtil.getNowDate());
					personnelManagementMapper.updateByPrimaryKey(resultDO);
				}
			}
		}
		return true;
	}

	/**
	 * @Description 保存信息-批量
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(Map<String, Object> pManagementList,PersonnelManagementVO vo) throws Exception {
		boolean bool = false; 
		Example example = new Example(PersonnelManagementDO.class);
		Criteria criteria = example.createCriteria();
		String OrganizationId=pManagementList.get("id").toString();
		List<Map> voList=(List<Map>) pManagementList.get("ryData");
		if(voList.size()>0 && voList != null){
			for(int i=0; i<voList.size(); i++){ 
		    	  if(voList.get(i) != null){ 
		    			if(null==voList.get(i).get("id")) {
			    			if (!"".equals(pManagementList.get("id")) && null != pManagementList.get("id")) {
								criteria.andEqualTo("organizationId", pManagementList.get("id"));
							}
			    		    if (!"".equals(voList.get(i).get("name")) && null != voList.get(i).get("name")) {
			    				criteria.andEqualTo("name", voList.get(i).get("name"));
			    			}
			    		    if (null == voList.get(i).get("name") ) {
			    		    	throw new RuntimeException("请输入人员姓名！");
			    			}
			    			criteria.andIsNull("deleteTime");
			    			if (personnelManagementMapper.selectCountByExample(example) > 0) {
			    				throw new RuntimeException(voList.get(i).get("name") + "已存在!");
			    			}
			    			PersonnelManagementDO personnelManagementDO = new PersonnelManagementDO();
			    			personnelManagementDO.setOrganizationId(OrganizationId);
			    			personnelManagementDO.setName(mapper.isNull(voList.get(i).get("name")+""));
			    			personnelManagementDO.setSex(mapper.isNull(voList.get(i).get("sex")+""));
			    			personnelManagementDO.setEducation(mapper.isNull(voList.get(i).get("education")+""));
			    			personnelManagementDO.setTechnical(mapper.isNull(voList.get(i).get("technical")+""));
			    			personnelManagementDO.setWorkingSeniority(mapper.isNull(voList.get(i).get("workingSeniority")+""));
			    			personnelManagementDO.setPhone(mapper.isNull(voList.get(i).get("phone")+""));
			    			/**-------天津-start---------**/
			    			personnelManagementDO.setNation(mapper.isNull(voList.get(i).get("nation")+""));
			    			personnelManagementDO.setUnit(mapper.isNull(voList.get(i).get("unit")+""));
			    			personnelManagementDO.setIdCard(mapper.isNull(voList.get(i).get("idCard")+""));
			    			personnelManagementDO.setVocationalGrade(mapper.isNull(voList.get(i).get("vocationalGrade")+""));
			    			personnelManagementDO.setBirthday(mapper.isNull(voList.get(i).get("birthday")+""));
			    			/**-------天津-end---------**/
			    			
			    			/**-------安全生产-start---------**/
			    			personnelManagementDO.setDivide(mapper.isNull(voList.get(i).get("divide")+""));
			    			/**-------安全生产-end---------**/
			    			personnelManagementDO.setOrgId(vo.getOrgId() + "");
			    			personnelManagementDO.setDeptId(vo.getDeptId() + "");
			    			personnelManagementDO.setAreaCode(vo.getAreaCode());
			    			personnelManagementDO.setCreateBy(vo.getCreateBy());
			    			personnelManagementDO.setCreateTime(DateUtil.getNowDate());
			    			if (personnelManagementMapper.insert(personnelManagementDO) < 1) {
			    				throw new RuntimeException(personnelManagementDO.getName() + "无法保存成功，请检查数据。");
			    			}
			    			bool = true; 
			    	  }
			      }
				}
		 	}else {
		 		throw new RuntimeException("请输入正确的人员信息！");
		 	}
		return bool;
	}
	/**
	 * @Description 更新信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:49
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(Map<String, Object> personnelManagementVOlist,PersonnelManagementVO vo) throws Exception {
		//根据机构id查询页面有多少条数据 
		String organizationId=personnelManagementVOlist.get("id").toString();
		
	    List<PersonnelManagementVO> oldList = findByIdAndIsDeleted(organizationId); 
	    List<Map> voList=(List<Map>) personnelManagementVOlist.get("ryData");
	    if (null==oldList) {
			throw new RuntimeException("此数据未存储到数据库中。");
		}
	    int num = voList.size(); 
	    if(voList != null&&voList.size() > 0){ 
	        //检查页面的信息是否有修改，然后更新到数据库 
	        for(int i = 0; i<num; i++){ 
	        	if(null==voList.get(i).get("id")) {
	        		save(personnelManagementVOlist,vo);
	        	}else {
		        	PersonnelManagementDO personnelManagementDO = new PersonnelManagementDO();
		        	personnelManagementDO.setId(oldList.get(i).getId()+"");
	    			personnelManagementDO.setOrganizationId(organizationId);
	    			personnelManagementDO.setName(mapper.isNull(voList.get(i).get("name")+""));
	    			personnelManagementDO.setSex(mapper.isNull(voList.get(i).get("sex")+""));
	    			personnelManagementDO.setEducation(mapper.isNull(voList.get(i).get("education")+""));
	    			personnelManagementDO.setTechnical(mapper.isNull(voList.get(i).get("technical")+""));
	    			personnelManagementDO.setWorkingSeniority(mapper.isNull(voList.get(i).get("workingSeniority")+""));
	    			personnelManagementDO.setPhone(mapper.isNull(voList.get(i).get("phone")+""));
	    			/**-------天津-start---------**/
	    			personnelManagementDO.setNation(mapper.isNull(voList.get(i).get("nation")+""));
	    			personnelManagementDO.setUnit(mapper.isNull(voList.get(i).get("unit")+""));
	    			personnelManagementDO.setIdCard(mapper.isNull(voList.get(i).get("idCard")+""));
	    			personnelManagementDO.setVocationalGrade(mapper.isNull(voList.get(i).get("vocationalGrade")+""));
	    			personnelManagementDO.setBirthday(mapper.isNull(voList.get(i).get("birthday")+""));
	    			/**-------天津-end---------**/
	    			
	    			/**-------安全生产-start---------**/
	    			personnelManagementDO.setDivide(mapper.isNull(voList.get(i).get("divide")+""));
	    			/**-------安全生产-end---------**/
	    			personnelManagementDO.setOrgId(oldList.get(i).getOrgId() + "");
	    			personnelManagementDO.setDeptId(oldList.get(i).getDeptId() + "");
	    			personnelManagementDO.setAreaCode(oldList.get(i).getAreaCode());
	    			personnelManagementDO.setCreateBy(oldList.get(i).getCreateBy());
	    			personnelManagementDO.setUpdateBy(vo.getUpdateBy());
	    			personnelManagementDO.setUpdateTime(DateUtil.getNowDate());
	    			if (personnelManagementMapper.updateByPrimaryKey(personnelManagementDO) < 1) {
	    				throw new RuntimeException("更新失败，请检查数据格式。");
	    			}
	        	}
	        }
	    }
	    return true;
	}

//    "rybh": "911202236794497949001009",
//    "ryxm": "任秀竹",
//    "kddm": "911202236794497949001",
//    "kdmc": null,
//    "sfzh": "",
//    "xb": "女",
//    "jg": "",
//    "mz": "",
//    "cssj": "1971-10-04 00:00:00",
//    "cjgzsj": null,
//    "whcd": null,
//    "xxzy": null,
//    "zzmm": "13",
//    "zwdm": null,
//    "zwmc": "化验员",
//    "bmdm": "",
//    "bmbdm": "",
//    "bmzdm": "",
//    "zgqkdm": null,
//    "gwdm": 16,
//    "jszcdm": null,
//    "jszcmc": "",
//    "lxdh": "13821022028",
//    "jbzs": "",
//    "fzdw": "",
//    "sfba": null,
//    "gddh": "",
//    "dzyx": "",
//    "jyxs": null,
//    "byyx": "",
//    "xw": "",
//    "zcdj": null,
//    "bzsj": null,
//    "qtzy": "",
//    "qtbzjg": "",
//    "qtbzsj": null,
//    "tyshxydm": "911202236794497949",
//    "qymc": "天津市静海古城粮食储备库",
//    "qyzt": 1
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 同步base-server中的人员--化验
	 * @Date 2020年3月10日 下午3:49:55
	 * @param contentJsonArr
	 * @return boolean
	 */
	public boolean synBaseServerPerson(JSONArray contentJsonArr) {
		//删除质量有 库级没有的机构
		deleteSynData(contentJsonArr);
		
		List<OrganizationDO> orgList = organizationMapper.selectAll();
		
		for (int i = 0; i < contentJsonArr.size(); i++) {
			JSONObject jsonObject = contentJsonArr.getJSONObject(i);
			String kddm = jsonObject.getString("kddm");
			String qymc = jsonObject.getString("qymc");
			String ryxm = jsonObject.getString("ryxm");
			String xb = jsonObject.getString("xb");
			String mz = jsonObject.getString("mz");
			String sfzh = jsonObject.getString("sfzh");
			String cssj = jsonObject.getString("cssj");
			String zcdj = jsonObject.getString("zcdj");
			String jszcmc = jsonObject.getString("jszcmc");
			String whcd = jsonObject.getString("whcd");
			String lxdh = jsonObject.getString("lxdh");
			
			if(StringUtils.isNotEmpty(cssj)) {
				try {
					cssj = DateUtil.getDateFormat(new SimpleDateFormat(DateUtil.YYYYMMDDHHMM).parse(cssj), DateUtil.YYYYMMDD);
				} catch (ParseException e) {
					e.printStackTrace();
				}
			}
			
			PersonnelManagementDO record = new PersonnelManagementDO();
			record.setUnit(qymc);
			record.setName(ryxm);
			record.setSex(xb);
			record.setTechnical(BaseTechnicalEnum.getNameByCode(jszcmc));
			record.setIdCard(sfzh);
			record.setNation(mz);
			record.setBirthday(cssj);
			record.setVocationalGrade(zcdj);
			record.setEducation(BaseServerEduEnum.getNameByCode(whcd));
			record.setPhone(lxdh);
			record.setOrgId(kddm);
			
			for (OrganizationDO org : orgList) {
				if(org.getOrganizationCode().contentEquals(kddm)) {
					record.setOrganizationId(org.getId());
				}
			}
			
			if(record.getOrganizationId() == null) {
				continue;
			}
			
			//姓名+出生年月
			Example example = new Example(PersonnelManagementDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("name", ryxm);
			criteria.andEqualTo("birthday", cssj);
			PersonnelManagementDO dbDO = personnelManagementMapper.selectOneByExample(example);
			
			//若查不到 新增，查得到 修改
			if(dbDO == null) {
				record.buildKjPush();
				personnelManagementMapper.insertSelective(record);
			}else {
				record.setId(dbDO.getId());
				personnelManagementMapper.updateByPrimaryKeySelective(record);
			}
		}
		return true;
	}
	
	/**
	 * @Author lidiaoquan
	 * @version V1.0
	 * @Description 删除质量有 库级没有的人员
	 * @Date 2020年3月18日 上午10:46:41
	 * @param contentJsonArr void
	 */
    private void deleteSynData(JSONArray contentJsonArr) {
    	//质量
    	Set<String> setLocal = personnelManagementMapper.findNameConcatBirthdayList(DataReceiveConstant.KJTS);
    	
    	//库级
    	Set<String> setPush = new HashSet<>();
    	for (int i = 0; i < contentJsonArr.size(); i++) {
    		JSONObject jsonObject = contentJsonArr.getJSONObject(i);
			String mz = jsonObject .getString("mz");
    		String cssj = jsonObject.getString("cssj");
			if(StringUtils.isNotEmpty(cssj)) {
				try {
					cssj = DateUtil.getDateFormat(new SimpleDateFormat(DateUtil.YYYYMMDDHHMM).parse(cssj), DateUtil.YYYYMMDD);
				} catch (ParseException e) {
					e.printStackTrace();
				}
			}
    		setPush.add(mz + "-" +cssj);
		}
    	
    	//拿出质量-有,库级-没有的 删除
		setLocal.removeAll(setPush);
		for (String string : setLocal) {
			String[] split = string.split("-");
			String name = split[0];
			String birthday = split[1];
			if(name != null && birthday != null) {
				personnelManagementMapper.deleteByNameAndBirthday(name,birthday);
			}
		}
	}
}
