package com.unis.quality.server.domain;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.quality.common.constant.Constant;
import com.unis.quality.common.dto.FoodStockDTO;
import com.unis.quality.common.vo.QualityPredictionAduitVO;
import com.unis.quality.common.vo.QualityPredictionItemsVO;
import com.unis.quality.server.dao.GradeTestResultsItemsDao;
import com.unis.quality.server.dao.QualityPredictionAduitDao;
import com.unis.quality.server.dao.QualityPredictionItemsDao;
import com.unis.quality.server.entity.quality.QualityPredictionAduitDO;
import com.unis.quality.server.entity.quality.QualityPredictionItemsDO;
import com.unis.quality.server.service.impl.FoodStockServiceImpl;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * 
 * @ClassName: QualityPredictionAduitService
 * @Description: 品质测报-结果审核   
 * @author lfx
 * @date 2019年7月10日15:01:34
 * 
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class QualityPredictionAduitDomain{

	@Autowired
	private QualityPredictionAduitDao mapper;
	
	@Autowired
	private QualityPredictionItemsDao itemsMapper;
	
	@Autowired
	private FoodStockServiceImpl fservice;
	
	@Autowired
	private GradeTestResultsItemsDao gradeItemsMapper;
	
    /**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public Map<String, Object>  findByIdAndIsDeleted(String id,String batch) throws Exception {
    	Map<String, Object> resultMap = new HashMap<String, Object>();
    	QualityPredictionAduitDO qualityResultsDO = findByIdAndIsDeleted(id, 0,batch);
    	String attachments7="";
    	String attachments=qualityResultsDO.getAttachments();
		if(null!=attachments) {
			String attachments1=attachments.replaceAll(", ", "\",\"");
			String attachments2=attachments1.replaceAll("=", "\":\"");
			String attachments3=attachments2.replaceAll("name", "\"name");
		    String attachments4=attachments3.replaceAll("success", "success\"");
		    String attachments5=attachments4.replaceAll("\"id\":\"", "\"id\":");
		    String attachments6=attachments5.replaceAll("\",\"uri", ",\"uri");
		    attachments7=attachments6.replaceAll("\\}\",\"\\{", "},{");
		}
		qualityResultsDO.setAttachments(attachments7);
    	QualityPredictionAduitVO aduitData=LsBeanUtils.copyProperties(qualityResultsDO, QualityPredictionAduitVO.class);
    	List<QualityPredictionItemsVO> itemsData= findItemsByIdAndIsDeleted(id,batch);
    	resultMap.put("aduitData", aduitData);
    	resultMap.put("itemsData", itemsData);
		return resultMap;
	} 
	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public QualityPredictionAduitDO findByIdAndIsDeleted(String id,int isDelete,String batch) throws Exception {
		Example example = new Example(QualityPredictionAduitDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
	/*	if("zjda".equals(zjda)) {
			criteria.andEqualTo("planId", id);
			criteria.andEqualTo("areaCode", currentUtils.getAreaCode());
		}else {*/
			criteria.andEqualTo("id", id);
		//}
		if(!"".equals(batch)) {
			criteria.andEqualTo("batch", batch);
		}
		QualityPredictionAduitDO qualityResultsDO = mapper.selectOneByExample(example);
		if (ObjectUtils.equals(qualityResultsDO, null)) {
			return null;
		}
		return qualityResultsDO;
	}

    
    /**
	 * @Description 根据id查询检查项目详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
    public List<QualityPredictionItemsVO> findItemsByIdAndIsDeleted(String id,String batch) throws Exception {
		Example example = new Example(QualityPredictionItemsDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("aduitId", id);
		if(!"".equals(batch)) {
			criteria.andEqualTo("batch", batch);
		}
		List<QualityPredictionItemsDO> list = itemsMapper.selectByExample(example);
		List<QualityPredictionItemsVO> resultVOList = new ArrayList<>();
		if (!list.isEmpty()) {
			for (QualityPredictionItemsDO resultDO : list) {
				QualityPredictionItemsVO resultVO = LsBeanUtils.copyProperties(resultDO, QualityPredictionItemsVO.class);
				resultVOList.add(resultVO);
			}
		}
		return resultVOList;
	}
    
    //根据行政区划过滤数据
    public Map<String,Object> findByArea(QualityPredictionAduitVO qualityVO) {
	 	 Map<String, Object> resultMap = new HashMap<String, Object>();
	 	 //数据过滤
	 	 //areaCode,deptName,qualityVO.getFindingsAudit()
	 	String areaCode=qualityVO.getAreaCode();
	 	String deptName=qualityVO.getDeptId();
	 	String status=qualityVO.getFindingsAudit();
	 	 String ac="";
	 	 String condition = "";
	 	 String conditionZt="";
	 	if (!"".equals(areaCode) && null != areaCode) {
	        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
	            ac= areaCode.substring(0, 2);
	            if((Constant.ZJZX).equals(deptName)) {//省级质检中心
	            	if("审核".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT in ('15','12','11','8') or (FINDINGS_AUDIT ='10'  and AREA_CODE!="+areaCode+") ";//15、8质检中心未上报 10已上报 12 粮食局驳回
	            		if("审核通过".equals(status)) {
		     				conditionZt ="(FINDINGS_AUDIT ='8'  and AREA_CODE!="+areaCode+") or FINDINGS_AUDIT='11'";
		     			}if("驳回".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT ='12' ";
		     			}if("未审核".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT ='15' ";
		     			}
	            	}
	            	if("上报".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT in ('8','10','11') ";//15、8质检中心未上报 10已上报 12 粮食局驳回
	            		if("未上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('8') ";
		     			}if("已上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('10','11') ";
		     			}
	            	}
	            }
	            if((Constant.LSJ).equals(deptName)) {//省级粮食局
	            	 condition = "  FINDINGS_AUDIT in ('10','11') ";//10省质检中心上报--粮食局未审核 11粮食局已审核
            		if("审核通过".equals(status)) {
	     				conditionZt ="FINDINGS_AUDIT='11' ";
	     			}if("未审核".equals(status)) {
	     				conditionZt = " FINDINGS_AUDIT ='10' ";
	     			}if("驳回".equals(status)) {
	     				conditionZt = " FINDINGS_AUDIT ='16' ";//看不见驳回数据
	     			}
	            }
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	            ac= areaCode.substring(0, 4);
	            if((Constant.ZJZX).equals(deptName)) {//市级质检中心
	            	 //condition = " FINDINGS_AUDIT in ('14','4','5','7','9') ";//14、4市质检中心未上报 5市质检中心已上报 7市粮食局驳回 9省质检中心驳回
	            	//14未审核  4审核通过  5 审核通过  6审核通过 4 未上报 5已上报  6未上报 8审核通过
	            	if("审核".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT not in ('2','3','1','0','13') ";
	            		if("审核通过".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in('4','5','6','15') or (FINDINGS_AUDIT ='8' or FINDINGS_AUDIT ='10' or FINDINGS_AUDIT ='11'  and AREA_CODE="+areaCode+") ";
		     			}if("驳回".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT in ('7','9') ";
		     			}if("未审核".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT in ('14') ";
		     			}
	            	}
	            	if("上报".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT not in ('2','3','1','0','7','9','14','13','12') ";
	            		if("未上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('4' ) ";
		     			}if("已上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('5','15','8','10','11')";
		     			}
	            	}
	            }
	            if((Constant.LSJ).equals(deptName)) {//市级粮食局
	            	// condition = " FINDINGS_AUDIT in ('5','6','15') ";//5 市质检中心上报--粮食局未审核 6粮食局已审核 15审核已上报
	            	
	            	if("审核".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT not in ('2','3','1','0','13','14','4','7','9','12') ";
	            		if("审核通过".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in('6','15','8','10','11') ";
		     			}if("未审核".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT  in('5' ) ";
		     			}if("驳回".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT ='16' ";//看不见驳回数据
		     			}
	            	}
	            	if("上报".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT not in ('2','3','1','0','14','4','5','13','7','9','12') ";
		     			if("未上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('6') ";
		     			}if("已上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('15','8','10','11') ";
		     			}
	            	}
	            }
	        } else {
	            ac= areaCode;
	            //县质检中心可以查看本地区所有状态的数据
	            if((Constant.ZJZX).equals(deptName)) {//县级质检中心
	            	 //condition = " FINDINGS_AUDIT in ('0','1','2','3','13') ";//0 质检中心未上报 1质检中心上报  2粮食局审核通过 3县粮食局驳回 13市质检中心驳回
	            	 //condition ="1=1";
	            	if("审核".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT not in ('0','1') ";
	            		if("审核通过".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('2','14','4','5','6','15','8','10','11') ";
		     			}if("驳回".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT in ('3','13','7','9','12') ";
		     			}if("未审核".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT ='16' ";//看不见驳回数据
		     			}
	            	}if("上报".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT not in ('3','13','7','9','12') ";
	            		if("未上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('0') ";
		     			}if("已上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('1','14','2','4','5','6','15','8','10','11') ";
		     			}
	            	}
	            }
	            if((Constant.LSJ).equals(deptName)) {//县级粮食局
	            	 //condition = " FINDINGS_AUDIT in ('2','1','14') ";//1质检中心上报--粮食局未审核   2粮食局审核通过 14 审核已上报
	            	if("审核".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT not in ('0','3','13','7','9','12') ";
	            		if("审核通过".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('14','2','4','5','6','15','8','10','11') ";
		     			}if("未审核".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT ='1' ";
		     			}if("驳回".equals(status)) {
		     				conditionZt = " FINDINGS_AUDIT ='16' ";//看不见驳回数据
		     			}
	            	}if("上报".equals(qualityVO.getState())) {
	            		condition = "  FINDINGS_AUDIT not in ('0','1','3','13','7','9','12') ";
	            		if("未上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('2') ";
		     			}if("已上报".equals(status)) {
		     				conditionZt ="FINDINGS_AUDIT in ('14','4','5','6','15','8','10','11') ";
		     			}
	            	}
	            } 
	        }
	    }
	 	resultMap.put("areaCode", ac);
	 	resultMap.put("condition", condition);
	 	resultMap.put("conditionZt", conditionZt);
	 	return resultMap;
 	 }
    
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(QualityPredictionAduitVO qualityVO, Integer page, Integer size) throws Exception {
 		Example example = new Example(QualityPredictionAduitDO.class);
		Criteria criteria = example.createCriteria();
		//数据过滤
		 String deptName=qualityVO.getDeptId();
		 Map<String,Object> map=findByArea( qualityVO);
		 String condition1=map.get("condition").toString();
		 String conditionZt=map.get("conditionZt").toString();
		 String ac=map.get("areaCode").toString();
		 if(null==qualityVO.getZjda()) {
			 criteria.andCondition("1=1");
			 if("".equals(conditionZt)) {
				 criteria.andCondition(condition1);
			 }
			 //添加按状态查询
			 if(!"".equals(conditionZt)) {
				 criteria.andCondition(conditionZt);
			 }
		 }
		 criteria.andLike("areaCode",  ac + "%");
		// 添加按承储企业名称查询
		if (!"".equals(qualityVO.getPlanFileName()) && null != qualityVO.getPlanFileName()) {
			criteria.andLike("planFileName", "%" + qualityVO.getPlanFileName() + "%");
		}
		// 添加按计划下发时间查询
		if (!"".equals(qualityVO.getCompanyName()) && null != qualityVO.getCompanyName()) {
			criteria.andLike("companyName", "%" + qualityVO.getCompanyName() + "%");
		}
		// 添加按状态查询
		if (!"".equals(qualityVO.getFindingsAudit()) && null != qualityVO.getFindingsAudit()) {
			String status= qualityVO.getFindingsAudit();
		}
		// 未删除的
		criteria.andIsNull("deleteTime");
		if("zjda".equals(qualityVO.getZjda())) {
			criteria.andEqualTo("planId", qualityVO.getPlanId());
			//criteria.andEqualTo("areaCode",areaCode);
			if (!"".equals(qualityVO.getCity()) && null != qualityVO.getCity()) {
				criteria.andLike("city", "%" + qualityVO.getCity() + "%");
			}
		}
		// 按时间排序
		example.setOrderByClause("CREATE_TIME DESC");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<QualityPredictionAduitDO> resultQualityList = mapper.selectByExample(example);
		PageInfo<QualityPredictionAduitDO> pageInfo = new PageInfo<QualityPredictionAduitDO>(resultQualityList);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<QualityPredictionAduitVO> resultList = new ArrayList<>();
		if (!resultQualityList.isEmpty()) {
			for (QualityPredictionAduitDO resultDO : resultQualityList) {
				QualityPredictionAduitVO resultVO = LsBeanUtils.copyProperties(resultDO, QualityPredictionAduitVO.class);
				if(ac.length()==2) {//省
					if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("15".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("12".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("驳回");
							}if("8".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}if("10".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("8".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}if("11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}/*if("12".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}*/
						}
					}
					if((Constant.LSJ).equals(deptName)) {
						if("10".equals(resultVO.getFindingsAudit())) {
							resultVO.setStateName("未审核");
						}
					}
					
				}else if(ac.length()==4) {//市
					if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("14".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}
							if("5".equals(resultVO.getFindingsAudit()) || "4".equals(resultVO.getFindingsAudit()) || "6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}if("15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("4".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("未上报");
							}
							if("5".equals(resultVO.getFindingsAudit()) || "15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit()) ||"6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}
						}
						
					}
					if((Constant.LSJ).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("5".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("15".equals(resultVO.getFindingsAudit()) || "6".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}
						if("上报".equals(qualityVO.getState())) {
							if("15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}
							if("6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}
						}
					}
				}
				else {//县
					if((Constant.LSJ).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("1".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
									resultVO.setStateName("审核通过");
								}
						}if("上报".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}if("14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("已上报");
								}
						}
						
					}if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
								||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
								||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("已上报");
							}
						}
						
					}
				}
				resultList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultList);
		return resultMap;
	}
	
	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return boolean
	 * @throws Exception
	 */
	
	public boolean deletes(String[] ids,QualityPredictionAduitVO vo) throws Exception {
		for (String id : ids) {
			Example example = new Example(QualityPredictionAduitDO.class);
			Criteria criteria = example.createCriteria();
			String areaCode=vo.getAreaCode();
			if (!"".equals(areaCode) && null != areaCode) {
		        String condition = "";
		        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
		        	 condition = " FINDINGS_AUDIT ='8'  and AREA_CODE="+areaCode;
		        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
		            condition = " FINDINGS_AUDIT ='4'  and AREA_CODE="+areaCode;
		        } else {
		            condition = " FINDINGS_AUDIT ='0' ";
		        }
		        criteria.andCondition(condition);
			}
			
			criteria.andEqualTo("id", id);
			if(!"".equals(vo.getBatch())) {
				criteria.andEqualTo("batch", vo.getBatch());
			}
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			QualityPredictionAduitDO qDO = mapper.selectOneByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				qDO.setDeleteBy(vo.getDeleteBy());
				qDO.setDeleteTime(DateUtil.getNowDate());
				mapper.updateByPrimaryKey(qDO);
			}
		}
		return true;
	}
	  //判断字符串是否为空
    public String isNull(String key) {
    	String str="";
    	if("null".equals(key)) {
    		str="";
    	}else {
    		str=key;
    	}
    	return  str;
    }
	/**
	 * @Description 保存品质测报审核结果
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/20
	 * @param QualityPredictionAduitVO
	 * @return boolean
	 * @throws Exception
	 */
	
	public boolean save(Map<String, Object> aduitList,QualityPredictionAduitVO vo) throws Exception {
		boolean bool = false; 
		Map<String,Object> aduitData=(Map<String,Object>)aduitList.get("aduitData");
		List<Map> itemsData=(List<Map>) aduitList.get("itemsData");
		FoodStockDTO fDto=new FoodStockDTO();
		fDto.setCondition("BIZ_QUALITY_PREDICTION_AUDIT");
    	fDto.setAreaCode(vo.getAreaCode());
    	fDto.setPlanFileName(aduitData.get("planFileName")+"");
    	String batch=fservice.queryMaxBatch(fDto);
    	int batch1=0;
    	if("".equals(batch)  || null==batch) {
    		batch1=1;
    	}else {
    		batch1=Integer.valueOf(batch)+1;
    	}
    	if(null!=aduitData.get("id")) {
    		batch1=Integer.parseInt(aduitData.get("batch")+"");
    	}
    	if(aduitData.size()>0) {
    		vo.setBatch(String.valueOf(batch1));
    		bool=saveAduit(aduitData,vo);
			 if(bool==true) {
				 if(itemsData.size() > 0 && itemsData != null) {
					 bool=saveItems(itemsData,vo);
				 }
			 }
		}
		return bool;
	}
	
	public boolean saveAduit(Map<String, Object> aduitData,QualityPredictionAduitVO vo) throws Exception {
		Example example = new Example(QualityPredictionAduitDO.class);
		Criteria criteria = example.createCriteria();
		String areaCode=vo.getAreaCode();
		criteria.andLike("areaCode",  areaCode + "%");
		if(null!=aduitData.get("id")) {
			return true;
		}
		if(aduitData.size()>0) {
			if (!"".equals(aduitData.get("planFileName")) && null != aduitData.get("planFileName")) {
				criteria.andEqualTo("planFileName", aduitData.get("planFileName"));
			}
			// 未删除
			criteria.andIsNull("deleteTime");
			String condition = " FINDINGS_AUDIT not in ('3' ,'13','9','7','12')";
	    	criteria.andCondition(condition);
			if (mapper.selectCountByExample(example) > 0) {
				throw new RuntimeException(aduitData.get("planFileName") + "已存在!");
			}
			QualityPredictionAduitDO resultsDO = new QualityPredictionAduitDO();
			resultsDO.setId(vo.getId());
			resultsDO.setBatch(vo.getBatch());
			resultsDO.setProcessId(vo.getProcessId());
			resultsDO.setPlanFileName(isNull(aduitData.get("planFileName")+""));
			resultsDO.setCity(isNull(aduitData.get("city")+""));
			resultsDO.setCompanyName(isNull(aduitData.get("companyName")+""));
			resultsDO.setMigrationAgencies(isNull(aduitData.get("migrationAgencies")+""));
			resultsDO.setMigrationDate(isNull(aduitData.get("migrationDate")+""));
			resultsDO.setRelocationNumber(isNull(aduitData.get("relocationNumber")+""));
			resultsDO.setNatureFood(isNull(aduitData.get("natureFood")+""));
			resultsDO.setVarieties(isNull(aduitData.get("varieties")+""));
			resultsDO.setSampleNumber(isNull(aduitData.get("sampleNumber")+""));
			resultsDO.setNumberRepresentatives(isNull(aduitData.get("numberRepresentatives")+""));
			resultsDO.setYears(isNull(aduitData.get("years")+""));
			resultsDO.setPlaceOrigin(isNull(aduitData.get("placeOrigin")+""));
			resultsDO.setAttachments(isNull(aduitData.get("attachments")+""));
			resultsDO.setPlanId(isNull(aduitData.get("planId")+""));
			resultsDO.setOrgId(vo.getOrgId() + "");
			resultsDO.setDeptId(vo.getDeptId() + "");
			resultsDO.setAreaCode(vo.getAreaCode());
			resultsDO.setCreateBy(vo.getCreateBy());
			resultsDO.setCreateTime(DateUtil.getNowDate());
			resultsDO.setFindingsAudit(vo.getFindingsAudit());
			resultsDO.setStateName("未上报");
			System.out.println(resultsDO.getId());
			if (mapper.insert(resultsDO) < 1) {
				throw new RuntimeException(resultsDO.getPlanFileName() + "无法保存成功，请检查数据。");
			}
		}
		return true;
	}

	public boolean saveItems(List<Map> itemsData ,QualityPredictionAduitVO vo) throws Exception {
		Example example1 = new Example(QualityPredictionItemsDO.class);
		Criteria criteria1 = example1.createCriteria();
		if(itemsData.size() > 0 && itemsData != null) {
			for (int t = 0; t < itemsData.size(); t++) {
				if (itemsData.get(t) != null) {
					if(null==itemsData.get(t).get("id")) {
						if (!"".equals(itemsData.get(t).get("testIndicators")) && null != itemsData.get(t).get("testIndicators")) {
							criteria1.andEqualTo("testIndicators", itemsData.get(t).get("testIndicators"));
						}
						// 未删除
						criteria1.andIsNull("deleteTime");
						QualityPredictionItemsDO itemsDO = new QualityPredictionItemsDO();
						itemsDO.setBatch(vo.getBatch());
						itemsDO.setAduitId(vo.getId());
						itemsDO.setVarieties(isNull(itemsData.get(t).get("varieties")+""));
						itemsDO.setTestIndicators(isNull(itemsData.get(t).get("testIndicators")+""));
						itemsDO.setTestValue(isNull(itemsData.get(t).get("testValue")+""));
						itemsDO.setOrgId(vo.getOrgId() + "");
						itemsDO.setDeptId(vo.getDeptId() + "");
						itemsDO.setAreaCode(vo.getAreaCode());
						itemsDO.setCreateBy(vo.getCreateBy());
						itemsDO.setCreateTime(DateUtil.getNowDate());
						if (itemsMapper.insert(itemsDO) < 1) {
							throw new RuntimeException(itemsDO.getTestIndicators() + "无法保存成功，请检查数据。");
						}
					}
				}
			}
		}
	return true;
}
	/**
	 * @Description 更新品质测报-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:03:46
	 * @param QualityPredictionPlannedVO
	 * @return boolean
	 * @throws Exception
	 */
	
	public boolean update(Map<String, Object> aduitList,QualityPredictionAduitVO vo) throws Exception {
    	Map<String,Object> aduitData=(Map<String,Object>)aduitList.get("aduitData");
		List<Map> itemsData=(List<Map>) aduitList.get("itemsData");
		Map<String,Object> map=findByArea(vo);
	    String ac=map.get("areaCode").toString();
		if(aduitData.size()>0) {
			QualityPredictionAduitDO qualityResultsDO = findByIdAndIsDeleted(aduitData.get("id")+"", 0,aduitData.get("batch")+"");
			if (ObjectUtils.equals(qualityResultsDO, null)) {
				throw new RuntimeException("此数据未存储到数据库中。");
			}
			QualityPredictionAduitDO resultsDO = new QualityPredictionAduitDO(); 
			resultsDO.setBatch(aduitData.get("batch")+"");
			resultsDO.setPlanFileName(isNull(aduitData.get("planFileName")+""));
			resultsDO.setCity(isNull(aduitData.get("city")+""));
			resultsDO.setCompanyName(isNull(aduitData.get("companyName")+""));
			resultsDO.setMigrationAgencies(isNull(aduitData.get("migrationAgencies")+""));
			resultsDO.setMigrationDate(isNull(aduitData.get("migrationDate")+""));
			resultsDO.setRelocationNumber(isNull(aduitData.get("relocationNumber")+""));
			resultsDO.setNatureFood(isNull(aduitData.get("natureFood")+""));
			resultsDO.setVarieties(isNull(aduitData.get("varieties")+""));
			resultsDO.setSampleNumber(isNull(aduitData.get("sampleNumber")+""));
			resultsDO.setNumberRepresentatives(isNull(aduitData.get("numberRepresentatives")+""));
			resultsDO.setYears(isNull(aduitData.get("years")+""));
			resultsDO.setPlaceOrigin(isNull(aduitData.get("placeOrigin")+""));
			resultsDO.setAttachments(isNull(aduitData.get("attachments")+""));
			resultsDO.setId(isNull(aduitData.get("id")+""));
			resultsDO.setFindingsAudit(isNull(aduitData.get("findingsAudit")+""));
			resultsDO.setPlanId(isNull(aduitData.get("planId")+""));
			if(ac.length()==4) {
				resultsDO.setFindingsAudit("4");
			}else if(ac.length()==6) {
				resultsDO.setFindingsAudit("0");
			}
			resultsDO.setProcessId(isNull(aduitData.get("processId")+""));
			resultsDO.setStateName(isNull(aduitData.get("stateName")+""));
			resultsDO.setCreateBy(isNull(aduitData.get("createBy")+""));
			if(null!=aduitData.get("xlsjState") || null!=aduitData.get("shzjzxState") || 
					null!=aduitData.get("shlsjState") || null!=aduitData.get("szjzxState") || null!=aduitData.get("slsjState")) {
				if( null!=vo.getFindingsAudit()) {
					resultsDO.setFindingsAudit(vo.getFindingsAudit());
				}if( null!=vo.getAuditOpinion()) {
					resultsDO.setAuditOpinion(vo.getAuditOpinion());
				}if( null!=vo.getStateName()) {
					resultsDO.setStateName(vo.getStateName());
				}if( null!=vo.getState()) {
					resultsDO.setState(vo.getState());
				}
				
				if( null!=vo.getSlsjState()) {
					resultsDO.setSlsjState(vo.getSlsjState());
				}if(null!=vo.getSlsjMessage()) {
					resultsDO.setSlsjMessage(vo.getSlsjMessage());
				}if( null!=vo.getSzjzxState()) {
					resultsDO.setSzjzxState(vo.getSzjzxState());
				}if(null!=vo.getSzjzxMessage()) {
					resultsDO.setSzjzxMessage(vo.getSzjzxMessage());
				}
				
				if( null!=vo.getShlsjMessage()) {
					resultsDO.setShlsjMessage(vo.getShlsjMessage());
				}if(null!=vo.getShlsjState()) {
					resultsDO.setShlsjState(vo.getShlsjState());
				}if( null!=vo.getShzjzxMessage()) {
					resultsDO.setShzjzxMessage(vo.getShzjzxMessage());
				}if( null!=vo.getShzjzxState()) {
					resultsDO.setShzjzxState(vo.getShzjzxState());
				}
				
				if( null!=vo.getXlsjState()) {
					resultsDO.setXlsjState(vo.getXlsjState());
				}if( null!=vo.getXlsjMessage()) {
					resultsDO.setXlsjMessage(vo.getXlsjMessage());
				}
			}
			String ss=aduitData.get("createTime")+"" ;
			if(null!=ss) {
				SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
				Date dateStr = sdf.parse(ss);
				resultsDO.setCreateTime(dateStr);
			}
			resultsDO.setOrgId(vo.getOrgId() + "");
			resultsDO.setDeptId(vo.getOrgId() + "");
			resultsDO.setAreaCode(qualityResultsDO.getAreaCode());
			resultsDO.setUpdateBy(vo.getUpdateBy());
			resultsDO.setUpdateTime(DateUtil.getNowDate());
			if (mapper.updateByPrimaryKey(resultsDO) < 1) {
				return false;
			}
			List<QualityPredictionItemsVO> oldList = findItemsByIdAndIsDeleted(aduitData.get("id")+"",aduitData.get("batch")+""); 
			int num = itemsData.size(); 
			if(itemsData != null&&itemsData.size() > 0){ 
		        //检查页面的信息是否有修改，然后更新到数据库 
		        for(int i = 0; i<num; i++){
		        	if(null==itemsData.get(i).get("id")) {
		        		vo.setId(aduitData.get("id")+"");
		        		vo.setBatch(aduitData.get("batch")+"");
		        		save(aduitList,vo);
		        	}else {
		        		QualityPredictionItemsDO itemsDO = new QualityPredictionItemsDO();
			        	itemsDO.setVarieties(isNull(itemsData.get(i).get("varieties")+""));
			        	itemsDO.setTestIndicators(isNull(itemsData.get(i).get("testIndicators")+""));
						itemsDO.setTestValue(isNull(itemsData.get(i).get("testValue")+""));
						itemsDO.setAduitId(isNull(itemsData.get(i).get("aduitId")+""));
						itemsDO.setBatch(oldList.get(i).getBatch());
						itemsDO.setId(oldList.get(i).getId());
			        	itemsDO.setOrgId(vo.getOrgId() + "");
			        	itemsDO.setDeptId(vo.getDeptId() + "");
			        	itemsDO.setAreaCode(itemsData.get(i).get("areaCode")+"");
			        	itemsDO.setUpdateBy(vo.getUpdateBy());
			        	itemsDO.setUpdateTime(DateUtil.getNowDate());
			        	if (itemsMapper.updateByPrimaryKey(itemsDO) < 1) {
			        		throw new RuntimeException("更新失败，请检查数据格式。");
			    		}
		        	}
		        	
		        }
			}
		}
		return true;
	}
    
    
    /**
	 * @Description 品质测报-结果上报
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月19日15:12:44
	 * @return boolean
	 * @throws Exception
	 */
	/*vo.getId();
	vo.getAreaCode();
	currentUtils.getDeptName()=vo.getDeptId()*/
	public boolean updateState(QualityPredictionAduitVO vo) throws Exception{
		Example example = new Example(QualityPredictionAduitDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("id", vo.getId());
		// 未删除的
		criteria.andIsNull("deleteTime");
		QualityPredictionAduitDO qDO = mapper.selectOneByExample(example);
		if (ObjectUtils.notEqual(qDO, null)) {
			//下级审批用户id
			String areaCode=vo.getAreaCode();
			if (!"".equals(areaCode) && null != areaCode) {
		        qDO.setFindingsAudit(vo.getFindingsAudit());
		        qDO.setStateName("已上报");
			}
			mapper.updateByPrimaryKey(qDO);
		}
		return true;
	}
	
	/**
	 * @Description 移动端-新收获粮分类汇总统计
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> qualityHarvestCorn(String years) throws Exception {
		Map<String, Object> resultMap = new HashMap<String, Object>();
		QualityPredictionAduitVO vo=new QualityPredictionAduitVO();
		vo.setYears(years);
		vo.setVarieties("小麦");
		List<Map> listXm=mapper.qualityH(vo);
		QualityPredictionAduitVO voym=new QualityPredictionAduitVO();
		voym.setYears(years);
		voym.setVarieties("玉米");
		List<Map> listYm=mapper.qualityH(voym);
		QualityPredictionAduitVO vodg=new QualityPredictionAduitVO();
		vodg.setYears(years);
		vodg.setVarieties("稻谷");
		List<Map>listDg=mapper.qualityH(vodg);
		QualityPredictionAduitVO vodd=new QualityPredictionAduitVO();
		vodd.setYears(years);
		vodd.setVarieties("大豆");
		List<Map> listDd=mapper.qualityH(vodd);
		resultMap.put("listXm", listXm);
		resultMap.put("listYm", listYm);
		resultMap.put("listDg", listDg);
		resultMap.put("listDd", listDd);
		return resultMap;
	}
	
	/**
	 * @Description 移动端-按企业、企业总数、合格率
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> company() throws Exception {
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<Map> total=gradeItemsMapper.companyTotal();
		List<Map> passRate=gradeItemsMapper.companyPassRate();
		resultMap.put("total", total);
		resultMap.put("passRate", passRate);
		return resultMap;
	}
	
	/**
	 * @Description 移动端-按品种、企业总数、合格率
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> varieties(String varieties) throws Exception {
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<Map> total=gradeItemsMapper.varietiesTotal(varieties);
		List<Map> passRate=gradeItemsMapper.varietiesPassRate(varieties);
		resultMap.put("total", total);
		resultMap.put("passRate", passRate);
		return resultMap;
	}
}
