package com.unis.quality.server.domain;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UpdateTool;
import com.unis.quality.common.constant.Constant;
import com.unis.quality.common.vo.QualityPredictionPlannedVO;
import com.unis.quality.server.dao.QualityPredictionPlannedDao;
import com.unis.quality.server.entity.quality.QualityPredictionPlannedDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * 
 * @ClassName: QualityPredictionPlannedService
 * @Description: 品质测报计划下发 
 * @author lfx
 * @date 2019年7月10日15:01:34
 * 
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class QualityPredictionPlannedDomain{

	@Autowired
	private QualityPredictionPlannedDao mapper;
	
    /**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public QualityPredictionPlannedVO findByIdAndIsDeleted(String id) throws Exception {
    	QualityPredictionPlannedDO qualityResultsDO = findByIdAndIsDeleted(id, 0);
		return LsBeanUtils.copyProperties(qualityResultsDO, QualityPredictionPlannedVO.class);
	}

	/**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public QualityPredictionPlannedDO findByIdAndIsDeleted(String id, int isDelete) throws Exception {
		Example example = new Example(QualityPredictionPlannedDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		QualityPredictionPlannedDO qualityResultsDO = mapper.selectOneByExample(example);
		if (ObjectUtils.equals(qualityResultsDO, null)) {
			return null;
		}
		return qualityResultsDO;
	}

    //根据行政区划过滤数据--弃用
    public Map<String,Object> findByArea(String area,String deptName) {
	 	  Map<String, Object> resultMap = new HashMap<String, Object>();
	 	 //数据过滤
	 	 String areaCode=area;
	 	 String ac="";
	 	 String condition = "";
	 	if (!"".equals(areaCode) && null != areaCode) {
	        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
	            ac= areaCode.substring(0, 2);
	            if((Constant.ZJZX).equals(deptName)) {//省级质检中心
	            	 condition = " DOWNWARD_STATE in ('1','2','3') ";
	            }
	            if((Constant.LSJ).equals(deptName)) {//省级粮食局
	            	  condition = " DOWNWARD_STATE in ('0','1','2','3') ";
	            }
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	            ac= areaCode.substring(0, 4);
	            if((Constant.ZJZX).equals(deptName)) {//市级质检中心
	            	 condition = " DOWNWARD_STATE in ('2','3') ";
	            }
	            if((Constant.LSJ).equals(deptName)) {//市级粮食局
	            	  condition = " DOWNWARD_STATE in ('1','2','3') ";
	            }
	        } else {
	            ac= areaCode;
	            if((Constant.ZJZX).equals(deptName)) {//县级质检中心
	            	 condition = " DOWNWARD_STATE in ('3') ";
	            }
	            if((Constant.LSJ).equals(deptName)) {//县级粮食局
	            	  condition = " DOWNWARD_STATE in ('3','2') ";
	            }
	        }
	 	}
		resultMap.put("areaCode", ac);
		resultMap.put("condition", condition);
	 	 return resultMap;
 	 }
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(QualityPredictionPlannedVO qualityVO, Integer page, Integer size) throws Exception {
 		Example example = new Example(QualityPredictionPlannedDO.class);
		Criteria criteria = example.createCriteria();
		//数据过滤        省未下发：0  省已下发：1  市未下发：1  市已下发：2  县未下发：2  县已下发：3
		String areaCode=qualityVO.getAreaCode();
		String deptName=qualityVO.getDeptId();
		Map<String,Object> map=findByArea(areaCode,deptName);
	    String condition=map.get("condition").toString();
	    String ac=map.get("areaCode").toString();
       /* if(!"".equals(condition)) {
        	criteria.andCondition(condition);
        }*/
       // criteria.andLike("areaCode",  ac + "%");
		// 添加按计划文件名称查询
		if (!"".equals(qualityVO.getPlanFileName()) && null != qualityVO.getPlanFileName()) {
			criteria.andLike("planFileName", "%" + qualityVO.getPlanFileName() + "%");
		}
		// 添加按计划下发时间查询
		if (!"".equals(qualityVO.getScheduledReleaseTime()) && null != qualityVO.getScheduledReleaseTime()) {
			condition =" SUBSTR(SCHEDULED_RELEASE_TIME,0,10)  >='"+qualityVO.getScheduledReleaseTime() +"' and SUBSTR(SCHEDULED_RELEASE_TIME,0,10) <='"+qualityVO.getScheduledReleaseTimeTo()+"'";
			criteria.andCondition(condition);
		}
		// 添加按状态查询
	/*	if (!"".equals(qualityVO.getDownwardState()) && null != qualityVO.getDownwardState()) {
			String status= qualityVO.getDownwardState();
			String state="";
			if("未下发".equals(status)) {
				if(ac.length()==2) {//省
					criteria.andEqualTo("downwardState","0");
				}else if (ac.length()==4) {//市
					criteria.andEqualTo("downwardState","1");
				}else {
					criteria.andEqualTo("downwardState","2");
				}
			}
			if("已下发".equals(status)) {
				String downwardState="";
				if(ac.length()==2) {//省
					downwardState=" DOWNWARD_STATE in ('1','2','3')";
				}else if (ac.length()==4) {//市
					downwardState=" DOWNWARD_STATE in ('2','3')";
				}else {
					downwardState=" DOWNWARD_STATE in ('1','2','3')";
				}
				criteria.andCondition(downwardState);
			}
		}*/
		// 未删除的
		criteria.andIsNull("deleteTime");
		if("zjda".equals(qualityVO.getZjda())) {
			if (!"".equals(qualityVO.getPlanType()) && null != qualityVO.getPlanType()) {//计划类型
				criteria.andLike("planType", "%" + qualityVO.getPlanType() + "%");
			}
			criteria.andEqualTo("downwardState", "3");//状态为县已下发
		}
		// 按时间排序
		example.setOrderByClause("CREATE_TIME DESC");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<QualityPredictionPlannedDO> resultQualityList = mapper.selectByExample(example);
		PageInfo<QualityPredictionPlannedDO> pageInfo = new PageInfo<QualityPredictionPlannedDO>(resultQualityList);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<QualityPredictionPlannedVO> resultList = new ArrayList<>();
		if (!resultQualityList.isEmpty()) {
			for (QualityPredictionPlannedDO resultDO : resultQualityList) {
				QualityPredictionPlannedVO resultVO = LsBeanUtils.copyProperties(resultDO, QualityPredictionPlannedVO.class);
				String time=resultVO.getScheduledReleaseTime();
				if(null!=time) {
					String date=time.substring(0, 10);
					resultVO.setScheduledReleaseTime(date);
				}
				resultVO.setStateName("已下发");
				/*if(ac.length()==2) {//省
					if((Constant.LSJ).equals(deptName)) {//当前登录用户的deptName
						if("0".equals(resultVO.getDownwardState())) {
							resultVO.setStateName("未下发");
						}
						if("1".equals(resultVO.getDownwardState()) ||"2".equals(resultVO.getDownwardState())||"3".equals(resultVO.getDownwardState())) {
							resultVO.setStateName("已下发");
						}
		            }
				}else if (ac.length()==4) {//市
					if((Constant.LSJ).equals(deptName)) {
						if("1".equals(resultVO.getDownwardState())) {
							resultVO.setStateName("未下发");
						}
						if("2".equals(resultVO.getDownwardState())||"3".equals(resultVO.getDownwardState())) {
							resultVO.setStateName("已下发");
						}
		            }
		           
				}else {
					if((Constant.LSJ).equals(deptName)) {
						if("2".equals(resultVO.getDownwardState())) {
							resultVO.setStateName("未下发");
						}
						if("3".equals(resultVO.getDownwardState())) {
							resultVO.setStateName("已下发");
						}
		            }
				}*/
				String type=resultVO.getPlanType();
				if("1".equals(type)) {
					resultVO.setPlanTypeName("新收获粮品质测报");
				}else{
					resultVO.setPlanTypeName("库存粮食质量安全");
				}
				resultList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultList);
		return resultMap;
	}
	
	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(QualityPredictionPlannedVO qualityVO) throws Exception {
		for (String id : qualityVO.getIds()) {
			Example example = new Example(QualityPredictionPlannedDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andEqualTo("downwardState", "0");//状态未省未下发
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			QualityPredictionPlannedDO qDO = mapper.selectOneByExample(example);
			if(ObjectUtils.equals(qDO, null)) {
				throw new RuntimeException("此数据未存储到数据库中。");
			}
			if (ObjectUtils.notEqual(qDO, null)) {
				qDO.setDeleteBy(qualityVO.getDeleteBy());
				qDO.setDeleteTime(DateUtil.getNowDate());
				mapper.updateByPrimaryKey(qDO);
			}
		}
		return true;
	}

	/**
	 * @Description 保存品质测报计划下发
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/20
	 * @param QualityPredictionPlannedVO
	 * @return boolean
	 * @throws Exception
	 */
	public String save(QualityPredictionPlannedVO resultsVO) throws Exception {
		Example example = new Example(QualityPredictionPlannedDO.class);
		Criteria criteria = example.createCriteria();
		if (!"".equals(resultsVO.getPlanFileName()) && null != resultsVO.getPlanFileName()) {
			criteria.andEqualTo("planFileName", resultsVO.getPlanFileName());
		}
		if ("".equals(resultsVO.getPlanType()) ) {
			throw new RuntimeException("请选择计划类型！");
		}
		if ("".equals(resultsVO.getPlanFileName()) ) {
			throw new RuntimeException("请输入计划文件名称！");
		}
		if ("".equals(resultsVO.getScheduledReleaseTime()) ) {
			throw new RuntimeException("请输入计划下发时间！");
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		if (mapper.selectCountByExample(example) > 0) {
			throw new RuntimeException(resultsVO.getPlanFileName() + "已存在!");
		}
		QualityPredictionPlannedDO resultsDO=new QualityPredictionPlannedDO();
		LsBeanUtils.copyPropertiesIgnoreNull(resultsVO, resultsDO);
		resultsDO.setDownwardState("0");//省未下发
		resultsDO.setId(resultsVO.getId());
		resultsDO.setOrgId(resultsVO.getOrgId() + "");
		resultsDO.setDeptId(resultsVO.getDeptId() + "");
		resultsDO.setAreaCode(resultsVO.getAreaCode());
		resultsDO.setCreateBy(resultsVO.getCreateBy());
		resultsDO.setCreateTime(DateUtil.getNowDate());
		//启动工作流返回processId--弃用，流程改为直接下发
		//resultsDO.setProcessId(resultsVO.getProcessId());
		if (mapper.insert(resultsDO) < 1) {
			throw new RuntimeException(resultsDO.getPlanFileName() + "无法保存成功，请检查数据。");
		}
		return resultsDO.getId();
	}

	/**
	 * @Description 更新品质测报计划下发
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:03:46
	 * @param QualityPredictionPlannedVO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(QualityPredictionPlannedVO resultsVO) throws Exception {

    	QualityPredictionPlannedDO qualityResultsDO = findByIdAndIsDeleted(resultsVO.getId(), 0);
		if (ObjectUtils.equals(qualityResultsDO, null)) {
				throw new RuntimeException("此数据未存储到数据库中。");
		}
		QualityPredictionPlannedDO resultsDO = new QualityPredictionPlannedDO();
		LsBeanUtils.copyPropertiesIgnoreNull(resultsVO, resultsDO);
		UpdateTool.copyNullProperties(qualityResultsDO, resultsDO);
		resultsDO.setOrgId(resultsVO.getOrgId() + "");
		resultsDO.setDeptId(resultsVO.getOrgId() + "");
		resultsDO.setAreaCode(resultsVO.getAreaCode());
		resultsDO.setUpdateBy(resultsVO.getCreateBy());
		resultsDO.setUpdateTime(DateUtil.getNowDate());
		if (mapper.updateByPrimaryKey(resultsDO) < 1) {
			throw new RuntimeException("更新失败，请检查数据格式。");
		}
		return true;
	}
    
    
    
    /**
	 * @Description 查询计划文件名称
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:02:41
	 * @return boolean
	 * @throws Exception
	 */
	public List getFlieName(QualityPredictionPlannedVO vo) throws Exception{
		Example example = new Example(QualityPredictionPlannedDO.class);
		Criteria criteria = example.createCriteria();
		//数据过滤
		 String areaCode=vo.getAreaCode();
		 String downwardState="";
		if (!"".equals(areaCode) && null != areaCode) {
	        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
	        	downwardState=" DOWNWARD_STATE in ('1','2','3')";
	        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
	        	if((Constant.LSJ).equals(vo.getDeptId())) {
	        		 downwardState=" DOWNWARD_STATE in ('1','2','3')";
	        	}
	        	if((Constant.ZJZX).equals(vo.getDeptId())) {
	        		 downwardState=" DOWNWARD_STATE in ('2','3')";
	        	}
	        } else {
	        	if((Constant.LSJ).equals(vo.getDeptId())) {
	        		 downwardState=" DOWNWARD_STATE in ('2','3')";
	        	}
	        	if((Constant.ZJZX).equals(vo.getDeptId())) {
	        		downwardState=" DOWNWARD_STATE in ('3')";
	        	}
	        }
		}
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("planType", vo.getPlanType());
		/*if(!"".equals(downwardState)) {弃用
			criteria.andCondition(downwardState);
		}*/
		List<QualityPredictionPlannedDO> list = mapper.selectByExample(example);
		return list;
	}
	

	/**
	 * @Description 品质测报-计划下发
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:02:41
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateState(QualityPredictionPlannedVO vo) throws Exception{
		Example example = new Example(QualityPredictionPlannedDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("id", vo.getId());
		// 未删除的
		criteria.andIsNull("deleteTime");
		QualityPredictionPlannedDO qDO = mapper.selectOneByExample(example);
		if (ObjectUtils.notEqual(qDO, null)) {
			qDO.setDownwardState(vo.getDownwardState());
			mapper.updateByPrimaryKey(qDO);
		}
		return true;
	}
	
}
