package com.unis.quality.server.domain;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.quality.common.constant.Constant;
import com.unis.quality.common.dto.FoodStockDTO;
import com.unis.quality.common.vo.QualityPredictionAduitVO;
import com.unis.quality.common.vo.SummaryInspectionResultVO;
import com.unis.quality.common.vo.SummaryNotSuitableVO;
import com.unis.quality.common.vo.SummaryResultsItemsVO;
import com.unis.quality.common.vo.SummaryResultsVO;
import com.unis.quality.common.vo.SummarySubstandardSampleVO;
import com.unis.quality.server.dao.SummaryInspectionResultDao;
import com.unis.quality.server.dao.SummaryNotSuitableDao;
import com.unis.quality.server.dao.SummaryResultsDao;
import com.unis.quality.server.dao.SummaryResultsItemsDao;
import com.unis.quality.server.dao.SummarySubstandardSampleDao;
import com.unis.quality.server.entity.quality.SummaryInspectionResultDO;
import com.unis.quality.server.entity.quality.SummaryNotSuitableDO;
import com.unis.quality.server.entity.quality.SummaryResultsDO;
import com.unis.quality.server.entity.quality.SummaryResultsItemsDO;
import com.unis.quality.server.entity.quality.SummarySubstandardSampleDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * 
 * @ClassName: SummaryResultsService
 * @Description: 安全监测-粮食质量检验结果汇总表
 * @author lfx
 * @date 2019年7月10日15:01:34
 * 
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class SummaryResultsDomain  {
	
	@Autowired
	private QualityPredictionAduitDomain mapper;
	
	@Autowired
	private SummaryResultsDao summaryMapper;
	@Autowired
	private SummaryResultsItemsDao summaryItemsMapper;
	
	@Autowired
	private SummarySubstandardSampleDao  sampleMapper;
	
	@Autowired
	private SummaryInspectionResultDao summaryInspectionResultMapper;
	
	@Autowired
	private SummaryNotSuitableDao summaryNotSuitableMapper;
	
	/**
	 * @Description 根据id查询3、粮食质量检验结果汇总表
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public SummaryResultsDO findByIdAndIsDeleted(String id, String areaCode,String batch) throws Exception {
		Example example = new Example(SummaryResultsDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("planId", id);
		if(!"".equals(batch)) {
			criteria.andEqualTo("batch", batch);
		}
		SummaryResultsDO qualityResultsDO = summaryMapper.selectOneByExample(example);
		if (ObjectUtils.equals(qualityResultsDO, null)) {
			return null;
		}
		return qualityResultsDO;
	}

    
    /**
	 * @Description 根据id查询3、粮食质量检验结果汇总表-明细表
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
    public List<SummaryResultsItemsVO> findItemsByIdAndIsDeleted(FoodStockDTO fdto) throws Exception {
		Example example = new Example(SummaryResultsItemsDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		String id=fdto.getPlanId();
		String type=fdto.getType();
		String batch=fdto.getBatch();
		String planFileName=fdto.getPlanFileName();
		if(!"".equals(id)) {
			criteria.andEqualTo("summaryId", id);
		} if(!"".equals(type)){
			criteria.andEqualTo("type", type);
		}if(!"".equals(batch)){
			criteria.andEqualTo("batch", batch);
		}
		if(null!=planFileName){
			criteria.andEqualTo("planFileName", planFileName);
		}
		List<SummaryResultsItemsDO> list = summaryItemsMapper.selectByExample(example);
		List<SummaryResultsItemsVO> resultVOList = new ArrayList<>();
		if (!list.isEmpty()) {
			for (SummaryResultsItemsDO resultDO : list) {
				SummaryResultsItemsVO resultVO = LsBeanUtils.copyProperties(resultDO, SummaryResultsItemsVO.class);
				resultVOList.add(resultVO);
			}
		}
		return resultVOList;
	}
    
   
    /**
   	 * @Description 根据id查询 4、质量不达标样品汇总表
   	 * @version v1.0
   	 * @author lfx
   	 * @date 2018/10/24
   	 * @param id
   	 * @return
   	 * @throws Exception
   	 */
       public List<SummarySubstandardSampleVO> findSampleByIdAndIsDeleted(FoodStockDTO fdto) throws Exception {
   		Example example = new Example(SummarySubstandardSampleDO.class);
   		Criteria criteria = example.createCriteria();
   		criteria.andIsNull("deleteTime");
   		String id=fdto.getPlanId();
		String type=fdto.getType();
		String batch=fdto.getBatch();
		String planFileName=fdto.getPlanFileName();
   		if(!"".equals(id)) {
   			criteria.andEqualTo("planId", id);
   		} if(!"".equals(type)) {
   			criteria.andEqualTo("type", type);
   		}if(!"".equals(batch)) {
   			criteria.andEqualTo("batch", batch);
   		}	if(null!=planFileName)  {
   			criteria.andEqualTo("planFileName", planFileName);
   		}
   		
   		List<SummarySubstandardSampleDO> list = sampleMapper.selectByExample(example);
   		List<SummarySubstandardSampleVO> resultVOList = new ArrayList<>();
   		if (!list.isEmpty()) {
   			for (SummarySubstandardSampleDO resultDO : list) {
   				SummarySubstandardSampleVO resultVO = LsBeanUtils.copyProperties(resultDO, SummarySubstandardSampleVO.class);
   				resultVOList.add(resultVO);
   			}
   		}
   		return resultVOList;
   	}
   /**
  	 * @Description 根据id查询 5、粮食储存品质检验结果汇总表
  	 * @version v1.0
  	 * @author lfx
  	 * @date 2018/10/24
  	 * @param id
  	 * @return
  	 * @throws Exception
  	 */
       //String id,String type,String areaCode,String batch,String planFileName
      public List<SummaryInspectionResultVO> findInspectionByIdAndIsDeleted(FoodStockDTO fdto) throws Exception {
  		Example example = new Example(SummaryInspectionResultDO.class);
  		Criteria criteria = example.createCriteria();
  		criteria.andIsNull("deleteTime");
  		if(!"".equals(fdto.getId())) {
   			criteria.andEqualTo("planId", fdto.getPlanId());
   		} if(!"".equals(fdto.getType())) {
   			criteria.andEqualTo("type", fdto.getType());
   		}if(!"".equals(fdto.getBatch())) {
   			criteria.andEqualTo("batch", fdto.getBatch());
   		}	if(null!=fdto.getPlanFileName()) {
   			criteria.andEqualTo("planFileName", fdto.getPlanFileName());
   		}if(null!=fdto.getYears()) {
   			String condition = (" substr(CHECK_POINT,0,4)="+fdto.getYears());
   			criteria.andCondition(condition);
   		}
  		List<SummaryInspectionResultDO> list = summaryInspectionResultMapper.selectByExample(example);
  		List<SummaryInspectionResultVO> resultVOList = new ArrayList<>();
  		if (!list.isEmpty()) {
  			for (SummaryInspectionResultDO resultDO : list) {
  				SummaryInspectionResultVO resultVO = LsBeanUtils.copyProperties(resultDO, SummaryInspectionResultVO.class);
  				resultVOList.add(resultVO);
  			}
  		}
  		return resultVOList;
  	}
      /**
    	 * @Description 根据id查询6、储存品质不宜存样品汇总表
    	 * @version v1.0
    	 * @author lfx
    	 * @date 2018/10/24
    	 * @param id
    	 * @return
    	 * @throws Exception
    	 */
        public List<SummaryNotSuitableVO> findyNotSuitableByIdAndIsDeleted(FoodStockDTO fdto) throws Exception {
    		Example example = new Example(SummaryNotSuitableDO.class);
    		Criteria criteria = example.createCriteria();
    		criteria.andIsNull("deleteTime");
    		String id=fdto.getPlanId();
    		String type=fdto.getType();
    		String batch=fdto.getBatch();
    		String planFileName=fdto.getPlanFileName();
    		if(!"".equals(id)) {
       			criteria.andEqualTo("planId", id);
       		} if(!"".equals(type)) {
       			criteria.andEqualTo("type", type);
       		}if(!"".equals(batch)) {
       			criteria.andEqualTo("batch", batch);
       		}
       		if(null!=planFileName) {
       			criteria.andEqualTo("planFileName", planFileName);
       		}
    		List<SummaryNotSuitableDO> list = summaryNotSuitableMapper.selectByExample(example);
    		List<SummaryNotSuitableVO> resultVOList = new ArrayList<>();
    		if (!list.isEmpty()) {
    			for (SummaryNotSuitableDO resultDO : list) {
    				SummaryNotSuitableVO resultVO = LsBeanUtils.copyProperties(resultDO, SummaryNotSuitableVO.class);
    				resultVOList.add(resultVO);
    			}
    		}
    		return resultVOList;
    	} 		
       
  
       
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
   public Map<String, Object> findSummaryResultsByPage(SummaryResultsVO qualityVO, Integer page, Integer size) throws Exception {
		Example example = new Example(SummaryResultsDO.class);
		Criteria criteria = example.createCriteria();
		//数据过滤
		String areaCode=qualityVO.getAreaCode();
        String deptName=qualityVO.getDeptId();
        QualityPredictionAduitVO vo=new QualityPredictionAduitVO();
		 vo.setAreaCode(areaCode);
		 vo.setDeptId(deptName);
		 vo.setState(qualityVO.getState());
		 vo.setFindingsAudit(qualityVO.getFindingsAudit());
		 Map<String,Object> map=mapper.findByArea(vo);
		 String condition1=map.get("condition").toString();
		 String conditionZt=map.get("conditionZt").toString();
		 String ac=map.get("areaCode").toString();
		 criteria.andCondition("1=1");
		 if("".equals(conditionZt)) {
			 criteria.andCondition(condition1);
		 }
		 //添加按状态查询
		 if(!"".equals(conditionZt)) {
			 criteria.andCondition(conditionZt);
		 }
	      criteria.andLike("areaCode",  ac + "%");
		// 添加按承储企业名称查询
		if (!"".equals(qualityVO.getPlanFileName()) && null != qualityVO.getPlanFileName()) {
			criteria.andLike("planFileName", "%" + qualityVO.getPlanFileName() + "%");
		}
		// 添加按计划下发时间查询
		if (!"".equals(qualityVO.getCity()) && null != qualityVO.getCity()) {
			criteria.andLike("city", "%" + qualityVO.getCity() + "%");
		}
	
		// 未删除的
		criteria.andIsNull("deleteTime");
		// 按时间排序
		example.setOrderByClause("CREATE_TIME DESC");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<SummaryResultsDO> resultQualityList = summaryMapper.selectByExample(example);
		PageInfo<SummaryResultsDO> pageInfo = new PageInfo<SummaryResultsDO>(resultQualityList);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<SummaryResultsVO> resultList = new ArrayList<>();
		if (!resultQualityList.isEmpty()) {
			for (SummaryResultsDO resultDO : resultQualityList) {
				SummaryResultsVO resultVO = LsBeanUtils.copyProperties(resultDO, SummaryResultsVO.class);
				if(ac.length()==2) {//省
					if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("15".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("12".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("驳回");
							}if("8".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}if("10".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("8".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}if("11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}/*if("12".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}*/
						}
					}
					if((Constant.LSJ).equals(deptName)) {
						if("10".equals(resultVO.getFindingsAudit())) {
							resultVO.setStateName("未审核");
						}
					}
					
				}else if(ac.length()==4) {//市
					if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("14".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}
							if("5".equals(resultVO.getFindingsAudit()) || "4".equals(resultVO.getFindingsAudit()) || "6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}if("15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("4".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("未上报");
							}
							if("5".equals(resultVO.getFindingsAudit()) || "15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit()) ||"6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}
						}
						
					}
					if((Constant.LSJ).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("5".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("15".equals(resultVO.getFindingsAudit()) || "6".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("审核通过");
							}
						}
						if("上报".equals(qualityVO.getState())) {
							if("15".equals(resultVO.getFindingsAudit()) || "8".equals(resultVO.getFindingsAudit()) || "10".equals(resultVO.getFindingsAudit())
									|| "11".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("已上报");
							}
							if("6".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}
						}
					}
				}
				else {//县
					if((Constant.LSJ).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("1".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未审核");
							}if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
									resultVO.setStateName("审核通过");
								}
						}if("上报".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit())) {
								resultVO.setStateName("未上报");
							}if("14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("已上报");
								}
						}
						
					}if((Constant.ZJZX).equals(deptName)) {
						if("审核".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
								||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
								||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("审核通过");
							}
						}if("上报".equals(qualityVO.getState())) {
							if("2".equals(resultVO.getFindingsAudit()) ||"14".equals(resultVO.getFindingsAudit()) ||"4".equals(resultVO.getFindingsAudit()) 
									||"5".equals(resultVO.getFindingsAudit())  ||"6".equals(resultVO.getFindingsAudit()) ||"15".equals(resultVO.getFindingsAudit()) 
									||"8".equals(resultVO.getFindingsAudit())  ||"10".equals(resultVO.getFindingsAudit()) ||"11".equals(resultVO.getFindingsAudit()) ) {
								resultVO.setStateName("已上报");
							}
						}
						
					}
				}
				resultList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultList);
		return resultMap;
	}
	
	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return boolean
	 * @throws Exception
	 */

	public boolean deletesSummaryResults(String[] ids,String batch,String areaCode,String deptName) throws Exception {
		for (String id : ids) {
			Example example = new Example(SummaryResultsDO.class);
			Criteria criteria = example.createCriteria();
			if (!"".equals(areaCode) && null != areaCode) {
		        String condition = "";
		        if ((Constant.PROVINCE_CODE).equals(StringUtils.substring(areaCode, 2, 6))) {
		        	 condition = " FINDINGS_AUDIT ='8'  and AREA_CODE="+areaCode;
		        } else if (Constant.CITY_CODE.equals(StringUtils.substring(areaCode, 4, 6))) {
		            condition = " FINDINGS_AUDIT ='4'  and AREA_CODE="+areaCode;
		        } else {
		            condition = " FINDINGS_AUDIT ='0' ";
		        }
		        criteria.andCondition(condition);
			}
			
			criteria.andEqualTo("planId", id);
			criteria.andEqualTo("batch", batch);
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			List<SummaryResultsDO> qDO = summaryMapper.selectByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				for(int i=0;i<qDO.size();i++) {
					qDO.get(i).setDeleteBy(deptName);
					qDO.get(i).setDeleteTime(DateUtil.getNowDate());
					summaryMapper.updateByPrimaryKey(qDO.get(i));
				}
			}
		}
		return true;
	}
	public boolean deletesSummaryResultsItems(String[] ids,String batch,String areaCode,String deptName) throws Exception {
		for (String id : ids) {
			SummaryResultsDO summaryResultsDO = findByIdAndIsDeleted(id,areaCode,batch);
			Example example = new Example(SummaryResultsItemsDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("summaryId", summaryResultsDO.getId());
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			criteria.andEqualTo("batch", batch);
			List<SummaryResultsItemsDO> qDO = summaryItemsMapper.selectByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				for(int i=0;i<qDO.size();i++) {
					qDO.get(i).setDeleteBy(deptName);
					qDO.get(i).setDeleteTime(DateUtil.getNowDate());
					summaryItemsMapper.updateByPrimaryKey(qDO.get(i));
				}
			}
		}
		return true;
	}

	public boolean deletesSubstandardSample(String[] ids,String batch,String deptName) throws Exception {
		for (String id : ids) {
			Example example = new Example(SummarySubstandardSampleDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("planId", id);
			criteria.andEqualTo("batch", batch);
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			List<SummarySubstandardSampleDO> qDO = sampleMapper.selectByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				for(int i=0;i<qDO.size();i++) {
					qDO.get(i).setDeleteBy(deptName);
					qDO.get(i).setDeleteTime(DateUtil.getNowDate());
					sampleMapper.updateByPrimaryKey(qDO.get(i));
				}
			}
		}
		return true;
	}
	
	public boolean deletesInspectionResult(String[] ids,String batch,String deptName) throws Exception {
		for (String id : ids) {
			Example example = new Example(SummaryInspectionResultDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("planId", id);
			criteria.andEqualTo("batch", batch);
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			List<SummaryInspectionResultDO> qDO = summaryInspectionResultMapper.selectByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				for(int i=0;i<qDO.size();i++) {
					qDO.get(i).setDeleteBy(deptName);
					qDO.get(i).setDeleteTime(DateUtil.getNowDate());
					summaryInspectionResultMapper.updateByPrimaryKey(qDO.get(i));
				}
			}
		}
		return true;
	}
	
	public boolean deletesNotSuitable(String[] ids,String batch,String deptName) throws Exception {
		for (String id : ids) {
			Example example = new Example(SummaryNotSuitableDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("planId", id);
			// 未删除的收购资格
			criteria.andIsNull("deleteTime");
			criteria.andEqualTo("batch", batch);
			List<SummaryNotSuitableDO> qDO = summaryNotSuitableMapper.selectByExample(example);
			if (ObjectUtils.notEqual(qDO, null)) {
				for(int i=0;i<qDO.size();i++) {
					qDO.get(i).setDeleteBy(deptName);
					qDO.get(i).setDeleteTime(DateUtil.getNowDate());
					summaryNotSuitableMapper.updateByPrimaryKey(qDO.get(i));
				}
			}
		}
		return true;
	}

    //保存安全监测-3、粮食质量检验结果汇总表
    public boolean saveSummaryResults(Map<String,Object> aduitData,SummaryResultsDO resultsDO) {
    	Example example = new Example(SummaryResultsDO.class);
		Criteria criteria = example.createCriteria();
		String areaCode=resultsDO.getAreaCode();
		criteria.andLike("areaCode",  areaCode + "%");
    	if (!"".equals(aduitData.get("planFileName")) && null != aduitData.get("planFileName")) {
			criteria.andEqualTo("planFileName", aduitData.get("planFileName"));
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		String condition = " FINDINGS_AUDIT not in ('3' ,'13','9','7','12')";
    	criteria.andCondition(condition);
		if (summaryMapper.selectCountByExample(example) > 0) {
			throw new RuntimeException(aduitData.get("planFileName")+"已存在！");
		}
		resultsDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
		resultsDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
		resultsDO.setCity(mapper.isNull(aduitData.get("city")+""));
		resultsDO.setType(mapper.isNull(aduitData.get("type")+""));
		resultsDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
		resultsDO.setFoodNature(mapper.isNull(aduitData.get("foodNature")+""));
		resultsDO.setCheckPoint(mapper.isNull(aduitData.get("checkPoint")+""));
	
		resultsDO.setCreateTime(DateUtil.getNowDate());
		if (summaryMapper.insert(resultsDO) < 1) {
			throw new RuntimeException(resultsDO.getPlanFileName() + "无法保存成功，请检查数据。");
		}
			
		return true;
    }
    
    //保存安全监测-3、粮食质量检验结果汇总表-明细表
    public boolean saveSummaryResultsItems(List<Map> itemsData,SummaryResultsDO resultsDO) {
    	Example example1 = new Example(SummaryResultsItemsDO.class);
		Criteria criteria1 = example1.createCriteria();
		String areaCode=resultsDO.getAreaCode();
		criteria1.andLike("areaCode",  areaCode + "%");
		for (int t = 0; t < itemsData.size(); t++) {
			if (itemsData.get(t) != null) {
				if(null==itemsData.get(t).get("id")) {
					if (!"".equals(resultsDO.getId()) && null != resultsDO.getId()) {
						criteria1.andEqualTo("summaryId", resultsDO.getId());
					}
					if (!"".equals(itemsData.get(t).get("checkLibraryPoints")) && null != itemsData.get(t).get("checkLibraryPoints")) {
						criteria1.andEqualTo("checkLibraryPoints", itemsData.get(t).get("checkLibraryPoints"));
					}
					criteria1.andIsNull("deleteTime");
					String condition = " FINDINGS_AUDIT not in ('3' ,'13','9','7','12')";
			    	criteria1.andCondition(condition);
					/*if (summaryItemsMapper.selectCountByExample(example1) > 0) {
						throw new RuntimeException(itemsData.get(t).get("checkLibraryPoints")+"已存在！");
					}*/
					SummaryResultsItemsDO itemsDO = new SummaryResultsItemsDO();
					itemsDO.setBatch(resultsDO.getBatch());
					itemsDO.setSummaryId(resultsDO.getId());//汇总表id
					itemsDO.setType("3");
					itemsDO.setCheckLibraryPoints(mapper.isNull(itemsData.get(t).get("checkLibraryPoints")+""));
					itemsDO.setCompanyNumber(mapper.isNull(itemsData.get(t).get("companyNumber")+""));
					itemsDO.setSamplesTotal(mapper.isNull(itemsData.get(t).get("samplesTotal")+""));
					itemsDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
					itemsDO.setAchievementRate(mapper.isNull(itemsData.get(t).get("achievementRate")+""));
					itemsDO.setPaddySamplesNumber(mapper.isNull(itemsData.get(t).get("paddySamplesNumber")+""));
					itemsDO.setPaddyRepresentativesNumber(mapper.isNull(itemsData.get(t).get("paddyRepresentativesNumber")+""));
					itemsDO.setPaddyAchievementRate(mapper.isNull(itemsData.get(t).get("paddyAchievementRate")+""));
					itemsDO.setWheatSamplesNumber(mapper.isNull(itemsData.get(t).get("wheatSamplesNumber")+""));
					itemsDO.setWheatRepresentativesNumber(mapper.isNull(itemsData.get(t).get("wheatRepresentativesNumber")+""));
					itemsDO.setWheatAchievementRate(mapper.isNull(itemsData.get(t).get("wheatAchievementRate")+""));
					itemsDO.setCornSamplesNumber(mapper.isNull(itemsData.get(t).get("cornSamplesNumber")+""));
					itemsDO.setCornRepresentativesNumber(mapper.isNull(itemsData.get(t).get("cornRepresentativesNumber")+""));
					itemsDO.setCornAchievementRate(mapper.isNull(itemsData.get(t).get("cornAchievementRate")+""));
					itemsDO.setSoybeanSamplesNumber(mapper.isNull(itemsData.get(t).get("soybeanSamplesNumber")+""));
					itemsDO.setSoybeanRepresentativesNumber(mapper.isNull(itemsData.get(t).get("soybeanRepresentativesNumber")+""));
					itemsDO.setSoybeanAchievementRate(mapper.isNull(itemsData.get(t).get("soybeanAchievementRate")+""));
					itemsDO.setRiceSamplesNumber(mapper.isNull(itemsData.get(t).get("riceSamplesNumber")+""));
					itemsDO.setRiceRepresentativesNumber(mapper.isNull(itemsData.get(t).get("riceRepresentativesNumber")+""));
					itemsDO.setRiceAchievementRate(mapper.isNull(itemsData.get(t).get("riceAchievementRate")+""));
					itemsDO.setWheatmealSamplesNumber(mapper.isNull(itemsData.get(t).get("wheatmealSamplesNumber")+""));
					itemsDO.setWheatmealRepresentativesNumb(mapper.isNull(itemsData.get(t).get("wheatmealRepresentativesNumb")+""));
					itemsDO.setWheatmealAchievementRate(mapper.isNull(itemsData.get(t).get("wheatmealAchievementRate")+""));
					
					itemsDO.setAreaCode(resultsDO.getAreaCode());
					itemsDO.setCreateBy(resultsDO.getCreateBy());
					itemsDO.setCreateTime(DateUtil.getNowDate());
					if (summaryItemsMapper.insert(itemsDO) < 1) {
						throw new RuntimeException(itemsDO.getCheckLibraryPoints() + "无法保存成功，请检查数据。");
					}
				}
			}
		}
    	return true;
    }
    
    //保存 4、质量不达标样品汇总表
    public boolean saveSummarySubstandardSample(Map<String,Object> aduitData,List<Map> itemsData,SummarySubstandardSampleDO sampleDO) {
    	Example example2 = new Example(SummarySubstandardSampleDO.class);
		Criteria criteria2 = example2.createCriteria();
		String areaCode=sampleDO.getAreaCode();
		criteria2.andLike("areaCode",  areaCode + "%");
		if(itemsData.size() > 0 && itemsData != null) {
			for (int t = 0; t < itemsData.size(); t++) {
				if (itemsData.get(t) != null) {
					if(null==itemsData.get(t).get("id")) {
						if (!"".equals(aduitData.get("planFileName")) && null != aduitData.get("planFileName")) {
							criteria2.andEqualTo("planFileName", aduitData.get("planFileName"));
						}
						if (!"".equals(itemsData.get(t).get("libraryPointName")) && null != itemsData.get(t).get("libraryPointName")) {
							criteria2.andEqualTo("libraryPointName", itemsData.get(t).get("libraryPointName"));
						}
						criteria2.andIsNull("deleteTime");
						/*if (sampleMapper.selectCountByExample(example2) > 0) {
							throw new RuntimeException( itemsData.get(t).get("libraryPointName")+"已存在！");
						}*/
						sampleDO.setBatch(mapper.isNull(aduitData.get("batch")+""));
						sampleDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
						sampleDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
						sampleDO.setCity(mapper.isNull(aduitData.get("city")+""));
						sampleDO.setType(mapper.isNull(aduitData.get("type")+""));
						sampleDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
						//明细
						sampleDO.setLibraryPointName(mapper.isNull(itemsData.get(t).get("libraryPointName")+""));
						sampleDO.setWarehouse(mapper.isNull(itemsData.get(t).get("warehouse")+""));
						sampleDO.setSampleNumber(mapper.isNull(itemsData.get(t).get("sampleNumber")+""));
						sampleDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
						sampleDO.setNature(mapper.isNull(itemsData.get(t).get("nature")+""));
						sampleDO.setVarieties(mapper.isNull(itemsData.get(t).get("varieties")+""));
						sampleDO.setPlaceOrigin(mapper.isNull(itemsData.get(t).get("placeOrigin")+""));
						sampleDO.setHarvestLife(mapper.isNull(itemsData.get(t).get("harvestLife")+""));
						sampleDO.setStorageTime(mapper.isNull(itemsData.get(t).get("storageTime")+""));
						sampleDO.setUnqualifiedItems(mapper.isNull(itemsData.get(t).get("unqualifiedItems")+""));
						sampleDO.setDetectionValue(mapper.isNull(itemsData.get(t).get("detectionValue")+""));
						sampleDO.setCreateTime(DateUtil.getNowDate());
						
						if (sampleMapper.insert(sampleDO) < 1) {
							throw new RuntimeException( "无法保存成功，请检查数据。");
						}
					}
				}
			}
		}
    	return true;
    }
    
  //保存5、粮食储存品质检验结果汇总表
    public boolean saveSummaryInspectionResult(Map<String,Object> aduitData,List<Map> itemsData,SummaryInspectionResultDO sampleDO) {
    	Example example2 = new Example(SummaryInspectionResultDO.class);
		Criteria criteria2 = example2.createCriteria();
		if(itemsData.size() > 0 && itemsData != null) {
			String areaCode=sampleDO.getAreaCode();
			criteria2.andLike("areaCode",  areaCode + "%");
			for (int t = 0; t < itemsData.size(); t++) {
				if (itemsData.get(t) != null) {
					if (!"".equals(aduitData.get("planFileName")) && null != aduitData.get("planFileName")) {
						criteria2.andEqualTo("planFileName", aduitData.get("planFileName"));
					}
					if (!"".equals(itemsData.get(t).get("inspectionArea")) && null != itemsData.get(t).get("inspectionArea")) {
						criteria2.andEqualTo("inspectionArea", itemsData.get(t).get("inspectionArea"));
					}
					criteria2.andIsNull("deleteTime");
					/*if (summaryInspectionResultMapper.selectCountByExample(example2) > 0) {
						throw new RuntimeException(itemsData.get(t).get("inspectionArea")+"已存在！");
					}*/
					sampleDO.setBatch(mapper.isNull(aduitData.get("batch")+""));
					sampleDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
					sampleDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
					sampleDO.setCity(mapper.isNull(aduitData.get("city")+""));
					sampleDO.setType(mapper.isNull(aduitData.get("type")+""));
					sampleDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
					sampleDO.setFoodNature(mapper.isNull(aduitData.get("foodNature")+""));
					sampleDO.setCheckPoint(mapper.isNull(aduitData.get("checkPoint")+""));
					
					//明细
					sampleDO.setInspectionArea(mapper.isNull(itemsData.get(t).get("inspectionArea")+""));
					sampleDO.setCompanyNumber(mapper.isNull(itemsData.get(t).get("companyNumber")+""));
					sampleDO.setSamplesTotal(mapper.isNull(itemsData.get(t).get("samplesTotal")+""));
					sampleDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
					sampleDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
					sampleDO.setSurvivabilityRate(mapper.isNull(itemsData.get(t).get("survivabilityRate")+""));
					sampleDO.setMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("mildUnsuitableStorage")+""));
					sampleDO.setSevereInappropriateSurvival(mapper.isNull(itemsData.get(t).get("severeInappropriateSurvival")+""));
					sampleDO.setPaddySamplesNumber(mapper.isNull(itemsData.get(t).get("paddySamplesNumber")+""));
					sampleDO.setPaddySurvivabilityRate(mapper.isNull(itemsData.get(t).get("paddySurvivabilityRate")+""));
					sampleDO.setPaddyMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("paddyMildUnsuitableStorage")+""));
					sampleDO.setPaddySevereInappropriateSur(mapper.isNull(itemsData.get(t).get("paddySevereInappropriateSur")+""));
					sampleDO.setWheatSamplesNumber(mapper.isNull(itemsData.get(t).get("wheatSamplesNumber")+""));
					sampleDO.setWheatSurvivabilityRate(mapper.isNull(itemsData.get(t).get("wheatSurvivabilityRate")+""));
					sampleDO.setWheatMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("wheatMildUnsuitableStorage")+""));
					sampleDO.setWheatSevereInappropriateSur(mapper.isNull(itemsData.get(t).get("wheatSevereInappropriateSur")+""));
					sampleDO.setCornSamplesNumber(mapper.isNull(itemsData.get(t).get("cornSamplesNumber")+""));
					sampleDO.setCornSurvivabilityRate(mapper.isNull(itemsData.get(t).get("cornSurvivabilityRate")+""));
					sampleDO.setCornMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("cornMildUnsuitableStorage")+""));
					sampleDO.setCornSevereInappropriateSurv(mapper.isNull(itemsData.get(t).get("cornSevereInappropriateSurv")+""));
					sampleDO.setSoybeanSamplesSumber(mapper.isNull(itemsData.get(t).get("soybeanSamplesSumber")+""));
					sampleDO.setSoybeanSurvivabilityRate(mapper.isNull(itemsData.get(t).get("soybeanSurvivabilityRate")+""));
					sampleDO.setSoybeanMildUnsuitableStorag(mapper.isNull(itemsData.get(t).get("soybeanMildUnsuitableStorag")+""));
					sampleDO.setSoybeanSevereInappropriates(mapper.isNull(itemsData.get(t).get("soybeanSevereInappropriates")+""));
					
					sampleDO.setCreateTime(DateUtil.getNowDate());
					if (summaryInspectionResultMapper.insert(sampleDO) < 1) {
						throw new RuntimeException( "无法保存成功，请检查数据。");
					}
				}
			}
		}
    	return true;
    }
    
  //保存6、储存品质不宜存样品汇总表
    public boolean saveSummaryNotSuitable(Map<String,Object> aduitData,List<Map> itemsData,SummaryNotSuitableDO sampleDO) {
    	Example example2 = new Example(SummaryNotSuitableDO.class);
		Criteria criteria2 = example2.createCriteria();
		if(itemsData.size() > 0 && itemsData != null) {
			String areaCode=sampleDO.getAreaCode();
			criteria2.andLike("areaCode",  areaCode + "%");
			for (int t = 0; t < itemsData.size(); t++) {
				if (itemsData.get(t) != null) {
					if(null==itemsData.get(t).get("id")) {
						if (!"".equals(aduitData.get("planFileName")) && null != aduitData.get("planFileName")) {
							criteria2.andEqualTo("planFileName", aduitData.get("planFileName"));
						}
						if (!"".equals(itemsData.get(t).get("checkLibraryPoints")) && null != itemsData.get(t).get("checkLibraryPoints")) {
							criteria2.andEqualTo("checkLibraryPoints", itemsData.get(t).get("checkLibraryPoints"));
						}
						criteria2.andIsNull("deleteTime");
						/*if (summaryNotSuitableMapper.selectCountByExample(example2) > 0) {
							throw new RuntimeException(itemsData.get(t).get("checkLibraryPoints")+"已存在");
						}*/
						sampleDO.setBatch(mapper.isNull(aduitData.get("batch")+""));
						sampleDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
						sampleDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
						sampleDO.setCity(mapper.isNull(aduitData.get("city")+""));
						sampleDO.setType(mapper.isNull(aduitData.get("type")+""));
						sampleDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
						//明细
						sampleDO.setCheckLibraryPoints(mapper.isNull(itemsData.get(t).get("checkLibraryPoints")+""));
						sampleDO.setWarehouse(mapper.isNull(itemsData.get(t).get("warehouse")+""));
						sampleDO.setFoodNature(mapper.isNull(itemsData.get(t).get("foodNature")+""));
						sampleDO.setVarieties(mapper.isNull(itemsData.get(t).get("varieties")+""));
						sampleDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
						sampleDO.setProject(mapper.isNull(itemsData.get(t).get("project")+""));
						sampleDO.setTestValue(mapper.isNull(itemsData.get(t).get("testValue")+""));
						sampleDO.setSevereInappropriateSurvival(mapper.isNull(itemsData.get(t).get("severeInappropriateSurvival")+""));
						sampleDO.setMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("mildUnsuitableStorage")+""));
						sampleDO.setCreateTime(DateUtil.getNowDate());
						if (summaryNotSuitableMapper.insert(sampleDO) < 1) {
							throw new RuntimeException( "无法保存成功，请检查数据。");
						}
					}
				}
			}
		}
    	return true;
    }

    //修改3、粮食质量检验结果汇总表
    public boolean updateSummaryResults(Map<String,Object> aduitData,SummaryResultsDO resultsDO) throws Exception {
    	Example example = new Example(SummaryResultsDO.class);
		Criteria criteria = example.createCriteria();
		String areaCode=resultsDO.getAreaCode();
		criteria.andLike("areaCode",  areaCode + "%");
		SummaryResultsDO qualityResultsDO = findByIdAndIsDeleted(aduitData.get("planId")+"", areaCode,resultsDO.getBatch());
		if (ObjectUtils.equals(qualityResultsDO, null)) {
			throw new RuntimeException("此数据未存储到数据库中。");
		}
		resultsDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
		resultsDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
		resultsDO.setCity(mapper.isNull(aduitData.get("city")+""));
		resultsDO.setType(mapper.isNull(aduitData.get("type")+""));
		resultsDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
		resultsDO.setFoodNature(mapper.isNull(aduitData.get("foodNature")+""));
		resultsDO.setCheckPoint(mapper.isNull(aduitData.get("checkPoint")+""));
		resultsDO.setId(aduitData.get("id")+"");
		if( null==aduitData.get("slsjState")) {
			resultsDO.setFindingsAudit("8");
		}
		resultsDO.setProcessId(aduitData.get("processId")+"");
		//resultsDO.setStateName(aduitData.get("stateName")+"");
		resultsDO.setOrgId(qualityResultsDO.getOrgId() + "");
		resultsDO.setDeptId(qualityResultsDO.getDeptId() + "");
		resultsDO.setAreaCode(qualityResultsDO.getAreaCode()+"");
		resultsDO.setCreateTime(qualityResultsDO.getCreateTime());
		resultsDO.setCreateBy(qualityResultsDO.getCreateBy());
		resultsDO.setUpdateTime(DateUtil.getNowDate());
		if (summaryMapper.updateByPrimaryKey(resultsDO) < 1) {
			throw new RuntimeException("更新失败，请检查数据格式。");
		}
			
		return true;
    }
    
  //修改3、粮食质量检验结果汇总表-明细表
    public boolean updateSummaryResultsItems(List<Map> itemsData,String id,String areaCode,String batch) throws Exception {
    	FoodStockDTO fdto=new FoodStockDTO();
    	fdto.setPlanId(id);
    	fdto.setAreaCode(areaCode);
    	fdto.setBatch(batch);
    	List<SummaryResultsItemsVO> oldList = findItemsByIdAndIsDeleted(fdto); 
    	if(oldList.size()==0) {
    		SummaryResultsDO resultsDO=new SummaryResultsDO();
    		resultsDO.setBatch(batch);
    		resultsDO.setId(id);
    		saveSummaryResultsItems(itemsData,resultsDO);
    	}else {
    		int num = itemsData.size(); 
    		if(itemsData != null&&itemsData.size() > 0){ 
    	        //检查页面的信息是否有修改，然后更新到数据库 
    	        for(int t = 0; t<num; t++){
    	        	/*if(null==itemsData.get(t).get("id")) {
    	        	
    	        	}else {*/
    	        		SummaryResultsItemsDO itemsDO = new SummaryResultsItemsDO();
    	        		itemsDO.setBatch(batch);
    					itemsDO.setId(oldList.get(t).getId());
    					itemsDO.setSummaryId(itemsData.get(t).get("summaryId")+"");//汇总表id
    					itemsDO.setCheckLibraryPoints(mapper.isNull(itemsData.get(t).get("checkLibraryPoints")+""));
    					itemsDO.setCompanyNumber(mapper.isNull(itemsData.get(t).get("companyNumber")+""));
    					itemsDO.setSamplesTotal(mapper.isNull(itemsData.get(t).get("samplesTotal")+""));
    					itemsDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
    					itemsDO.setAchievementRate(mapper.isNull(itemsData.get(t).get("achievementRate")+""));
    					itemsDO.setPaddySamplesNumber(mapper.isNull(itemsData.get(t).get("paddySamplesNumber")+""));
    					itemsDO.setPaddyRepresentativesNumber(mapper.isNull(itemsData.get(t).get("paddyRepresentativesNumber")+""));
    					itemsDO.setPaddyAchievementRate(mapper.isNull(itemsData.get(t).get("paddyAchievementRate")+""));
    					itemsDO.setWheatSamplesNumber(mapper.isNull(itemsData.get(t).get("wheatSamplesNumber")+""));
    					itemsDO.setWheatRepresentativesNumber(mapper.isNull(itemsData.get(t).get("wheatRepresentativesNumber")+""));
    					itemsDO.setWheatAchievementRate(mapper.isNull(itemsData.get(t).get("wheatAchievementRate")+""));
    					itemsDO.setCornSamplesNumber(mapper.isNull(itemsData.get(t).get("cornSamplesNumber")+""));
    					itemsDO.setCornRepresentativesNumber(mapper.isNull(itemsData.get(t).get("cornRepresentativesNumber")+""));
    					itemsDO.setCornAchievementRate(mapper.isNull(itemsData.get(t).get("cornAchievementRate")+""));
    					itemsDO.setSoybeanSamplesNumber(mapper.isNull(itemsData.get(t).get("soybeanSamplesNumber")+""));
    					itemsDO.setSoybeanRepresentativesNumber(mapper.isNull(itemsData.get(t).get("soybeanRepresentativesNumber")+""));
    					itemsDO.setSoybeanAchievementRate(mapper.isNull(itemsData.get(t).get("soybeanAchievementRate")+""));
    					itemsDO.setRiceSamplesNumber(mapper.isNull(itemsData.get(t).get("riceSamplesNumber")+""));
    					itemsDO.setRiceRepresentativesNumber(mapper.isNull(itemsData.get(t).get("riceRepresentativesNumber")+""));
    					itemsDO.setRiceAchievementRate(mapper.isNull(itemsData.get(t).get("riceAchievementRate")+""));
    					itemsDO.setWheatmealSamplesNumber(mapper.isNull(itemsData.get(t).get("wheatmealSamplesNumber")+""));
    					itemsDO.setWheatmealRepresentativesNumb(mapper.isNull(itemsData.get(t).get("wheatmealRepresentativesNumb")+""));
    					itemsDO.setWheatmealAchievementRate(mapper.isNull(itemsData.get(t).get("wheatmealAchievementRate")+""));
    					itemsDO.setType(mapper.isNull(oldList.get(t).getType()));
    					itemsDO.setOrgId(oldList.get(t).getOrgId() + "");
    					itemsDO.setDeptId(oldList.get(t).getDeptId() + "");
    					itemsDO.setAreaCode(oldList.get(t).getAreaCode()+"");
    					itemsDO.setCreateTime(oldList.get(t).getCreateTime());
    					itemsDO.setCreateBy(oldList.get(t).getCreateBy());
    					itemsDO.setUpdateTime(DateUtil.getNowDate());
    					if (summaryItemsMapper.updateByPrimaryKey(itemsDO) < 1) {
    						throw new RuntimeException("更新失败，请检查数据格式。");
    					}
    	        	//}
    			}
    		}
    	}
		
    	return true;
    }
    
  //修改4、质量不达标样品汇总表
    public boolean updateSummarySubstandardSample(Map<String,Object> aduitData,List<Map> itemsData,String areaCode) throws Exception {
    	Example example2 = new Example(SummarySubstandardSampleDO.class);
    	Criteria criteria2 = example2.createCriteria();
    	FoodStockDTO fdto=new FoodStockDTO();
    	fdto.setPlanId(aduitData.get("planId")+"");
    	fdto.setAreaCode(areaCode);
    	fdto.setBatch(aduitData.get("batch")+"");
		List<SummarySubstandardSampleVO> oldList = findSampleByIdAndIsDeleted(fdto);
		if(oldList.size()==0) {
			SummarySubstandardSampleDO sampleDO=new SummarySubstandardSampleDO();
    		sampleDO.setAreaCode(areaCode);
    		sampleDO.setBatch(aduitData.get("batch")+"");
    		saveSummarySubstandardSample(aduitData,itemsData,sampleDO);
		}else {
			int num = itemsData.size(); 
			if(itemsData != null&&itemsData.size() > 0){ 
		        //检查页面的信息是否有修改，然后更新到数据库 
		        for(int t = 0; t<num; t++){
		        	/*if(null==itemsData.get(t).get("id")) {
		        		
		        	}else {*/
		        		SummarySubstandardSampleDO sampleDO= new SummarySubstandardSampleDO();
		        		sampleDO.setBatch(oldList.get(t).getBatch());
			        	sampleDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
			        	sampleDO.setId(mapper.isNull(oldList.get(t).getId()));
						sampleDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
						sampleDO.setCity(mapper.isNull(aduitData.get("city")+""));
						sampleDO.setType(mapper.isNull(aduitData.get("type")+""));
						sampleDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
						//明细
						sampleDO.setLibraryPointName(mapper.isNull(itemsData.get(t).get("libraryPointName")+""));
						sampleDO.setWarehouse(mapper.isNull(itemsData.get(t).get("warehouse")+""));
						sampleDO.setSampleNumber(mapper.isNull(itemsData.get(t).get("sampleNumber")+""));
						sampleDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
						sampleDO.setNature(mapper.isNull(itemsData.get(t).get("nature")+""));
						sampleDO.setVarieties(mapper.isNull(itemsData.get(t).get("varieties")+""));
						sampleDO.setPlaceOrigin(mapper.isNull(itemsData.get(t).get("placeOrigin")+""));
						sampleDO.setHarvestLife(mapper.isNull(itemsData.get(t).get("harvestLife")+""));
						sampleDO.setStorageTime(mapper.isNull(itemsData.get(t).get("storageTime")+""));
						sampleDO.setUnqualifiedItems(mapper.isNull(itemsData.get(t).get("unqualifiedItems")+""));
						sampleDO.setDetectionValue(mapper.isNull(itemsData.get(t).get("detectionValue")+""));
						sampleDO.setOrgId(oldList.get(t).getOrgId() + "");
						sampleDO.setDeptId(oldList.get(t).getDeptId() + "");
						sampleDO.setAreaCode(oldList.get(t).getAreaCode());
						sampleDO.setCreateBy(oldList.get(t).getCreateBy());
						sampleDO.setCreateTime(oldList.get(t).getCreateTime());
						sampleDO.setUpdateTime(DateUtil.getNowDate());
						if (sampleMapper.updateByPrimaryKey(sampleDO) < 1) {
							throw new RuntimeException("更新失败，请检查数据格式。");
						}
		        	//}
		        }
		    }
		}
		
    	return true;
    }
    
    
  //修改5、粮食储存品质检验结果汇总表
    public boolean updateSummaryInspectionResult(Map<String,Object> aduitData,List<Map> itemsData,String areaCode) throws Exception {
    	Example example2 = new Example(SummaryInspectionResultDO.class);
    	Criteria criteria2 = example2.createCriteria();
    	FoodStockDTO fdto=new FoodStockDTO();
    	fdto.setPlanId(aduitData.get("planId")+"");
    	fdto.setAreaCode(areaCode);
    	fdto.setBatch(aduitData.get("batch")+"");
		List<SummaryInspectionResultVO> oldList = findInspectionByIdAndIsDeleted(fdto);
		if(oldList.size()==0) {
			SummaryInspectionResultDO sampleDO=new SummaryInspectionResultDO();
    		sampleDO.setBatch(aduitData.get("batch")+"");
    		sampleDO.setAreaCode(areaCode);
    		saveSummaryInspectionResult(aduitData,itemsData,sampleDO);
		}else {
			int num = itemsData.size(); 
			if(itemsData != null&&itemsData.size() > 0){ 
		        //检查页面的信息是否有修改，然后更新到数据库 
		        for(int t = 0; t<num; t++){
		        /*	if(null==itemsData.get(t).get("id")) {
		        		
		        	}else {*/
		        		SummaryInspectionResultDO sampleDO= new SummaryInspectionResultDO();
		        		sampleDO.setBatch(oldList.get(t).getBatch());
			        	sampleDO.setId(mapper.isNull(oldList.get(t).getId()));
			        	sampleDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
						sampleDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
						sampleDO.setCity(mapper.isNull(aduitData.get("city")+""));
						sampleDO.setType(mapper.isNull(aduitData.get("type")+""));
						sampleDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
						sampleDO.setFoodNature(mapper.isNull(aduitData.get("foodNature")+""));
						sampleDO.setCheckPoint(mapper.isNull(aduitData.get("checkPoint")+""));
						
						//明细
						sampleDO.setInspectionArea(mapper.isNull(itemsData.get(t).get("inspectionArea")+""));
						sampleDO.setCompanyNumber(mapper.isNull(itemsData.get(t).get("companyNumber")+""));
						sampleDO.setSamplesTotal(mapper.isNull(itemsData.get(t).get("samplesTotal")+""));
						sampleDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
						sampleDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
						sampleDO.setSurvivabilityRate(mapper.isNull(itemsData.get(t).get("survivabilityRate")+""));
						sampleDO.setMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("mildUnsuitableStorage")+""));
						sampleDO.setSevereInappropriateSurvival(mapper.isNull(itemsData.get(t).get("severeInappropriateSurvival")+""));
						sampleDO.setPaddySamplesNumber(mapper.isNull(itemsData.get(t).get("paddySamplesNumber")+""));
						sampleDO.setPaddySurvivabilityRate(mapper.isNull(itemsData.get(t).get("paddySurvivabilityRate")+""));
						sampleDO.setPaddyMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("paddyMildUnsuitableStorage")+""));
						sampleDO.setPaddySevereInappropriateSur(mapper.isNull(itemsData.get(t).get("paddySevereInappropriateSur")+""));
						sampleDO.setWheatSamplesNumber(mapper.isNull(itemsData.get(t).get("wheatSamplesNumber")+""));
						sampleDO.setWheatSurvivabilityRate(mapper.isNull(itemsData.get(t).get("wheatSurvivabilityRate")+""));
						sampleDO.setWheatMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("wheatMildUnsuitableStorage")+""));
						sampleDO.setWheatSevereInappropriateSur(mapper.isNull(itemsData.get(t).get("wheatSevereInappropriateSur")+""));
						sampleDO.setCornSamplesNumber(mapper.isNull(itemsData.get(t).get("cornSamplesNumber")+""));
						sampleDO.setCornSurvivabilityRate(mapper.isNull(itemsData.get(t).get("cornSurvivabilityRate")+""));
						sampleDO.setCornMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("cornMildUnsuitableStorage")+""));
						sampleDO.setCornSevereInappropriateSurv(mapper.isNull(itemsData.get(t).get("cornSevereInappropriateSurv")+""));
						sampleDO.setSoybeanSamplesSumber(mapper.isNull(itemsData.get(t).get("soybeanSamplesSumber")+""));
						sampleDO.setSoybeanSurvivabilityRate(mapper.isNull(itemsData.get(t).get("soybeanSurvivabilityRate")+""));
						sampleDO.setSoybeanMildUnsuitableStorag(mapper.isNull(itemsData.get(t).get("soybeanMildUnsuitableStorag")+""));
						sampleDO.setSoybeanSevereInappropriates(mapper.isNull(itemsData.get(t).get("soybeanSevereInappropriates")+""));
						sampleDO.setOrgId(oldList.get(t).getOrgId() + "");
						sampleDO.setDeptId(oldList.get(t).getDeptId() + "");
						sampleDO.setAreaCode(oldList.get(t).getAreaCode());
						sampleDO.setCreateBy(oldList.get(t).getCreateBy());
						sampleDO.setCreateTime(oldList.get(t).getCreateTime());
						sampleDO.setUpdateTime(DateUtil.getNowDate());
						if (summaryInspectionResultMapper.updateByPrimaryKey(sampleDO) < 1) {
							throw new RuntimeException("更新失败，请检查数据格式。");
						}
		        	//}
		        }
		    }
		}
		
    	return true;
    }
    
  //修改6、储存品质不宜存样品汇总表
    public boolean updateSummaryNotSuitable(Map<String,Object> aduitData,List<Map> itemsData,String areaCode) throws Exception {
    	Example example2 = new Example(SummaryNotSuitableDO.class);
		Criteria criteria2 = example2.createCriteria();
		FoodStockDTO fdto=new FoodStockDTO();
    	fdto.setPlanId(aduitData.get("planId")+"");
    	fdto.setAreaCode(areaCode);
    	fdto.setBatch(aduitData.get("batch")+"");
		List<SummaryNotSuitableVO> oldList = findyNotSuitableByIdAndIsDeleted(fdto);
		if(oldList.size()==0) {
			SummaryNotSuitableDO sampleDO= new SummaryNotSuitableDO();
    		sampleDO.setAreaCode(areaCode);
    		sampleDO.setBatch(aduitData.get("batch")+"");
    		saveSummaryNotSuitable(aduitData,itemsData,sampleDO);
		}else {
			int num = itemsData.size(); 
			if(itemsData != null&&itemsData.size() > 0){ 
		        //检查页面的信息是否有修改，然后更新到数据库 
		        for(int t = 0; t<num; t++){
		        	/*if(null==itemsData.get(t).get("id")) {
		        		
		        	}else {*/
		        		SummaryNotSuitableDO sampleDO= new SummaryNotSuitableDO();
		        		sampleDO.setBatch(oldList.get(t).getBatch());
			        	sampleDO.setId(mapper.isNull(oldList.get(t).getId()));
						sampleDO.setPlanId(mapper.isNull(aduitData.get("planId")+""));
						sampleDO.setPlanFileName(mapper.isNull(aduitData.get("planFileName")+""));
						sampleDO.setCity(mapper.isNull(aduitData.get("city")+""));
						sampleDO.setType(mapper.isNull(aduitData.get("type")+""));
						sampleDO.setFillingUnit(mapper.isNull(aduitData.get("fillingUnit")+""));
						//明细
						sampleDO.setCheckLibraryPoints(mapper.isNull(itemsData.get(t).get("checkLibraryPoints")+""));
						sampleDO.setWarehouse(mapper.isNull(itemsData.get(t).get("warehouse")+""));
						sampleDO.setFoodNature(mapper.isNull(aduitData.get("foodNature")+""));
						sampleDO.setVarieties(mapper.isNull(itemsData.get(t).get("varieties")+""));
						sampleDO.setRepresentativesNumber(mapper.isNull(itemsData.get(t).get("representativesNumber")+""));
						sampleDO.setProject(mapper.isNull(itemsData.get(t).get("project")+""));
						sampleDO.setTestValue(mapper.isNull(itemsData.get(t).get("testValue")+""));
						sampleDO.setSevereInappropriateSurvival(mapper.isNull(itemsData.get(t).get("severeInappropriateSurvival")+""));
						sampleDO.setMildUnsuitableStorage(mapper.isNull(itemsData.get(t).get("mildUnsuitableStorage")+""));
						sampleDO.setOrgId(oldList.get(t).getOrgId() + "");
						sampleDO.setDeptId(oldList.get(t).getDeptId() + "");
						sampleDO.setAreaCode(oldList.get(t).getAreaCode());
						sampleDO.setCreateBy(oldList.get(t).getCreateBy());
						sampleDO.setCreateTime(oldList.get(t).getCreateTime());
						sampleDO.setUpdateTime(DateUtil.getNowDate());
						if (summaryNotSuitableMapper.updateByPrimaryKey(sampleDO) < 1) {
							throw new RuntimeException("更新失败，请检查数据格式。");
						}
		        	//}
		        }
		    }
		}
		
    	return true;
    }
    /**
	 * @Description 安全监测-结果上报
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月19日15:12:44
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateState(FoodStockDTO fdto) throws Exception{
		Example example = new Example(SummaryResultsDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("planId", fdto.getId());
		// 未删除的
		criteria.andIsNull("deleteTime");
		String condition = " FINDINGS_AUDIT not in ('3' ,'13','9','7','12')";
    	criteria.andCondition(condition);
    	String areaCode=fdto.getAreaCode();
    	criteria.andEqualTo("areaCode", areaCode);
		SummaryResultsDO qDO = summaryMapper.selectOneByExample(example);
		if (ObjectUtils.notEqual(qDO, null)) {
			 qDO.setFindingsAudit(fdto.getFindingsAudit());
		     qDO.setStateName("已上报");
			summaryMapper.updateByPrimaryKey(qDO);
		}
		return true;
	}
	
	/**
	 * @Description 检测业务查询统计     饼图-样品份数
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> sampleNumber(String years) throws Exception{
		 
		 List<Map> listMap = new ArrayList<Map>(6);
		 Map<String,Object> map = new HashMap<String, Object>();
		 List<Map> list=summaryMapper.sampleNumber(years);
		 String total=list.get(0).get("total") +"";
		 String num=list.get(0).get("num")+"";
		 System.out.println(null==num);
		 System.out.println("null".equals(num));
		 if("null".equals(num)) {
			 num="0";
		 }
		 map.put("total", "全区"+total+"企业,扦取样品"+num+"份");
		 listMap.add(map);
		 Map<String,Object> map1 = new HashMap<String, Object>(6);
		
		 String dd=list.get(0).get("dd") +"";
		 if("null".equals(dd)) {
			 dd="0";
		 }
		 map1.put("name", "大豆");
	     map1.put("value",dd);
	     listMap.add(map1);
	     
	     String xmf=list.get(0).get("xmf") +"";
		 if("null".equals(xmf)) {
			 xmf="0";
		 }
	     map1 = new HashMap<String, Object>(6);
         map1.put("name", "小麦粉");
         map1.put("value",  xmf);
         listMap.add(map1);
         
         String dg=list.get(0).get("dg")+"";
		 if("null".equals(dg)) {
			 dg="0";
		 }
         map1 = new HashMap<String, Object>(6);
         map1.put("name", "稻谷");
         map1.put("value",  dg);
         listMap.add(map1);
         
         String ym=list.get(0).get("ym")+"";
		 if("null".equals(ym)) {
			 ym="0";
		 }
         map1 = new HashMap<String, Object>(6);
         map1.put("name", "玉米");
         map1.put("value",  ym);
         listMap.add(map1);
         
         String xm=list.get(0).get("xm")+"";
		 if("null".equals(xm)) {
			 xm="0";
		 }
         map1 = new HashMap<String, Object>(6);
         map1.put("name", "小麦");
         map1.put("value",  xm);
         listMap.add(map1);
         
         String dm=list.get(0).get("dm")+"";
		 if("null".equals(dm)) {
			 dm="0";
		 }
         map1 = new HashMap<String, Object>(6);
         map1.put("name", "大米");
         map1.put("value", dm);
         listMap.add(map1);
		return listMap;
	}
}
