package com.unis.quality.server.domain;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.quality.common.vo.EquipmentVO;
import com.unis.quality.common.vo.TestParametersVO;
import com.unis.quality.server.dao.TestParametersDao;
import com.unis.quality.server.entity.quality.EquipmentDO;
import com.unis.quality.server.entity.quality.TestParametersDO;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;
/**
 * @Description: 质检机构管理--检验参数
 * @ClassName: OrganizationService
 * @author lfx
 * @date 2018年10月30日14:12:47
 *
 * @version v1.0
 */
@Getter
@Setter
@ToString
@Component
public class TestParametersDomain  {

	@Autowired
	private TestParametersDao testParametersMapper;

	@Autowired
	private EquipmentDomain mapper;
	/**
	 * @Description 根据id查询设备详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日14:17:21
	 * @param id
	 * @return
	 * @throws Exception
	 */
	public List<TestParametersVO> findByIdAndIsDeleted(String id) throws Exception {
		Example example = new Example(TestParametersDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("organizationId", id);
		List<TestParametersDO> list = testParametersMapper.selectByExample(example);
		List<TestParametersVO> resultVOList = new ArrayList<>();
		if (!list.isEmpty()) {
			for (TestParametersDO resultDO : list) {
				TestParametersVO resultVO = LsBeanUtils.copyProperties(resultDO, TestParametersVO.class);
				String w=resultDO.getInspectionCategory();
				if(null!=w) {
					String[] q=w.split(",");
					resultVO.setInspectionCategory(q);
				}
				resultVOList.add(resultVO);
			}
		}
		return resultVOList;
	}


	/**
	 * @Description 查询设备信息、分页
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日15:01:37
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(TestParametersVO testParametersVO, Integer page, Integer size) throws Exception {


 		Example example = new Example(TestParametersDO.class);
		Criteria criteria = example.createCriteria();
		// 未删除的收购资格
		criteria.andIsNull("deleteTime");
		//根据机构id只能查询自己机构下的设备
		criteria.andEqualTo("organizationId",testParametersVO.getOrganizationId());
		// 按时间排序
		example.setOrderByClause("CREATE_TIME DESC");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");

		List<TestParametersDO> resultEquipmentDOList = testParametersMapper.selectByExample(example);
		PageInfo<TestParametersDO> pageInfo = new PageInfo<TestParametersDO>(resultEquipmentDOList);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<TestParametersVO> resulEquipmentVOList = new ArrayList<>();
		if (!resultEquipmentDOList.isEmpty()) {
			for (TestParametersDO resultDO : resultEquipmentDOList) {
				TestParametersVO resultVO = LsBeanUtils.copyProperties(resultDO, TestParametersVO.class);
				String w=resultDO.getInspectionCategory();
				if(null!=w) {
					String[] q=w.split(",");
					resultVO.setInspectionCategory(q);
				}
				resulEquipmentVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resulEquipmentVOList);
		return resultMap;
	}

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018年10月30日10:41:56
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids,TestParametersVO vo) throws Exception {
		for (String id : ids) {
			Example example = new Example(EquipmentDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("organizationId", id);
			criteria.andIsNull("deleteTime");
			TestParametersDO testParametersDO = testParametersMapper.selectOneByExample(example);
			if(ObjectUtils.equals(testParametersDO, null)) {
				throw new RuntimeException("此数据未存储到数据库中。");
			}
			if (ObjectUtils.notEqual(testParametersDO, null)) {
				testParametersDO.setDeleteBy(vo.getCreateBy());
				testParametersDO.setDeleteTime(DateUtil.getNowDate());
				testParametersMapper.updateByPrimaryKey(testParametersDO);
			}
		}
		return true;
	}

	/**
	 * @Description 保存信息--批量
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:43:55
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(Map<String, Object> tParametersList,TestParametersVO vo) throws Exception {
		boolean bool = false;
		Example example = new Example(TestParametersDO.class);
		Criteria criteria = example.createCriteria();
		String OrganizationId=tParametersList.get("id")+"";
		List<Map> voList=(List<Map>) tParametersList.get("jycsData");
		if (voList.size() > 0 && voList != null) {
			for (int i = 0; i < voList.size(); i++) {
				if (null!=voList.get(i) ) {
					if(null==voList.get(i).get("id")) {
						 List<String> list = new ArrayList<String>();
						 list=(List<String>) voList.get(i).get("inspectionCategory");
						 String category="";
						 if(null!=list) {
							 if(1==list.size()) {
								 category=list.get(0);
							 }
							 if(2==list.size()) {
								  category=list.get(0)+","+list.get(1);
							 }else if(3==list.size()) {
								 category=list.get(0)+","+list.get(1)+","+list.get(2);
							 }
						 }
						if (!"".equals(tParametersList.get("id")) && null != tParametersList.get("id")) {
							criteria.andEqualTo("organizationId", tParametersList.get("id"));
						}
						if (!"".equals(voList.get(i).get("inspectionCategory")) && null != voList.get(i).get("inspectionCategory")) {
							criteria.andEqualTo("inspectionCategory",category);
						}
						if ( null == voList.get(i).get("inspectionCategory")) {
							throw new RuntimeException("请输入检验类别！");
						}
						criteria.andIsNull("deleteTime");
						if (testParametersMapper.selectCountByExample(example) > 0) {
							throw new RuntimeException(voList.get(i).get("inspectionCategory") + "已存在!");
						}
						TestParametersDO testParametersDO = new TestParametersDO();
						testParametersDO.setOrganizationId(OrganizationId);
						testParametersDO.setInspectionCategory(category);
						testParametersDO.setTestParameters(mapper.isNull(voList.get(i).get("testParameters")+""));
						testParametersDO.setOrgId(vo.getOrgId() + "");
						testParametersDO.setDeptId(vo.getDeptId() + "");
						testParametersDO.setAreaCode(vo.getAreaCode());
						testParametersDO.setCreateBy(vo.getCreateBy());
						testParametersDO.setCreateTime(DateUtil.getNowDate());
						if (testParametersMapper.insert(testParametersDO) < 1) {
							throw new RuntimeException(testParametersDO.getInspectionCategory()+ "无法保存成功，请检查数据。");
						}
						bool = true;
					}
				}
			}
		}else {
			throw new RuntimeException("请输入正确的检验参数信息!");
		}
		return bool;
	}
	/**
	 * @Description 更新设备信息
	 * @version v1.0
	 * @author lfx
	 * @date 2018年10月30日10:45:49
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(Map<String, Object> testParametersVOlist,TestParametersVO vo) throws Exception {
		 //根据机构id查询页面有多少条数据
		String organizationId=testParametersVOlist.get("id").toString();
		List<Map> voList=(List<Map>) testParametersVOlist.get("jycsData");
	    List<TestParametersVO> oldList = findByIdAndIsDeleted(organizationId);
	    if (null==oldList) {
			throw new RuntimeException("此数据未存储到数据库中。");
		}
	    int num = oldList.size();
	    if(voList != null&&voList.size() > 0){
	        //检查页面的信息是否有修改，然后更新到数据库
	        for(int i = 0; i<voList.size(); i++){
	        	System.out.println(voList.get(i).get("id"));
	        	if(null==voList.get(i).get("id")) {
	        		save(testParametersVOlist,vo);
	        	}else {
	        		List<String> list = new ArrayList<String>();
					 list=(List<String>)  voList.get(i).get("inspectionCategory");
					 String category="";
					 if(2==list.size()) {
						  category=list.get(0)+","+list.get(1);
					 }else if(3==list.size()) {
						 category=list.get(0)+","+list.get(1)+","+list.get(2);
					 }
		        	TestParametersDO testParametersDO = new TestParametersDO();
		        	testParametersDO.setOrganizationId(organizationId);
					testParametersDO.setInspectionCategory(category);
					testParametersDO.setTestParameters(mapper.isNull(voList.get(i).get("testParameters")+""));
					testParametersDO.setId(oldList.get(i).getId().toString());
					testParametersDO.setOrgId(oldList.get(i).getOrgId() + "");
					testParametersDO.setDeptId(oldList.get(i).getDeptId() + "");
					testParametersDO.setAreaCode(oldList.get(i).getAreaCode());
					testParametersDO.setCreateBy(oldList.get(i).getCreateBy());
					testParametersDO.setCreateTime(oldList.get(i).getCreateTime());
					testParametersDO.setUpdateBy(vo.getUpdateBy());
					testParametersDO.setUpdateTime(DateUtil.getNowDate());
					if (testParametersMapper.updateByPrimaryKey(testParametersDO) < 1) {
						throw new RuntimeException("更新失败，请检查数据格式。");
					}
	        	}
	        }
	    }
	    return true;
	}
}
