/*
 * AbnormalDetailDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-05-12 16:19:04 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.domain.abnormal;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.utils.IdsWorker;
import com.unis.quality.common.vo.abnormal.AbnormalDetailVO;
import com.unis.quality.server.dao.AbnormalDetailDao;
import com.unis.quality.server.entity.abnormal.AbnormalDetailDO;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * TY_YCQKZGTZMX-异常情况整改通知明细
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-05-12 16:19:04
 */
@Component
@Transactional
public class AbnormalDetailDomain {

    @Autowired
    AbnormalDetailDao abnormalDetailDao;

    @Autowired
    private IdsWorker idWorker;

   /**
    * 通用的插入处理
    * @param entity    <异常情况整改通知明细>对象
    */
    private void buildInsertData(AbnormalDetailDO entity){
        if(StringUtils.isEmpty(entity.getYcqkmxid())){
            String pk=String.valueOf(idWorker.nextId());
            entity.setYcqkmxid(pk);
            //entity.buildInsertData();
            Date date = new Date();
            entity.setStatus(1);
            entity.setCreateDate(date);
            entity.setRefreshTime(date);
        }
    }

   /**
    * 通用的更新处理
    * @param entity    <异常情况整改通知明细>对象
    */
    private void buildUpdateData(AbnormalDetailDO entity){
        //entity.buildUpdateData();
        Date date = new Date();
        entity.setRefreshTime(date);
    }

    /**
    * 通用的返回数据处理
    * @param abnormalDetailVO    <异常情况整改通知明细>对象
    */
    private AbnormalDetailVO buildResult(AbnormalDetailVO abnormalDetailVO){
        AbnormalDetailVO abnormalDetailVOResult=new AbnormalDetailVO();
        abnormalDetailVOResult.setYcqkmxid(abnormalDetailVO.getYcqkmxid());
        return abnormalDetailVOResult;
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>插入全部字段
     * @param entity    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntity(AbnormalDetailDO entity) {
        buildInsertData(entity);
        return abnormalDetailDao.insert(entity);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>插入全部字段
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(AbnormalDetailVO abnormalDetailVO) {
        //有属性操作则优先在vo处理
        AbnormalDetailDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalDetailVO), AbnormalDetailDO.class);
        int num= insertEntity(entity);
        if(num>0){
            //主键设置回去
            abnormalDetailVO.setYcqkmxid(entity.getYcqkmxid());
            return ResponseWrapper.success(buildResult(abnormalDetailVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>选择性插入字段
     * @param entity    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(AbnormalDetailDO entity) {
        buildInsertData(entity);
        return abnormalDetailDao.insertSelective(entity);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>选择性插入字段
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(AbnormalDetailVO abnormalDetailVO) {
        //有属性操作则优先在vo处理
        AbnormalDetailDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalDetailVO), AbnormalDetailDO.class);
        int num= insertEntitySelective(entity);
        if(num>0){
            //主键设置回去
            abnormalDetailVO.setYcqkmxid(entity.getYcqkmxid());
            return ResponseWrapper.success(buildResult(abnormalDetailVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>更改状态
     * @param entity    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(AbnormalDetailDO entity) {
        return abnormalDetailDao.updateStatusByEntity(entity);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>更改状态
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(AbnormalDetailVO abnormalDetailVO) {
        //有属性操作则优先在vo处理
        AbnormalDetailDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalDetailVO), AbnormalDetailDO.class);
        int num= updateStatusByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            abnormalDetailVO.setYcqkmxid(entity.getYcqkmxid());
            return ResponseWrapper.success(buildResult(abnormalDetailVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体某些属性更新全部字段
     * @param entity    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(AbnormalDetailDO entity) {
        buildUpdateData(entity);
        return abnormalDetailDao.updateByEntity(entity);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体某些属性更新全部字段
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(AbnormalDetailVO abnormalDetailVO) {
        //有属性操作则优先在vo处理
        AbnormalDetailDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalDetailVO), AbnormalDetailDO.class);
        int num= updateByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            abnormalDetailVO.setYcqkmxid(entity.getYcqkmxid());
            return ResponseWrapper.success(buildResult(abnormalDetailVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体不为空的属性,选择性更新字段
     * @param entity    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(AbnormalDetailDO entity) {
        buildUpdateData(entity);
        return abnormalDetailDao.updateByEntitySelective(entity);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(AbnormalDetailVO abnormalDetailVO) {
        //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
        //有属性操作则优先在vo处理
        AbnormalDetailDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalDetailVO), AbnormalDetailDO.class);
        int num= updateByEntitySelective(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            abnormalDetailVO.setYcqkmxid(entity.getYcqkmxid());
            return ResponseWrapper.success(buildResult(abnormalDetailVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(AbnormalDetailVO abnormalDetailVO) {
        int num= abnormalDetailDao.deleteByEntity(abnormalDetailVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <TY_YCQKZGTZMX-异常情况整改通知明细>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <异常情况整改通知明细>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(AbnormalDetailDO entity) {
        AbnormalDetailVO abnormalDetailVO= JsonUtils.parse(
            JsonUtils.serialize(entity), AbnormalDetailVO.class);
        return abnormalDetailDao.deleteByEntity(abnormalDetailVO);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(AbnormalDetailVO abnormalDetailVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= abnormalDetailDao.deleteShamByEntity(abnormalDetailVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <TY_YCQKZGTZMX-异常情况整改通知明细>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <异常情况整改通知明细>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(AbnormalDetailDO entity) {
        AbnormalDetailVO abnormalDetailVO= JsonUtils.parse(
            JsonUtils.serialize(entity), AbnormalDetailVO.class);
        return abnormalDetailDao.deleteShamByEntity(abnormalDetailVO);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体的某些属性查询数量
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(AbnormalDetailVO abnormalDetailVO) {
        int num= abnormalDetailDao.selectCountByEntity(abnormalDetailVO);
        return num;
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体的某些属性判断是否存在
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(AbnormalDetailVO abnormalDetailVO) {
        int num= abnormalDetailDao.selectExistsByEntity(abnormalDetailVO);
        return num;
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体(唯一标示)查询一条数据
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public AbnormalDetailVO selectById(AbnormalDetailVO abnormalDetailVO) {
        AbnormalDetailVO abnormalDetailVODb= abnormalDetailDao.selectById(abnormalDetailVO);
        return abnormalDetailVODb;
    }

    /**
    * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体(唯一标示)查询一条数据
    * @param entity    <异常情况整改通知明细>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public AbnormalDetailVO selectById(AbnormalDetailDO entity) {
        AbnormalDetailVO abnormalDetailVO= JsonUtils.parse(
            JsonUtils.serialize(entity), AbnormalDetailVO.class);
        return abnormalDetailDao.selectById(abnormalDetailVO);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体的某些属性查询分页数据
     * @param abnormalDetailVO    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<AbnormalDetailVO> selectPageByEntity(int pageNo, int pageSize
        , AbnormalDetailVO abnormalDetailVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return abnormalDetailDao.selectPageByEntity(abnormalDetailVO);
    }

    /**
    * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体的某些属性查询列表
    * @param abnormalDetailVO    <异常情况整改通知明细>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<AbnormalDetailVO> selectByEntity(AbnormalDetailVO abnormalDetailVO) {
        return abnormalDetailDao.selectByEntity(abnormalDetailVO);
    }

    /**
     * <TY_YCQKZGTZMX-异常情况整改通知明细>根据实体的某些属性查询列表
     * @param entity    <异常情况整改通知明细>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<AbnormalDetailVO> selectByEntity(AbnormalDetailDO entity) {
        AbnormalDetailVO abnormalDetailVO= JsonUtils.parse(
            JsonUtils.serialize(entity), AbnormalDetailVO.class);
        return abnormalDetailDao.selectByEntity(abnormalDetailVO);
    }

}
