/*
 * AbnormalDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-05-12 16:19:04 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.domain.abnormal;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.EntityUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.quality.common.constant.AbnormalConstant;
import com.unis.quality.common.constant.AbnormalStatusConstant;
import com.unis.quality.common.utils.IdsWorker;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.vo.abnormal.AbnormalDetailVO;
import com.unis.quality.common.vo.abnormal.AbnormalVO;
import com.unis.quality.server.dao.AbnormalDao;
import com.unis.quality.server.entity.abnormal.AbnormalDO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.stream.Collectors;

/**
 * TY_YCQKZGTZ-异常情况整改通知
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-05-12 16:19:04
 */
@Component
@Transactional
public class AbnormalDomain {

    @Autowired
    AbnormalDao abnormalDao;

    @Autowired
    AbnormalDetailDomain abnormalDetailDomain;

    @Autowired
    private IdsWorker idWorker;

   /**
    * 通用的插入处理
    * @param entity    <异常情况整改通知>对象
    */
    private void buildInsertData(AbnormalDO entity){
        String pk=String.valueOf(idWorker.nextId());
        entity.setYcqkid(pk);
        //entity.buildInsertData(pk);
        Date date = new Date();
        entity.setStatus(1);
        entity.setCreateDate(date);
        entity.setRefreshTime(date);
    }

   /**
    * 通用的更新处理
    * @param entity    <异常情况整改通知>对象
    */
    private void buildUpdateData(AbnormalDO entity){
        //entity.buildUpdateData();
        Date date = new Date();
        entity.setRefreshTime(date);
    }

    /**
    * 通用的返回数据处理
    * @param abnormalVO    <异常情况整改通知>对象
    */
    private AbnormalVO buildResult(AbnormalVO abnormalVO){
        AbnormalVO abnormalVOResult=new AbnormalVO();
        abnormalVOResult.setYcqkid(abnormalVO.getYcqkid());
        return abnormalVOResult;
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>插入全部字段
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper saveEntity(AbnormalVO abnormalVO) {
        ResponseWrapper responseWrapper=null;
     /*   if(abnormalVO.getWtbh().equals("QJ20200516001")){
            System.out.println("111111111111");
        }*/
        AbnormalVO dbAbnormalVO=selectById(abnormalVO);
        refreshData(abnormalVO, dbAbnormalVO);
//        System.out.println("abnormalVO:"+JsonUtils.serialize(abnormalVO));
//        System.out.println("dbAbnormalVO:"+JsonUtils.serialize(dbAbnormalVO));
        if(dbAbnormalVO==null){
            responseWrapper=insertEntitySelective(abnormalVO);
        }else{
            abnormalVO.setYcqkid(dbAbnormalVO.getYcqkid());
            responseWrapper=updateByEntitySelectiveSimple(abnormalVO);
        }
        return responseWrapper;
    }

    public void refreshData(AbnormalVO abnormalVO,AbnormalVO dbAbnormalVO){
        List<AbnormalDetailVO> detailList=abnormalVO.getDetailList();
        if(dbAbnormalVO!=null){
            List<AbnormalDetailVO> dbDetailList=dbAbnormalVO.getDetailList();
            if(dbDetailList!=null && dbDetailList.size()>0){
                /*Map<String,AbnormalDetailVO> qydbhMap=dbDetailList.stream().collect( Collectors.toMap(k-> k.getQydbh(), a -> a));
                for(AbnormalDetailVO abnormalDetailVO: detailList){
                    if(qydbhMap.containsKey(abnormalDetailVO.getQydbh())){
                        qydbhMap.remove(abnormalDetailVO.getQydbh());
                    }
                }
                detailList.addAll(qydbhMap.values());*/
                detailList.addAll(dbDetailList);
            }
        }
        if(detailList!=null && detailList.size()>0){
            List<String> chList=new ArrayList<>();
            List<String> ycwzList=new ArrayList<>();
            for(AbnormalDetailVO abnormalDetailVO: detailList){
                if(StringUtils.isNotEmpty(abnormalDetailVO.getSf())
                        && !ycwzList.contains(AbnormalConstant.ShuiFen.getValue())
                        &&abnormalDetailVO.getStatus()== BaseStatusConstant.STATUS_NORMAL){
                    ycwzList.add(AbnormalConstant.ShuiFen.getValue());
                }
                if(StringUtils.isNotEmpty(abnormalDetailVO.getZz())  && !ycwzList.contains(AbnormalConstant.ZaZhi.getValue())
                        &&abnormalDetailVO.getStatus()== BaseStatusConstant.STATUS_NORMAL){
                    ycwzList.add(AbnormalConstant.ZaZhi.getValue());
                }
                if(StringUtils.isNotEmpty(abnormalDetailVO.getBwsl())  && !ycwzList.contains(AbnormalConstant.BuWanShanLi.getValue())
                        &&abnormalDetailVO.getStatus()== BaseStatusConstant.STATUS_NORMAL){
                    ycwzList.add(AbnormalConstant.BuWanShanLi.getValue());
                }
            }
            for(AbnormalDetailVO abnormalDetailVO: detailList){
                if(!chList.contains(abnormalDetailVO.getCh())){
                    chList.add(abnormalDetailVO.getCh());
                }
            }
            if(chList.size()>0){
                abnormalVO.setChmcs(StringUtils.join(chList,","));
            }
            if(ycwzList.size()>0){
                abnormalVO.setYcwzs(StringUtils.join(ycwzList,","));
            }
        }
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>插入全部字段
     * @param entity    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntity(AbnormalDO entity) {
        buildInsertData(entity);
        return abnormalDao.insert(entity);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>插入全部字段
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(AbnormalVO abnormalVO) {
        //有属性操作则优先在vo处理
        AbnormalDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalVO), AbnormalDO.class);
        int num= insertEntity(entity);
        if(num>0){
            //主键设置回去
            abnormalVO.setYcqkid(entity.getYcqkid());
            return ResponseWrapper.success(buildResult(abnormalVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>选择性插入字段
     * @param entity    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(AbnormalDO entity) {
        buildInsertData(entity);
        return abnormalDao.insertSelective(entity);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>选择性插入字段
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(AbnormalVO abnormalVO) {
        //有属性操作则优先在vo处理
        AbnormalDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalVO), AbnormalDO.class);
        int num= insertEntitySelective(entity);
        if(num>0){
            //主键设置回去
            abnormalVO.setYcqkid(entity.getYcqkid());
            //TY_YCQKZGTZMX-异常情况整改通知明细
            List<AbnormalDetailVO> detailList=abnormalVO.getDetailList();
            int detailListSize=0;
            if(detailList!=null && (detailListSize=detailList.size())>0){
                AbnormalDetailVO abnormalDetailVO=null;
                for(int i=0;i<detailListSize;i++){
                    abnormalDetailVO=detailList.get(i);
                    //给子对象设置主表主键
                    abnormalDetailVO.setYcqkid(entity.getYcqkid());
                    abnormalDetailDomain.insertEntitySelective(abnormalDetailVO);
                }
            }
            return ResponseWrapper.success(buildResult(abnormalVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>更改状态
     * @param entity    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(AbnormalDO entity) {
        return abnormalDao.updateStatusByEntity(entity);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>更改状态
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(AbnormalVO abnormalVO) {
        //有属性操作则优先在vo处理
        AbnormalDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalVO), AbnormalDO.class);
        int num= updateStatusByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            abnormalVO.setYcqkid(entity.getYcqkid());
            return ResponseWrapper.success(buildResult(abnormalVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体某些属性更新全部字段
     * @param entity    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(AbnormalDO entity) {
        buildUpdateData(entity);
        return abnormalDao.updateByEntity(entity);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体某些属性更新全部字段
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(AbnormalVO abnormalVO) {
        //有属性操作则优先在vo处理
        AbnormalDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalVO), AbnormalDO.class);
        int num= updateByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            abnormalVO.setYcqkid(entity.getYcqkid());
            return ResponseWrapper.success(buildResult(abnormalVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体不为空的属性,选择性更新字段
     * @param entity    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(AbnormalDO entity) {
        buildUpdateData(entity);
        return abnormalDao.updateByEntitySelective(entity);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(AbnormalVO abnormalVO) {
        //不考虑修改过程中推送导致的脏读
        refreshData(abnormalVO,null);

        //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
        //有属性操作则优先在vo处理
        AbnormalDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalVO), AbnormalDO.class);
        int num= updateByEntitySelective(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            abnormalVO.setYcqkid(entity.getYcqkid());
            //TY_YCQKZGTZMX-异常情况整改通知明细
            List<AbnormalDetailVO> detailList=abnormalVO.getDetailList();
            int detailListSize=0;
            if(detailList!=null && (detailListSize=detailList.size())>0){
                AbnormalDetailVO abnormalDetailVODb=new AbnormalDetailVO();
                //给子对象设置主表主键
                abnormalDetailVODb.setYcqkid(entity.getYcqkid());
                List<AbnormalDetailVO> detailListDb=abnormalDetailDomain.selectByEntity(abnormalDetailVODb);
                String maxDetailId="";
                if(detailListDb.size()>0){
                    //获取子表最大的id号
                    detailListDb.sort(Comparator.comparing(AbnormalDetailVO::getYcqkmxid).reversed());
                    maxDetailId=detailListDb.get(0).getYcqkmxid();
                }else{
                    maxDetailId= EntityUtil.getIdByParentId(AbnormalDetailVO.class,entity.getYcqkid(),0);
                }
                Map<String, AbnormalDetailVO> detailListMap=detailListDb.stream()
                    .collect(Collectors.toMap(a->a.getYcqkmxid(), p -> p));
                String keyTemp=null;
                AbnormalDetailVO abnormalDetailVO=null;
                for(int i=0;i<detailListSize;i++){
                    abnormalDetailVO=detailList.get(i);
                    if(StringUtils.isEmpty(abnormalDetailVO.getYcqkid())){
                        //不存在则插入
                        //给子对象设置主表主键
                        abnormalDetailVO.setYcqkid(entity.getYcqkid());
                        abnormalDetailVO.setYcqkmxid(String.valueOf(idWorker.nextId()));
                        abnormalDetailDomain.insertEntitySelective(abnormalDetailVO);
                    }else{
                        //存在则更新
                        keyTemp=abnormalDetailVO.getYcqkmxid();
                        if(detailListMap.containsKey(keyTemp)){
                            detailListMap.remove(keyTemp);
                        }
                        abnormalDetailDomain.updateByEntitySelective(abnormalDetailVO);
                    }
                }
                //剩余的删除
                for(Map.Entry<String, AbnormalDetailVO> abnormalDetailVOEntry:detailListMap.entrySet()){
                    abnormalDetailDomain.deleteByEntity(abnormalDetailVOEntry.getValue());
                }
            }
            return ResponseWrapper.success(buildResult(abnormalVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体不为空的属性,选择性更新字段(子表先删除再插入)
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelectiveSimple(AbnormalVO abnormalVO) {
        //不考虑修改过程中推送导致的脏读
        refreshData(abnormalVO,null);
        //此处是先删除再直接更新,较为简单
        //有属性操作则优先在vo处理
        AbnormalDO entity= JsonUtils.parse(
            JsonUtils.serialize(abnormalVO), AbnormalDO.class);
        int num= updateByEntitySelective(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            abnormalVO.setYcqkid(entity.getYcqkid());
            //TY_YCQKZGTZMX-异常情况整改通知明细
            List<AbnormalDetailVO> detailList=abnormalVO.getDetailList();
            int detailListSize=0;
            if(detailList!=null && (detailListSize=detailList.size())>0){
                AbnormalDetailVO abnormalDetailVODb=new AbnormalDetailVO();
                //给子对象设置主表主键
                abnormalDetailVODb.setYcqkid(abnormalVO.getYcqkid());
                //先删除
                abnormalDetailDomain.deleteByEntity(abnormalDetailVODb);
                AbnormalDetailVO abnormalDetailVO=null;
                //再重新插入
                for(int i=0;i<detailListSize;i++){
                    abnormalDetailVO=detailList.get(i);
                    //给子对象设置主表主键
                    abnormalDetailVO.setYcqkid(abnormalVO.getYcqkid());
                    abnormalDetailDomain.insertEntitySelective(abnormalDetailVO);
                }
            }
            return ResponseWrapper.success(buildResult(abnormalVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(AbnormalVO abnormalVO) {
        int num= abnormalDao.deleteByEntity(abnormalVO);
        if(num>0){
            //TY_YCQKZGTZMX-异常情况整改通知明细
            AbnormalDetailVO abnormalDetailVODb=new AbnormalDetailVO();
                //给子对象设置主表主键
            abnormalDetailVODb.setYcqkid(abnormalVO.getYcqkid());
            abnormalDetailDomain.deleteByEntity(abnormalDetailVODb);
        }
        return ResponseWrapper.choose(num);
    }

    /**
    * <TY_YCQKZGTZ-异常情况整改通知>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <异常情况整改通知>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(AbnormalDO entity) {
        AbnormalVO abnormalVO= JsonUtils.parse(
            JsonUtils.serialize(entity), AbnormalVO.class);
        return abnormalDao.deleteByEntity(abnormalVO);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(AbnormalVO abnormalVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= abnormalDao.deleteShamByEntity(abnormalVO);
        if(num>0){
            //TY_YCQKZGTZMX-异常情况整改通知明细
            AbnormalDetailVO abnormalDetailVO=new AbnormalDetailVO();
                //给子对象设置主表主键
            abnormalDetailVO.setYcqkid(abnormalVO.getYcqkid());
                //设置子表状态和父表一致
            abnormalDetailVO.setStatus(abnormalVO.getStatus());
            abnormalDetailDomain.deleteShamByEntity(abnormalDetailVO);
        }
        return ResponseWrapper.choose(num);
    }

    /**
    * <TY_YCQKZGTZ-异常情况整改通知>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <异常情况整改通知>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(AbnormalDO entity) {
        AbnormalVO abnormalVO= JsonUtils.parse(
            JsonUtils.serialize(entity), AbnormalVO.class);
        return abnormalDao.deleteShamByEntity(abnormalVO);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体的某些属性查询数量
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(AbnormalVO abnormalVO) {
        int num= abnormalDao.selectCountByEntity(abnormalVO);
        return num;
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体的某些属性判断是否存在
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(AbnormalVO abnormalVO) {
        int num= abnormalDao.selectExistsByEntity(abnormalVO);
        return num;
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体(唯一标示)查询一条数据
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public AbnormalVO selectById(AbnormalVO abnormalVO) {
        AbnormalVO abnormalVODb= abnormalDao.selectById(abnormalVO);
        if(abnormalVODb!=null){
            //TY_YCQKZGTZMX-异常情况整改通知明细
            AbnormalDetailVO abnormalDetailVO=new AbnormalDetailVO();
                //给子对象设置主表主键
            abnormalDetailVO.setYcqkid(abnormalVODb.getYcqkid());
            List<AbnormalDetailVO> abnormalDetailVOList=abnormalDetailDomain.selectByEntity(abnormalDetailVO);
            abnormalVODb.setDetailList(abnormalDetailVOList);
        }
        return abnormalVODb;
    }

    /**
    * <TY_YCQKZGTZ-异常情况整改通知>根据实体(唯一标示)查询一条数据
    * @param entity    <异常情况整改通知>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public AbnormalVO selectById(AbnormalDO entity) {
        AbnormalVO abnormalVO= JsonUtils.parse(
            JsonUtils.serialize(entity), AbnormalVO.class);
        return abnormalDao.selectById(abnormalVO);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体的某些属性查询分页数据
     * @param abnormalVO    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<AbnormalVO> selectPageByEntity(int pageNo, int pageSize
        , AbnormalVO abnormalVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return abnormalDao.selectPageByEntity(abnormalVO);
    }

    /**
    * <TY_YCQKZGTZ-异常情况整改通知>根据实体的某些属性查询列表
    * @param abnormalVO    <异常情况整改通知>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<AbnormalVO> selectByEntity(AbnormalVO abnormalVO) {
        return abnormalDao.selectByEntity(abnormalVO);
    }

    /**
     * <TY_YCQKZGTZ-异常情况整改通知>根据实体的某些属性查询列表
     * @param entity    <异常情况整改通知>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<AbnormalVO> selectByEntity(AbnormalDO entity) {
        AbnormalVO abnormalVO= JsonUtils.parse(
            JsonUtils.serialize(entity), AbnormalVO.class);
        return abnormalDao.selectByEntity(abnormalVO);
    }

}
