/*
 * CheckstandardInfoDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-20 23:32:16 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.domain.standard;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.utils.IdsWorker;
import com.unis.quality.common.vo.standard.CheckstandardInfoVO;
import com.unis.quality.common.vo.standard.CheckstandardItemVO;
import com.unis.quality.server.dao.CheckstandardInfoDao;
import com.unis.quality.server.entity.standard.CheckstandardInfoDO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * CHECKSTANDARD_INFO-标准信息
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-08-20 23:32:16
 */
@Component
@Transactional
public class CheckstandardInfoDomain {

    @Autowired
    CheckstandardInfoDao checkstandardInfoDao;

    @Autowired
    CheckstandardItemDomain checkstandardItemDomain;

    @Autowired
    IdsWorker idsWorker;

   /**
    * 通用的插入处理
    * @param entity    <标准信息>对象
    */
    private void buildInsertData(CheckstandardInfoDO entity){
        String pk=null;
        //当前为主表
        pk= "CS"+idsWorker.nextId();
        entity.setCheckstandardId(pk);
        entity.buildInsertData(pk);
        
    }

   /**
    * 通用的更新处理
    * @param entity    <标准信息>对象
    */
    private void buildUpdateData(CheckstandardInfoDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param checkstandardInfoVO    <标准信息>对象
    */
    private CheckstandardInfoVO buildResult(CheckstandardInfoVO checkstandardInfoVO){
        CheckstandardInfoVO checkstandardInfoVOResult=new CheckstandardInfoVO();
        checkstandardInfoVOResult.setCheckstandardId(checkstandardInfoVO.getCheckstandardId());
        return checkstandardInfoVOResult;
    }

    /**
    * 通用的数据处理
    * @param checkstandardInfoVO    <标准信息>对象
    */
    private void buildData(CheckstandardInfoVO checkstandardInfoVO){
        //CheckstandardInfoVO checkstandardInfoVODb= selectById(checkstandardInfoVO);
    }

    /**
    * <CHECKSTANDARD_INFO-标准信息>非主键的业务唯一属性校验
    * @param checkstandardInfoVO    <标准信息>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper uniqueCheck(CheckstandardInfoVO checkstandardInfoVO) {
        return ResponseWrapper.success();
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>选择性保存,包含新增和修改
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper saveEntitySelective(CheckstandardInfoVO checkstandardInfoVO) {
        if((StringUtils.isNotEmpty(checkstandardInfoVO.getCheckstandardId()))){
            return updateByEntitySelective(checkstandardInfoVO);
        }else{
            return insertEntitySelective(checkstandardInfoVO);
        }
    }

    /**
    * <CHECKSTANDARD_INFO-标准信息>插入全部字段
    * @param entity    <标准信息>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int insertEntity(CheckstandardInfoDO entity) {
        buildInsertData(entity);
        entity.setStandardId(entity.getCheckstandardId());
        return checkstandardInfoDao.insertEntity(entity);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>插入全部字段
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(CheckstandardInfoVO checkstandardInfoVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardInfoVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardInfoVO);
            //有属性操作则优先在vo处理
            CheckstandardInfoDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardInfoVO), CheckstandardInfoDO.class);
            int num= insertEntity(entity);
            if(num>0){
                //主键设置回去
                checkstandardInfoVO.setCheckstandardId(entity.getCheckstandardId());
                checkstandardInfoVO.setStandardId(entity.getCheckstandardId());
                return ResponseWrapper.success(buildResult(checkstandardInfoVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>选择性插入字段
     * @param entity    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(CheckstandardInfoDO entity) {
        buildInsertData(entity);
        entity.setStandardId(entity.getCheckstandardId());
        CheckstandardInfoVO vo=new CheckstandardInfoVO();
        vo.setStandardName(entity.getStandardName());
        int num= selectCountByEntity(vo);
        if(num>0){
            entity.setIsUsed("0");
        }
        return checkstandardInfoDao.insertEntitySelective(entity);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>选择性插入字段
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(CheckstandardInfoVO checkstandardInfoVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardInfoVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardInfoVO);
            //有属性操作则优先在vo处理
            CheckstandardInfoDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardInfoVO), CheckstandardInfoDO.class);
            int num= insertEntitySelective(entity);
            if(num>0){
                //主键设置回去
                checkstandardInfoVO.setCheckstandardId(entity.getCheckstandardId());
                //CHECKSTANDARD_ITEM-标准详情
                List<CheckstandardItemVO> itemList=checkstandardInfoVO.getItemList();
                int itemListSize=0;
                if(itemList!=null && (itemListSize=itemList.size())>0){
                    CheckstandardItemVO checkstandardItemVO=null;
                    for(int i=0;i<itemListSize;i++){
                        checkstandardItemVO=itemList.get(i);
                        //给子对象设置主表主键
                        checkstandardItemVO.setCheckstandardId(entity.getCheckstandardId());
                        //给子对象设置配置的主表,子表主键映射
                        checkstandardItemVO.setStandardId(entity.getStandardId());
                        checkstandardItemDomain.insertEntitySelective(checkstandardItemVO);
                    }
                }
                return ResponseWrapper.success(buildResult(checkstandardInfoVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>更改状态
     * @param entity    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(CheckstandardInfoDO entity) {
        buildUpdateData(entity);
        return checkstandardInfoDao.updateStatusByEntity(entity);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>更改状态
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(CheckstandardInfoVO checkstandardInfoVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardInfoVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardInfoVO);
            CheckstandardInfoDO standardInfoDO=new CheckstandardInfoDO();
            standardInfoDO.setCheckstandardId(checkstandardInfoVO.getCheckstandardId());
            CheckstandardInfoVO checkstandardInfoVODB=selectById(standardInfoDO);
            if(checkstandardInfoVODB !=null && "1".equals(checkstandardInfoVO.getIsUsed())){
                standardInfoDO=new CheckstandardInfoDO();
                standardInfoDO.setStandardName(checkstandardInfoVODB.getStandardName());
                standardInfoDO.setIsUsed("0");
                updateStatusByEntity(standardInfoDO);
            }

            //有属性操作则优先在vo处理
            CheckstandardInfoDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardInfoVO), CheckstandardInfoDO.class);
            int num= updateStatusByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                checkstandardInfoVO.setCheckstandardId(entity.getCheckstandardId());
                return ResponseWrapper.success(buildResult(checkstandardInfoVO));
            }else{
                return ResponseWrapper.fail();
            }
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体某些属性更新全部字段
     * @param entity    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(CheckstandardInfoDO entity) {
        buildUpdateData(entity);
        return checkstandardInfoDao.updateByEntity(entity);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体某些属性更新全部字段
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(CheckstandardInfoVO checkstandardInfoVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardInfoVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardInfoVO);
            //有属性操作则优先在vo处理
            CheckstandardInfoDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardInfoVO), CheckstandardInfoDO.class);
            int num= updateByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                checkstandardInfoVO.setCheckstandardId(entity.getCheckstandardId());
                return ResponseWrapper.success(buildResult(checkstandardInfoVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体不为空的属性,选择性更新字段
     * @param entity    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(CheckstandardInfoDO entity) {
        buildUpdateData(entity);
        return checkstandardInfoDao.updateByEntitySelective(entity);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(CheckstandardInfoVO checkstandardInfoVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardInfoVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardInfoVO);
            //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
            //有属性操作则优先在vo处理
            CheckstandardInfoDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardInfoVO), CheckstandardInfoDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                checkstandardInfoVO.setCheckstandardId(entity.getCheckstandardId());
                //CHECKSTANDARD_ITEM-标准详情
                List<CheckstandardItemVO> itemList=checkstandardInfoVO.getItemList();
                int itemListSize=0;
                if(itemList!=null && (itemListSize=itemList.size())>0){
                    CheckstandardItemVO checkstandardItemVODb=new CheckstandardItemVO();
                    //给子对象设置主表主键
                    checkstandardItemVODb.setCheckstandardId(entity.getCheckstandardId());
                    //给子对象设置配置的主表,子表主键映射
                    checkstandardItemVODb.setStandardId(entity.getStandardId());
                    List<CheckstandardItemVO> itemListDb=checkstandardItemDomain.selectByEntity(checkstandardItemVODb);
                    Map<String, CheckstandardItemVO> itemListMap=itemListDb.stream()
                        .collect(Collectors.toMap(a->a.getItemId(), p -> p));
                    String keyTemp=null;
                    CheckstandardItemVO checkstandardItemVO=null;
                    for(int i=0;i<itemListSize;i++){
                        checkstandardItemVO=itemList.get(i);
                        if(StringUtils.isEmpty(checkstandardItemVO.getCheckstandardId())){
                            //不存在则插入
                            //给子对象设置主表主键
                            checkstandardItemVO.setCheckstandardId(entity.getCheckstandardId());
                            //给子对象设置配置的主表,子表主键映射
                            checkstandardItemVO.setStandardId(entity.getStandardId());
                            checkstandardItemDomain.insertEntitySelective(checkstandardItemVO);
                        }else{
                            //存在则更新
                            keyTemp=checkstandardItemVO.getItemId();
                            if(itemListMap.containsKey(keyTemp)){
                                itemListMap.remove(keyTemp);
                            }
                            checkstandardItemDomain.updateByEntitySelective(checkstandardItemVO);
                        }
                    }
                    //剩余的删除
                    for(Map.Entry<String, CheckstandardItemVO> checkstandardItemVOEntry:itemListMap.entrySet()){
                        checkstandardItemDomain.deleteByEntity(checkstandardItemVOEntry.getValue());
                    }
                }
                return ResponseWrapper.success(buildResult(checkstandardInfoVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体不为空的属性,选择性更新字段(子表先删除再插入)
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelectiveSimple(CheckstandardInfoVO checkstandardInfoVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardInfoVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardInfoVO);
            //此处是先删除再直接更新,较为简单
            //有属性操作则优先在vo处理
            CheckstandardInfoDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardInfoVO), CheckstandardInfoDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                checkstandardInfoVO.setCheckstandardId(entity.getCheckstandardId());
                //CHECKSTANDARD_ITEM-标准详情
                List<CheckstandardItemVO> itemList=checkstandardInfoVO.getItemList();
                int itemListSize=0;
                if(itemList!=null && (itemListSize=itemList.size())>0){
                    CheckstandardItemVO checkstandardItemVODb=new CheckstandardItemVO();
                    //给子对象设置主表主键
                    checkstandardItemVODb.setCheckstandardId(checkstandardInfoVO.getCheckstandardId());
                    //给子对象设置配置的主表,子表主键映射
                    checkstandardItemVODb.setStandardId(checkstandardInfoVO.getStandardId());
                    //先删除
                    checkstandardItemDomain.deleteByEntity(checkstandardItemVODb);
                    CheckstandardItemVO checkstandardItemVO=null;
                    //再重新插入
                    for(int i=0;i<itemListSize;i++){
                        checkstandardItemVO=itemList.get(i);
                        //给子对象设置主表主键
                        checkstandardItemVO.setCheckstandardId(checkstandardInfoVO.getCheckstandardId());
                        //给子对象设置配置的主表,子表主键映射
                        checkstandardItemVO.setStandardId(checkstandardInfoVO.getStandardId());
                        checkstandardItemDomain.insertEntitySelective(checkstandardItemVO);
                    }
                }
                return ResponseWrapper.success(buildResult(checkstandardInfoVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(CheckstandardInfoVO checkstandardInfoVO) {
        int num= checkstandardInfoDao.deleteByEntity(checkstandardInfoVO);
        if(num>0){
            if(StringUtils.isNotEmpty(checkstandardInfoVO.getStandardId())
                || StringUtils.isNotEmpty(checkstandardInfoVO.getCheckstandardId())){
                //CHECKSTANDARD_ITEM-标准详情
                CheckstandardItemVO checkstandardItemVODb=new CheckstandardItemVO();
                //给子对象设置主表主键
                checkstandardItemVODb.setCheckstandardId(checkstandardInfoVO.getCheckstandardId());
                //给子对象设置配置的主表,子表主键映射
                checkstandardItemVODb.setStandardId(checkstandardInfoVO.getStandardId());
                checkstandardItemDomain.deleteByEntity(checkstandardItemVODb);
            }
        }
        return ResponseWrapper.choose(num);
    }

    /**
    * <CHECKSTANDARD_INFO-标准信息>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <标准信息>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(CheckstandardInfoDO entity) {
        CheckstandardInfoVO checkstandardInfoVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardInfoVO.class);
        return checkstandardInfoDao.deleteByEntity(checkstandardInfoVO);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(CheckstandardInfoVO checkstandardInfoVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= checkstandardInfoDao.deleteShamByEntity(checkstandardInfoVO);
        if(num>0){
            if(StringUtils.isNotEmpty(checkstandardInfoVO.getStandardId())
                    || StringUtils.isNotEmpty(checkstandardInfoVO.getCheckstandardId())){
                //CHECKSTANDARD_ITEM-标准详情
                CheckstandardItemVO checkstandardItemVO=new CheckstandardItemVO();
                //给子对象设置主表主键
                checkstandardItemVO.setCheckstandardId(checkstandardInfoVO.getCheckstandardId());
                //给子对象设置配置的主表,子表主键映射
                checkstandardItemVO.setStandardId(checkstandardInfoVO.getStandardId());
                //设置子表状态和父表一致
                checkstandardItemVO.setStatus(checkstandardInfoVO.getStatus());
                checkstandardItemDomain.deleteShamByEntity(checkstandardItemVO);
            }
        }
        return ResponseWrapper.choose(num);
    }

    /**
    * <CHECKSTANDARD_INFO-标准信息>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <标准信息>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(CheckstandardInfoDO entity) {
        CheckstandardInfoVO checkstandardInfoVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardInfoVO.class);
        return checkstandardInfoDao.deleteShamByEntity(checkstandardInfoVO);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体的某些属性查询数量
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(CheckstandardInfoVO checkstandardInfoVO) {
        int num= checkstandardInfoDao.selectCountByEntity(checkstandardInfoVO);
        return num;
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体的业务唯一属性(且非指定主键数据)判断是否存在
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(CheckstandardInfoVO checkstandardInfoVO) {
        int num= checkstandardInfoDao.selectExistsByEntity(checkstandardInfoVO);
        return num;
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体(唯一标示)查询一条数据
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public CheckstandardInfoVO selectById(CheckstandardInfoVO checkstandardInfoVO) {
        CheckstandardInfoVO checkstandardInfoVODb= checkstandardInfoDao.selectById(checkstandardInfoVO);
        if(checkstandardInfoVODb!=null){
            //CHECKSTANDARD_ITEM-标准详情
            CheckstandardItemVO checkstandardItemVO=new CheckstandardItemVO();
            if(StringUtils.isNotEmpty(checkstandardInfoVODb.getStandardId())
                    || StringUtils.isNotEmpty(checkstandardInfoVO.getCheckstandardId())){
                //给子对象设置主表主键
                checkstandardItemVO.setCheckstandardId(checkstandardInfoVODb.getCheckstandardId());
                //给子对象设置配置的主表,子表主键映射
                checkstandardItemVO.setStandardId(checkstandardInfoVODb.getStandardId());
                List<CheckstandardItemVO> checkstandardItemVOList=checkstandardItemDomain.selectByEntity(checkstandardItemVO);
                checkstandardInfoVODb.setItemList(checkstandardItemVOList);
            }
        }
        return checkstandardInfoVODb;
    }

    /**
    * <CHECKSTANDARD_INFO-标准信息>根据实体(唯一标示)查询一条数据
    * @param entity    <标准信息>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public CheckstandardInfoVO selectById(CheckstandardInfoDO entity) {
        CheckstandardInfoVO checkstandardInfoVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardInfoVO.class);
        return checkstandardInfoDao.selectById(checkstandardInfoVO);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体的某些属性查询分页数据
     * @param checkstandardInfoVO    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<CheckstandardInfoVO> selectPageByEntity(int pageNo, int pageSize
        , CheckstandardInfoVO checkstandardInfoVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return checkstandardInfoDao.selectPageByEntity(checkstandardInfoVO);
    }

    /**
    * <CHECKSTANDARD_INFO-标准信息>根据实体的某些属性查询列表
    * @param checkstandardInfoVO    <标准信息>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<CheckstandardInfoVO> selectByEntity(CheckstandardInfoVO checkstandardInfoVO) {
        return checkstandardInfoDao.selectByEntity(checkstandardInfoVO);
    }

    /**
     * <CHECKSTANDARD_INFO-标准信息>根据实体的某些属性查询列表
     * @param entity    <标准信息>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<CheckstandardInfoVO> selectByEntity(CheckstandardInfoDO entity) {
        CheckstandardInfoVO checkstandardInfoVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardInfoVO.class);
        return checkstandardInfoDao.selectByEntity(checkstandardInfoVO);
    }

}
