/*
 * CheckstandardItemDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-20 23:32:16 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.domain.standard;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.utils.IdsWorker;
import com.unis.quality.common.vo.standard.CheckstandardItemLevelVO;
import com.unis.quality.common.vo.standard.CheckstandardItemVO;
import com.unis.quality.server.dao.CheckstandardItemDao;
import com.unis.quality.server.entity.standard.CheckstandardItemDO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * CHECKSTANDARD_ITEM-标准详情
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-08-20 23:32:16
 */
@Component
@Transactional
public class CheckstandardItemDomain {

    @Autowired
    CheckstandardItemDao checkstandardItemDao;

    @Autowired
    CheckstandardItemLevelDomain checkstandardItemLevelDomain;

    @Autowired
    IdsWorker idsWorker;

   /**
    * 通用的插入处理
    * @param entity    <标准详情>对象
    */
    private void buildInsertData(CheckstandardItemDO entity){
        Long pk=null;
        //当前为子表,主键生成部分根据实际情况修改,如果主键是主表设置,则删除此处代码
        pk= idsWorker.nextId();
        entity.setItemId(String.valueOf(pk));
        entity.buildInsertData(String.valueOf(pk));
        
    }

   /**
    * 通用的更新处理
    * @param entity    <标准详情>对象
    */
    private void buildUpdateData(CheckstandardItemDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param checkstandardItemVO    <标准详情>对象
    */
    private CheckstandardItemVO buildResult(CheckstandardItemVO checkstandardItemVO){
        CheckstandardItemVO checkstandardItemVOResult=new CheckstandardItemVO();
        checkstandardItemVOResult.setItemId(checkstandardItemVO.getItemId());
        return checkstandardItemVOResult;
    }

    /**
    * 通用的数据处理
    * @param checkstandardItemVO    <标准详情>对象
    */
    private void buildData(CheckstandardItemVO checkstandardItemVO){
        //CheckstandardItemVO checkstandardItemVODb= selectById(checkstandardItemVO);
    }

    /**
    * <CHECKSTANDARD_ITEM-标准详情>非主键的业务唯一属性校验
    * @param checkstandardItemVO    <标准详情>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper uniqueCheck(CheckstandardItemVO checkstandardItemVO) {
        return ResponseWrapper.success();
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>选择性保存,包含新增和修改
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper saveEntitySelective(CheckstandardItemVO checkstandardItemVO) {
        if((StringUtils.isNotEmpty(checkstandardItemVO.getItemId()))){
            return updateByEntitySelective(checkstandardItemVO);
        }else{
            return insertEntitySelective(checkstandardItemVO);
        }
    }

    /**
    * <CHECKSTANDARD_ITEM-标准详情>插入全部字段
    * @param entity    <标准详情>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int insertEntity(CheckstandardItemDO entity) {
        buildInsertData(entity);
        return checkstandardItemDao.insertEntity(entity);
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>插入全部字段
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(CheckstandardItemVO checkstandardItemVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardItemVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardItemVO);
            //有属性操作则优先在vo处理
            CheckstandardItemDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardItemVO), CheckstandardItemDO.class);
            int num= insertEntity(entity);
            if(num>0){
                //主键设置回去
                checkstandardItemVO.setItemId(entity.getItemId());
                return ResponseWrapper.success(buildResult(checkstandardItemVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>选择性插入字段
     * @param entity    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(CheckstandardItemDO entity) {
        buildInsertData(entity);
        return checkstandardItemDao.insertEntitySelective(entity);
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>选择性插入字段
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(CheckstandardItemVO checkstandardItemVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardItemVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardItemVO);
            //有属性操作则优先在vo处理
            CheckstandardItemDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardItemVO), CheckstandardItemDO.class);
            int num= insertEntitySelective(entity);
            if(num>0){
                //主键设置回去
                checkstandardItemVO.setItemId(entity.getItemId());
                //CHECKSTANDARD_ITEMLEVEL-标准详情规则
                CheckstandardItemLevelVO levelVO=checkstandardItemVO.getLevelVO();
                if(levelVO!=null){
                    //给子对象设置主表主键
                    levelVO.setItemId(entity.getItemId());
                    //给子对象设置配置的主表,子表主键映射
                    levelVO.setItemId(entity.getItemId());
                    checkstandardItemLevelDomain.insertEntitySelective(levelVO);
                }
                return ResponseWrapper.success(buildResult(checkstandardItemVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>更改状态
     * @param entity    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(CheckstandardItemDO entity) {
        buildUpdateData(entity);
        return checkstandardItemDao.updateStatusByEntity(entity);
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>更改状态
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(CheckstandardItemVO checkstandardItemVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardItemVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardItemVO);
            //有属性操作则优先在vo处理
            CheckstandardItemDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardItemVO), CheckstandardItemDO.class);
            int num= updateStatusByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                checkstandardItemVO.setItemId(entity.getItemId());
                return ResponseWrapper.success(buildResult(checkstandardItemVO));
            }else{
                return ResponseWrapper.fail();
            }
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体某些属性更新全部字段
     * @param entity    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(CheckstandardItemDO entity) {
        buildUpdateData(entity);
        return checkstandardItemDao.updateByEntity(entity);
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体某些属性更新全部字段
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(CheckstandardItemVO checkstandardItemVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardItemVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardItemVO);
            //有属性操作则优先在vo处理
            CheckstandardItemDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardItemVO), CheckstandardItemDO.class);
            int num= updateByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                checkstandardItemVO.setItemId(entity.getItemId());
                return ResponseWrapper.success(buildResult(checkstandardItemVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体不为空的属性,选择性更新字段
     * @param entity    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(CheckstandardItemDO entity) {
        buildUpdateData(entity);
        return checkstandardItemDao.updateByEntitySelective(entity);
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(CheckstandardItemVO checkstandardItemVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardItemVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardItemVO);
            //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
            //有属性操作则优先在vo处理
            CheckstandardItemDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardItemVO), CheckstandardItemDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                checkstandardItemVO.setItemId(entity.getItemId());
                //CHECKSTANDARD_ITEMLEVEL-标准详情规则
                CheckstandardItemLevelVO levelVO=checkstandardItemVO.getLevelVO();
                if(levelVO!=null){
                    //给子对象设置主表主键
                    levelVO.setItemId(entity.getItemId());
                    //给子对象设置配置的主表,子表主键映射
                    levelVO.setItemId(entity.getItemId());
                    CheckstandardItemLevelVO itemLevelVODb=new CheckstandardItemLevelVO();
                    itemLevelVODb.setItemId(checkstandardItemVO.getItemId());
                    //给子对象设置配置的主表,子表主键映射
                    itemLevelVODb.setItemId(checkstandardItemVO.getItemId());
                    itemLevelVODb=checkstandardItemLevelDomain.selectById(itemLevelVODb);
                    if(itemLevelVODb!=null){
                        checkstandardItemLevelDomain.updateByEntitySelective(levelVO);
                    }else{
                        checkstandardItemLevelDomain.insertEntitySelective(levelVO);
                    }
                }
                return ResponseWrapper.success(buildResult(checkstandardItemVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体不为空的属性,选择性更新字段(子表先删除再插入)
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelectiveSimple(CheckstandardItemVO checkstandardItemVO) {
        ResponseWrapper responseWrapper= uniqueCheck(checkstandardItemVO);
        if(responseWrapper.isSuccess()){
            buildData(checkstandardItemVO);
            //此处是先删除再直接更新,较为简单
            //有属性操作则优先在vo处理
            CheckstandardItemDO entity= JsonUtils.parse(
                JsonUtils.serialize(checkstandardItemVO), CheckstandardItemDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                checkstandardItemVO.setItemId(entity.getItemId());
                //CHECKSTANDARD_ITEMLEVEL-标准详情规则
                CheckstandardItemLevelVO levelVO=checkstandardItemVO.getLevelVO();
                if(levelVO!=null){
                    //给子对象设置主表主键
                    levelVO.setItemId(checkstandardItemVO.getItemId());
                    //给子对象设置配置的主表,子表主键映射
                    levelVO.setItemId(checkstandardItemVO.getItemId());
                    CheckstandardItemLevelVO itemLevelVODb=new CheckstandardItemLevelVO();
                    itemLevelVODb.setItemId(checkstandardItemVO.getItemId());
                    itemLevelVODb=checkstandardItemLevelDomain.selectById(itemLevelVODb);
                    if(itemLevelVODb!=null){
                        checkstandardItemLevelDomain.updateByEntitySelective(levelVO);
                    }else{
                        checkstandardItemLevelDomain.insertEntitySelective(levelVO);
                    }
                }
                return ResponseWrapper.success(buildResult(checkstandardItemVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(CheckstandardItemVO checkstandardItemVO) {
        int num= checkstandardItemDao.deleteByEntity(checkstandardItemVO);
        if(num>0){
            //CHECKSTANDARD_ITEMLEVEL-标准详情规则
            CheckstandardItemLevelVO itemLevelVODb=new CheckstandardItemLevelVO();
                //给子对象设置主表主键
            itemLevelVODb.setItemId(checkstandardItemVO.getItemId());
                //给子对象设置配置的主表,子表主键映射
            itemLevelVODb.setItemId(checkstandardItemVO.getItemId());
            checkstandardItemLevelDomain.deleteByEntity(itemLevelVODb);
        }
        return ResponseWrapper.choose(num);
    }

    /**
    * <CHECKSTANDARD_ITEM-标准详情>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <标准详情>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(CheckstandardItemDO entity) {
        CheckstandardItemVO checkstandardItemVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardItemVO.class);
        return checkstandardItemDao.deleteByEntity(checkstandardItemVO);
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(CheckstandardItemVO checkstandardItemVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= checkstandardItemDao.deleteShamByEntity(checkstandardItemVO);
        if(num>0){
            //CHECKSTANDARD_ITEMLEVEL-标准详情规则
            CheckstandardItemLevelVO itemLevelVO=new CheckstandardItemLevelVO();
                //给子对象设置主表主键
            itemLevelVO.setItemId(checkstandardItemVO.getItemId());
                //给子对象设置配置的主表,子表主键映射
            itemLevelVO.setItemId(checkstandardItemVO.getItemId());
                //设置子表状态和父表一致
            itemLevelVO.setStatus(checkstandardItemVO.getStatus());
            checkstandardItemLevelDomain.deleteShamByEntity(itemLevelVO);
        }
        return ResponseWrapper.choose(num);
    }

    /**
    * <CHECKSTANDARD_ITEM-标准详情>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <标准详情>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(CheckstandardItemDO entity) {
        CheckstandardItemVO checkstandardItemVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardItemVO.class);
        return checkstandardItemDao.deleteShamByEntity(checkstandardItemVO);
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体的某些属性查询数量
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(CheckstandardItemVO checkstandardItemVO) {
        int num= checkstandardItemDao.selectCountByEntity(checkstandardItemVO);
        return num;
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体的业务唯一属性(且非指定主键数据)判断是否存在
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(CheckstandardItemVO checkstandardItemVO) {
        int num= checkstandardItemDao.selectExistsByEntity(checkstandardItemVO);
        return num;
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体(唯一标示)查询一条数据
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public CheckstandardItemVO selectById(CheckstandardItemVO checkstandardItemVO) {
        CheckstandardItemVO checkstandardItemVODb= checkstandardItemDao.selectById(checkstandardItemVO);
        if(checkstandardItemVODb!=null){
            //CHECKSTANDARD_ITEMLEVEL-标准详情规则
            CheckstandardItemLevelVO itemLevelVO=new CheckstandardItemLevelVO();
                //给子对象设置主表主键
            itemLevelVO.setItemId(checkstandardItemVODb.getItemId());
                //给子对象设置配置的主表,子表主键映射
            itemLevelVO.setItemId(checkstandardItemVODb.getItemId());
            itemLevelVO=checkstandardItemLevelDomain.selectById(itemLevelVO);
            checkstandardItemVODb.setLevelVO(itemLevelVO);
        }
        return checkstandardItemVODb;
    }

    /**
    * <CHECKSTANDARD_ITEM-标准详情>根据实体(唯一标示)查询一条数据
    * @param entity    <标准详情>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public CheckstandardItemVO selectById(CheckstandardItemDO entity) {
        CheckstandardItemVO checkstandardItemVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardItemVO.class);
        return checkstandardItemDao.selectById(checkstandardItemVO);
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体的某些属性查询分页数据
     * @param checkstandardItemVO    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<CheckstandardItemVO> selectPageByEntity(int pageNo, int pageSize
        , CheckstandardItemVO checkstandardItemVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return checkstandardItemDao.selectPageByEntity(checkstandardItemVO);
    }

    /**
    * <CHECKSTANDARD_ITEM-标准详情>根据实体的某些属性查询列表
    * @param checkstandardItemVO    <标准详情>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<CheckstandardItemVO> selectByEntity(CheckstandardItemVO checkstandardItemVO) {
        List<CheckstandardItemVO> list= checkstandardItemDao.selectByEntity(checkstandardItemVO);

        CheckstandardItemLevelVO levelVO=new CheckstandardItemLevelVO();
        for(CheckstandardItemVO checkstandardItem: list){
            levelVO.setItemId(checkstandardItem.getItemId());
            checkstandardItem.setLevelVO(checkstandardItemLevelDomain.selectById(levelVO));
        }
        return list;
    }

    /**
     * <CHECKSTANDARD_ITEM-标准详情>根据实体的某些属性查询列表
     * @param entity    <标准详情>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<CheckstandardItemVO> selectByEntity(CheckstandardItemDO entity) {
        CheckstandardItemVO checkstandardItemVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardItemVO.class);
        return checkstandardItemDao.selectByEntity(checkstandardItemVO);
    }

}
