/*
 * CheckstandardItemLevelDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-20 23:32:16 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.domain.standard;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.utils.IdsWorker;
import com.unis.quality.common.vo.standard.CheckstandardItemLevelVO;
import com.unis.quality.server.dao.CheckstandardItemLevelDao;
import com.unis.quality.server.entity.standard.CheckstandardItemLevelDO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * CHECKSTANDARD_ITEMLEVEL-标准详情规则
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-08-20 23:32:16
 */
@Component
@Transactional
public class CheckstandardItemLevelDomain {

    @Autowired
    CheckstandardItemLevelDao checkstandardItemLevelDao;

    @Autowired
    IdsWorker idsWorker;

   /**
    * 通用的插入处理
    * @param entity    <标准详情规则>对象
    */
    private void buildInsertData(CheckstandardItemLevelDO entity){
        Long pk=null;
        //当前为子表,主键生成部分根据实际情况修改,如果主键是主表设置,则删除此处代码
        pk= idsWorker.nextId();
        entity.setLevelId(String.valueOf(pk));
        entity.buildInsertData(String.valueOf(pk));
        
    }

   /**
    * 通用的更新处理
    * @param entity    <标准详情规则>对象
    */
    private void buildUpdateData(CheckstandardItemLevelDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param itemLevelVO    <标准详情规则>对象
    */
    private CheckstandardItemLevelVO buildResult(CheckstandardItemLevelVO itemLevelVO){
        CheckstandardItemLevelVO itemLevelVOResult=new CheckstandardItemLevelVO();
        itemLevelVOResult.setLevelId(itemLevelVO.getLevelId());
        return itemLevelVOResult;
    }

    /**
    * 通用的数据处理
    * @param itemLevelVO    <标准详情规则>对象
    */
    private void buildData(CheckstandardItemLevelVO itemLevelVO){
        //CheckstandardItemLevelVO itemLevelVODb= selectById(itemLevelVO);
    }

    /**
    * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>非主键的业务唯一属性校验
    * @param itemLevelVO    <标准详情规则>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper uniqueCheck(CheckstandardItemLevelVO itemLevelVO) {
        return ResponseWrapper.success();
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>选择性保存,包含新增和修改
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper saveEntitySelective(CheckstandardItemLevelVO itemLevelVO) {
        if((StringUtils.isNotEmpty(itemLevelVO.getLevelId()))){
            return updateByEntitySelective(itemLevelVO);
        }else{
            return insertEntitySelective(itemLevelVO);
        }
    }

    /**
    * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>插入全部字段
    * @param entity    <标准详情规则>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int insertEntity(CheckstandardItemLevelDO entity) {
        buildInsertData(entity);
        return checkstandardItemLevelDao.insertEntity(entity);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>插入全部字段
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(CheckstandardItemLevelVO itemLevelVO) {
        ResponseWrapper responseWrapper= uniqueCheck(itemLevelVO);
        if(responseWrapper.isSuccess()){
            buildData(itemLevelVO);
            //有属性操作则优先在vo处理
            CheckstandardItemLevelDO entity= JsonUtils.parse(
                JsonUtils.serialize(itemLevelVO), CheckstandardItemLevelDO.class);
            int num= insertEntity(entity);
            if(num>0){
                //主键设置回去
                itemLevelVO.setLevelId(entity.getLevelId());
                return ResponseWrapper.success(buildResult(itemLevelVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>选择性插入字段
     * @param entity    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(CheckstandardItemLevelDO entity) {
        buildInsertData(entity);
        return checkstandardItemLevelDao.insertEntitySelective(entity);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>选择性插入字段
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(CheckstandardItemLevelVO itemLevelVO) {
        ResponseWrapper responseWrapper= uniqueCheck(itemLevelVO);
        if(responseWrapper.isSuccess()){
            buildData(itemLevelVO);
            //有属性操作则优先在vo处理
            CheckstandardItemLevelDO entity= JsonUtils.parse(
                JsonUtils.serialize(itemLevelVO), CheckstandardItemLevelDO.class);
            int num= insertEntitySelective(entity);
            if(num>0){
                //主键设置回去
                itemLevelVO.setLevelId(entity.getLevelId());
                return ResponseWrapper.success(buildResult(itemLevelVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>更改状态
     * @param entity    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(CheckstandardItemLevelDO entity) {
        buildUpdateData(entity);
        return checkstandardItemLevelDao.updateStatusByEntity(entity);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>更改状态
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(CheckstandardItemLevelVO itemLevelVO) {
        ResponseWrapper responseWrapper= uniqueCheck(itemLevelVO);
        if(responseWrapper.isSuccess()){
            buildData(itemLevelVO);
            //有属性操作则优先在vo处理
            CheckstandardItemLevelDO entity= JsonUtils.parse(
                JsonUtils.serialize(itemLevelVO), CheckstandardItemLevelDO.class);
            int num= updateStatusByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                itemLevelVO.setLevelId(entity.getLevelId());
                return ResponseWrapper.success(buildResult(itemLevelVO));
            }else{
                return ResponseWrapper.fail();
            }
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体某些属性更新全部字段
     * @param entity    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(CheckstandardItemLevelDO entity) {
        buildUpdateData(entity);
        return checkstandardItemLevelDao.updateByEntity(entity);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体某些属性更新全部字段
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(CheckstandardItemLevelVO itemLevelVO) {
        ResponseWrapper responseWrapper= uniqueCheck(itemLevelVO);
        if(responseWrapper.isSuccess()){
            buildData(itemLevelVO);
            //有属性操作则优先在vo处理
            CheckstandardItemLevelDO entity= JsonUtils.parse(
                JsonUtils.serialize(itemLevelVO), CheckstandardItemLevelDO.class);
            int num= updateByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                itemLevelVO.setLevelId(entity.getLevelId());
                return ResponseWrapper.success(buildResult(itemLevelVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体不为空的属性,选择性更新字段
     * @param entity    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(CheckstandardItemLevelDO entity) {
        buildUpdateData(entity);
        return checkstandardItemLevelDao.updateByEntitySelective(entity);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(CheckstandardItemLevelVO itemLevelVO) {
        ResponseWrapper responseWrapper= uniqueCheck(itemLevelVO);
        if(responseWrapper.isSuccess()){
            buildData(itemLevelVO);
            //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
            //有属性操作则优先在vo处理
            CheckstandardItemLevelDO entity= JsonUtils.parse(
                JsonUtils.serialize(itemLevelVO), CheckstandardItemLevelDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                itemLevelVO.setLevelId(entity.getLevelId());
                return ResponseWrapper.success(buildResult(itemLevelVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(CheckstandardItemLevelVO itemLevelVO) {
        int num= checkstandardItemLevelDao.deleteByEntity(itemLevelVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <标准详情规则>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(CheckstandardItemLevelDO entity) {
        CheckstandardItemLevelVO itemLevelVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardItemLevelVO.class);
        return checkstandardItemLevelDao.deleteByEntity(itemLevelVO);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(CheckstandardItemLevelVO itemLevelVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= checkstandardItemLevelDao.deleteShamByEntity(itemLevelVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <标准详情规则>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(CheckstandardItemLevelDO entity) {
        CheckstandardItemLevelVO itemLevelVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardItemLevelVO.class);
        return checkstandardItemLevelDao.deleteShamByEntity(itemLevelVO);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体的某些属性查询数量
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(CheckstandardItemLevelVO itemLevelVO) {
        int num= checkstandardItemLevelDao.selectCountByEntity(itemLevelVO);
        return num;
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体的业务唯一属性(且非指定主键数据)判断是否存在
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(CheckstandardItemLevelVO itemLevelVO) {
        int num= checkstandardItemLevelDao.selectExistsByEntity(itemLevelVO);
        return num;
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体(唯一标示)查询一条数据
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public CheckstandardItemLevelVO selectById(CheckstandardItemLevelVO itemLevelVO) {
        CheckstandardItemLevelVO itemLevelVODb= checkstandardItemLevelDao.selectById(itemLevelVO);
        return itemLevelVODb;
    }

    /**
    * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体(唯一标示)查询一条数据
    * @param entity    <标准详情规则>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public CheckstandardItemLevelVO selectById(CheckstandardItemLevelDO entity) {
        CheckstandardItemLevelVO itemLevelVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardItemLevelVO.class);
        return checkstandardItemLevelDao.selectById(itemLevelVO);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体的某些属性查询分页数据
     * @param itemLevelVO    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<CheckstandardItemLevelVO> selectPageByEntity(int pageNo, int pageSize
        , CheckstandardItemLevelVO itemLevelVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return checkstandardItemLevelDao.selectPageByEntity(itemLevelVO);
    }

    /**
    * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体的某些属性查询列表
    * @param itemLevelVO    <标准详情规则>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<CheckstandardItemLevelVO> selectByEntity(CheckstandardItemLevelVO itemLevelVO) {
        return checkstandardItemLevelDao.selectByEntity(itemLevelVO);
    }

    /**
     * <CHECKSTANDARD_ITEMLEVEL-标准详情规则>根据实体的某些属性查询列表
     * @param entity    <标准详情规则>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<CheckstandardItemLevelVO> selectByEntity(CheckstandardItemLevelDO entity) {
        CheckstandardItemLevelVO itemLevelVO= JsonUtils.parse(
            JsonUtils.serialize(entity), CheckstandardItemLevelVO.class);
        return checkstandardItemLevelDao.selectByEntity(itemLevelVO);
    }

}
