/*
 * RainDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-11 17:08:12 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.domain.weather;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.quality.common.utils.IdsWorker;
import com.unis.quality.common.vo.weather.RainVO;
import com.unis.quality.server.dao.RainDao;
import com.unis.quality.server.entity.quality.weather.RainDO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * PLUG_WEATHER_RAIN-降雨量表
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-08-11 17:08:12
 */
@Component
@Transactional
public class RainDomain {

    @Autowired
    RainDao rainDao;

    @Autowired
    IdsWorker idsWorker;

   /**
    * 通用的插入处理
    * @param entity    <降雨量表>对象
    */
    private void buildInsertData(RainDO entity){
        Date date = new Date();
        entity.setCreateDate(date);
        entity.setRainId(idsWorker.nextId());
        //entity.setVersion("0");
    }

   /**
    * 通用的更新处理
    * @param entity    <降雨量表>对象
    */
    private void buildUpdateData(RainDO entity){
        Date date = new Date();
        entity.setRefreshTime(date);
    }

    /**
    * 通用的返回数据处理
    * @param rainVO    <降雨量表>对象
    */
    private RainVO buildResult(RainVO rainVO){
        RainVO rainVOResult=new RainVO();
        rainVOResult.setRainId(rainVO.getRainId());
        return rainVOResult;
    }

    /**
    * 通用的数据处理
    * @param rainVO    <降雨量表>对象
    */
    private void buildData(RainVO rainVO){
        //RainVO rainVODb= selectById(rainVO);
    }

    /**
    * <PLUG_WEATHER_RAIN-降雨量表>非主键的业务唯一属性校验
    * @param rainVO    <降雨量表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper uniqueCheck(RainVO rainVO) {
        boolean bl=true;
        //非主键的业务唯一数据校验
        if((rainVO.getId() !=null)
            || (StringUtils.isNotEmpty(rainVO.getParentId()) && StringUtils.isNotEmpty(rainVO.getTimeStamp()))){
            int num= rainDao.selectExistsByEntity(rainVO);
            bl = num==0;
        }
        if(bl){
            return ResponseWrapper.success();
        }else{
            return ResponseWrapper.fail();
        }
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>插入全部字段
     * @param entity    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntity(RainDO entity) {
        buildInsertData(entity);
        return rainDao.insertEntity(entity);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>插入全部字段
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(RainVO rainVO) {
        ResponseWrapper responseWrapper= uniqueCheck(rainVO);
        if(responseWrapper.isSuccess()){
            buildData(rainVO);
            //有属性操作则优先在vo处理
            RainDO entity= JsonUtils.parse(
                JsonUtils.serialize(rainVO), RainDO.class);
            int num= insertEntity(entity);
            if(num>0){
                //主键设置回去
                rainVO.setRainId(entity.getRainId());
                return ResponseWrapper.success(buildResult(rainVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>选择性插入字段
     * @param entity    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(RainDO entity) {
        buildInsertData(entity);
        return rainDao.insertEntitySelective(entity);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>选择性插入字段
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(RainVO rainVO) {
        ResponseWrapper responseWrapper= uniqueCheck(rainVO);
        if(responseWrapper.isSuccess()){
            buildData(rainVO);
            //有属性操作则优先在vo处理
            RainDO entity= JsonUtils.parse(
                JsonUtils.serialize(rainVO), RainDO.class);
            int num= insertEntitySelective(entity);
            if(num>0){
                //主键设置回去
                rainVO.setRainId(entity.getRainId());
                return ResponseWrapper.success(buildResult(rainVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>更改状态
     * @param entity    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(RainDO entity) {
        buildUpdateData(entity);
        return rainDao.updateStatusByEntity(entity);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>更改状态
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(RainVO rainVO) {
        ResponseWrapper responseWrapper= uniqueCheck(rainVO);
        if(responseWrapper.isSuccess()){
            buildData(rainVO);
            //有属性操作则优先在vo处理
            RainDO entity= JsonUtils.parse(
                JsonUtils.serialize(rainVO), RainDO.class);
            int num= updateStatusByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                rainVO.setRainId(entity.getRainId());
                return ResponseWrapper.success(buildResult(rainVO));
            }else{
                return ResponseWrapper.fail();
            }
        }else{
            return responseWrapper;
        }
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体某些属性更新全部字段
     * @param entity    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(RainDO entity) {
        buildUpdateData(entity);
        return rainDao.updateByEntity(entity);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体某些属性更新全部字段
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(RainVO rainVO) {
        ResponseWrapper responseWrapper= uniqueCheck(rainVO);
        if(responseWrapper.isSuccess()){
            buildData(rainVO);
            //有属性操作则优先在vo处理
            RainDO entity= JsonUtils.parse(
                JsonUtils.serialize(rainVO), RainDO.class);
            int num= updateByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                rainVO.setRainId(entity.getRainId());
                return ResponseWrapper.success(buildResult(rainVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体不为空的属性,选择性更新字段
     * @param entity    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(RainDO entity) {
        buildUpdateData(entity);
        return rainDao.updateByEntitySelective(entity);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(RainVO rainVO) {
        ResponseWrapper responseWrapper= uniqueCheck(rainVO);
        if(responseWrapper.isSuccess()){
            buildData(rainVO);
            //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
            //有属性操作则优先在vo处理
            RainDO entity= JsonUtils.parse(
                JsonUtils.serialize(rainVO), RainDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                rainVO.setRainId(entity.getRainId());
                return ResponseWrapper.success(buildResult(rainVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(RainVO rainVO) {
        int num= rainDao.deleteByEntity(rainVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <PLUG_WEATHER_RAIN-降雨量表>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <降雨量表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(RainDO entity) {
        RainVO rainVO= JsonUtils.parse(
            JsonUtils.serialize(entity), RainVO.class);
        return rainDao.deleteByEntity(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(RainVO rainVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= rainDao.deleteShamByEntity(rainVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <PLUG_WEATHER_RAIN-降雨量表>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <降雨量表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(RainDO entity) {
        RainVO rainVO= JsonUtils.parse(
            JsonUtils.serialize(entity), RainVO.class);
        return rainDao.deleteShamByEntity(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体的某些属性查询数量
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(RainVO rainVO) {
        int num= rainDao.selectCountByEntity(rainVO);
        return num;
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体的业务唯一属性(且非指定主键数据)判断是否存在
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(RainVO rainVO) {
        int num= rainDao.selectExistsByEntity(rainVO);
        return num;
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体(唯一标示)查询一条数据
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public RainVO selectById(RainVO rainVO) {
        RainVO rainVODb= rainDao.selectById(rainVO);
        return rainVODb;
    }

    /**
    * <PLUG_WEATHER_RAIN-降雨量表>根据实体(唯一标示)查询一条数据
    * @param entity    <降雨量表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public RainVO selectById(RainDO entity) {
        RainVO rainVO= JsonUtils.parse(
            JsonUtils.serialize(entity), RainVO.class);
        return rainDao.selectById(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体的某些属性查询分页数据
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page selectPageByEntity(int pageNo, int pageSize
        , RainVO rainVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return rainDao.selectPageByEntity(rainVO);
    }

    /**
    * <PLUG_WEATHER_RAIN-降雨量表>根据实体的某些属性查询列表
    * @param rainVO    <降雨量表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List selectByEntity(RainVO rainVO) {
        return rainDao.selectByEntity(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>根据实体的某些属性查询列表
     * @param entity    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List selectByEntity(RainDO entity) {
        RainVO rainVO= JsonUtils.parse(
            JsonUtils.serialize(entity), RainVO.class);
        return rainDao.selectByEntity(rainVO);
    }

}
