package com.unis.quality.server.entity.quality;

import com.unis.quality.common.vo.EntrustInspectApplyDetailVO;
import com.unis.quality.common.vo.EntrustInspectVO;
import com.unis.quality.server.entity.BasePO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 检测委托书
 * 委托检验申请接收后创建
 * @see EntrustInspectApplyDO
 * @author by PIG
 * 2023/9/21 14
 */
@ApiModel(value = "检测委托书")
@Data
@EqualsAndHashCode(callSuper = true)
@Table(name = "t_entrust_inspect")
public class EntrustInspectDO extends BasePO {

    @Id
    @Column(name = "fid")
    private Long fid;

    @Column(name = "node_id")
    private String nodeId;

    @Column(name = "node_name")
    private String nodeName;

    @Column(name = "action_type")
    private String actionType;

    /** 委托书编号*/
    @Column(name = "entrust_num")
    private String entrustNum;

    /** 申请类型 e.g:出库质检、入库质检、移库质检 */
    @Column(name = "entrust_apply_type")
    private Integer entrustApplyType;
    /** 申请类型 e.g:出库质检、入库质检、移库质检 */
    @Column(name = "entrust_apply_type_name")
    private String entrustApplyTypeName;

    /** 委托方*/
    @Column(name = "entrust_org")
    private String entrustOrg;
    /** 委托方联系人*/
    @Column(name = "entrust_link_man")
    private String entrustLinkMan;

    /** 联系电话*/
    @Column(name = "entrust_link_phone")
    private String entrustLinkPhone;
    /** 被检单位*/
    @Column(name = "be_inspect_org")
    private String beInspectOrg;

    @Column(name = "be_inspect_org_name")
    private String beInspectOrgName;
    /** 受检地址*/
    @Column(name = "be_inspect_address")
    private String beInspectAddress;
    /** 抽样单位联系人*/
    @Column(name = "chooser_link_man")
    private String chooserLinkMan;

    @Column(name = "choose_org_link_phone")
    private String chooseOrgLinkPhone;

    @Column(name = "sub_type_detailed")
    private String subTypeDetailed;
    @Column(name = "sub_type_detailed_name")
    private String subTypeDetailedName;
    //样品状态 e.g 颗粒袋装、液态瓶装
    @Column(name = "sample_status")
    private String sampleStatus;
    /** 抽样基数 库存数量*/
    @Column(name = "sample_basic_num")
    private BigDecimal sampleBasicNum;
    /** 委托时间*/
    @Column(name = "entrust_date")
    private Date entrustDate;

    @ApiModelProperty(name = "仓号")
    @Column(name = "house_Id")
    private String houseId;
    @ApiModelProperty(name = "仓号")
    @Column(name = "house_name")
    private String houseName;

    /** 完成时间*/
    @Column(name = "finish_date")
    private Date finishDate;
    @Column(name = "quality_item")
    private String qualityItem;
    @Column(name = "choose_org_opinion")
    private String chooseOrgOpinion;
    @Column(name = "entrust_org_signature")
    private String entrustOrgSignature;
    @ApiModelProperty(value = "签章日期")
    @Column(name = "entrust_org_signature_date")
    private Date entrustOrgSignatureDate;
    @Column(name = "entrust_org_submit_date")
    private Date entrustOrgSubmitDate;

    @Column(name = "choose_org_signature")
    private String chooseOrgSignature;
    @Column(name = "choose_org_signature_date")
    private Date chooseOrgSignatureDate;
    /** 检测扦样机构*/
    @Column(name = "chooser")
    private String  chooser;
    @Column(name = "choose_date")
    private Date  chooseDate;
    /** 附件-受委托方盖章委托书*/
    @Column(name = "choose_attachment")
    private String chooseAttachment;
    /** 附件-质检结果*/
    @Column(name = "inspect_attachment")
    private String inspectAttachment;

    /**
     * @see EntrustInspectApplyDetailVO
     * EntrustInspectApplyDetailVO.fid*/
    @Column(name = "apply_detail_fid")
    private Long applyDetailFid;
    @Column(name = "apply_number")
    private String applyNumber;

    /** 品种*/
    @Column(name = "apply_sub_type")
    private String applySubType;

    /** 备注*/
    @Column(name = "remark")
    private String remark;

    public boolean checkFinish(){
        return EntrustInspectVO.NODE_INFO.FINISH.equalVal(this.nodeId);
    }


    public void createBean(EntrustInspectApplyDO apply, EntrustInspectApplyDetailVO detail) {
        this.applyNumber = apply.getApplyNumber();
        this.applyDetailFid = detail.getFid();
        this.nodeId = EntrustInspectVO.NODE_INFO.CREATE_PEND.getValue();
        this.nodeName = EntrustInspectVO.NODE_INFO.CREATE_PEND.getName();
        this.entrustApplyType = apply.getEntrustApplyType();
        this.entrustApplyTypeName = apply.getEntrustApplyTypeName();
        this.beInspectOrg = apply.getApplyOrg();
        this.beInspectOrgName = apply.getApplyOrgName();
        this.beInspectAddress = apply.getApplyAddress();
        this.applySubType = apply.getApplySubType();
        this.subTypeDetailed = detail.getSubTypeDetailed();
        this.subTypeDetailedName = detail.getSubTypeDetailedName();
        this.sampleBasicNum = detail.getInventoryNumber();
        this.houseId = detail.getHouseId();
        this.houseName = detail.getHouseName();
        this.buildInsertData(1);
    }

    public void finish() {
        this.nodeId = EntrustInspectVO.NODE_INFO.FINISH.getValue();
        this.nodeName = EntrustInspectVO.NODE_INFO.FINISH.getName();
        this.buildUpdateData();
    }
}
