package com.unis.quality.server.service.impl;

import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.quality.common.constant.Constant;
import com.unis.quality.common.dto.DictDO;
import com.unis.quality.common.vo.TbCheckstandardItemVO;
import com.unis.quality.common.vo.TbCheckstandardItemlevelVO;
import com.unis.quality.server.dao.BaseRepository;
import com.unis.quality.server.dao.CheckstandandItemDao;
import com.unis.quality.server.dao.CheckstandandItemLevelDao;
import com.unis.quality.server.dao.CheckstandardItemRepository;
import com.unis.quality.server.entity.quality.TbCheckstandardItemDO;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.*;

/**
 * 
 * @ClassName: CheckstandardItemServer
 * @Description: 检测项目
 * @date 2019年7月19日 上午9:48:19
 * 
 * @version v1.0
 */
@Service
public class CheckstandardItemServer {

	@Autowired
	private CheckstandardItemRepository checkstandardItemRepository;

	@Autowired
	private CheckstandardItemlevelServer itemlevelServer;

	@Autowired
	private BaseRepository baseRepository;

	@Autowired
	private CheckstandandItemDao checkstandandItemDao;


	/**
	 * 项目列表接口
	 */
	public Map<Object, Object> findByPage(TbCheckstandardItemVO checkstandardInfoBO, Integer page, Integer size)
			throws Exception {
		PageRequest pageable = PageRequest.of((page - 1), size, Sort.Direction.DESC, "createDate");
		@SuppressWarnings("serial")
		Specification<TbCheckstandardItemDO> specification = new Specification<TbCheckstandardItemDO>() {
			@Override
			public Predicate toPredicate(Root<TbCheckstandardItemDO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
				List<Predicate> list = new ArrayList<Predicate>();
				// 标准编号
				if (StringUtils.isNotBlank(checkstandardInfoBO.getStandardCode())) {
					if("%%".equals(checkstandardInfoBO.getStandardCode())) {
						list.add(cb.like(root.get("standardCode").as(String.class),
								"% [" + checkstandardInfoBO.getStandardCode() + "] %"));
					}else {
						list.add(cb.like(root.get("standardCode").as(String.class),
								"%" + checkstandardInfoBO.getStandardCode() + "%"));
					}
				}
				// 项目明细
				if (StringUtils.isNotBlank(checkstandardInfoBO.getProjectDetails())) {
					list.add(cb.like(root.get("projectDetails").as(String.class),
							"%" + checkstandardInfoBO.getProjectDetails() + "%"));
				}
				// 创建时间搜索
				if (StringUtils.isNotBlank(checkstandardInfoBO.getCreateDateStart())
						&& StringUtils.isNotBlank(checkstandardInfoBO.getCreateDateEnd())) {
					list.add(cb.between(root.get("createDate").as(Date.class), DateUtil.toDate(checkstandardInfoBO.getCreateDateStart()),
							DateUtil.toDate(checkstandardInfoBO.getCreateDateEnd()+" 23:59:59","yyyy-MM-dd HH:mm:ss")));
				}
				list.add(cb.equal(root.get("status").as(Integer.class), 1));
				return cb.and(list.toArray(new Predicate[list.size()]));
			}
		};
		Page<TbCheckstandardItemDO> findAll = checkstandardItemRepository.findAll(specification, pageable);

		List<TbCheckstandardItemDO> content = findAll.getContent();
		List<Object> arrayList = new ArrayList<>();
		for (TbCheckstandardItemDO tbPO : content) {
			TbCheckstandardItemVO infoBO = LsBeanUtils.copyProperties(tbPO, TbCheckstandardItemVO.class);
			arrayList.add(infoBO);
			List<TbCheckstandardItemlevelVO> list=itemlevelServer.findByItemId(infoBO.getItemId());
			infoBO.setJudgeRuleList(list);
		}
		Map<Object, Object> map = new HashMap<>();
		map.put("content", arrayList);
		map.put("totalElements", findAll.getTotalElements());

		return map;
	}

	/**
	 * 项目保存接口
	 */
	public int save(TbCheckstandardItemVO checkstandardInfoBO) {

		TbCheckstandardItemDO entity=new TbCheckstandardItemDO();
		entity.setStandardType(checkstandardInfoBO.getStandardType());
		entity.setProjectDetails(checkstandardInfoBO.getProjectDetails());
		entity.setStandardCode(checkstandardInfoBO.getStandardCode());
		entity.setStandardName(checkstandardInfoBO.getStandardName());
		entity.setCreateDate(null);
		entity.setRefreshTime(null);
		Integer num= checkstandandItemDao.selectCount(entity);
		System.out.println("num: "+num +"  bool:"+(num==0));
		if(num==0){
			if (StringUtils.isEmpty(checkstandardInfoBO.getItemId())) {// 表示不存在id进行id自动生成
				checkstandardInfoBO.setItemId(baseRepository.selectByTableNameAndAttr("tb_checkstandard_item", "item_id",
						"CI" + DateUtil.getDate(), 5));
			}
			TbCheckstandardItemDO checkstandardInfoPO = LsBeanUtils.copyProperties(checkstandardInfoBO, TbCheckstandardItemDO.class);
			checkstandardInfoPO.setCreateDate(new Date());
			checkstandardInfoPO.setStandardId(checkstandardInfoBO.getStandardId());
			TbCheckstandardItemDO infoPO = checkstandardItemRepository.findByItemIdAndStatus(checkstandardInfoBO.getItemId(), 1);
			if (infoPO != null) {// 如果存在验收信息，复制属性
				LsBeanUtils.copyPropertiesIgnoreNull(checkstandardInfoPO, infoPO);
			}else{
				// 保存检测标准信息
				checkstandardItemRepository.save(checkstandardInfoPO);
			}
			itemlevelServer.save(checkstandardInfoBO.getJudgeRuleList(), checkstandardInfoPO.getCheckstandardId(),
					checkstandardInfoBO.getItemId());
		}

		return 1;
	}

	/**
	 * 项目修改接口
	 */
	public int update(TbCheckstandardItemVO checkstandardInfoBO) {
		TbCheckstandardItemDO infoPO = checkstandardItemRepository
				.findByItemIdAndStatus(checkstandardInfoBO.getItemId(), 1);
		if (infoPO == null) {
			return 0;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(checkstandardInfoBO, infoPO);
		itemlevelServer.delete(infoPO.getItemId());
		// 规则为空则不添加
		if (null != checkstandardInfoBO.getJudgeRuleList()) {
			itemlevelServer.save(checkstandardInfoBO.getJudgeRuleList(), infoPO.getCheckstandardId(),
					infoPO.getItemId());
		}
		checkstandardItemRepository.save(infoPO);
		return 1;
	}

	/**
	 * 项目详情接口
	 */
	public TbCheckstandardItemVO findByItemId(String itemId) throws Exception {
		TbCheckstandardItemDO infoPO = checkstandardItemRepository.findByItemIdAndStatus(itemId ,1);
		TbCheckstandardItemVO infoBO = LsBeanUtils.copyProperties(infoPO, TbCheckstandardItemVO.class);
		if(null != infoBO) {
			List<TbCheckstandardItemlevelVO> judgeRuleList = itemlevelServer.findByItemId(itemId);
			infoBO.setJudgeRuleList(judgeRuleList);
		}
		return infoBO;
	}

	/**
	 * @Description: 删除项目以及下面的规则
	 * @date 2019年7月18日,下午4:36:49
	 * @version v1.0
	 *
	 * @param itemId
	 * @return
	 */
	public int delete(String[] itemId) {
		for (String id : itemId) {
			itemlevelServer.delete(id);
		}
		checkstandardItemRepository.deleteitemId(itemId, "test", "test");
		return 1;
	}

	/**
	 * 返回所有的未删除的项目集合(包含规则)
	 * 
	 * @throws Exception
	 */
	public List<TbCheckstandardItemVO> getAllInfo() {
		List<TbCheckstandardItemDO> lisPO = checkstandardItemRepository.findByStatus(1);
		List<TbCheckstandardItemVO> arrayList = new ArrayList<>();
		for (TbCheckstandardItemDO tbPO : lisPO) {
			TbCheckstandardItemVO infoBO = LsBeanUtils.copyProperties(tbPO, TbCheckstandardItemVO.class);
			List<TbCheckstandardItemlevelVO> lis = itemlevelServer.findByItemId(infoBO.getItemId());
			infoBO.setJudgeRuleList(lis);
			arrayList.add(infoBO);
		}
		return arrayList;
	}

	/**
	 * 返回所有的未删除的项目集合(包含规则)
	 *
	 * @throws Exception
	 */
	public List<TbCheckstandardItemVO> selectByEntity() {
		TbCheckstandardItemDO checkstandardItemDO=new TbCheckstandardItemDO();
		checkstandardItemDO.setCreateDate(null);
		checkstandardItemDO.setRefreshTime(null);
		checkstandardItemDO.setStatus(1);
		List<TbCheckstandardItemDO> lisPO = checkstandandItemDao.select(checkstandardItemDO);
		List<TbCheckstandardItemVO> arrayList = new ArrayList<>();
		for (TbCheckstandardItemDO tbPO : lisPO) {
			TbCheckstandardItemVO infoBO = LsBeanUtils.copyProperties(tbPO, TbCheckstandardItemVO.class);
			List<TbCheckstandardItemlevelVO> lis = itemlevelServer.selectByEntity(infoBO.getItemId());
			infoBO.setJudgeRuleList(lis);
			arrayList.add(infoBO);
		}
		return arrayList;
	}

}
