package com.unis.quality.server.service.impl;

import cn.hutool.core.date.DatePattern;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.EntityUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.base.PageResult;
import com.unis.quality.common.constant.RedisDataBaseIndex;
import com.unis.quality.common.constant.RedisKey;
import com.unis.quality.common.utils.IdsWorker;
import com.unis.quality.common.utils.QualityIndexUtil;
import com.unis.quality.common.vo.*;
import com.unis.quality.server.config.RedisCache;
import com.unis.quality.server.dao.*;
import com.unis.quality.server.entity.quality.EntrustInspectApplyDO;
import com.unis.quality.server.entity.quality.EntrustInspectDO;
import com.unis.quality.server.entity.quality.QualityInspectionDO;
import com.unis.quality.server.entity.quality.QualityOpinionOutDO;
import com.unis.quality.server.service.EntrustInspectService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import tk.mybatis.mapper.entity.Example;

import javax.annotation.PostConstruct;
import javax.transaction.Transactional;
import java.time.LocalDate;
import java.time.Year;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.function.Consumer;

/**
 * @author by PIG
 * 2023/10/10 10
 */
@Service
@Log4j2
public class EntrustInspectServiceImpl implements EntrustInspectService {

    @Autowired
    private EntrustInspectDao entrustInspectDao;

    @Autowired
    private EntrustInspectApplyDao entrustInspectApplyDao;

    @Autowired
    private EntrustInspectApplyDetailDao entrustInspectApplyDetailDao;
    @Autowired
    private QualityInspectionDao qualityInspectionDao;
    @Autowired
    private QualityInspectionDetailDao qualityInspectionDetailDao;

    @Autowired
    private QualityOpinionOutDao qualityOpinionOutDao;
    @Autowired
    private QualityOpinionOutDetailDao qualityOpinionOutDetailDao;

    @Autowired
    private BaseRepository baseRepository;

    @Autowired
    RedisCache redisCache;

    @Autowired
    QualityIndexUtil qualityIndexUtil;

    @Autowired
    IdsWorker idsWorker;



    protected Map<String, Consumer<EntrustInspectApplyVO>> applyOperatorMap = new HashMap<>();
    protected Map<String, Consumer<EntrustInspectVO>> entrustOperatorMap = new HashMap<>();

    @PostConstruct
    private void init() {
        applyOperatorMap.put(EntrustInspectApplyVO.NODE_INFO.SEAL_PEND.getValue(), this::sealPend);
        applyOperatorMap.put(EntrustInspectApplyVO.NODE_INFO.ACCEPTED.getValue(), this::accepted);

        entrustOperatorMap.put(EntrustInspectVO.NODE_INFO.FINISH.getValue(), this::entrustInspectFinish);
    }

    public void doneApplyOperator(EntrustInspectApplyVO entity){
        Optional.ofNullable(applyOperatorMap.get(entity.getNodeId())).ifPresent(i -> i.accept(entity));
    }
    public void doneEntrustOperator(EntrustInspectVO entity){
        Optional.ofNullable(entrustOperatorMap.get(entity.getNodeId())).ifPresent(i -> i.accept(entity));
    }



    @Override
    public PageResult<EntrustInspectApplyVO> selectApplyPageByEntity(int pageNum, int pageSize, int pageType, JSONObject queryParams) {
        queryParams.put("pageType", pageType);
        if (pageNum == -1) {
            Page<EntrustInspectApplyVO> list = entrustInspectApplyDao.listByParams(queryParams);
            PageResult<EntrustInspectApplyVO> pageResult = new PageResult<>(list);
            return pageResult;
        } else {
            PageHelper.startPage(pageNum, pageSize);
            String orgId = CurrentUtil.getOrgId();
            if (1 == pageType) {
                queryParams.put("applyOrg", CurrentUtil.getOrgId());
            } else {
                queryParams.put("nodeList", Arrays.asList(EntrustInspectApplyVO.NODE_INFO.ACCEPT_PEND.getValue(), EntrustInspectApplyVO.NODE_INFO.ACCEPTED.getValue()));

            }
            Page<EntrustInspectApplyVO> list = entrustInspectApplyDao.listByParams(queryParams);
            PageResult<EntrustInspectApplyVO> pageResult = new PageResult<>(list);
            return pageResult;
        }
    }

    @Override
    public EntrustInspectApplyVO selectEntrustInspectApplyById(Long fid) {
        EntrustInspectApplyDO queryDO = new EntrustInspectApplyDO();
        queryDO.setFid(fid);
        queryDO.setStatus(1);
        EntrustInspectApplyDO entrustInspectApplyDO = entrustInspectApplyDao.selectOne(queryDO);
        EntrustInspectApplyVO entrustInspectApplyVO = new EntrustInspectApplyVO();
        BeanUtils.copyProperties(entrustInspectApplyDO, entrustInspectApplyVO);
        EntrustInspectApplyDetailVO applyDetailQuery = new EntrustInspectApplyDetailVO();
        applyDetailQuery.setEntrustInspectApplyId(fid);
        List<EntrustInspectApplyDetailVO> entrustInspectApplyDetailList = entrustInspectApplyDetailDao.select(applyDetailQuery);
        entrustInspectApplyVO.setEntrustInspectApplyDetailList(entrustInspectApplyDetailList);
        return entrustInspectApplyVO;
    }

    @Override
    @Transactional
    public int insertEntrustInspectApply(EntrustInspectApplyVO entity) {
        List<EntrustInspectApplyDetailVO> entrustInspectApplyDetailList = entity.getEntrustInspectApplyDetailList();
        EntrustInspectApplyDO applyEntity = new EntrustInspectApplyDO();
        LsBeanUtils.copyAllProperties(entity, applyEntity);
        Integer entrustApplyType = applyEntity.getEntrustApplyType();
        String prefix = EntrustInspectApplyVO.getEntrustApplyTypeName(entrustApplyType).name() + LocalDate.now().format(DateTimeFormatter.ofPattern("yyyyMMdd"));
        String applyNumber = baseRepository.selectByTableNameAndAttr(EntityUtil.getTableName(EntrustInspectApplyDO.class), "apply_number", prefix, 3, () -> null);
        log.info("新生成的申请编号 applyNumber ------>\t{}", applyNumber);
        applyEntity.setApplyNumber(applyNumber);
        Long fid = entrustInspectApplyDao.selectKey();
        applyEntity.setFid(fid);
        applyEntity.buildInsertData();
        EntrustInspectApplyDetailVO detailQuery = new EntrustInspectApplyDetailVO();
        for (EntrustInspectApplyDetailVO item : entrustInspectApplyDetailList) {
            String warehouseId = item.getWarehouseId();
            String contractNumber = item.getContractNumber();
            detailQuery.setWarehouseId(warehouseId);
            detailQuery.setContractNumber(contractNumber);
//            int i = entrustInspectApplyDetailDao.selectCount(detailQuery);
//            if (i> 0) {
//                return -1;
//            }
            item.setEntrustInspectApplyId(fid);
            entrustInspectApplyDetailDao.insertSelective(item);
        }
        int insertCount = entrustInspectApplyDao.insertSelective(applyEntity);
        return insertCount;
    }


    @Override
    public int saveEntrustInspectApplyOut(EntrustInspectApplyVO entity) {
        List<EntrustInspectApplyDetailVO> detailList = entity.getEntrustInspectApplyDetailList();
        if (null != detailList) {
            EntrustInspectApplyDetailVO applyDetailVO = detailList.get(0);
            String subTypeDetailed = applyDetailVO.getSubTypeDetailed();
            Map<String, String> subType = entrustInspectApplyDao.getSubType(subTypeDetailed);
            entity.setApplySubType(subType.get("value"));
            entity.setApplySubTypeName(subType.get("name"));
            for (EntrustInspectApplyDetailVO detailVO : detailList) {
                Map<String, String> house = entrustInspectApplyDetailDao.getHouse(applyDetailVO.getWarehouseId());
                detailVO.setHouseId(house.get("value"));
                detailVO.setHouseName(house.get("name"));
            }
        }
        return insertEntrustInspectApply(entity);
    }

    @Override
    @Transactional
    public int updateEntrustInspectApply(EntrustInspectApplyVO entity) {
        Long fid = entity.getFid();
        String nodeId = entity.getNodeId();

        EntrustInspectApplyDO entrustInspectApplyDO = new EntrustInspectApplyDO();
        LsBeanUtils.copyAllProperties(entity, entrustInspectApplyDO);

        int updateRows = entrustInspectApplyDao.updateByPrimaryKeySelective(entrustInspectApplyDO);
        doneApplyOperator(entity);
        return updateRows;
    }

    /**
     * 质检申请-接收
     * @param entity 委托申请
     */
    @Transactional
    protected void accepted(EntrustInspectApplyVO entity) {
        Long applyFid = entity.getFid();

        EntrustInspectDO queryDO = new EntrustInspectDO();
        String applyNumber = entity.getApplyNumber();
        queryDO.setApplyNumber(applyNumber);
        List<EntrustInspectDO> select = entrustInspectDao.select(queryDO);
        if (select.size() > 0) {
            log.info("已存在委托书 {} 条", select.size());
            entrustInspectDao.delete(queryDO);
        }
        // 创建 委托书
        Example example = new Example(EntrustInspectApplyDO.class).excludeProperties("signature");
        example.createCriteria().andEqualTo("fid", applyFid);
        EntrustInspectApplyDO entrustInspectApplyDO = entrustInspectApplyDao.selectOneByExample(example);

        String applySubType = entity.getApplySubType();
        String subTypeKey = qualityIndexUtil.getRedisKeyByCode(applySubType);
        // 获取质检项目
        redisCache.changeData(RedisDataBaseIndex.DB0);
        JSONArray qualityIndex = redisCache.getCacheObject(RedisKey.THEAD_TREE_PREFIX + subTypeKey);

        EntrustInspectApplyDetailVO detailQuery = new EntrustInspectApplyDetailVO();
        detailQuery.setEntrustInspectApplyId(applyFid);
        List<EntrustInspectApplyDetailVO> entrustInspectApplyDetailList = entrustInspectApplyDetailDao.select(detailQuery);
        EntrustInspectDO entrustInspectDO = new EntrustInspectDO();
        if (null != qualityIndex) {
            String item = qualityIndex.toJavaList(JSONObject.class).stream().reduce("", (prev, curr) -> {
                if (!"".equals(prev)) {
                    prev += "\n";
                }
                return prev + curr.getString("desc") + ":" + curr.getString("remark");
            }, (curr, prev) -> null);
            entrustInspectDO.setQualityItem(item);
        }
        entrustInspectDO.buildInsertData();
        String type = EntrustInspectApplyVO.getEntrustApplyTypeName(entity.getEntrustApplyType()).getType();
        String prefix = "津DC-" + type + "-" + Year.now(); // 津DC-R(C)-四位年份-两位顺序号
        log.info("委托书编号前缀 ====================>\n{}", prefix);
        for (EntrustInspectApplyDetailVO item : entrustInspectApplyDetailList) {
            entrustInspectDO.createBean(entrustInspectApplyDO, item);
            String entrustNum = baseRepository.selectByTableNameAndAttr(EntityUtil.getTableName(EntrustInspectDO.class), "entrust_num", prefix, 3, () -> null);
            log.info("委托书编号 ====================>\t{}", entrustNum);
            entrustInspectDO.setEntrustNum(entrustNum);
            entrustInspectDao.insertSelective(entrustInspectDO);
        }
    }

    @Transactional
    protected void sealPend(EntrustInspectApplyVO entity) {
        Long fid = entity.getFid();
        EntrustInspectApplyDetailVO delParams = new EntrustInspectApplyDetailVO();
        delParams.setEntrustInspectApplyId(fid);
        int deleteRows = entrustInspectApplyDetailDao.delete(delParams);
        log.info("删除质检申请 明细数据 {} 条", deleteRows);
        List<EntrustInspectApplyDetailVO> entrustInspectApplyDetailList = entity.getEntrustInspectApplyDetailList();
        for (EntrustInspectApplyDetailVO item : entrustInspectApplyDetailList) {
            item.setEntrustInspectApplyId(fid);
            entrustInspectApplyDetailDao.insertSelective(item);
        }
    }


    @Override
    public int removeEntrustInspectApplyById(Long fid) {
        return entrustInspectApplyDao.removeByFid(fid);
    }

    @Override
    public PageResult<EntrustInspectVO> selectPageByEntity(int pageNum, int pageSize, int pageType, JSONObject queryParams) {
        queryParams.put("pageType", pageType);
        if (pageNum == -1) {
            Page<EntrustInspectVO> entrustInspectList = entrustInspectDao.listByParams(queryParams);
            PageResult<EntrustInspectVO> pageResult = new PageResult<>(entrustInspectList);
            return pageResult;
        }else {
            PageHelper.startPage(pageNum, pageSize);
            String orgId = CurrentUtil.getOrgId();
            if (1 == pageType) {
//                queryParams.put("applyOrg", CurrentUtil.getOrgId());
//                queryParams.put("nodeList", Arrays.asList(EntrustInspectVO.))
            }else if (2 == pageType){
//                queryParams.put("nodeList", Arrays.asList(EntrustInspectVO.));
            }else if (3 == pageType){
                // 第三方
                queryParams.put("nodeList", Arrays.asList(
                        EntrustInspectVO.NODE_INFO.ACCEPT_PEND.getValue(),
                        EntrustInspectVO.NODE_INFO.UPLOAD_ENTRUST_PEND.getValue(),
                        EntrustInspectVO.NODE_INFO.UPLOAD_REPORT_PEND.getValue(),
                        EntrustInspectVO.NODE_INFO.FINISH.getValue()
                        ));
            }
            Page<EntrustInspectVO> entrustInspectList = entrustInspectDao.listByParams(queryParams);
            PageResult<EntrustInspectVO> pageResult = new PageResult<>(entrustInspectList);
            return pageResult;

        }
    }

    @Override
    public EntrustInspectVO getEntrustInspectById(Long fid) {
        EntrustInspectDO queryDO = new EntrustInspectDO();
        queryDO.setFid(fid);
        queryDO.setStatus(1);
        EntrustInspectDO entrustInspectDO = entrustInspectDao.selectOne(queryDO);
        EntrustInspectVO entrustInspectVO = new EntrustInspectVO();
        BeanUtils.copyProperties(entrustInspectDO, entrustInspectVO);
        return entrustInspectVO;
    }

    @Override
    public Map<String, Object> createEntrustInspect(EntrustInspectVO entity) {
        EntrustInspectDO entrustInspectDO = new EntrustInspectDO();
        BeanUtils.copyProperties(entity, entrustInspectDO);
        entrustInspectDO.buildUpdateData();

        int updateRows = entrustInspectDao.updateByPrimaryKeySelective(entrustInspectDO);
        HashMap<String, Object> map = new HashMap<>();
        map.put("updateRows", updateRows);
        return map;
    }

    @Override
    @Transactional
    public int updateEntrustInspect(EntrustInspectVO entity) {
        EntrustInspectDO entrustInspectDO = new EntrustInspectDO();
        BeanUtils.copyProperties(entity, entrustInspectDO);
        entrustInspectDO.buildUpdateData();
        doneEntrustOperator(entity);
        int i = entrustInspectDao.updateByPrimaryKeySelective(entrustInspectDO);
        return i;
    }

    @Override
    @Transactional
    public int uploadQualityInspection(Long entrustInspectFid, String inspectAttachment, QualityInspectionVO fileData) {
        EntrustInspectDO entrustInspectDO = entrustInspectDao.selectByPrimaryKey(entrustInspectFid); // 委托书
        entrustInspectDO.setInspectAttachment(inspectAttachment);
        entrustInspectDO.finish();
        List<QualityInspectionDetailVO> qualityInspectionDetailList = fileData.getQualityInspectionDetailList();
        QualityInspectionDO qualityInspectionDO = new QualityInspectionDO();
        BeanUtils.copyProperties(fileData, qualityInspectionDO);
        qualityInspectionDO.setEntrustInspectFid(entrustInspectFid);
        qualityInspectionDO.setSubTypeDetailed(entrustInspectDO.getSubTypeDetailed());
        qualityInspectionDO.buildInsertData();
        long inspectionFid = idsWorker.nextId();
        log.info("雪花算法 id----------->\t{}", inspectionFid);
        qualityInspectionDO.setFid(inspectionFid);
        for (QualityInspectionDetailVO item : qualityInspectionDetailList) {
            item.setQualityInspectionFid(inspectionFid);
            qualityInspectionDetailDao.insertSelective(item);
        }
        qualityInspectionDao.insertSelective(qualityInspectionDO);
        int updateRows = entrustInspectDao.updateByPrimaryKeySelective(entrustInspectDO);
        EntrustInspectVO entity = new EntrustInspectVO();
        BeanUtils.copyProperties(entrustInspectDO, entity);
        doneEntrustOperator(entity);
        return updateRows;
    }

    @Override
    public PageResult<QualityInspectionVO> selectQualityInspectionPageByEntity(int pageNum, int pageSize, int pageType, JSONObject queryParams) {
        queryParams.put("pageType", pageType);
        String orgId = CurrentUtil.getOrgId();
        if (pageNum == -1) {
            Page<QualityInspectionVO> qualityInspectionList = qualityInspectionDao.listByParams(queryParams);
            PageResult<QualityInspectionVO> pageResult = new PageResult<>(qualityInspectionList);
            return pageResult;

        }else {
            PageHelper.startPage(pageNum, pageSize);
            if (1 == pageType) {
                queryParams.put("applyOrg", orgId);
            }else {

            }
            Page<QualityInspectionVO> qualityInspectionList = qualityInspectionDao.listByParams(queryParams);
            PageResult<QualityInspectionVO> pageResult = new PageResult<>(qualityInspectionList);
            return pageResult;
        }
    }

    @Override
    public QualityInspectionVO selectQualityInspectionById(Long fid) {
        QualityInspectionDO qualityInspectionDO = qualityInspectionDao.selectByPrimaryKey(fid);
        if (null == qualityInspectionDO) {
            return new QualityInspectionVO();
        }
        QualityInspectionVO qualityInspectionVO = new QualityInspectionVO();
        LsBeanUtils.copyAllProperties(qualityInspectionDO, qualityInspectionVO);

        QualityInspectionDetailVO queryVO = new QualityInspectionDetailVO();
        queryVO.setQualityInspectionFid(fid);
        List<QualityInspectionDetailVO> detailList = qualityInspectionDetailDao.select(queryVO);

        qualityInspectionVO.setQualityInspectionDetailList(detailList);
        return qualityInspectionVO;
    }

    @Override
    public ResponseWrapper checkFinish(String xybh, String houseId) {
        EntrustInspectVO entity = entrustInspectDao.checkFinish(xybh, houseId);
        Map<String, Object> map = new HashMap<>();
        if (null == entity) {
            map.put("complete", 0);
            return ResponseWrapper.success(map);
        }
        int complete = EntrustInspectVO.NODE_INFO.FINISH.equalVal(entity.getNodeId()) ? 1 : 0;
        map.put("complete", complete);
        return ResponseWrapper.success(map);
    }

    /* 节点逻辑↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓↓*/
    @Transactional
    protected void entrustInspectFinish(EntrustInspectVO entity){
        Integer entrustApplyType = entity.getEntrustApplyType();
        if (EntrustInspectApplyVO.ENTRUST_APPLY_TYPE.CK.equalsVal(entrustApplyType)) {
            String applyNumber = entity.getApplyNumber();
            Long applyDetailFid = entity.getApplyDetailFid();

            Example entrustInspectExample = new Example(EntrustInspectDO.class);
            entrustInspectExample.selectProperties("nodeId")
                    .createCriteria()
                    .andEqualTo("applyNumber", applyNumber)
                    .andEqualTo("status", 1);
            List<EntrustInspectDO> entrustInspectDOList = entrustInspectDao.selectByExample(entrustInspectExample);
            boolean allFinish = entrustInspectDOList.stream().allMatch(EntrustInspectDO::checkFinish);
            if (allFinish) {
                List<QualityOpinionOutDetailVO> list = qualityOpinionOutDetailDao.listOutQualitySource(applyDetailFid);
                Example applyExample = new Example(EntrustInspectApplyDO.class);
                applyExample.createCriteria().andEqualTo("applyNumber", applyNumber);
                EntrustInspectApplyDO entrustInspectApplyDO = entrustInspectApplyDao.selectOneByExample(applyExample);

                long qualityOpinionOutId = idsWorker.nextId();
                log.info("\tqualityOpinionOutId:{}", qualityOpinionOutId);
                QualityOpinionOutDO qualityOpinionOutDO = new QualityOpinionOutDO();
                qualityOpinionOutDO.initNode(qualityOpinionOutId);
                qualityOpinionOutDO.buildInsertData(1);
                qualityOpinionOutDO.setApplyNumber(applyNumber);
                qualityOpinionOutDO.setRkdwbm(entrustInspectApplyDO.getApplyOrg());
                qualityOpinionOutDO.setRkdwmc(entrustInspectApplyDO.getApplyOrgName());
                qualityOpinionOutDO.setContractNumber(entrustInspectApplyDO.getRotateApplyCode());

                Long fid = entity.getFid();
                QualityInspectionDO queryDO = new QualityInspectionDO();
                queryDO.setEntrustInspectFid(fid);
                queryDO.setStatus(1);
                QualityInspectionDO qualityInspectionDO = qualityInspectionDao.selectOne(queryDO); // 质检报告
                Long qualityInspectionFid = qualityInspectionDO.getFid();
                QualityInspectionDetailVO queryVO = new QualityInspectionDetailVO();
                queryVO.setQualityInspectionFid(qualityInspectionFid);

                for (QualityOpinionOutDetailVO item : list) {
                    // 仓号 品种 数量 年限 质检指标只存平均样品的id。。。 有效日期
                    DateTimeFormatter formatter = DateTimeFormatter.ofPattern(DatePattern.NORM_DATE_PATTERN);
                    LocalDate parse = LocalDate.parse(item.getValidity(), formatter);
                    String validity = parse.plusMonths(3).minusDays(1).format(formatter);
                    item.setValidity(validity);
                    item.setQualityOpinionOutFid(qualityOpinionOutId);
                    qualityOpinionOutDetailDao.insertSelective(item);
                }
                qualityOpinionOutDao.insertSelective(qualityOpinionOutDO);
            }
        }
    }



}
