package com.unis.quality.server.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.quality.common.dto.FoodStockDTO;
import com.unis.quality.common.vo.FoodStockItemsVO;
import com.unis.quality.common.vo.FoodStockVO;
import com.unis.quality.common.vo.GradeTestResultsItemsVO;
import com.unis.quality.common.vo.QualityPredictionAduitVO;
import com.unis.quality.common.vo.SummaryInspectionResultVO;
import com.unis.quality.common.vo.SummaryNotSuitableVO;
import com.unis.quality.common.vo.SummaryResultsItemsVO;
import com.unis.quality.common.vo.SummaryResultsVO;
import com.unis.quality.common.vo.SummarySubstandardSampleVO;
import com.unis.quality.server.domain.FoodStockDomain;
import com.unis.quality.server.domain.QualityPredictionAduitDomain;
import com.unis.quality.server.domain.SummaryResultsDomain;
import com.unis.quality.server.entity.quality.FoodStockDO;
import com.unis.quality.server.entity.quality.GradeTestResultsDO;
import com.unis.quality.server.entity.quality.SummaryInspectionResultDO;
import com.unis.quality.server.entity.quality.SummaryNotSuitableDO;
import com.unis.quality.server.entity.quality.SummaryResultsDO;
import com.unis.quality.server.entity.quality.SummarySubstandardSampleDO;
import com.unis.quality.server.service.FoodStockService;

/**
 * @ClassName FoodStockDao
 * @Description 品质测报-库存粮食质量检测品登统表
 * @author lfx
 * @date 2019年7月24日17:26:44
 * @version v1.0
 */
@Service
public class FoodStockServiceImpl implements FoodStockService{
	@Autowired
	private FoodStockDomain domain;
	
	
	@Autowired
	private SummaryResultsDomain service;
	

    
    @Autowired
	private QualityPredictionAduitDomain mapper;
	/**
	 * @Description 根据id查询审核详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
	
	
    /**
	 * @Description 根据id查询详情--质检档案
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param id
	 * @return
	 * @throws Exception
	 */
    //String id,String zjda,String type,String batch,String areaCode
	public Map<String, Object>  findByIdAndIsDeleted(FoodStockDTO fdto1) throws Exception {
    	Map<String, Object> resultMap = new HashMap<String, Object>();
    	String id=fdto1.getPlanId();
    	String zjda=fdto1.getZjda();
    	String areaCode=fdto1.getAreaCode();
    	String batch=fdto1.getBatch();
    	String type=fdto1.getType();
    	FoodStockDO qualityResultsDO = domain.findByIdAndIsDeleted(id,zjda, 0,areaCode,batch);
    	FoodStockVO aduitData=LsBeanUtils.copyProperties(qualityResultsDO, FoodStockVO.class);
    	if("1".equals(type)) {
    	List<FoodStockItemsVO> itemsData=null;
    	if(null!=aduitData) {
    		 itemsData= domain.findItemsByIdAndIsDeleted(aduitData.getId(),batch);
    	}
    	resultMap.put("aduitData", aduitData);
    	resultMap.put("itemsData", itemsData);
    	}else if("2".equals(type)) {
    		GradeTestResultsDO gradeAduitData=domain.findGradeByIdAndIsDeleted(aduitData.getId(),batch);
    		List<GradeTestResultsItemsVO> gradeItemsData=null;
    		if(null==gradeAduitData) {
    			resultMap.put("aduitData", "");
        		resultMap.put("itemsData", "");
    		}else {
    			FoodStockDTO fdto=new FoodStockDTO();
    	    	fdto.setPlanId(gradeAduitData.getId());
    	    	fdto.setBatch(batch);
    		    gradeItemsData=domain.findGradeItemsByIdAndIsDeleted(fdto);
    		    if(null==gradeItemsData) {
    		    	resultMap.put("itemsData", "");
    		    }else {
    		    	resultMap.put("itemsData", gradeItemsData);
    		    }
    		    resultMap.put("aduitData", gradeAduitData);
    		}
    		
    	}else if("3".equals(type)) {
    		SummaryResultsDO summaryResultsDO = service.findByIdAndIsDeleted(id,areaCode,batch);
    		SummaryResultsVO summaryResultsData=LsBeanUtils.copyProperties(summaryResultsDO, SummaryResultsVO.class);
    		List<SummaryResultsItemsVO> sitemsData=null;
    		if(null==summaryResultsData) {
    			resultMap.put("aduitData", "");
        		resultMap.put("itemsData", ""); 
    		}else {
    			FoodStockDTO fdto=new FoodStockDTO();
    	    	fdto.setPlanId(summaryResultsData.getId());
    	    	fdto.setBatch(batch);
    	    	fdto.setAreaCode(areaCode);
    			sitemsData= service.findItemsByIdAndIsDeleted(fdto);
    			if(null==summaryResultsData) {
    				resultMap.put("itemsData","");
        		}else {
        			resultMap.put("itemsData", sitemsData);
        		}
        		resultMap.put("aduitData", summaryResultsData);
    		}
    		
    	}else if("4".equals(type)) {
    		FoodStockDTO fdto=new FoodStockDTO();
	    	fdto.setPlanId(id);
	    	fdto.setBatch(batch);
	    	fdto.setAreaCode(areaCode);
    		List<SummarySubstandardSampleVO> sitemsData1= service.findSampleByIdAndIsDeleted(fdto);
    		if(sitemsData1.size()>0) {
    			resultMap.put("aduitData",sitemsData1.get(0));
            	resultMap.put("itemsData", sitemsData1);
    		}else{
    			resultMap.put("aduitData", "");
        		resultMap.put("itemsData", "");
    		}
    	}else if("5".equals(type)) {
    		FoodStockDTO fdto=new FoodStockDTO();
	    	fdto.setPlanId(id);
	    	fdto.setBatch(batch);
	    	fdto.setAreaCode(areaCode);
    		List<SummaryInspectionResultVO> sitemsData2= service.findInspectionByIdAndIsDeleted(fdto);
    		if(sitemsData2.size()>0) {
    			resultMap.put("aduitData", sitemsData2.get(0));
            	resultMap.put("itemsData", sitemsData2);
    		}else {
    			resultMap.put("aduitData", "");
        		resultMap.put("itemsData", "");
    		}
    	}else if("6".equals(type)) {
    		FoodStockDTO fdto=new FoodStockDTO();
	    	fdto.setPlanId(id);
	    	fdto.setBatch(batch);
	    	fdto.setAreaCode(areaCode);
    		List<SummaryNotSuitableVO> sitemsData3= service.findyNotSuitableByIdAndIsDeleted(fdto);
    		if(sitemsData3.size()>0) {
    			resultMap.put("aduitData", sitemsData3.get(0));
            	resultMap.put("itemsData", sitemsData3);
    		}else {
    			resultMap.put("aduitData", "");
        		resultMap.put("itemsData", "");
    		}
    	}else if("7".equals(type)) {//质检档案不需要7
    		/**/
    	}
    	
		return resultMap;
	} 
	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(FoodStockDTO fDto, Integer page, Integer size) throws Exception {
		   Map<String, Object> resultMap = new HashMap<String, Object>();
		   if("1".equals(fDto.getType())) {//盟市、旗县列表
			   FoodStockVO qualityVO=new FoodStockVO();
			   qualityVO.setPlanFileName(fDto.getPlanFileName());
			   qualityVO.setCity(fDto.getCity());
			   qualityVO.setFindingsAudit(fDto.getFindingsAudit());
			   qualityVO.setAreaCode(fDto.getAreaCode());
			   qualityVO.setDeptId(fDto.getRemarks());
			   qualityVO.setState(fDto.getState());
			   resultMap= domain.findByPage1(qualityVO,page,size);
		   }else if("2".equals(fDto.getType())) {//自治区列表
			   SummaryResultsVO qualityVO=new SummaryResultsVO();
			   qualityVO.setPlanFileName(fDto.getPlanFileName());
			   qualityVO.setCity(fDto.getCity());
			   qualityVO.setFindingsAudit(fDto.getFindingsAudit());
			   qualityVO.setAreaCode(fDto.getAreaCode());
			   qualityVO.setDeptId(fDto.getRemarks());
			   qualityVO.setState(fDto.getState());
			   resultMap= service.findSummaryResultsByPage(qualityVO,page,size);
		   }
		   return resultMap;
	   }

	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return boolean
	 * @throws Exception
	 */
	public boolean deletes(String[] ids,String batch,String areaCode,String deptName) throws Exception {
    	boolean bool=false;
    	 QualityPredictionAduitVO vo=new QualityPredictionAduitVO();
		 vo.setAreaCode(areaCode);
		 vo.setDeptId(deptName);
    	 Map<String,Object> map=mapper.findByArea(vo);
		 String ac=map.get("areaCode").toString();
    	if(ac.length()!=2) {//旗县、盟市
    		bool=domain.deletesFoodStockItems(ids,batch,deptName);
    		bool=domain.deletesGradeItems(ids,batch,deptName);
    		bool=domain.deletesGrade(ids,batch,deptName);
    		bool=domain.deletesFoodStock(ids,batch,areaCode,deptName);
        }else {//自治区
        	bool=service.deletesSummaryResultsItems(ids,batch,areaCode,deptName);
        	bool=service.deletesSummaryResults(ids,batch,areaCode,deptName);
        	bool=service.deletesSubstandardSample(ids,batch,deptName);
        	bool=service.deletesInspectionResult(ids,batch,deptName);
        	bool=service.deletesNotSuitable(ids,batch,deptName);
    	}
    	
    	return bool;
    }

	/**
	 * @Description 保存品质测报-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日11:25:58
	 * @return boolean
	 * @throws Exception
	 */
	public boolean save(Map<String, Object> aduitList,FoodStockDTO fDto) throws Exception {
    	boolean bool = false; 
		List<Map> itemsData=(List<Map>)aduitList.get("itemsData");
		Map<String,Object> aduitData=(Map<String,Object>)aduitList.get("aduitData");
		String type=aduitData.get("type")+"";
		FoodStockDTO fDto2=new FoodStockDTO();
		fDto2.setCondition("BIZ_FOOD_STOCK");
    	fDto2.setAreaCode(fDto.getAreaCode());
    	fDto2.setPlanFileName(aduitData.get("planFileName")+"");
    	String batch=queryMaxBatch(fDto2);
    	int batch1=0;
    	if("".equals(batch)  || null==batch) {
    		batch1=1;
    	}else {
    		batch1=Integer.valueOf(batch)+1;
    	}
    	
    	FoodStockDTO fDto1=new FoodStockDTO();
		fDto1.setCondition("BIZ_SUMMARY_RESULTS");
    	fDto1.setAreaCode(fDto.getAreaCode());
    	fDto1.setPlanFileName(aduitData.get("planFileName")+"");
    	String batch2=queryMaxBatch(fDto1);
    	int batch3=0;
    	if("".equals(batch2)  || null==batch2) {
    		batch3=1;
    	}else {
    		batch3=Integer.valueOf(batch2)+1;
    	}
		if("1".equals(type)) {//库存粮食质量检测品登统表
			if(aduitData.size()>0) {
				FoodStockDO resultsDO = new FoodStockDO();
				resultsDO.setFindingsAudit(fDto.getFindingsAudit());
				resultsDO.setId(fDto.getId());
				resultsDO.setProcessId(fDto.getProcessId());
				resultsDO.setBatch(String.valueOf(batch1));
				resultsDO.setAreaCode(fDto.getAreaCode());
				resultsDO.setCreateBy(fDto.getDeptName());
				 bool=domain.saveFoodStock(aduitData,resultsDO);
				 if(bool==true) {
					 if(itemsData.size() > 0 && itemsData != null) {
						 bool=domain.saveFoodStockItems(itemsData,resultsDO);
					 }
				 }
			}
		}
		if("2".equals(type)) {//检验结果登记表
			if(aduitData.size()>0) {
				GradeTestResultsDO resultsDO1 = new GradeTestResultsDO();
				int t=0;
				if(1==batch1) {
					t=batch1;
				}else {
					t=batch1-1;
				}
				resultsDO1.setBatch(String.valueOf(t));
				resultsDO1.setAreaCode(fDto.getAreaCode());
				resultsDO1.setCreateBy(fDto.getDeptName());
				bool =domain.saveGradeTest(aduitData,resultsDO1);
				if(bool==true) {
					bool =domain.saveGradeTestItems(itemsData,resultsDO1);
				}
			}
		}
		if("3".equals(type)) {//3粮食质量检验结果汇总表 
			if(aduitData.size()>0) {
				SummaryResultsDO resultsDO = new SummaryResultsDO();
				resultsDO.setFindingsAudit(fDto.getFindingsAudit());
				resultsDO.setId(fDto.getId());
				resultsDO.setProcessId(fDto.getProcessId());
				resultsDO.setBatch(String.valueOf(batch3));
				resultsDO.setAreaCode(fDto.getAreaCode());
				resultsDO.setCreateBy(fDto.getDeptName());
				bool=service.saveSummaryResults(aduitData,resultsDO);
				 if(bool==true) {
					 if(itemsData.size() > 0 && itemsData != null) {
						 bool=service.saveSummaryResultsItems(itemsData,resultsDO);
					 }
				 }
			}
		}
		if("4".equals(type)) {//4、质量不达标样品汇总表
			if(aduitData.size()>0) {
				SummarySubstandardSampleDO sampleDO=new SummarySubstandardSampleDO();
				sampleDO.setAreaCode(fDto.getAreaCode());
				sampleDO.setCreateBy(fDto.getDeptName());
				int i=0;
				if(1==batch3) {
					i=batch3;
				}else {
					i=batch3-1;
				}
				sampleDO.setBatch(String.valueOf(i));
				 bool=service.saveSummarySubstandardSample(aduitData,itemsData,sampleDO);
			}
		}
		if("5".equals(type)) {//5、粮食储存品质检验结果汇总表
			if(aduitData.size()>0) {
				SummaryInspectionResultDO sampleDO=new SummaryInspectionResultDO();
				sampleDO.setAreaCode(fDto.getAreaCode());
				sampleDO.setCreateBy(fDto.getDeptName());
				int i=0;
				if(1==batch3) {
					i=batch3;
				}else {
					i=batch3-1;
				}
				sampleDO.setBatch(String.valueOf(i));
				 bool=service.saveSummaryInspectionResult(aduitData,itemsData,sampleDO);
			}
		}
		if("6".equals(type)) {//6、储存品质不宜存样品汇总表
			if(aduitData.size()>0) {
				SummaryNotSuitableDO sampleDO= new SummaryNotSuitableDO();
				sampleDO.setAreaCode(fDto.getAreaCode());
				sampleDO.setCreateBy(fDto.getDeptName());
				int i=0;
				if(1==batch3) {
					i=batch3;
				}else {
					i=batch3-1;
				}
				sampleDO.setBatch(String.valueOf(i));
				 bool=service.saveSummaryNotSuitable(aduitData,itemsData,sampleDO);
			}
		}
		return bool;
	}

	/**
	 * @Description 更新安全监测-结果审核
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:03:46
	 * @param QualityPredictionPlannedVO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(Map<String, Object> aduitList,FoodStockDTO fDto) throws Exception {
    	boolean bool = false; 
    	String areaCode=fDto.getAreaCode();
		List<Map> itemsData=(List<Map>)aduitList.get("itemsData");
		Map<String,Object> aduitData=(Map<String,Object>)aduitList.get("aduitData");
		String type=aduitData.get("type")+"";
		if("1".equals(type)) {//1库存粮食质量检测品登统表
			if(aduitData.size()>0) {
				FoodStockDO resultsDO = new FoodStockDO();
				if( null!=fDto.getFindingsAudit()) {
					resultsDO.setFindingsAudit(fDto.getFindingsAudit());
				}if( null!=fDto.getAuditOpinions()) {
					resultsDO.setAuditOpinions(fDto.getAuditOpinions());
				}if( null!=fDto.getStateName()) {
					resultsDO.setStateName(fDto.getStateName());
				}if(null!=fDto.getState()) {
					resultsDO.setState(fDto.getState());
				}
				if( null!=fDto.getSlsjState()) {
					resultsDO.setSlsjState(fDto.getSlsjState());
				}if( null!=fDto.getSlsjMessage()) {
					resultsDO.setSlsjMessage(fDto.getSlsjMessage());
				}if(null!=fDto.getSzjzxState()) {
					resultsDO.setSzjzxState(fDto.getSzjzxState());
				}if(null!=fDto.getSzjzxMessage()) {
					resultsDO.setSzjzxMessage(fDto.getSzjzxMessage());
				}
				
				if( null!=fDto.getShlsjMessage()) {
					resultsDO.setShlsjMessage(fDto.getShlsjMessage());
				}if( null!=fDto.getShlsjState()) {
					resultsDO.setShlsjState(fDto.getShlsjState());
				}if( null!=fDto.getShzjzxMessage()) {
					resultsDO.setShzjzxMessage(fDto.getShzjzxMessage());
				}if( null!=fDto.getShzjzxState()) {
					resultsDO.setShzjzxState(fDto.getShzjzxState());
				}
				
				if( null!=fDto.getXlsjState()) {
					resultsDO.setXlsjState(fDto.getXlsjState());
				}if(null!=fDto.getXlsjMessage()) {
					resultsDO.setXlsjMessage(fDto.getXlsjMessage());
				}
				resultsDO.setBatch(aduitData.get("batch")+"");
				resultsDO.setAreaCode(areaCode);
				resultsDO.setDeptId(fDto.getDeptName());
				 bool=domain.updateFoodStock(aduitData,resultsDO);
				 if(bool==true) {
					 if(itemsData.size() > 0 && itemsData != null) {
						 bool=domain.updateFoodStockItems(itemsData,aduitData.get("id")+"",aduitData.get("batch")+"");
					 }
				 }
			}
		}
		if("2".equals(type)) {//2检验结果登记表
			if(aduitData.size()>0) {
				GradeTestResultsDO grado=new GradeTestResultsDO();
				grado.setAreaCode(areaCode);
				if(null==aduitData.get("id")) {
					grado.setId(UUIDUtils.uuid());
				}else {
					grado.setId(aduitData.get("id")+"");
				}
				bool =domain.updateGradeTest(aduitData,grado);
				if(bool==true) {
					String id="";
					if(null==aduitData.get("id")) {
						id=grado.getId();
					}else {
						id=aduitData.get("id")+"";
					}
					bool =domain.updateGradeTestItems(itemsData,id,aduitData.get("batch")+"");
				}
			}
		}
		if("3".equals(type)) {//3、粮食质量检验结果汇总表
			if(aduitData.size()>0) {
				SummaryResultsDO resultsDO=new SummaryResultsDO();
				if( null!=fDto.getFindingsAudit()) {
					resultsDO.setFindingsAudit(fDto.getFindingsAudit());
				}if( null!=fDto.getAuditOpinions()) {
					resultsDO.setAuditOpinions(fDto.getAuditOpinions());
				}if(null!=fDto.getStateName()) {
					resultsDO.setStateName(fDto.getStateName());
				}if( null!=fDto.getState()) {
					resultsDO.setState(fDto.getState());
				}
				
				if( null!=fDto.getSlsjState()) {
					resultsDO.setSlsjState(fDto.getSlsjState());
				}if( null!=fDto.getSlsjMessage()) {
					resultsDO.setSlsjMessage(fDto.getSlsjMessage());
				}if( null!=fDto.getSzjzxState()) {
					resultsDO.setSzjzxState(fDto.getSzjzxState());
				}if( null!=fDto.getSzjzxMessage()) {
					resultsDO.setSzjzxMessage(fDto.getSzjzxMessage());
				}
				
				if( null!=fDto.getShlsjMessage()) {
					resultsDO.setShlsjMessage(fDto.getShlsjMessage());
				}if( null!=fDto.getShlsjState()) {
					resultsDO.setShlsjState(fDto.getShlsjState());
				}if( null!=fDto.getShzjzxMessage()) {
					resultsDO.setShzjzxMessage(fDto.getShzjzxMessage());
				}if( null!=fDto.getShzjzxState()) {
					resultsDO.setShzjzxState(fDto.getShzjzxState());
				}
				
				if( null!=fDto.getXlsjState()) {
					resultsDO.setXlsjState(fDto.getXlsjState());
				}if(null!=fDto.getXlsjMessage()) {
					resultsDO.setXlsjMessage(fDto.getXlsjMessage());
				}
				resultsDO.setBatch(aduitData.get("batch")+"");
				resultsDO.setAreaCode(areaCode);
				resultsDO.setDeptId(fDto.getDeptName());
				bool =service.updateSummaryResults(aduitData,resultsDO);
				if(bool==true) {
					bool =service.updateSummaryResultsItems(itemsData,aduitData.get("id")+"",areaCode,aduitData.get("batch")+"");
				}
			}
		}
		if("4".equals(type)) {//4、质量不达标样品汇总表
			if(aduitData.size()>0) {
				bool =service.updateSummarySubstandardSample(aduitData,itemsData,areaCode);
			}
		}
		if("5".equals(type)) {//5、粮食储存品质检验结果汇总表
			if(aduitData.size()>0) {
				bool =service.updateSummaryInspectionResult(aduitData,itemsData,areaCode);
			}
		}
		if("6".equals(type)) {//6、储存品质不宜存样品汇总表
			if(aduitData.size()>0) {
				bool =service.updateSummaryNotSuitable(aduitData,itemsData,areaCode);
			}
		}
		return bool;
	}
    
    
	
	
	/**
	 * @Description 品质测报-结果上报
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月19日15:12:44
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateState(FoodStockDTO fDto) throws Exception{
		return domain.updateState(fDto);
	}
	
	
	/**
	 * @Description 样品信息同步
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> getSampleInformation(FoodStockDTO fDto) throws Exception{
		return domain.getSampleInformation(fDto);
	}
	
	
	/**
	 * @Description 盟市、旗县、自治区质检档案
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public Map<String,Object> allInformation(FoodStockDTO fDto) throws Exception{
		return domain.AllInformation(fDto);
	}
	

	/**
	 * @Description 盟市、旗县、自治区汇总
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public Map<String,Object> getAll(String type,String areaCode) throws Exception{
		return domain.getAll(type, areaCode);
	}
	

	/**
	 * @Description 查询数据库中最大batch
	 * @version v1.0
	 * @author lfx
	 * @date 2019年8月16日11:28:06
	 * @param codedate
	 * @return String
	 * @throws Exception
	 */
	public  String queryMaxBatch(FoodStockDTO fDto) throws Exception{
		String batch = domain.queryMaxBatch(fDto);
		return batch;
	}
	
	/**
	 * @Description 检测业务查询统计     饼图-样品份数
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> sampleNumber(String years) throws Exception{
		return  service.sampleNumber(years);
	}
	
	/**
	 * @Description 检测业务查询统计     柱状图-储存品质总代表数量
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> natureNumber(String years) throws Exception{
		List<Map> list=domain.natureNumber(years);
		return list;
	}
	
	/**
	 * @Description 检测业务查询统计     柱状图-宜存率 
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月27日15:29:45
	 * @return boolean
	 * @throws Exception
	 */
	public List<Map> suitableDeposit(String years) throws Exception{
		List<Map> list=domain.suitableDeposit(years);
		return list;
	}
}
