package com.unis.quality.server.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.base.PageResult;
import com.unis.quality.common.dto.QualityOpinionOutDetailDTO;
import com.unis.quality.common.flow_node.QualityOpinionNodeAbs;
import com.unis.quality.common.vo.QualityInspectionDetailVO;
import com.unis.quality.common.vo.QualityOpinionInVO;
import com.unis.cbl.client.FinancialSettlementClient;
import com.unis.quality.common.vo.QualityOpinionOutDetailVO;
import com.unis.quality.common.vo.QualityOpinionOutVO;
import com.unis.quality.server.dao.*;
import com.unis.quality.server.entity.quality.QualityOpinionInDO;
import com.unis.quality.server.entity.quality.QualityOpinionOutDO;
import com.unis.quality.server.service.QualityOpinionService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import tk.mybatis.mapper.entity.Example;

import javax.transaction.Transactional;
import java.math.BigDecimal;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author by PIG
 * 2023/10/30 09
 */
@Service
@Log4j2
public class QualityOpinionServiceImpl extends QualityOpinionNodeAbs implements QualityOpinionService {

    @Autowired
    private QualityOpinionInDao qualityOpinionInDao;
    @Autowired
    private QualityOpinionOutDao qualityOpinionOutDao;
    @Autowired
    private QualityOpinionOutDetailDao qualityOpinionOutDetailDao;

    @Autowired
    private QualityInspectionDetailDao qualityInspectionDetailDao;

    @Autowired
    private EntrustInspectApplyDao entrustInspectApplyDao;

    @Autowired
    private FinancialSettlementClient financialSettlementClient;

    private void doneOperation(QualityOpinionInVO entity){
        Optional.ofNullable(opinionOperationMap.get(entity.getNodeId())).ifPresent(i -> {
            i.apply(entity);
        });
    }
    private void doneOperation(QualityOpinionOutVO entity){
        Optional.ofNullable(opinionOutOperationMap.get(entity.getNodeId())).ifPresent(i -> {
            i.apply(entity);
        });
    }


    @Override
    public Map<String, Object> createQualityOpinion(QualityOpinionInVO entity) {
        String ysbgbh = entity.getYsbgbh();
        int updateRows = qualityOpinionInDao.removeOldData(ysbgbh);
        log.info("更新旧数据为删除状态 {}", updateRows);
        QualityOpinionInDO inQualityOpinionEntity = new QualityOpinionInDO();
        BeanUtils.copyProperties(entity, inQualityOpinionEntity);
//        inQualityOpinionEntity.setBasicNum(BigDecimal.ZERO);
        inQualityOpinionEntity.buildInsertData(1);
        int insertRows = qualityOpinionInDao.insertSelective(inQualityOpinionEntity);
        Map<String, Object> map = new HashMap<>();
        map.put("res", insertRows);
        return map;
    }

    @Override
    public PageResult<QualityOpinionInVO> selectInOpinionPageByEntity(int pageNum, int pageSize, int pageType, JSONObject queryParams) {
        queryParams.put("pageType", pageType);
        String orgId = CurrentUtil.getOrgId();

        if (pageNum == -1) {
            Page<QualityOpinionInVO> pageData = qualityOpinionInDao.listDataByParams(queryParams);
            PageResult<QualityOpinionInVO> pageResult = new PageResult<>(pageData);
            return pageResult;

        }else {
            PageHelper.startPage(pageNum, pageSize);
            if (1 == pageType) {
                queryParams.put("applyOrg", orgId);
            } else {

            }
            Page<QualityOpinionInVO> pageData = qualityOpinionInDao.listDataByParams(queryParams);
            PageResult<QualityOpinionInVO> pageResult = new PageResult<>(pageData);
            return pageResult;
        }
    }

    @Override
    public QualityOpinionInVO selectInOpinionById(Long fid) {
        QualityOpinionInDO queryDO = new QualityOpinionInDO();
        queryDO.setFid(fid);
        queryDO.setStatus(1);
        QualityOpinionInDO opinionDO = qualityOpinionInDao.selectOne(queryDO);
        QualityOpinionInVO opinionVO = new QualityOpinionInVO();
        BeanUtils.copyProperties(opinionDO, opinionVO);
        return opinionVO;
    }

    @Override
    @Transactional
    public int updateInOpinion(QualityOpinionInVO entity) {
        QualityOpinionInDO opinionDO = new QualityOpinionInDO();
        BeanUtils.copyProperties(entity, opinionDO);
        int updateRows = qualityOpinionInDao.updateByPrimaryKeySelective(opinionDO);
        doneOperation(entity);
        return updateRows;
    }

    @Override
    public ResponseWrapper changeQualityOpinionNode(String ysbgbh) {
        QualityOpinionInDO queryDO = new QualityOpinionInDO();
        queryDO.setStatus(1);
        queryDO.setYsbgbh(ysbgbh);
        QualityOpinionInDO entity = qualityOpinionInDao.selectOne(queryDO);
        boolean isComplete = QualityOpinionInVO.NODE_INFO.COMPLETE.equalVal(entity.getNodeId());

        Map<String, Object> res = new HashMap<>();
        res.put("isComplete", isComplete);
        return ResponseWrapper.success(res);
    }

    @Override
    public QualityOpinionInVO selectInOpinionByYsbgbh(String ysbgbh) {
        return qualityOpinionInDao.selectInOpinionByYsbgbh(ysbgbh);
    }

    @Override
    @Transactional
    public int updateOutOpinion(QualityOpinionOutVO entity) {
        QualityOpinionOutDO opinionOutDO = new QualityOpinionOutDO();
        BeanUtils.copyProperties(entity, opinionOutDO);
        int i = qualityOpinionOutDao.updateByPrimaryKeySelective(opinionOutDO);
        doneOperation(entity);
        return i;
    }

    @Override
    public PageResult<QualityOpinionOutVO> selectOutOpinionPageByEntity(int pageNum, int pageSize, int pageType, JSONObject queryParams) {
        queryParams.put("pageType", pageType);
        String orgId = CurrentUtil.getOrgId();
        if (pageNum == -1) {
            Page<QualityOpinionOutVO> pageData = qualityOpinionOutDao.listDataByParams(queryParams);
            PageResult<QualityOpinionOutVO> pageResult = new PageResult<>(pageData);
            return pageResult;
        }else {
            PageHelper.startPage(pageNum, pageSize);
            if (1 == pageType) {
                queryParams.put("applyOrg", orgId);
            } else {

            }
            Page<QualityOpinionOutVO> pageData = qualityOpinionOutDao.listDataByParams(queryParams);
            PageResult<QualityOpinionOutVO> pageResult = new PageResult<>(pageData);
            return pageResult;
        }
    }

    @Override
    public QualityOpinionOutVO selectOutOpinionById(Long fid) {
        QualityOpinionOutDO queryDO = new QualityOpinionOutDO();
        queryDO.setFid(fid);
        queryDO.setStatus(1);
        QualityOpinionOutDO opinionDO = qualityOpinionOutDao.selectOne(queryDO);
        QualityOpinionOutVO opinionVO = new QualityOpinionOutVO();
        BeanUtils.copyProperties(opinionDO, opinionVO);
        String applyNumber = opinionDO.getApplyNumber();
        String subType = entrustInspectApplyDao.getSubTypeByAppluNumber(applyNumber);
        opinionVO.setApplySubType(subType);
        QualityOpinionOutDetailVO detailQuery = new QualityOpinionOutDetailVO();
        detailQuery.setQualityOpinionOutFid(fid);
        List<QualityOpinionOutDetailVO> detailList = qualityOpinionOutDetailDao.select(detailQuery);
        List<Long> qualityInspectionDetailFidList = detailList.stream().map(QualityOpinionOutDetailVO::getQualityInspectionDetailFid)
                .collect(Collectors.toList());
        Example inspectionDetailExample = new Example(QualityInspectionDetailVO.class);
        inspectionDetailExample.createCriteria().andIn("fid", qualityInspectionDetailFidList);
        List<QualityInspectionDetailVO> inspectionDetailList = qualityInspectionDetailDao.selectByExample(inspectionDetailExample);

        LinkedHashMap<Long, QualityInspectionDetailVO> fidMap = inspectionDetailList.stream()
                .collect(Collectors.toMap(QualityInspectionDetailVO::getFid, Function.identity(), (key1, key2) -> key2, LinkedHashMap::new));

        List<JSONObject> objectList = detailList.stream().map(i -> {
            JSONObject object = JSONObject.parseObject(JSONObject.toJSONString(i));
            Long qualityInspectionDetailFid = i.getQualityInspectionDetailFid();
            QualityInspectionDetailVO qualityInspectionDetailVO = fidMap.get(qualityInspectionDetailFid);
            JSONObject inspectionDetail = JSONObject.parseObject(JSONObject.toJSONString(qualityInspectionDetailVO));
            return object.fluentPutAll(inspectionDetail).fluentPut("fid", i.getFid());
        }).collect(Collectors.toList());

        opinionVO.setDetailObjectList(objectList);
        return opinionVO;
    }

    //----------------------------------------------------------------------------------
    @Override
    protected Map<String, Object> commitPend(QualityOpinionInVO entity) {
        return null;
    }

    @Override
    protected Map<String, Object> sealPend(QualityOpinionInVO entity) {
        return null;
    }

    @Override
    protected Map<String, Object> acceptPend(QualityOpinionInVO entity) {
        return null;
    }

    @Override
    @Transactional
    protected Map<String, Object> complete(QualityOpinionInVO entity) {
        // 入库质检意见
        String ysbgbh = entity.getYsbgbh();
        JSONObject params = new JSONObject();
        params.put("ysbgbh", ysbgbh);
        ResponseWrapper response = financialSettlementClient.completeFinancialSettlement(params);
        log.info("更新结算单结果 -------> \n{}", JSONObject.toJSONString(response));
        if (response.isSuccess()) {
            log.info("更新结算单成功");
        }else {
            log.error("更新结算单失败");
        }
        HashMap<String, Object> resMap = new HashMap<>();
        resMap.put("msg", response.getMsg());
        return resMap;
    }

    @Override
    protected Map<String, Object> commitPend(QualityOpinionOutVO entity) {
        return null;
    }

    @Override
    @Transactional
    protected Map<String, Object> sealPend(QualityOpinionOutVO entity) {
        List<QualityOpinionOutDetailDTO> detailList = entity.getDetailList();
        detailList.forEach(item -> {
            qualityOpinionOutDetailDao.updateByPrimaryKeySelective(item.toVO());
        });
        return null;
    }

    @Override
    protected Map<String, Object> acceptPend(QualityOpinionOutVO entity) {
        return null;
    }

    @Override
    protected Map<String, Object> complete(QualityOpinionOutVO entity) {
        String rotateApplyCode = qualityOpinionOutDao.getRotateApplyCode(entity.getFid());
        JSONObject params = new JSONObject();
        params.put("pfzt", QualityOpinionNodeAbs.TO_BE_SEALED);
        params.put("lhzxsqbm", rotateApplyCode);
        Integer updateRows = qualityOpinionOutDao.updateRotateApply(params);
        return null;
    }

    private void outQualityOpinion(){

    }

    private void inQualityOpinion(){

    }

}
