/*
 * RainServiceImpl.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-11 17:08:12 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.quality.server.service.impl;

import com.github.pagehelper.Page;
import com.unis.base.common.vo.CompanyVO;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.base.PageResult;
import com.unis.quality.common.vo.weather.RainVO;
import com.unis.quality.common.vo.weather.TianQiDetail;
import com.unis.quality.common.vo.weather.TianQiResult;
import com.unis.quality.server.domain.weather.RainDomain;
import com.unis.quality.server.entity.quality.weather.RainDO;
import com.unis.quality.server.service.RainService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * PLUG_WEATHER_RAIN-降雨量表
 * @author lipenghe at 2020-08-11 17:08:12
 */
@Component
@Transactional
public class RainServiceImpl implements RainService {

    @Autowired
    RainDomain rainDomain;

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 插入全部字段
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntityResult(RainVO rainVO) {
        return rainDomain.insertEntity(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 选择性插入字段
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntitySelectiveResult(RainVO rainVO) {
        return rainDomain.insertEntitySelective(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 选择性插入字段
     * @param tianQiResultList    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper saveSelective(List<TianQiResult> tianQiResultList){
        RainVO rainVO=null;
        CompanyVO companyVO=null;
        Date date=new Date();
        SimpleDateFormat sdf=new SimpleDateFormat("yyyy-MM-dd");
        String dateStr=sdf.format(date);
        int success=0;
        for(TianQiResult tianQiResult : tianQiResultList){
            rainVO=new RainVO();
            companyVO=tianQiResult.getCompanyVO();
            rainVO.setParentId(companyVO.getTyshxydm());

            List<TianQiDetail> data = tianQiResult.getData();
            for(TianQiDetail tianQiDetail : data){
                int num = rainDomain.selectExistsByEntity(rainVO);
                rainVO.setCityname(companyVO.getQymc());
                rainVO.setDateStamp(dateStr);
                rainVO.setDateStamp(tianQiDetail.getTime());

                rainVO.setRainMsg(tianQiResult.getMsg());
                rainVO.setTimeStamp(tianQiDetail.getTime());
                rainVO.setRainLevel(tianQiDetail.getLevel());
                rainVO.setRainValue(tianQiDetail.getValue());
                if(num==0){
                    rainDomain.insertEntitySelective(rainVO);
                }else{
                    rainDomain.updateByEntitySelective(rainVO);
                }
            }
            success++;
        }
        return ResponseWrapper.choose(success);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 更改状态
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateStatusByEntityResult(RainVO rainVO, String limit) {
        return rainDomain.updateStatusByEntity(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 根据实体某些属性更新全部字段
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntityResult(RainVO rainVO, String limit) {
        return rainDomain.updateByEntity(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 根据实体不为空的属性,选择性更新字段
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(RainVO rainVO, String limit) {
        return rainDomain.updateByEntitySelective(rainVO);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 根据实体不为空的属性,选择性更新字段
     * @param entity    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(RainDO entity, String limit) {
        int num= rainDomain.updateByEntitySelective(entity);
        return ResponseWrapper.choose(num);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * [真删除]根据实体的某些属性进行单条或者批量删除
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper deleteByEntityResult(RainVO rainVO, String limit) {
        return rainDomain.deleteShamByEntity(rainVO);
    }

    /**
    * <PLUG_WEATHER_RAIN-降雨量表>
    * 根据实体(唯一标示)查询一条数据
    * @param rainVO    <降雨量表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByIdResult(RainVO rainVO) {
        RainVO rainVODb=rainDomain.selectById(rainVO);
        if(rainVODb!=null){
            return ResponseWrapper.success(rainVODb);
        }
        return ResponseWrapper.notFound();
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 根据实体(唯一标示)查询一条数据
     * @param entity    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(RainDO entity) {
        RainVO rainVO=rainDomain.selectById(entity);
        if(rainVO!=null){
            return ResponseWrapper.success(rainVO);
        }
        return ResponseWrapper.notFound();
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 根据实体的某些属性查询分页数据
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectPageByEntityResult(int pageNo, int pageSize
        , RainVO rainVO, String order) {
        Page rainVOPage=rainDomain.selectPageByEntity(pageNo,pageSize,rainVO,order);
        PageResult rainVOPageResult=new PageResult<>(rainVOPage);
        return ResponseWrapper.success(rainVOPageResult);
    }

    /**
    * <PLUG_WEATHER_RAIN-降雨量表>
    * 根据实体的某些属性查询列表
    * @param rainVO    <降雨量表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByEntityResult(RainVO rainVO) {
        List rainVOList=rainDomain.selectByEntity(rainVO);
        return ResponseWrapper.success(rainVOList);
    }

    /**
    * <PLUG_WEATHER_RAIN-降雨量表>
    * 根据实体的某些属性查询列表
    * @param entity    <降雨量表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByEntityResult(RainDO entity) {
        List rainVOList=rainDomain.selectByEntity(entity);
        return ResponseWrapper.success(rainVOList);
    }

    /**
     * <PLUG_WEATHER_RAIN-降雨量表>
     * 根据实体查询初始化数据
     * @param rainVO    <降雨量表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectInitDataResult(RainVO rainVO) {
        return ResponseWrapper.success(rainVO);
    }

}
