package com.unis.quality.server.service.impl.mq;

import com.alibaba.fastjson.JSON;
import com.unis.common.utils.JsonUtils;
import com.unis.quality.common.constant.BacklogConstant;
import com.unis.quality.common.vo.backlog.BacklogAddVO;
import com.unis.quality.common.vo.backlog.BacklogUpdateVO;
import com.unis.quality.common.vo.backlog.ReceiverCollectionVO;
import com.unis.quality.server.service.BacklogMQService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 
 * @Description：待办服务实现
 * @author：王帅
 * @date: 2020年2月27日
 */
@Service
@Slf4j
public class BacklogMQServiceImpl implements BacklogMQService {

	@Autowired
	private RabbitTemplate amqpTemplate;

	@Override
	public void sendMsg(Object obj, String type) {
		try {
			this.amqpTemplate.convertAndSend(BacklogConstant.BACKLOG_EXCHANGE, "backlog." + type, obj);
		} catch (Exception e) {
			log.error("{}待办消息发送异常,待办实体{}", type, obj, e);
		}
	}

	@Override
	public void addNeedToDeals(String id, String title, String status, String statusName, String itemUrl, String itemQuery,
			String itemQueryHaveDone, String itemUrlHaveDone, List<ReceiverCollectionVO> userList) {
		System.out.println("*************进入创建待办************");
		BacklogAddVO record = new BacklogAddVO();
		record.buildAddVO(record);
		record.setItemId(id);
		record.setItemName(title);
		record.setItemStatus(Integer.valueOf(status));
		record.setItemStatusName(statusName);
		record.setItemUrl(itemUrl);
		record.setItemQuery(itemQuery);
		record.setItemQueryHaveDone(itemQueryHaveDone);
		record.setItemUrlHaveDone(itemUrlHaveDone);
		// 另起线程执行待办
		try {
			new Thread(new Runnable() {
				@Override
				public void run() {
					for (ReceiverCollectionVO userVO : userList) {
						System.out.println("********************接收人*******************");
						System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
						System.out.println("********************************************");
						record.setReceiver(userVO.getUserName());
						record.setReceiverId(userVO.getUserId());
						// 需要将对象序列化成JSONObject
						sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
					}
				}
			}).start();
		} catch (Exception e) {
			System.out.println("待办添加异常"+e.getMessage());
		}
	}
	
	@Override
	public void addDeals(String itemId, String itemName, String status, String statusName) {
		System.out.println("*************进入创建已办************");
		BacklogUpdateVO updateVO = new BacklogUpdateVO();
		updateVO.buildUpdateVO(updateVO);
		updateVO.setItemId(itemId);
		updateVO.setItemName(itemName);
		updateVO.setItemStatus(Integer.valueOf(status));
		updateVO.setItemStatusName(statusName);
		sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");
	}
	
	@Override
	public void addInfoCheckDeals(String itemId, String itemName, String status, String statusName) {
		System.out.println("*************进入创建已办************");
		BacklogUpdateVO updateVO = new BacklogUpdateVO();
		updateVO.buildInfoCheckUpdateVO(updateVO);
		updateVO.setItemId(itemId);
		updateVO.setItemName(itemName);
		updateVO.setItemStatus(Integer.valueOf(status));
		updateVO.setItemStatusName(statusName);
		sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");
	}

	@Override
	public void addInfoCheckNeedToDeals(String id, String title, String status, String statusName, String itemUrl,String itemQuery,
			String itemQueryHaveDone, 
			String itemUrlHaveDone, 
			List<ReceiverCollectionVO> userList) {
		System.out.println("*************进入创建待办************");
		BacklogAddVO record = new BacklogAddVO();
		record.buildInfoCheckAddVO(record);
		record.setItemId(id);
		record.setItemName(title);
		record.setItemStatus(Integer.valueOf(status));
		record.setItemStatusName(statusName);
		record.setItemUrl(itemUrl);
		record.setItemQuery(itemQuery);
		record.setItemQueryHaveDone(itemQueryHaveDone);
		record.setItemUrlHaveDone(itemUrlHaveDone);
		// 另起线程执行待办
		try {
			new Thread(new Runnable() {
				@Override
				public void run() {
					for (ReceiverCollectionVO userVO : userList) {
						System.out.println("********************接收人*******************");
						System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
						System.out.println("********************************************");
						record.setReceiver(userVO.getUserName());
						record.setReceiverId(userVO.getUserId());
						// 需要将对象序列化成JSONObject
						sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
					}
				}
			}).start();
		} catch (Exception e) {
			System.out.println("待办添加异常"+e.getMessage());
		}
	}
	

}
