package com.unis.quality.server.service.impl.tianjin;

import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.unis.quality.common.vo.backlog.ReceiverCollectionVO;
import com.unis.quality.server.service.BacklogMQService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.quality.common.dto.CheckSchemeDTO;
import com.unis.quality.common.dto.ViewSituationDTO;
import com.unis.quality.common.vo.tianjin.QualityHarvestCornVO;
import com.unis.quality.server.domain.tianjin.QualityHarvestCornDomain;
import com.unis.quality.server.domain.tianjin.StockDomain;
import com.unis.quality.server.entity.quality.tianjin.QualityHarvestCornDO;
import com.unis.quality.server.entity.quality.tianjin.ViewSituationDO;
import com.unis.quality.server.service.tianjin.QualityHarvestCornService;

/**
 * 
 * @ClassName: QualityHarvestCornService
 * @Description: 品质测报-抽样方案
 * @author lfx
 * @date 2019年7月10日15:01:34
 * 
 * @version v1.0
 */
@Service
public class QualityHarvestCornServiceImpl implements QualityHarvestCornService{
	@Autowired
	private QualityHarvestCornDomain domain;
	
	@Autowired
	private StockDomain stockDomain;

	@Autowired
	private BacklogMQService mqService;

    /**
	 * @Description 根据id查询详情
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/24
	 * @param dto
	 * @return
	 * @throws Exception
	 */
	public Map<String, Object>  findById(CheckSchemeDTO dto) throws Exception{
		return domain.findById(dto);
	}

	/**
	 * @Description 查询
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return java.util.List
	 * @throws Exception
	 */
	public Map<String, Object> findByPage(CheckSchemeDTO qualityVO, Integer page, Integer size) throws Exception{
		return domain.findByPage(qualityVO, page, size);
	}
	
	/**
	 * @Description 多选删除
	 * @version v1.0
	 * @author lfx
	 * @param ids
	 * @date 2018/10/24
	 * @return boolean
	 * @throws Exception
	 */
	
	public boolean deletes(String[] ids) throws Exception{
		boolean bool=false;
		bool=domain.deletesSites(ids);
		if(bool==true) {
			bool=domain.deletesVarieties(ids);
			if(bool==true) {
				bool=domain.deletesPlan(ids);
				if(bool==true) {
					bool=domain.deletesHarvest(ids);
				}
			}
		}
		return bool;
	}
	 
	/**
	 * @Description 保存品质测报抽查方案
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/20
	 * @param QualityHarvestCornVO
	 * @return boolean
	 * @throws Exception
	 */
	@SuppressWarnings("all")
	public boolean save(Map<String, Object> aduitList,CheckSchemeDTO vo) throws Exception {
		boolean bool = false; 
		Map<String,Object> aduitData=(Map<String,Object>)aduitList.get("aduitData");
		List<Map> itemsData=(List<Map>) aduitList.get("itemsData");
	
    	if(aduitData.size()>0) {
    		QualityHarvestCornDO qdo=new QualityHarvestCornDO();
    		qdo.setAreaCode(vo.getAreaCode());
			 bool=domain.saveAduit(aduitData,qdo,vo.getOrgList());
			 if(bool==true) {
				 if(itemsData.size() > 0 && itemsData != null) {
					 qdo.setFabt(aduitData.get("fabt")+"");
					 qdo.setCreateBy(vo.getCreateBy());
					 qdo.setFaxq(aduitData.get("faxq")+"");
					 qdo.setNd(aduitData.get("nd")+"");
					 qdo.setWtlx(aduitData.get("wtlx")+"");
					 SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
					 String fqsj=aduitData.get("fqsj")+"";
				     String jssj=aduitData.get("jssj")+"";
				     if(!"".equals(fqsj) ) {
				    	qdo.setFqsj(sdf.parse(fqsj));
				     }
				     if(!"".equals(jssj)) {
				    	qdo.setJssj(sdf.parse(jssj));
				     }
					 if("库存检查".equals(aduitData.get("wtlx"))) {
						 bool=stockDomain.savePlan(itemsData, qdo);
					 }else {
						 bool=domain.savePlan(itemsData,qdo);
					 }
				 }
				 
			 }
			if(StringUtils.isNotEmpty(vo.getLcId()) && "已委托".equals(vo.getLcId())){
				String title =  qdo.getId() + "抽样方案"+vo.getLcId();
				String itemUrl = vo.getItemUrl();
				String itemQuery = vo.getItemQuery();
				List<ReceiverCollectionVO> userList = vo.getUserList();
				String itemQueryHaveDone = vo.getItemQueryHaveDone();
				String itemUrlHaveDone = vo.getItemUrlHaveDone();
				mqService.addNeedToDeals(qdo.getId(), title, "10", vo.getLcId(), itemUrl, itemQuery, itemQueryHaveDone, itemUrlHaveDone, userList);
			}
		}
		return bool;
	}
	/**
	 * @Description 更新品质测报
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:03:46
	 * @param aduitList
	 * @return boolean
	 * @throws Exception
	 */
	public boolean update(Map<String, Object> aduitList,QualityHarvestCornVO vo) throws Exception {
		boolean bool = false; 
    	Map<String,Object> aduitData=(Map<String,Object>)aduitList.get("aduitData");
		List<Map> itemsData=(List<Map>) aduitList.get("itemsData");
    	if(aduitData.size()>0) {
    		QualityHarvestCornDO qdo=new QualityHarvestCornDO();
    		qdo.setAreaCode(vo.getAreaCode());
			 bool=domain.updateAduit(aduitData, qdo);
			 if(bool==true) {
				 if(itemsData.size() > 0 && itemsData != null) {
					 CheckSchemeDTO dto=new CheckSchemeDTO();
					 dto.setAreaCode(vo.getAreaCode());
					 dto.setNd( aduitData.get("nd")+"");
					 dto.setId( aduitData.get("id")+"");
					 dto.setWtlx(aduitData.get("wtlx")+"");
					 
					 dto.setFabt(aduitData.get("fabt")+"");
					 dto.setUpdateBy(vo.getUpdateBy());
					 dto.setFabt(aduitData.get("fabt")+"");
					 dto.setFjid(aduitData.get("fjid")+"");
					 if(StringUtils.isEmpty(String.valueOf(aduitData.get("lcId"))) || "null".equals(aduitData.get("lcId")+"")) {
						 dto.setLcId("待委托");
						 dto.setZt(0);
					 }else if("已委托".equals(aduitData.get("lcId")+"")  || "1".equals(aduitData.get("lcId")) ) {
						 dto.setLcId("已委托");
						 dto.setZt(1);
					 }
					SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
					String fqsj=aduitData.get("fqsj")+"";
				    String jssj=aduitData.get("jssj")+"";
				    if(!"".equals(fqsj) || null!=fqsj) {
				    	dto.setFqsj(sdf.parse(fqsj));
				    }
				    if(!"".equals(jssj) || null!=jssj) {
				    	dto.setJssj(sdf.parse(jssj));
				    }if("库存检查".equals(aduitData.get("wtlx"))) {
				    	bool=stockDomain.updateItemsStockPlan(itemsData, dto);
				    } else if("放心粮油".equals(aduitData.get("wtlx"))) {
					    bool=domain.updateItemsPlan(itemsData,dto);
					 }else {
						 bool=domain.updateItems(itemsData,dto);
					 }
				 }
			 }
			 String  status=(String)aduitData.get("lcId");
			if(StringUtils.isNotEmpty(status) && "已委托".equals(status)){
				String title =  qdo.getId() + "抽样方案"+status;
				String itemUrl = vo.getItemUrl();
				String itemQuery = vo.getItemQuery();
				List<ReceiverCollectionVO> userList = vo.getUserList();
				String itemQueryHaveDone = vo.getItemQueryHaveDone();
				String itemUrlHaveDone = vo.getItemUrlHaveDone();
				mqService.addNeedToDeals(qdo.getId(), title, "10", status, itemUrl, itemQuery, itemQueryHaveDone, itemUrlHaveDone, userList);
			}
		}
		return bool;
	}
    
    
	 /**
	 * @Description 品质测报-发布
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月19日15:12:44
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateState(String id) throws Exception{
		return domain.updateState(id);
    }
	
	/**
	 * @Description 查询抽查方案标题
	 * @version v1.0
	 * @author lfx
	 * @date 2019年7月10日15:02:41
	 * @return boolean
	 * @throws Exception
	 */
	public List<QualityHarvestCornDO> getFlieName() throws Exception{
		return domain.getFlieName();
	}
	

	/**
	 * @Description 根据名称查询id
	 * @version v1.0
	 * @author lfx
	 * @date 2018/10/29
	 * @param fabt
	 * @return
	 * @throws Exception
	 */
	public String queryFabt(String fabt,String wtlx) throws Exception{
		return domain.queryFabt(fabt,wtlx);
	}

	/**
	 * 抽样方案接收
	 * @throws Exception 
	 */
//	@Override
//	public boolean updateViewSituation(ViewSituationDTO vo) throws Exception {
//		return domain.saveViewSituation(null, null, 2,vo);
//	}
}
